#
# spec file for package kernel-syms
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define variant %{nil}

%include %_sourcedir/kernel-spec-macros

Name:           kernel-syms
Summary:        Kernel Symbol Versions (modversions)
License:        GPL-2.0
Group:          Development/Sources
Version:        5.3.18
%if %using_buildservice
%if 0%{?is_kotd}
Release:        lp152.69.1.gd532e33
%else
Release:        lp152.69.1
%endif
%else
%define kernel_source_release %(LC_ALL=C rpm -q kernel-devel%variant-%version --qf "%{RELEASE}" | grep -v 'not installed' || echo 0)
Release:        lp152.69.1
%endif
Url:            http://www.kernel.org/
AutoReqProv:    off
BuildRequires:  coreutils
%ifarch aarch64 armv7hl ppc64le s390x x86_64
Requires:       kernel-default-devel = %version-%source_rel
%endif
%ifarch armv7hl
Requires:       kernel-lpae-devel = %version-%source_rel
%endif
%ifarch aarch64 x86_64
Requires:       kernel-preempt-devel = %version-%source_rel
%endif
Requires:       pesign-obs-integration
Provides:       %name = %version-%source_rel
Provides:       %name-srchash-d532e33ad3cd1ccdbcd723b24a15207c12525a9b
Provides:       multiversion(kernel)
Source:         README.KSYMS
Requires:       kernel-devel%variant = %version-%source_rel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  aarch64 armv7hl ppc64le s390x x86_64
Prefix:         /usr/src

# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356 boo#1175882)
%define _binary_payload w9.bzdio

%description
Kernel symbols, such as functions and variables, have version
information attached to them. This package contains the symbol versions
for the standard kernels.

This package is needed for compiling kernel module packages with proper
package dependencies.


%source_timestamp
%prep

%install
install -m 644 -D %{SOURCE0} %buildroot/%_docdir/%name/README.SUSE

%files
%defattr(-, root, root)
%dir %_docdir/%name
%_docdir/%name/README.SUSE

%changelog
* Tue Apr  6 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/completion-Drop-init_completion-define.patch
- commit 33fba8d
* Tue Apr  6 2021 glin@suse.com
- libbpf: Fix BTF dump of pointer-to-array-of-struct
  (bsc#1155518).
- libbpf: Use SOCK_CLOEXEC when opening the netlink socket
  (bsc#1155518).
- selftests/bpf: Set gopt opt_class to 0 if get tunnel opt failed
  (bsc#1155518).
- libbpf: Clear map_info before each bpf_obj_get_info_by_fd
  (bsc#1155518).
- samples, bpf: Add missing munmap in xdpsock (bsc#1155518).
- selftests/bpf: Mask bpf_csum_diff() return value to 16 bits
  in test_verifier (bsc#1155518).
- selftests/bpf: No need to drop the packet when there is no
  geneve opt (bsc#1155518).
- commit 8d0ef1a
* Tue Apr  6 2021 ohering@suse.de
- video: hyperv_fb: Fix a double free in hvfb_probe (git-fixes).
- commit c457d1d
* Mon Apr  5 2021 dbueso@suse.de
- selinux: fix inode_doinit_with_dentry() LABEL_INVALID error
  handling (git-fixes).
- commit fa2b85d
* Mon Apr  5 2021 dbueso@suse.de
- include/linux/sched/mm.h: use rcu_dereference in in_vfork()
  (git-fixes).
- stop_machine: mark helpers __always_inline (git-fixes).
- selinux: fix error initialization in inode_doinit_with_dentry()
  (git-fixes).
- completion: Drop init_completion define (git-fixes).
- lib/syscall: fix syscall registers retrieval on 32-bit platforms
  (git-fixes).
- selinux: Fix error return code in sel_ib_pkey_sid_slow()
  (git-fixes).
- commit 3909dc1
* Mon Apr  5 2021 tiwai@suse.de
- extcon: Fix error handling in extcon_dev_register (git-fixes).
- extcon: Add stubs for extcon_register_notifier_all() functions
  (git-fixes).
- staging: rtl8192e: Change state information from u16 to u8
  (git-fixes).
- staging: rtl8192e: Fix incorrect source in memcpy() (git-fixes).
- usb: dwc2: Prevent core suspend when port connection flag is 0
  (git-fixes).
- usb: dwc2: Fix HPRT0.PrtSusp bit setting for HiKey 960 board
  (git-fixes).
- usb: musb: Fix suspend with devices connected for a64
  (git-fixes).
- usb: xhci-mtk: fix broken streams issue on 0.96 xHCI
  (git-fixes).
- USB: cdc-acm: fix use-after-free after probe failure
  (git-fixes).
- USB: cdc-acm: fix double free on probe failure (git-fixes).
- cdc-acm: fix BREAK rx code path adding necessary calls
  (git-fixes).
- usb: gadget: udc: amd5536udc_pci fix null-ptr-dereference
  (git-fixes).
- commit 7e1215f
* Sun Apr  4 2021 msuchanek@suse.de
- powerpc/pseries/mobility: handle premature return from H_JOIN
  (bsc#1181674 ltc#189159 git-fixes bsc#1183662 ltc#191922).
- powerpc/pseries/mobility: use struct for shared state
  (bsc#1181674 ltc#189159 git-fixes bsc#1183662 ltc#191922).
- commit e22e432
* Sat Apr  3 2021 jlee@suse.com
- ACPICA: Enable sleep button on ACPI legacy wake (bsc#1181383).
- commit 0d9d4e6
* Sat Apr  3 2021 tiwai@suse.de
- PM: runtime: Fix race getting/putting suppliers at probe
  (git-fixes).
- drm/tegra: sor: Grab runtime PM reference across reset
  (git-fixes).
- commit 064f8f4
* Sat Apr  3 2021 tiwai@suse.de
- ALSA: usb-audio: Apply sample rate quirk to Logitech Connect
  (git-fixes).
- ALSA: hda/realtek: call alc_update_headset_mode() in
  hp_automute_hook (git-fixes).
- ALSA: hda/realtek: fix a determine_headset_type issue for a
  Dell AIO (git-fixes).
- commit e6c8166
* Thu Apr  1 2021 fdmanana@suse.com
- Update
  patches.suse/btrfs-fix-race-when-cloning-extent-buffer-during-rew.patch
  (bsc#1184193 CVE-2021-28964).
- commit 2c0102a
* Thu Apr  1 2021 jdelvare@suse.de
- Update references of patches.suse/edac-amd64-set-grain-per-dimm.patch
- commit 881829d
* Thu Apr  1 2021 glin@suse.com
- bpf: Don't do bpf_cgroup_storage_set() for kuprobe/tp programs
  (bsc#1155518).
- commit 5d2df4e
* Thu Apr  1 2021 tiwai@suse.de
- pinctrl: rockchip: fix restore error in resume (git-fixes).
- commit 55f3605
* Thu Apr  1 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/mm-numa-fix-bad-pmd-by-atomically-check-for-pmd_trans_huge-when-marking-page-tables-prot_numa.patch
- commit e108d2c
* Thu Apr  1 2021 tonyj@suse.de
- perf/x86/intel: Fix a crash caused by zero PEBS status
  (CVE-2021-28971 bsc#1184196).
- commit fbc79f5
* Wed Mar 31 2021 jgross@suse.com
- xen-blkback: don't leak persistent grants from xen_blkbk_map()
  (bsc#1183646, CVE-2021-28688, XSA-371).
- commit f0c74da
* Wed Mar 31 2021 msuchanek@suse.de
- blacklist.conf: Add qspinlock commit revert.
- commit fbfdb5d
* Wed Mar 31 2021 fdmanana@suse.com
- btrfs: fix exhaustion of the system chunk array due to
  concurrent allocations (bsc#1183386).
- commit 419a4b8
* Wed Mar 31 2021 fdmanana@suse.com
- btrfs: fix subvolume/snapshot deletion not triggered on mount
  (bsc#1184219).
- btrfs: always pin deleted leaves when there are active tree
  mod log users (bsc#1184224).
- btrfs: fix race when cloning extent buffer during rewind of
  an old root (bsc#1184193).
- btrfs: fix stale data exposure after cloning a hole with
  NO_HOLES enabled (bsc#1184220).
- btrfs: fix extent buffer leak on failure to copy root
  (bsc#1184218).
- btrfs: abort the transaction if we fail to inc ref in
  btrfs_copy_root (bsc#1184217).
- commit ed1e8cf
* Wed Mar 31 2021 oneukum@suse.com
- blacklist.conf: breaks kABI
- commit 7450a15
* Wed Mar 31 2021 oneukum@suse.com
- media: vicodec: add missing v4l2_ctrl_request_hdl_put()
  (git-fixes).
- commit 1714c92
* Wed Mar 31 2021 oneukum@suse.com
- blacklist.conf: cosmetic fix
- commit 1478eb5
* Wed Mar 31 2021 oneukum@suse.com
- media: cros-ec-cec: do not bail on device_init_wakeup failure
  (git-fixes).
- commit 5533664
* Wed Mar 31 2021 tiwai@suse.de
- PM: EM: postpone creating the debugfs dir till fs_initcall
  (git-fixes).
- bus: omap_l3_noc: mark l3 irqs as IRQF_NO_THREAD (git-fixes).
- net: cdc-phonet: fix data-interface release on probe failure
  (git-fixes).
- mac80211: fix double free in ibss_leave (git-fixes).
- mac80211: fix rate mask reset (git-fixes).
- platform/x86: intel-vbtn: Stop reporting SW_DOCK events
  (git-fixes).
- drm/radeon: fix AGP dependency (git-fixes).
- gpiolib: acpi: Add missing IRQF_ONESHOT (git-fixes).
- ACPI: scan: Rearrange memory allocation in acpi_device_add()
  (git-fixes).
- gianfar: Account for Tx PTP timestamp in the skb headroom
  (git-fixes).
- gianfar: Replace skb_realloc_headroom with skb_cow_head for PTP
  (git-fixes).
- net: gianfar: Add of_node_put() before goto statement
  (git-fixes).
- gianfar: Fix TX timestamping with a stacked DSA driver
  (git-fixes).
- commit dbf2451
* Wed Mar 31 2021 oneukum@suse.com
- blacklist.conf: the fix is cosmetic
- commit 5c3f4dc
* Wed Mar 31 2021 glin@suse.com
- bpf: Fix truncation handling for mod32 dst reg wrt zero
  (bsc#1184170 CVE-2021-3444).
- bpf: Fix 32 bit src register truncation on div/mod
  (bsc#1184170).
- commit af158b0
* Wed Mar 31 2021 tiwai@suse.de
- Update patch reference for a usbip fix (CVE-2021-29265 bsc#1184167)
- commit 6988aeb
* Wed Mar 31 2021 tiwai@suse.de
- gianfar: fix jumbo packets+napi+rx overrun crash (CVE-2021-29264
  bsc#1184168).
- commit 9ae0342
* Wed Mar 31 2021 tiwai@suse.de
- Update patch reference of a PCI fix (CVE-2021-28972 bsc#1184198)
- commit dc7fd0e
* Wed Mar 31 2021 mgorman@suse.de
- mm, numa: fix bad pmd by atomically check for pmd_trans_huge
  when marking page tables prot_numa (bsc#1168777).
- commit c5a52b2
* Wed Mar 31 2021 tiwai@suse.de
- net: qrtr: fix a kernel-infoleak in qrtr_recvmsg()
  (CVE-2021-29647 bsc#1184192).
- commit f71857e
* Wed Mar 31 2021 ddiss@suse.de
- ovl: fix dentry leak in ovl_get_redirect (bsc#1184176).
- ovl: fix unneeded call to ovl_change_flags() (bsc#1184176).
- ovl: fix regression with re-formatted lower squashfs
  (bsc#1184176).
- ovl: relax WARN_ON() when decoding lower directory file handle
  (bsc#1184176).
- ovl: initialize error in ovl_copy_xattr (bsc#1184176).
- ovl: fix out of date comment and unreachable code (bsc#1184176).
- ovl: fix value of i_ino for lower hardlink corner case
  (bsc#1184176).
- commit 6ae489b
* Tue Mar 30 2021 tbogendoerfer@suse.de
- ionic: linearize tso skb with too many frags (bsc#1167773).
- nfp: flower: fix pre_tun mask id allocation (bsc#1154353).
- flow_dissector: fix byteorder of dissected ICMP ID
  (bsc#1154353).
- Revert "net: bonding: fix error return code of
  bond_neigh_init()" (bsc#1154353).
- igc: Fix igc_ptp_rx_pktstamp() (bsc#1160634).
- net/mlx5e: E-switch, Fix rate calculation division
  (jsc#SLE-8464).
- commit dcb0376
* Tue Mar 30 2021 dwagner@suse.de
- Replace ANA log reread patch
  Replace the fix with a simpler version. The upstream community
  has agreed on the simpler version after the ECN has been ratified.
  deleted:    patches.suse/nvme-re-read-ana-log-on-ns-changed-aen.patch
  new file:   patches.suse/nvme-retrigger-ana-log-update-if-group-descriptor-isn-t.patch
- commit 391a31f
* Tue Mar 30 2021 dwagner@suse.de
- nvme-fc: fix racing controller reset and create association
  (bsc#1183048).
- commit 69b4441
* Tue Mar 30 2021 dwagner@suse.de
- Move patches.suse/nvme-fc-avoid-calling-_nvme_fc_abort_outstanding_ios-from-interrupt-context.patch
  Move the patch into the sorted section.
- commit d6d55ac
* Tue Mar 30 2021 dwagner@suse.de
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/scsi-lpfc-Change-wording-of-invalid-pci-reset-log-me.patch
  patches.suse/scsi-lpfc-Correct-function-header-comments-related-t.patch
  patches.suse/scsi-lpfc-Fix-ADISC-handling-that-never-frees-nodes.patch
  patches.suse/scsi-lpfc-Fix-FLOGI-failure-due-to-accessing-a-freed.patch
  patches.suse/scsi-lpfc-Fix-PLOGI-ACC-to-be-transmit-after-REG_LOG.patch
  patches.suse/scsi-lpfc-Fix-crash-caused-by-switch-reboot.patch
  patches.suse/scsi-lpfc-Fix-dropped-FLOGI-during-pt2pt-discovery-r.patch
  patches.suse/scsi-lpfc-Fix-incorrect-dbde-assignment-when-buildin.patch
  patches.suse/scsi-lpfc-Fix-lpfc_els_retry-possible-null-pointer-d.patch
  patches.suse/scsi-lpfc-Fix-nodeinfo-debugfs-output.patch
  patches.suse/scsi-lpfc-Fix-null-pointer-dereference-in-lpfc_prep_.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-connection-does-not-recover-afte.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-state-transition-causing-rmmod-h.patch
  patches.suse/scsi-lpfc-Fix-reftag-generation-sizing-errors.patch
  patches.suse/scsi-lpfc-Fix-stale-node-accesses-on-stale-RRQ-reque.patch
  patches.suse/scsi-lpfc-Fix-status-returned-in-lpfc_els_retry-erro.patch
  patches.suse/scsi-lpfc-Fix-unnecessary-null-check-in-lpfc_release.patch
  patches.suse/scsi-lpfc-Fix-use-after-free-in-lpfc_els_free_iocb.patch
  patches.suse/scsi-lpfc-Fix-vport-indices-in-lpfc_find_vport_by_vp.patch
  patches.suse/scsi-lpfc-Reduce-LOG_TRACE_EVENT-logging-for-vports.patch
  patches.suse/scsi-lpfc-Update-copyrights-for-12.8.0.7-and-12.8.0..patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.8.patch
- commit 9b02aba
* Tue Mar 30 2021 glin@suse.com
- bpf: Add sanity check for upper ptr_limit (bsc#1183686
  bsc#1183775).
- bpf: Simplify alu_limit masking for pointer arithmetic
  (bsc#1183686 bsc#1183775).
- bpf: Fix off-by-one for area size in creating mask to left
  (bsc#1183775 CVE-2020-27171).
- bpf: Prohibit alu ops for pointer types not defining ptr_limit
  (bsc#1183686 CVE-2020-27170).
- commit d95f56b
* Mon Mar 29 2021 martin.wilck@suse.com
- scsi: target: pscsi: Clean up after failure in pscsi_map_sg()
  (bsc#1183843).
- commit 1af614d
* Mon Mar 29 2021 martin.wilck@suse.com
- scsi: target: pscsi: Avoid OOM in pscsi_map_sg() (bsc#1183843).
- commit 036f522
* Mon Mar 29 2021 msuchanek@suse.de
- blacklist.conf: Add 5ae5fbd21079 powerpc/perf: Fix handling of privilege
  level checks in perf interrupt context
- commit a7c4b4d
* Mon Mar 29 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/netsec-restore-phy-power-state-after-controller-rese.patch
- commit a6a1fc0
* Sun Mar 28 2021 tiwai@suse.de
- can: peak_usb: Revert "can: peak_usb: add forgotten supported
  devices" (git-fixes).
- commit ab32250
* Sun Mar 28 2021 tiwai@suse.de
- ACPI: video: Add missing callback back for Sony VPCEH3U1E
  (git-fixes).
- ACPICA: Always create namespace nodes using
  acpi_ns_create_node() (git-fixes).
- drm/msm: fix shutdown hook in case GPU components failed to bind
  (git-fixes).
- can: m_can: m_can_do_rx_poll(): fix extraneous msg loss warning
  (git-fixes).
- can: c_can: move runtime PM enable/disable to c_can_platform
  (git-fixes).
- can: c_can_pci: c_can_pci_remove(): fix use-after-free
  (git-fixes).
- can: flexcan: flexcan_chip_freeze(): fix chip freeze for
  missing bitrate (git-fixes).
- can: peak_usb: add forgotten supported devices (git-fixes).
- commit 54aa0c3
* Wed Mar 24 2021 acho@suse.com
- s390/vtime: fix increased steal time accounting (bsc#1183859).
- commit c966973
* Wed Mar 24 2021 tiwai@suse.de
- usb: typec: tcpm: Invoke power_supply_changed for
  tcpm-source-psy- (git-fixes).
- usb-storage: Add quirk to defeat Kindle's automatic unload
  (git-fixes).
- usb: gadget: configfs: Fix KASAN use-after-free (git-fixes).
- USB: replace hardcode maximum usb string length by definition
  (git-fixes).
- commit fe3af72
* Wed Mar 24 2021 tiwai@suse.de
- Revert "PM: runtime: Update device status before letting
  suppliers suspend" (git-fixes).
- commit cc82105
* Tue Mar 23 2021 denis.kirjanov@suse.com
- net: korina: cast KSEG0 address to pointer in kfree (git-fixes).
- commit cfb1933
* Mon Mar 22 2021 msuchanek@suse.de
- net: core: introduce __netdev_notify_peers (bsc#1183871
  ltc#192139).
- commit 5f42996
* Mon Mar 22 2021 msuchanek@suse.de
- ibmvnic: prefer strscpy over strlcpy (bsc#1183871 ltc#192139).
- ibmvnic: remove unused spinlock_t stats_lock definition
  (bsc#1183871 ltc#192139).
- ibmvnic: add comments for spinlock_t definitions (bsc#1183871
  ltc#192139).
- Refresh patches.suse/ibmvnic-serialize-access-to-work-queue-on-remove.patch
- Refresh patches.suse/net-re-solve-some-conflicts-after-net-net-next-merge.patch
- ibmvnic: fix miscellaneous checks (bsc#1183871 ltc#192139).
- ibmvnic: avoid multiple line dereference (bsc#1183871
  ltc#192139).
- ibmvnic: fix braces (bsc#1183871 ltc#192139).
- ibmvnic: fix block comments (bsc#1183871 ltc#192139).
- Refresh patches.suse/ibmvnic-fix-a-race-between-open-and-reset.patch.
- Refresh patches.suse/ibmvnic-serialize-access-to-work-queue-on-remove.patch.
- Refresh patches.suse/net-re-solve-some-conflicts-after-net-net-next-merge.patch.
- ibmvnic: prefer 'unsigned long' over 'unsigned long int'
  (bsc#1183871 ltc#192139).
- ibmvnic: remove unnecessary rmb() inside ibmvnic_poll
  (bsc#1183871 ltc#192139).
- ibmvnic: rework to ensure SCRQ entry reads are properly ordered
  (bsc#1183871 ltc#192139).
- net: ethernet: ibm: ibmvnic: Fix some kernel-doc misdemeanours
  (bsc#1183871 ltc#192139).
- ibmvnic: merge do_change_param_reset into do_reset (bsc#1183871
  ltc#192139).
- Refresh patches.suse/ibmvnic-fix-a-race-between-open-and-reset.patch
- use __netdev_notify_peers in ibmvnic (bsc#1183871 ltc#192139).
- commit ca7d43b
* Mon Mar 22 2021 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patches out of sorted section
  patches.suse/0001-squashfs-fix-inode-lookup-sanity-checks.patch
  patches.suse/0002-squashfs-fix-xattr-id-and-id-lookup-sanity-checks.patch
- commit 1d6e2f2
* Mon Mar 22 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/PCI-rpadlpar-Fix-potential-drc_name-corruption-in-st.patch
  patches.suse/nvme-allocate-the-keep-alive-request-using-BLK_MQ_RE.patch
  patches.suse/nvme-fabrics-only-reserve-a-single-tag.patch
  patches.suse/nvme-merge-nvme_keep_alive-into-nvme_keep_alive_work.patch
- commit 2e4b640
* Mon Mar 22 2021 tiwai@suse.de
- iio: gyro: mpu3050: Fix error handling in
  mpu3050_trigger_handler (git-fixes).
- iio: hid-sensor-temperature: Fix issues of timestamp channel
  (git-fixes).
- iio: hid-sensor-humidity: Fix alignment issue of timestamp
  channel (git-fixes).
- iio: adis16400: Fix an error code in adis16400_initial_setup()
  (git-fixes).
- iio: adc: ad7949: fix wrong ADC result due to incorrect bit mask
  (git-fixes).
- iio: hid-sensor-prox: Fix scale not correct issue (git-fixes).
- iio:adc:qcom-spmi-vadc: add default scale to LR_MUX2_BAT_ID
  channel (git-fixes).
- usbip: Fix incorrect double assignment to udc->ud.tcp_rx
  (git-fixes).
- efi: use 32-bit alignment for efi_guid_t literals (git-fixes).
- firmware/efi: Fix a use after bug in efi_mem_reserve_persistent
  (git-fixes).
- commit 5066b61
* Sat Mar 20 2021 tiwai@suse.de
- ASoC: rt5659: Update MCLK rate in set_sysclk() (git-fixes).
- ASoC: simple-card-utils: Do not handle device clock (git-fixes).
- commit f987c3c
* Sat Mar 20 2021 tiwai@suse.de
- ASoC: cs42l42: Always wait at least 3ms after reset (git-fixes).
- ASoC: cs42l42: Don't enable/disable regulator at Bias Level
  (git-fixes).
- ASoC: cs42l42: Fix mixer volume control (git-fixes).
- ASoC: cs42l42: Fix channel width support (git-fixes).
- commit 61d6928
* Sat Mar 20 2021 tiwai@suse.de
- ASoC: cs42l42: Fix Bitclock polarity inversion (git-fixes).
- ASoC: rt5651: Fix dac- and adc- vol-tlv values being off by
  a factor of 10 (git-fixes).
- ASoC: rt5640: Fix dac- and adc- vol-tlv values being off by
  a factor of 10 (git-fixes).
- ASoC: es8316: Simplify adc_pga_gain_tlv table (git-fixes).
- ASoC: sgtl5000: set DAP_AVC_CTRL register to correct default
  value on probe (git-fixes).
- commit 629faf0
* Sat Mar 20 2021 tiwai@suse.de
- ASoC: Intel: bytcr_rt5640: Fix HP Pavilion x2 10-p0XX OVCD
  current threshold (git-fixes).
- ASoC: rt5670: Add emulated 'DAC1 Playback Switch' control
  (git-fixes).
- ASoC: rt5670: Remove ADC vol-ctrl mute bits poking from Sto1
  ADC mixer settings (git-fixes).
- ASoC: rt5670: Remove 'HP Playback Switch' control (git-fixes).
- ASoC: rt5670: Remove 'OUT Channel Switch' control (git-fixes).
- ASoC: ak5558: Add MODULE_DEVICE_TABLE (git-fixes).
- ASoC: ak4458: Add MODULE_DEVICE_TABLE (git-fixes).
- ASoC: fsl_ssi: Fix TDM slot setup for I2S mode (git-fixes).
- commit 01440d8
* Sat Mar 20 2021 tiwai@suse.de
- ALSA: hda/realtek: apply pin quirk for XiaomiNotebook Pro
  (git-fixes).
- ALSA: hda/realtek: Apply headset-mic quirks for Xiaomi Redmibook
  Air (git-fixes).
- ALSA: hda: generic: Fix the micmute led init state (git-fixes).
- commit fc72277
* Fri Mar 19 2021 ptesarik@suse.cz
- s390/qeth: fix notification for pending buffers during teardown
  (git-fixes).
- s390/qeth: schedule TX NAPI on QAOB completion (git-fixes).
- s390/qeth: improve completion of pending TX buffers (git-fixes).
- s390/qeth: fix memory leak after failed TX Buffer allocation
  (git-fixes).
- commit ffdf1ba
* Fri Mar 19 2021 ptesarik@suse.cz
- s390/dasd: fix hanging IO request during DASD driver unbind
  (git-fixes).
- commit 77e1a65
* Fri Mar 19 2021 ptesarik@suse.cz
- s390/cio: return -EFAULT if copy_to_user() fails (git-fixes).
- s390/crypto: return -EFAULT if copy_to_user() fails (git-fixes).
- s390/cio: return -EFAULT if copy_to_user() fails (git-fixes).
- commit 86038a4
* Fri Mar 19 2021 varad.gautam@suse.com
- squashfs: fix xattr id and id lookup sanity checks (bsc#1183750).
- commit 8006352
* Fri Mar 19 2021 varad.gautam@suse.com
- squashfs: fix inode lookup sanity checks (bsc#1183750).
- commit cd40a2e
* Fri Mar 19 2021 yousaf.kaukab@suse.com
- netsec: restore phy power state after controller reset
  (bsc#1183757).
- commit 05da5bc
* Fri Mar 19 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Add missing BOOTUP_DEFAULT to profile_name[]'
- commit 82b8ebe
* Fri Mar 19 2021 tzimmermann@suse.de
- drm/msm: Fix races managing the OOB state for timestamp vs (bsc#1152489)
  Backporting notes:
  * context changes
- commit 58990b2
* Fri Mar 19 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/msm: Fix race of GPU init vs timestamp power management.'
- commit 5232b67
* Fri Mar 19 2021 tzimmermann@suse.de
- drm/vc4: hdmi: Restore cec physical address on reconnect (bsc#1152472)
  Backporting notes:
  * context changes
  * change vc4_hdmi to vc4->hdmi
  * removed references to encoder->hdmi_monitor
- commit 7cd936b
* Fri Mar 19 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Prevent shift wrapping in amdgpu_read_mask()'
- commit 6048fb7
* Fri Mar 19 2021 tzimmermann@suse.de
- drm/mediatek: Fix aal size config (bsc#1152489)
  Backporting notes:
  * replaced mtk_ddp_write() with writel()
- commit 5d50b21
* Fri Mar 19 2021 tzimmermann@suse.de
- drm/nouveau: bail out of nouveau_channel_new if channel init fails (bsc#1152489)
  Backporting notes:
  * replaces patches.suse/drm-bail-out-of-nouveau_channel_new-if-channel-init-.patch
- commit b88077f
* Fri Mar 19 2021 tzimmermann@suse.de
- drm/sun4i: tcon: fix inverted DCLK polarity (bsc#1152489)
  Backporting notes:
  * context changes
- commit 0c124bb
* Thu Mar 18 2021 dwagner@suse.de
- nvmet-rdma: Fix list_del corruption on queue establishment
  failure (bsc#1183501).
- commit 8d20dc6
* Thu Mar 18 2021 msuchanek@suse.de
- powerpc/book3s64/radix: Remove WARN_ON in destroy_context()
  (bsc#1183692 ltc#191963).
- commit 418290b
* Thu Mar 18 2021 dwagner@suse.de
- nvme: allocate the keep alive request using BLK_MQ_REQ_NOWAIT
  (bsc#1182077).
- nvme: merge nvme_keep_alive into nvme_keep_alive_work
  (bsc#1182077).
- nvme-fabrics: only reserve a single tag (bsc#1182077).
- commit c67a454
* Thu Mar 18 2021 tiwai@suse.de
- Update patch reference of x25 fix (CVE-2020-35519 bsc#1183696)
- commit 6cd53a3
* Thu Mar 18 2021 tiwai@suse.de
- usbip: fix vudc to check for stream socket (git-fixes).
- Refresh
  patches.suse/usbip-fix-vudc-usbip_sockfd_store-races-leading-to-g.patch.
- commit ecca945
* Thu Mar 18 2021 tiwai@suse.de
- xhci: Fix repeated xhci wake after suspend due to uncleared
  internal wake state (git-fixes).
- xhci: Improve detection of device initiated wake signal
  (git-fixes).
- commit 594832e
* Thu Mar 18 2021 tiwai@suse.de
- usbip: fix vhci_hcd to check for stream socket (git-fixes).
- Refresh
  patches.suse/usbip-fix-vhci_hcd-attach_store-races-leading-to-gpf.patch.
- commit a57cde3
* Thu Mar 18 2021 tiwai@suse.de
- usbip: fix stub_dev to check for stream socket (git-fixes).
- Refresh
  patches.suse/usbip-fix-stub_dev-usbip_sockfd_store-races-leading-.patch.
- commit 2ae7114
* Thu Mar 18 2021 tiwai@suse.de
- staging: rtl8712: Fix possible buffer overflow in
  r8712_sitesurvey_cmd (git-fixes).
- usb: xhci: Fix ASMedia ASM1042A and ASM3242 DMA addressing
  (git-fixes).
- USB: serial: ch341: add new Product ID (git-fixes).
- USB: serial: cp210x: add some more GE USB IDs (git-fixes).
- USB: serial: cp210x: add ID for Acuity Brands nLight Air Adapter
  (git-fixes).
- USB: usblp: fix a hang in poll() if disconnected (git-fixes).
- spi: stm32: make spurious and overrun interrupts visible
  (git-fixes).
- commit bc51b9d
* Thu Mar 18 2021 tiwai@suse.de
- staging: rtl8192e: Fix possible buffer overflow in
  _rtl92e_wx_set_scan (git-fixes).
- media: v4l: vsp1: Fix uif null pointer access (git-fixes).
- media: v4l: vsp1: Fix bru null pointer access (git-fixes).
- PCI: xgene-msi: Fix race in installing chained irq handler
  (git-fixes).
- PCI: mediatek: Add missing of_node_put() to fix reference leak
  (git-fixes).
- PCI: Fix pci_register_io_range() memory leak (git-fixes).
- Input: applespi - don't wait for responses to commands
  indefinitely (git-fixes).
- mmc: mxs-mmc: Fix a resource leak in an error handling path in
  'mxs_mmc_probe()' (git-fixes).
- Platform: OLPC: Fix probe error handling (git-fixes).
- commit 3f405a7
* Thu Mar 18 2021 tiwai@suse.de
- Goodix Fingerprint device is not a modem (git-fixes).
- drm/compat: Clear bounce structures (git-fixes).
- ethernet: alx: fix order of calls on resume (git-fixes).
- ath9k: fix transmitting to stations in dynamic SMPS mode
  (git-fixes).
- i2c: rcar: optimize cacheline to minimize HW race condition
  (git-fixes).
- i2c: rcar: faster irq code to minimize HW race condition
  (git-fixes).
- commit 31fcf0f
* Thu Mar 18 2021 tiwai@suse.de
- blacklist.conf: Add capbilities entry that was reverted
- commit dc865b3
* Wed Mar 17 2021 tiwai@suse.de
- Update patch reference of r8188eu fix (CVE-2021-28660 bsc#1183593)
- commit fc23dca
* Wed Mar 17 2021 jack@suse.cz
- Update tags
  patches.suse/ext4-check-journal-inode-extents-more-carefully.patch
  (bsc#1173485 bsc#1183509 CVE-2021-3428).
- commit 41a8fa6
* Wed Mar 17 2021 jroedel@suse.de
- iommu/qcom: add missing put_device() call in qcom_iommu_of_xlate() (bsc#1183637).
- commit de5577f
* Wed Mar 17 2021 tiwai@suse.de
- amd/amdgpu: Disable VCN DPG mode for Picasso (git-fixes).
- commit f34c818
* Wed Mar 17 2021 tiwai@suse.de
- HSI: Fix PM usage counter unbalance in ssi_hw_init (git-fixes).
- hwmon: (ina3221) Fix PM usage counter unbalance in
  ina3221_write_enable (git-fixes).
- gpio: zynq: fix reference leak in zynq_gpio functions
  (git-fixes).
- net: fec: Fix reference count leak in fec series ops
  (git-fixes).
- commit e27c26d
* Wed Mar 17 2021 tiwai@suse.de
- Update patch reference for fastrpc fix (CVE-2021-28375 bsc#1183596)
- commit 00ee058
* Wed Mar 17 2021 bp@suse.de
- x86/fsgsbase/64: Fix NULL deref in 86_fsgsbase_read_task
  (bsc#1152489).
- commit f996a8c
* Wed Mar 17 2021 bp@suse.de
- blacklist.conf: e504e74cc3a2 x86/unwind/orc: Disable KASAN checking in the ORC unwinder, part 2
- commit 12930ec
* Tue Mar 16 2021 tiwai@suse.de
- Update bug reference for USB-audio fixes (bsc#1182552 bsc#1183598)
- commit cd602fc
* Tue Mar 16 2021 msuchanek@suse.de
- rpadlpar: fix potential drc_name corruption in store functions
  (bsc#1183416 ltc#191079).
- commit cfa810c
* Tue Mar 16 2021 denis.kirjanov@suse.com
- net: stmmac: Use rtnl_lock/unlock on
  netif_set_real_num_rx_queues() call (git-fixes).
- commit aa3dcbf
* Tue Mar 16 2021 tzimmermann@suse.de
- drm/panfrost: Remove unused variables in panfrost_job_close() (bsc#1152472)
- commit 1350ad6
* Tue Mar 16 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/panfrost: Move the GPU reset bits outside the timeout handler'
- commit 5140c1f
* Mon Mar 15 2021 rgoldwyn@suse.com
- binfmt_misc: fix possible deadlock in bm_register_write
  (git-fixes).
- configfs: fix a use-after-free in __configfs_open_file
  (git-fixes).
- mount: fix mounting of detached mounts onto targets that reside
  on shared mounts  (git-fixes).
- mm: hugetlbfs: fix cannot migrate the fallocated HugeTLB page
  (git-fixes).
- epoll: check for events when removing a timed out thread from
  the wait queue  (git-fixes).
- proc: fix lookup in /proc/net subdirectories after setns(2)
  (git-fixes).
- apparmor: check/put label on apparmor_sk_clone_security()
  (git-fixes).
- apparmor: Fix aa_label refcnt leak in policy_update
  (git-fixes).
- exec: Move would_dump into flush_old_exec  (git-fixes).
- fuse: verify write return  (git-fixes).
- commit 55b045e
* Mon Mar 15 2021 ailiop@suse.com
- xfs: group quota should return EDQUOT when prj quota enabled
  (bsc#1180980).
- commit dbe17e3
* Mon Mar 15 2021 msuchanek@suse.de
- Delete patches.suse/sched-Reenable-interrupts-in-do_sched_yield.patch
  (bsc#1183530)
  This patch has been pointed out to break boot on qemu version 3 with
  azure config.
- commit d2d00bd
* Mon Mar 15 2021 aaptel@suse.com
- smb3: Fix out-of-bounds bug in SMB2_negotiate() (bsc#1183540).
- commit 860b1de
* Mon Mar 15 2021 aaptel@suse.com
- cifs: check pointer before freeing (bsc#1183534).
- commit 03b0110
* Mon Mar 15 2021 dwagner@suse.de
- nvme-fabrics: fix kato initialization (bsc#1182591).
- commit 4bcdc01
* Mon Mar 15 2021 dwagner@suse.de
- Remove patches.suse/nvme-hwmon-Return-error-code-when-registration-fails.patch
  hwmon_init() has no return value, hence we don't need this patch. The
  patch is only relevant for SLE15-SP3.
- commit b165e35
* Mon Mar 15 2021 denis.kirjanov@suse.com
- bnxt_en: Re-write PCI BARs after PCI fatal error (git-fixes). - Refresh patches.suse/bnxt_en-Fix-AER-recovery.patch.
- commit 05952f2
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: hdlc_raw_eth: Clear the IFF_TX_SKB_SHARING flag after calling ether_setup (git-fixes).
- commit d9b9ce4
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: hdlc: In hdlc_rcv, check to make sure dev is an HDLC device (git-fixes).
- commit 85c34ec
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: fec: Fix phy_device lookup for phy_reset_after_clk_enable() (git-fixes).
- commit 6a3b52e
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: korina: fix kfree of rx/tx descriptor array (git-fixes).
- commit f8b10af
* Mon Mar 15 2021 jgross@suse.com
- xen/events: avoid handling the same event on two cpus at the
  same time (git-fixes).
- commit d3a2816
* Mon Mar 15 2021 jgross@suse.com
- xen/events: don't unmask an event channel when an eoi is pending
  (git-fixes).
- commit 29c2c45
* Mon Mar 15 2021 tiwai@suse.de
- blacklist.conf: Add an inapplicable etnry for rtw88
- commit 65391e2
* Mon Mar 15 2021 jgross@suse.com
- xen/events: reset affinity of 2-level event when tearing it down
  (git-fixes).
- commit 43f9b1d
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: fec: Fix PHY init after phy_reset_after_clk_enable() (git-fixes).
- commit 93f1c3c
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: enic: Cure the enic api locking trainwreck (git-fixes).
- commit ee3b02c
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: dsa: rtl8366rb: Support all 4096 VLANs (git-fixes).
- commit abc3215
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/msm: Fix WARN_ON() splat in _free_object() (bsc#1152489)
  Backporting notes:
  * context changes
- commit f2973f5
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/panfrost: Don't corrupt the queue mutex on open/close (bsc#1152472)
  Backporting notes:
  * context changes
- commit ab54c88
* Mon Mar 15 2021 jgross@suse.com
- Update
  patches.suse/Xen-gnttab-handle-p2m-update-errors-on-a-per-slot-ba.patch
  (bsc#1183022 XSA-367 CVE-2021-28038): added CVE number
- Update
  patches.suse/xen-netback-respect-gnttab_map_refs-s-return-value.patch
  (bsc#1183022 XSA-367 CVE-2021-28038): added CVE number
- commit 91d5751
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: stmmac: use netif_tx_start|stop_all_queues() function (git-fixes).
- commit 2c830e3
* Mon Mar 15 2021 denis.kirjanov@suse.com
- net: stmmac: Fix incorrect location to set real_num_rx|tx_queues (git-fixes).
- commit 952bf43
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/msm/gem: Add obj->lock wrappers (bsc#1152489)
  Backporting notes:
  * taken for 9b73bde39cf2 ("drm/msm: Fix use-after-free in msm_gem with carveout")
  * context changes
- commit 37d3ff2
* Mon Mar 15 2021 tbogendoerfer@suse.de
- net: bonding: fix error return code of bond_neigh_init()
  (bsc#1154353).
- bnxt_en: reliably allocate IRQ table on reset to avoid crash
  (jsc#SLE-8371 bsc#1153274).
- commit f06fb53
* Mon Mar 15 2021 tzimmermann@suse.de
- drm: rcar-du: Fix crash when using LVDS1 clock for CRTC (bsc#1152489)
  Backporting notes:
  * context changes
- commit 69d2605
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/amd/powerplay: fix spelling mistake "smu_state_memroy_block" -> (bsc#1152489)
  Backporting notes:
  * rename amd/pm to amd/powerplay
  * context changes
- commit 6a3acb4
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/amdkfd: Put ACPI table after using it (bsc#1152489)
  Backporting notes:
  * context changes
- commit c115d9f
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/msm: Fix use-after-free in msm_gem with carveout (bsc#1152489)
  Backporting notes:
  * context changes
- commit 485d7ba
* Mon Mar 15 2021 tzimmermann@suse.de
- drm/panfrost: Fix job timeout handling (bsc#1152472)
  Backporting notes:
  * context changes
- commit ef50c07
* Mon Mar 15 2021 tzimmermann@suse.de
- video: fbdev: acornfb: remove free_unused_pages() (bsc#1152489)
- commit 979bc2a
* Mon Mar 15 2021 tiwai@suse.de
- binfmt_misc: fix possible deadlock in bm_register_write
  (git-fixes).
- misc/pvpanic: Export module FDT device table (git-fixes).
- misc: fastrpc: restrict user apps from sending kernel RPC
  messages (git-fixes).
- staging: rtl8188eu: prevent ->ssid overflow in rtw_wx_set_scan()
  (git-fixes).
- staging: rtl8188eu: fix potential memory corruption in
  rtw_check_beacon_data() (git-fixes).
- staging: rtl8192u: fix ->ssid overflow in r8192_wx_set_scan()
  (git-fixes).
- staging: comedi: pcl818: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: pcl711: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: me4000: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: dmm32at: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: das800: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: das6402: Fix endian problem for AI command data
  (git-fixes).
- staging: comedi: adv_pci1710: Fix endian problem for AI command
  data (git-fixes).
- staging: comedi: addi_apci_1500: Fix endian problem for command
  sample (git-fixes).
- staging: comedi: addi_apci_1032: Fix endian problem for COS
  sample (git-fixes).
- staging: ks7010: prevent buffer overflow in ks_wlan_set_scan()
  (git-fixes).
- staging: rtl8712: unterminated string leads to read overflow
  (git-fixes).
- usb: xhci: do not perform Soft Retry for some xHCI hosts
  (git-fixes).
- USB: serial: io_edgeport: fix memory leak in edge_startup
  (git-fixes).
- usbip: fix vudc usbip_sockfd_store races leading to gpf
  (git-fixes).
- usbip: fix vhci_hcd attach_store() races leading to gpf
  (git-fixes).
- usbip: fix stub_dev usbip_sockfd_store() races leading to gpf
  (git-fixes).
- usb: dwc3: qcom: Add missing DWC3 OF node refcount decrement
  (git-fixes).
- usb: renesas_usbhs: Clear PIPECFG for re-enabling pipe with
  other EPNUM (git-fixes).
- usb: dwc3: qcom: Honor wakeup enabled/disabled state
  (git-fixes).
- usb: gadget: f_uac1: stop playback on function disable
  (git-fixes).
- usb: gadget: f_uac2: always increase endpoint max_packet_size
  by one audio slot (git-fixes).
- USB: gadget: u_ether: Fix a configfs return code (git-fixes).
- commit e8f5b15
* Sat Mar 13 2021 tiwai@suse.de
- ALSA: usb-audio: Fix "RANGE setting not yet supported" errors
  (git-fixes).
- ALSA: usb-audio: Skip the clock selector inquiry for single
  connections (git-fixes).
- ALSA: usb: Use DIV_ROUND_UP() instead of open-coding it
  (git-fixes).
- commit 761b71c
* Sat Mar 13 2021 tiwai@suse.de
- block: rsxx: fix error return code of rsxx_pci_probe()
  (git-fixes).
- software node: Fix node registration (git-fixes).
- mmc: cqhci: Fix random crash when remove mmc module/card
  (git-fixes).
- mmc: core: Fix partition switch time for eMMC (git-fixes).
- commit c895b3d
* Sat Mar 13 2021 tiwai@suse.de
- ALSA: hda/hdmi: Cancel pending works before suspend (git-fixes).
- ALSA: hda: Avoid spurious unsol event handling during S3/S4
  (git-fixes).
- ALSA: hda: Drop the BATCH workaround for AMD controllers
  (git-fixes).
- commit dcc7c7c
* Sat Mar 13 2021 tiwai@suse.de
- Move upstreamed sound fixes into sorted section
- commit 8879ec1
* Fri Mar 12 2021 dfaggioli@suse.com
- kABI: repair after "nVMX: Properly handle userspace interrupt window request"
  Restore the signature of member function of kvm_x86_ops, which is kABI.
  The implementation does not use the second argument any longer, so mark
  it as __unused.
- commit ac3267f
* Fri Mar 12 2021 rgoldwyn@suse.com
- jfs: Fix array index bounds check in dbAdjTree  (bsc#1179454 CVE-2020-27815).
- commit 8c97baa
* Fri Mar 12 2021 dfaggioli@suse.com
- KVM x86: Extend AMD specific guest behavior to Hygon virtual CPUs
  (bsc#1183447).
- commit 07c11e6
* Fri Mar 12 2021 dfaggioli@suse.com
- KVM: x86: Add helpers to perform CPUID-based guest vendor check
  (bsc#1183445).
  Also refreshes:
  patches.suse/kvm-x86-fix-cpuid-range-checks-for-hypervisor-and-centaur-classes.
- commit e678df6
* Fri Mar 12 2021 tiwai@suse.de
- mwifiex: pcie: skip cancel_work_sync() on reset failure path
  (git-fixes).
- commit c95acf7
* Fri Mar 12 2021 tiwai@suse.de
- drm: meson_drv add shutdown function (git-fixes).
- qxl: Fix uninitialised struct field head.surface_id (git-fixes).
- media: usbtv: Fix deadlock on suspend (git-fixes).
- media: rc: compile rc-cec.c into rc-core (git-fixes).
- drm/msm/a5xx: Remove overwriting A5XX_PC_DBG_ECO_CNTL register
  (git-fixes).
- misc: eeprom_93xx46: Add quirk to support Microchip 93LC46B
  eeprom (git-fixes).
- ACPICA: Fix race in generic_serial_bus (I2C) and GPIO op_region
  parameter handling (git-fixes).
- HID: i2c-hid: Add I2C_HID_QUIRK_NO_IRQ_AFTER_RESET for ITE8568
  EC on Voyo Winpad A15 (git-fixes).
- mmc: sdhci-of-dwcmshc: set SDHCI_QUIRK2_PRESET_VALUE_BROKEN
  (git-fixes).
- HID: mf: add support for 0079:1846 Mayflash/Dragonrise USB
  Gamecube Adapter (git-fixes).
- PCI: Add function 1 DMA alias quirk for Marvell 9215 SATA
  controller (git-fixes).
- ACPI: video: Add DMI quirk for GIGABYTE GB-BXBT-2807
  (git-fixes).
- platform/x86: acer-wmi: Add ACER_CAP_KBD_DOCK quirk for the
  Aspire Switch 10E SW3-016 (git-fixes).
- platform/x86: acer-wmi: Add support for SW_TABLET_MODE on
  Switch devices (git-fixes).
- platform/x86: acer-wmi: Add ACER_CAP_SET_FUNCTION_MODE
  capability flag (git-fixes).
- platform/x86: acer-wmi: Add new force_caps module parameter
  (git-fixes).
- platform/x86: acer-wmi: Cleanup accelerometer device handling
  (git-fixes).
- platform/x86: acer-wmi: Cleanup ACER_CAP_FOO defines
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for ARCHOS Cesium 140
  (git-fixes).
- media: cx23885: add more quirks for reset DMA on some AMD IOMMU
  (git-fixes).
- commit f5bb9e4
* Fri Mar 12 2021 msuchanek@suse.de
- gcc-plugins: simplify GCC plugin-dev capability test
  (bsc#1181862).
- update config files
  - GCC_PLUGINS=y
  - GCC_PLUGIN_CYC_COMPLEXITY=n
  - GCC_PLUGIN_LATENT_ENTROPY=n
  - GCC_PLUGIN_RANDSTRUCT=n
  - GCC_PLUGIN_STRUCTLEAK_USER=n
  - GCC_PLUGIN_STRUCTLEAK_BYREF=n
  - GCC_PLUGIN_STRUCTLEAK_BYREF_ALL=n
  - GCC_PLUGIN_STACKLEAK=n
- commit f16b7b9
* Fri Mar 12 2021 dfaggioli@suse.com
- KVM: x86: Return -E2BIG when KVM_GET_SUPPORTED_CPUID hits max entries
  (bsc#1183428).
- commit 3773bcc
* Fri Mar 12 2021 dfaggioli@suse.com
- KVM: nVMX: Properly handle userspace interrupt window request
  (bsc#1183427).
- commit 3cc1c3a
* Fri Mar 12 2021 mcgrof@suse.com
- patches.suse/0007-block-add-docs-for-gendisk-request_queue-refcount-he.patch:
  (bsc#1171295, git fixes (block drivers)).
- patches.suse/0008-block-revert-back-to-synchronous-request_queue-remov.patch:
  (bsc#1171295, git fixes (block drivers)).
- patches.suse/0009-blktrace-fix-debugfs-use-after-free.patch:
  (bsc#1171295, git fixes (block drivers)).
  Update patches related to bsc#1171295 which were merged sooner due to
  other reasons.
- commit 2cd1e12
* Thu Mar 11 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/PCI-Add-a-REBAR-size-quirk-for-Sapphire-RX-5600-XT-P.patch
- commit e2c9c81
* Thu Mar 11 2021 mkubecek@suse.cz
- series.conf: cleanup
- move mainline patches into sorted section
  patches.suse/btrfs-unlock-extents-in-btrfs_zero_range-in-case-of-errors.patch
  patches.suse/btrfs-free-correct-amount-of-space-in-btrfs_delayed_inode_reserve_metadata.patch
  patches.suse/btrfs-don-t-flush-from-btrfs_delayed_inode_reserve_metadata.patch
  (no effect on expanded tree)
- commit 00edfef
* Thu Mar 11 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/ibmvnic-Fix-possibly-uninitialized-old_num_tx_queues.patch
  patches.suse/ibmvnic-always-store-valid-MAC-address.patch
  patches.suse/powerpc-pseries-Don-t-enforce-MSI-affinity-with-kdum.patch
- commit 31cb799
* Thu Mar 11 2021 rgoldwyn@suse.com
- Update patches.suse/apparmor-Fix-use-after-free-in-aa_audit_rule_init.patch
  (CVE-2019-18814 bsc#1156256).
- commit 7636680
* Thu Mar 11 2021 dwagner@suse.de
- scsi: lpfc: Update copyrights for 12.8.0.7 and 12.8.0.8 changes
  (bsc#1182574).
- scsi: lpfc: Update lpfc version to 12.8.0.8 (bsc#1182574).
- scsi: lpfc: Correct function header comments related to ndlp
  reference counting (bsc#1182574).
- scsi: lpfc: Reduce LOG_TRACE_EVENT logging for vports
  (bsc#1182574).
- scsi: lpfc: Change wording of invalid pci reset log message
  (bsc#1182574).
- scsi: lpfc: Fix crash caused by switch reboot (bsc#1182574).
- scsi: lpfc: Fix pt2pt state transition causing rmmod hang
  (bsc#1182574).
- scsi: lpfc: Fix nodeinfo debugfs output (bsc#1182574).
- scsi: lpfc: Fix ADISC handling that never frees nodes
  (bsc#1182574).
- scsi: lpfc: Fix PLOGI ACC to be transmit after REG_LOGIN
  (bsc#1182574).
- scsi: lpfc: Fix dropped FLOGI during pt2pt discovery recovery
  (bsc#1182574).
- scsi: lpfc: Fix status returned in lpfc_els_retry() error exit
  path (bsc#1182574).
- scsi: lpfc: Fix use after free in lpfc_els_free_iocb
  (bsc#1182574).
- scsi: lpfc: Fix null pointer dereference in lpfc_prep_els_iocb()
  (bsc#1182574).
- scsi: lpfc: Fix unnecessary null check in lpfc_release_scsi_buf
  (bsc#1182574).
- scsi: lpfc: Fix pt2pt connection does not recover after LOGO
  (bsc#1182574).
- scsi: lpfc: Fix lpfc_els_retry() possible null pointer
  dereference (bsc#1182574).
- scsi: lpfc: Fix FLOGI failure due to accessing a freed node
  (bsc#1182574).
- scsi: lpfc: Fix stale node accesses on stale RRQ request
  (bsc#1182574).
- scsi: lpfc: Fix reftag generation sizing errors (bsc#1182574).
- scsi: lpfc: Fix vport indices in lpfc_find_vport_by_vpid()
  (bsc#1182574).
- scsi: lpfc: Fix incorrect dbde assignment when building target
  abts wqe (bsc#1182574).
- commit 19f4943
* Thu Mar 11 2021 mcgrof@suse.com
- patches.suse/loop-be-paranoid-on-exit-and-prevent-new-additions-r.patch: (bsc#1171295).
- commit e598133
* Thu Mar 11 2021 mcgrof@suse.com
- patches.suse/blktrace-annotate-required-lock-on-do_blk_trace_setu.patch: (bsc#1171295).
- commit b590c4c
* Thu Mar 11 2021 mcgrof@suse.com
- patches.suse/block-clarify-context-for-refcount-increment-helpers.patch: (bsc#1171295).
- commit 252fb3e
* Thu Mar 11 2021 dfaggioli@suse.com
- KVM: x86: do not reset microcode version on INIT or RESET
  (bsc#1183412).
- commit 16ce873
* Thu Mar 11 2021 mcgrof@suse.com
- patches.suse/blktrace-Avoid-sparse-warnings-when-assigning-q-blk_.patch: (bsc#1171295).
- commit fbf1322
* Thu Mar 11 2021 mcgrof@suse.com
- patches.suse/blktrace-break-out-of-blktrace-setup-on-concurrent-c.patch: (bsc#1171295).
- commit 3bfed47
* Thu Mar 11 2021 denis.kirjanov@suse.com
- net: mvneta: fix double free of txq->buf (git-fixes).
- commit 1c0789f
* Thu Mar 11 2021 denis.kirjanov@suse.com
- net: mvneta: make tx buffer array agnostic (git-fixes).
- commit 49c79a4
* Thu Mar 11 2021 denis.kirjanov@suse.com
- net: usb: ax88179_178a: fix missing stop entry in driver_info (git-fixes).
- commit c51e8e9
* Thu Mar 11 2021 denis.kirjanov@suse.com
- mdio: fix mdio-thunder.c dependency & build error (git-fixes).
- commit 89b67ef
* Thu Mar 11 2021 denis.kirjanov@suse.com
- net: ethernet: cavium: octeon_mgmt: use phy_start and phy_stop (git-fixes).
- commit c74de85
* Thu Mar 11 2021 denis.kirjanov@suse.com
- ice: fix memory leak in ice_vsi_setup (git-fixes).
- commit 7c0d558
* Thu Mar 11 2021 denis.kirjanov@suse.com
- ice: fix memory leak if register_netdev_fails (git-fixes).
- commit 8c0fdc3
* Thu Mar 11 2021 dfaggioli@suse.com
- KVM: x86: list MSR_IA32_UCODE_REV as an emulated MSR
  (bsc#1183369).
- commit 3238faa
* Thu Mar 11 2021 jroedel@suse.de
- PM: runtime: Add pm_runtime_resume_and_get to deal with usage
  counter (bsc#1183366).
- commit a3fe770
* Thu Mar 11 2021 glin@suse.com
- bpf,x64: Pad NOPs to make images converge more easily
  (bsc#1178163).
- commit 9aadbb2
* Thu Mar 11 2021 denis.kirjanov@suse.com
- iavf: Fix incorrect adapter get in iavf_resume (git-fixes).
- commit f71dec5
* Thu Mar 11 2021 denis.kirjanov@suse.com
- iavf: use generic power management (git-fixes).
- commit 23712b8
* Thu Mar 11 2021 denis.kirjanov@suse.com
- net: stmmac: removed enabling eee in EEE set callback (git-fixes).
- commit d783a1f
* Wed Mar 10 2021 dwagner@suse.de
- nvme: return an error if nvme_set_queue_count() fails
  (bsc#1180197).
- commit a1a57eb
* Wed Mar 10 2021 rgoldwyn@suse.com
- locks: reinstate locks_delete_block optimization
  (CVE-2019-19769 bsc#1159280).
- locks: fix a potential use-after-free problem when wakeup a
  waiter  (CVE-2019-19769 bsc#1159280).
- commit 4a9973d
* Wed Mar 10 2021 msuchanek@suse.de
- ibmvnic: remove excessive irqsave (bsc#1182485 ltc#191591).
- commit 3c13549
* Wed Mar 10 2021 jroedel@suse.de
- KVM: x86: Set so called 'reserved CR3 bits in LM mask' at vCPU reset (bsc#1183288).
- Refresh
  patches.kabi/kABI-Fix-kABI-after-AMD-SEV-PCID-fixes.patch.
- commit cb76db4
* Wed Mar 10 2021 jroedel@suse.de
- iommu/amd: Fix sleeping in atomic in increase_address_space()
  (bsc#1183277).
- KVM: x86: Allow guests to see MSR_IA32_TSX_CTRL even if tsx=off
  (bsc#1183287).
- iommu/vt-d: Do not use flush-queue when caching-mode is on
  (bsc#1183282).
- iommu/vt-d: Correctly check addr alignment in
  qi_flush_dev_iotlb_pasid() (bsc#1183281).
- iommu/vt-d: Fix unaligned addresses for
  intel_flush_svm_range_dev() (bsc#1183285).
- iommu/vt-d: Fix ineffective devTLB invalidation for subdevices
  (bsc#1183284).
- iommu/vt-d: Fix general protection fault in aux_detach_device()
  (bsc#1183283).
- iommu/vt-d: Move intel_iommu info from struct intel_svm to
  struct intel_svm_dev (bsc#1183286).
- iommu/intel: Fix memleak in intel_irq_remapping_alloc
  (bsc#1183278).
- iommu/vt-d: Avoid panic if iommu init fails in tboot system
  (bsc#1183280).
- iommu/vt-d: Add get_domain_info() helper (bsc#1183279).
- commit b6d08d2
* Wed Mar 10 2021 bp@suse.de
- KVM: SVM: Clear the CR4 register on reset (bsc#1183252).
- commit e6e6e8c
* Wed Mar 10 2021 tiwai@suse.de
- netdevsim: init u64 stats for 32bit hardware (git-fixes).
- net: usb: qmi_wwan: allow qmimux add/del with master up
  (git-fixes).
- can: skb: can_skb_set_owner(): fix ref counting if socket was
  closed before setting skb ownership (git-fixes).
- can: flexcan: invoke flexcan_chip_freeze() to enter freeze mode
  (git-fixes).
- can: flexcan: enable RX FIFO after FRZ/HALT valid (git-fixes).
- can: flexcan: assert FRZ bit in flexcan_chip_freeze()
  (git-fixes).
- mt76: dma: do not report truncated frames to mac80211
  (git-fixes).
- gpio: pca953x: Set IRQ type when handle Intel Galileo Gen 2
  (git-fixes).
- drm/amdgpu: fix parameter error of RREG32_PCIE() in
  amdgpu_regs_pcie (git-fixes).
- usbip: tools: fix build error for multiple definition
  (git-fixes).
- commit 15f1b1c
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: comment on the list
  To explain what it actually is.
- commit e94bacf
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: define ignores more strictly
  * search for whole words, so make wildcards explicit
  * use ' for quoting
  * prepend CONFIG_ dynamically, so it need not be in the list
- commit f61e954
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: sort the ignores
  They are growing so to make them searchable by humans.
- commit 67c6b55
* Wed Mar 10 2021 jslaby@suse.cz
- rpm/check-for-config-changes: add -mrecord-mcount ignore
  Added by 3b15cdc15956 (tracing: move function tracer options to Kconfig)
  upstream.
- commit 018b013
* Wed Mar 10 2021 lduncan@suse.com
- scsi: iscsi: Verify lengths on passthrough PDUs (CVE-2021-27365
  bsc#1182715).
- scsi: iscsi: Ensure sysfs attributes are limited to PAGE_SIZE
  (CVE-2021-27365 bsc#1182715).
- scsi: iscsi: Restrict sessions and handles to admin capabilities
  (CVE-2021-27363 CVE-2021-27364 bsc#1182716 bsc#1182717).
- commit e5416af
* Tue Mar  9 2021 msuchanek@suse.de
- Refresh patches.suse/powerpc-pseries-Don-t-enforce-MSI-affinity-with-kdum.patch.
  Update patch metadata.
- commit 5b5a037
* Tue Mar  9 2021 msuchanek@suse.de
- Update config files.
- commit a7710ca
* Tue Mar  9 2021 msuchanek@suse.de
- arm64: make STACKPROTECTOR_PER_TASK configurable (bsc#1181862).
- commit e710608
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: gemini: Fix another missing clk_disable_unprepare()
  in probe (git-fixes).
- commit 6c94cd0
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: cpsw: fix clean up of vlan mc entries for
  host port (git-fixes).
- commit 05decbb
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: arc_emac: Fix memleak in arc_mdio_probe (git-fixes).
- commit 5898dda
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: gemini: Fix missing free_netdev() in error path of
  gemini_ethernet_port_probe() (git-fixes).
- commit a31c30f
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: qcom/emac: add missed clk_disable_unprepare in error path
  of emac_clks_phase1_init (git-fixes).
- commit 8bcb8c8
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net/mlx5: Delete extra dump stack that gives nothing
  (git-fixes).
- commit 8adc626
* Tue Mar  9 2021 denis.kirjanov@suse.com
- fsl/fman: fix eth hash table allocation (git-fixes).
- commit 888f0c2
* Tue Mar  9 2021 denis.kirjanov@suse.com
- fsl/fman: check dereferencing null pointer (git-fixes).
- commit 8b2d58f
* Tue Mar  9 2021 denis.kirjanov@suse.com
- fsl/fman: fix unreachable code (git-fixes).
- commit 44dfe0c
* Tue Mar  9 2021 denis.kirjanov@suse.com
- fsl/fman: fix dereference null return value (git-fixes).
- commit 54941fb
* Tue Mar  9 2021 denis.kirjanov@suse.com
- fsl/fman: use 32-bit unsigned integer (git-fixes).
- commit b5edb51
* Tue Mar  9 2021 denis.kirjanov@suse.com
- net: spider_net: Fix the size used in a 'dma_free_coherent()'
  call (git-fixes).
- commit 62d1c07
* Tue Mar  9 2021 glin@suse.com
- bpf_lru_list: Read double-checked variable once without lock
  (bsc#1155518).
- bpf: Declare __bpf_free_used_maps() unconditionally
  (bsc#1155518).
- bpf: Avoid warning when re-casting __bpf_call_base into
  __bpf_call_base_args (bsc#1155518).
- commit 30d5020
* Tue Mar  9 2021 tiwai@suse.de
- ALSA: usb-audio: fix use after free in usb_audio_disconnect
  (bsc#1182552).
- ALSA: usb-audio: fix NULL ptr dereference in usb_audio_probe
  (bsc#1182552).
- commit e4781c6
* Mon Mar  8 2021 fweisbecker@suse.de
- blacklist.conf: Blacklist CONFIG_UCLAMP_TASK fixes
  dcd6dffb0a75 sched/core: Fix size of rq::uclamp initialization
  eaf5a92ebde5 sched/core: Fix reset-on-fork from RT with uclamp
  d81ae8aac85c sched/uclamp: Fix initialization of struct uclamp_rq
  46609ce22703 sched/uclamp: Protect uclamp fast path code with static key
- commit 04723ee
* Mon Mar  8 2021 denis.kirjanov@suse.com
- net: ethernet: aquantia: Fix wrong return value (git-fixes).
- commit d7e8c64
* Mon Mar  8 2021 denis.kirjanov@suse.com
- net: dsa: rtl8366: Fix VLAN set-up (git-fixes).
- commit 332c76d
* Mon Mar  8 2021 dwagner@suse.de
- nvme-hwmon: Return error code when registration fails
  (bsc#1177326).
- commit 1f91b69
* Mon Mar  8 2021 denis.kirjanov@suse.com
- net: dsa: rtl8366: Fix VLAN semantics (git-fixes).
- commit eaed13b
* Mon Mar  8 2021 msuchanek@suse.de
- kbuild: improve cc-option to clean up all temporary files
  (bsc#1178330).
- Refresh patches.suse/livepatch-dump-ipa-clones.patch
- kbuild: use -S instead of -E for precise cc-option test in
  Kconfig (bsc#1178330).
- commit 9b47d75
* Mon Mar  8 2021 wqu@suse.com
- blacklist.conf: blacklist btrfs subpage RW related fixes
  As btrfs in SLE won't support subpage RW until SLE15-SP4.
- commit 74db4da
* Mon Mar  8 2021 tiwai@suse.de
- udlfb: Fix memory leak in dlfb_usb_probe (git-fixes).
- vt/consolemap: do font sum unsigned (git-fixes).
- wlcore: Fix command execute failure 19 for wl12xx (git-fixes).
- rsi: Move card interrupt handling to RX thread (git-fixes).
- commit 9236947
* Mon Mar  8 2021 tiwai@suse.de
- net: usb: qmi_wwan: support ZTE P685M modem (git-fixes).
- crypto: tcrypt - avoid signed overflow in byte count
  (git-fixes).
- drm/amd/display: Guard against NULL pointer deref when
  get_i2c_info fails (git-fixes).
- PCI: Add a REBAR size quirk for Sapphire RX 5600 XT Pulse
  (git-fixes).
- drm/amdgpu: Add check to prevent IH overflow (git-fixes).
- drm/hisilicon: Fix use-after-free (git-fixes).
- media: uvcvideo: Allow entities with no pads (git-fixes).
- media: v4l2-ctrls.c: fix shift-out-of-bounds in std_validate
  (git-fixes).
- media: mceusb: sanity check for prescaler value (git-fixes).
- staging: bcm2835-audio: Replace unsafe strcpy() with strscpy()
  (git-fixes).
- staging: most: sound: add sanity check for function argument
  (git-fixes).
- staging: fwserial: Fix error handling in fwserial_create
  (git-fixes).
- brcmfmac: Add DMI nvram filename quirk for Voyo winpad A15
  tablet (git-fixes).
- brcmfmac: Add DMI nvram filename quirk for Predia Basic tablet
  (git-fixes).
- ath10k: fix wmi mgmt tx queue full due to race condition
  (git-fixes).
- Bluetooth: Fix null pointer dereference in
  amp_read_loc_assoc_final_data (git-fixes).
- Bluetooth: hci_h5: Set HCI_QUIRK_SIMULTANEOUS_DISCOVERY for
  btrtl (git-fixes).
- Input: elantech - fix protocol errors for some trackpoints in
  SMBus mode (git-fixes).
- rsi: Fix TX EAPOL packet handling against iwlwifi AP
  (git-fixes).
- commit 2608a34
* Mon Mar  8 2021 tiwai@suse.de
- ASoC: Intel: bytcr_rt5640: Add quirk for the Acer One S1002
  tablet (git-fixes).
- ASoC: Intel: bytcr_rt5651: Add quirk for the Jumper EZpad 7
  tablet (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Voyo Winpad A15
  tablet (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for the Estar Beauty HD
  MID 7316R tablet (git-fixes).
- ASoC: Intel: Add DMI quirk table to soc_intel_is_byt_cr()
  (git-fixes).
- commit 4e131ac
* Mon Mar  8 2021 nborisov@suse.com
- Refresh patches.suse/btrfs-don-t-flush-from-btrfs_delayed_inode_reserve_metadata.patch.
- Refresh
  patches.suse/btrfs-free-correct-amount-of-space-in-btrfs_delayed_inode_reserve_metadata.patch.
- Refresh
  patches.suse/btrfs-unlock-extents-in-btrfs_zero_range-in-case-of-errors.patch.
- commit bafd254
* Mon Mar  8 2021 jslaby@suse.cz
- kbuild: dummy-tools, support MPROFILE_KERNEL checks for ppc
  (bsc#1181862).
- commit d053b67
* Sat Mar  6 2021 tiwai@suse.de
- ACPI: bus: Constify is_acpi_node() and friends (part 2)
  (git-fixes).
- commit 5937701
* Sat Mar  6 2021 tiwai@suse.de
- rsxx: Return -EFAULT if copy_to_user() fails (git-fixes).
- PM: runtime: Update device status before letting suppliers
  suspend (git-fixes).
- commit e05652b
* Sat Mar  6 2021 msuchanek@suse.de
- kbuild: stop filtering out $(GCC_PLUGINS_CFLAGS) from cc-option
  base (bcs#1181862).
- kbuild: include scripts/Makefile.* only when relevant CONFIG
  is enabled (bcs#1181862).
- commit 5819136
* Fri Mar  5 2021 msuchanek@suse.de
- gcc-plugins: drop support for GCC <= 4.7 (bcs#1181862).
- refresh config files (drop PLUGIN_HOSTCC)
- kconfig: introduce m32-flag and m64-flag (bcs#1181862).
- gcc-plugins: make it possible to disable CONFIG_GCC_PLUGINS
  again (bcs#1181862).
- kbuild: change *FLAGS_<basetarget>.o to take the path relative
  to $(obj) (bcs#1181862).
- kbuild: Fail if gold linker is detected (bcs#1181862).
- commit 9094f62
* Fri Mar  5 2021 msuchanek@suse.de
- kbuild: simplify GCC_PLUGINS enablement in dummy-tools/gcc
  (bcs#1181862).
- commit 77ad0cc
* Fri Mar  5 2021 msuchanek@suse.de
- kbuild: add dummy toolchains to enable all cc-option etc. in
  Kconfig (bcs#1181862).
- Delete patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch.
- commit 928cf1d
* Fri Mar  5 2021 dwagner@suse.de
- wireguard: kconfig: use arm chacha even with no neon
  (git-fixes).
- wireguard: device: do not generate ICMP for non-IP packets
  (git-fixes).
- wireguard: selftests: test multiple parallel streams
  (git-fixes).
- crypto: Kconfig - CRYPTO_MANAGER_EXTRA_TESTS requires the
  manager (git-fixes).
- crypto: arm64/poly1305-neon - reorder PAC authentication with
  SP update (git-fixes).
- commit c931ac8
* Fri Mar  5 2021 mbenes@suse.cz
- objtool: Fix ".cold" section suffix check for newer versions
  of GCC (bsc#1169514).
- commit 4b4e63c
* Fri Mar  5 2021 msuchanek@suse.de
- ibmvnic: always store valid MAC address (bsc#1182011 ltc#191844).
- commit dbe1065
* Fri Mar  5 2021 jslaby@suse.cz
- rpm/check-for-config-changes: declare sed args as an array
  So that we can reuse it in both seds.
  This also introduces IGNORED_CONFIGS_RE array which can be easily
  extended.
- commit a1976d2
* Fri Mar  5 2021 tiwai@suse.de
- ALSA: hda/realtek: Apply dual codec quirks for MSI Godlike
  X570 board (git-fixes).
- ALSA: hda/realtek: Add quirk for Intel NUC 10 (git-fixes).
- ALSA: hda/realtek: Add quirk for Clevo NH55RZQ (git-fixes).
- ALSA: hda/realtek: Enable headset mic of Acer SWIFT with ALC256
  (git-fixes).
- commit acba99b
* Fri Mar  5 2021 tiwai@suse.de
- Move upstreamed USB-audio fixes into sorted section
- commit 28c79bd
* Fri Mar  5 2021 tiwai@suse.de
- ALSA: ctxfi: cthw20k2: fix mask on conf to allow 4 bits
  (git-fixes).
- certs: Fix blacklist flag type confusion (git-fixes).
- commit 83ee089
* Fri Mar  5 2021 jgross@suse.com
- xen-netback: respect gnttab_map_refs()'s return value
  (bsc#1183022 XSA-367).
- commit 5a927d9
* Fri Mar  5 2021 jgross@suse.com
- Xen/gnttab: handle p2m update errors on a per-slot basis
  (bsc#1183022 XSA-367).
- commit b394e32
* Thu Mar  4 2021 tiwai@suse.de
- watchdog: mei_wdt: request stop on unregister (git-fixes).
- commit 1de5431
* Thu Mar  4 2021 tiwai@suse.de
- pwm: rockchip: rockchip_pwm_probe(): Remove superfluous
  clk_unprepare() (git-fixes).
- PCI: qcom: Use PHY_REFCLK_USE_PAD only for ipq8064 (git-fixes).
- PCI: Align checking of syscall user config accessors
  (git-fixes).
- random: fix the RNDRESEEDCRNG ioctl (git-fixes).
- VMCI: Use set_page_dirty_lock() when unregistering guest memory
  (git-fixes).
- staging: rtl8188eu: Add Edimax EW-7811UN V2 to device table
  (git-fixes).
- USB: serial: option: update interface mapping for ZTE P685M
  (git-fixes).
- USB: serial: ftdi_sio: fix FTX sub-integer prescaler
  (git-fixes).
- usb: dwc3: gadget: Fix dep->interval for fullspeed interrupt
  (git-fixes).
- usb: dwc3: gadget: Fix setting of DEPCFG.bInterval_m1
  (git-fixes).
- commit b47408f
* Thu Mar  4 2021 tiwai@suse.de
- PCI: Decline to resize resources if boot config must be
  preserved (git-fixes).
- drivers/misc/vmw_vmci: restrict too big queue size in
  qp_host_alloc_queue (git-fixes).
- misc: rtsx: init of rts522a add OCP power off when no card is
  present (git-fixes).
- Input: i8042 - add ASUS Zenbook Flip to noselftest list
  (git-fixes).
- Input: raydium_ts_i2c - do not send zero length (git-fixes).
- Input: xpad - add support for PowerA Enhanced Wired Controller
  for Xbox Series X|S (git-fixes).
- mmc: sdhci-esdhc-imx: fix kernel panic when remove module
  (git-fixes).
- fbdev: aty: SPARC64 requires FB_ATY_CT (git-fixes).
- media: mceusb: Fix potential out-of-bounds shift (git-fixes).
- staging: gdm724x: Fix DMA from stack (git-fixes).
- commit 837d6c3
* Thu Mar  4 2021 tiwai@suse.de
- drm/msm/mdp5: Fix wait-for-commit for cmd panels (git-fixes).
- drm/msm/dsi: Correct io_start for MSM8994 (20nm PHY)
  (git-fixes).
- crypto: arm64/sha - add missing module aliases (git-fixes).
- crypto: bcm - Rename struct device_private to bcm_device_private
  (git-fixes).
- crypto: aesni - prevent misaligned buffers on the stack
  (git-fixes).
- drm/i915: Reject 446-480MHz HDMI clock on GLK (git-fixes).
- drm/nouveau/kms: handle mDP connectors (git-fixes).
- drm/sched: Cancel and flush all outstanding jobs before finish
  (git-fixes).
- commit d2c4de8
* Thu Mar  4 2021 jslaby@suse.cz
- rpm/check-for-config-changes: ignore more configs
  Specifially, these:
  * CONFIG_CC_HAS_*
  * CONFIG_CC_HAVE_*
  * CONFIG_CC_CAN_*
  * CONFIG_HAVE_[A-Z]*_COMPILER
  * CONFIG_TOOLS_SUPPORT_*
  are compiler specific too. This will allow us to use super configs
  using kernel's dummy-tools.
- commit d12dcbd
* Thu Mar  4 2021 mbenes@suse.cz
- objtool: Fix retpoline detection in asm code (bsc#1169514).
- commit 15a53c5
* Thu Mar  4 2021 msuchanek@suse.de
- ibmvnic: substitute mb() with dma_wmb() for send_*crq* functions
  (bsc#1183023 ltc#191791).
- ibmvnic: simplify reset_long_term_buff function (bsc#1183023
  ltc#191791).
- commit 0960b37
* Thu Mar  4 2021 pmladek@suse.com
- printk: fix deadlock when kernel panic (bsc#1183018).
- commit 5021e3a
* Thu Mar  4 2021 mbenes@suse.cz
- objtool: Fix error handling for STD/CLD warnings (bsc#1169514).
- commit fb7ed7c
* Thu Mar  4 2021 tiwai@suse.de
- ALSA: usb-audio: Apply the control quirk to Plantronics headsets
  (bsc#1182552).
- ALSA: usb-audio: Fix "cannot get freq eq" errors on Dell AE515
  sound bar (bsc#1182552).
- ALSA: usb-audio: Disable USB autosuspend properly in
  setup_disable_autosuspend() (bsc#1182552).
- commit a815647
* Thu Mar  4 2021 yousaf.kaukab@suse.com
- config: net: freescale: change xgmac-mdio to built-in
  References: bsc#1183015,bsc#1182595
- commit b29b589
* Wed Mar  3 2021 msuchanek@suse.de
- Refresh patches.suse/ibmvnic-Fix-possibly-uninitialized-old_num_tx_queues.patch.
  Update patch metadata
- commit d8a9644
* Wed Mar  3 2021 tiwai@suse.de
- ALSA: usb: Add Plantronics C320-M USB ctrl msg delay quirk
  (bsc#1182552).
- commit 0a8c8cf
* Wed Mar  3 2021 tiwai@suse.de
- exfat: add the dummy mount options to be backward compatible
  with staging/exfat (bsc#1182989).
- commit d7a202d
* Wed Mar  3 2021 tiwai@suse.de
- exfat: add missing MODULE_ALIAS_FS() (bsc#1182989).
- commit d9a7a48
* Wed Mar  3 2021 tbogendoerfer@suse.de
- ice: update the number of available RSS queues (jsc#SLE-7926).
- ice: Fix state bits on LLDP mode switch (jsc#SLE-7926).
- net/mlx5: Disable devlink reload for lag devices (jsc#SLE-8464).
- ice: renegotiate link after FW DCB on (jsc#SLE-8464).
- commit 51a1824
* Wed Mar  3 2021 jslaby@suse.cz
- kbuild: dummy-tools, fix inverted tests for gcc (bcs#1181862).
- commit e90afb3
* Wed Mar  3 2021 tbogendoerfer@suse.de
- ice: report correct max number of TCs (jsc#SLE-7926).
- RDMA/hns: Disable RQ inline by default (jsc#SLE-8449).
- RDMA/hns: Fix type of sq_signal_bits (jsc#SLE-8449).
- net/mlx5: Disallow RoCE on lag device (jsc#SLE-8464).
- net/mlx5: Disallow RoCE on multi port slave device
  (jsc#SLE-8464).
- net/mlx5: Disable devlink reload for multi port slave device
  (jsc#SLE-8464).
- net/mlx5e: E-switch, Fix rate calculation for overflow
  (jsc#SLE-8464).
- commit 5c94309
* Wed Mar  3 2021 tiwai@suse.de
- ALSA: usb-audio: Drop bogus dB range in too low level
  (bsc#1182552).
- ALSA: usb-audio: Don't abort even if the clock rate differs
  (bsc#1182552).
- ALSA: usb-audio: Allow modifying parameters with succeeding
  hw_params calls (bsc#1182552).
- commit 037cfcf
* Wed Mar  3 2021 dfaggioli@suse.com
- KVM: x86: Add RIP to the kvm_entry, i.e. VM-Enter, tracepoint
  Needed as a dependency of 0b40723a827 ("kvm: tracing: Fix unmatched
  kvm_entry and kvm_exit events", bsc#1182770).
- commit bca7352
* Tue Mar  2 2021 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section
  patches.suse/ibmvnic-Fix-possibly-uninitialized-old_num_tx_queues.patch
- commit be18357
* Tue Mar  2 2021 mkubecek@suse.cz
- Update kabi files.
- update from March 2021 maintenance update submission (commit c35b1245712f)
- commit ebf0b27
* Tue Mar  2 2021 msuchanek@suse.de
- ibmvnic: Fix possibly uninitialized old_num_tx_queues variable
  warning (jsc#SLE-17268).
- commit 2b2d062
* Tue Mar  2 2021 mbenes@suse.cz
- blacklist.conf: c7ff651960a6 ("blktrace: fix blk_rq_issue documentation")
  Cosmetic.
- commit ee4b49c
* Tue Mar  2 2021 mbenes@suse.cz
- blacklist.conf: 179d16007236 ("block: remove superfluous param in blk_fill_rwbs()")
  Cleanup only.
- commit ed3c6d0
* Tue Mar  2 2021 jgross@suse.com
- kernel/smp: add more data to CSD lock debugging (bsc#1180846).
- commit 08badc9
* Tue Mar  2 2021 jgross@suse.com
- kernel/smp: prepare more CSD lock debugging (bsc#1180846).
- commit d717867
* Tue Mar  2 2021 jgross@suse.com
- Update config files: activate CONFIG_CSD_LOCK_WAIT_DEBUG for x86 (bsc#1180846).
- commit f88a325
* Tue Mar  2 2021 jgross@suse.com
- kernel/smp: add boot parameter for controlling CSD lock
  debugging (bsc#1180846).
- commit fb4cf71
* Tue Mar  2 2021 jgross@suse.com
- kernel/smp: Provide CSD lock timeout diagnostics (bsc#1180846).
- update config files (CSD_LOCK_WAIT_DEBUG=n)
- commit 59bec34
* Tue Mar  2 2021 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ibmvnic-fix-a-race-between-open-and-reset.patch
- commit 9ab8f38
* Tue Mar  2 2021 jgross@suse.com
- kABI: Fix kABI after modifying struct __call_single_data
  (bsc#1180846).
- commit 3c0b378
* Tue Mar  2 2021 mkubecek@suse.cz
- series.conf: cleanup
- move submitted patches to appropriate section:
  patches.suse/btrfs-free-correct-amount-of-space-in-btrfs_delayed_inode_reserve_metadata.patch
  patches.suse/btrfs-don-t-flush-from-btrfs_delayed_inode_reserve_metadata.patch
  patches.suse/btrfs-cleanup-try_flush_qgroup.patch
  patches.suse/btrfs-remove-btrfs_inode-from-btrfs_delayed_inode_reserve_metadata.patch
  patches.suse/btrfs-simplify-code-flow-in-btrfs_delayed_inode_reserve_metadata.patch
  patches.suse/btrfs-unlock-extents-in-btrfs_zero_range-in-case-of-errors.patch
  (no effect on expanded tree)
- commit d631784
* Tue Mar  2 2021 jgross@suse.com
- smp: Add source and destination CPUs to __call_single_data
  (bsc#1180846).
- commit 10244d3
* Mon Mar  1 2021 msuchanek@suse.de
- powerpc/numa: Fix build when CONFIG_NUMA=n (bsc#1132477
  ltc#175530).
- commit 2b8436c
* Mon Mar  1 2021 msuchanek@suse.de
- pseries/hotplug-memory: hot-add: skip redundant LMB lookup (bsc#1132477 ltc#175530).
- Refresh patches.suse/powerpc-pseries-group-lmb-operation-and-memblock-s.patch.
- commit 5c9ac54
* Mon Mar  1 2021 msuchanek@suse.de
- powerpc/pseries: Don't enforce MSI affinity with kdump
  (bsc#1181655 ltc#190855).
- commit 1c51dbc
* Mon Mar  1 2021 msuchanek@suse.de
- pseries/drmem: don't cache node id in drmem_lmb struct (bsc#1132477 ltc#175530).
- Refresh patches.suse/powerpc-pseries-group-lmb-operation-and-memblock-s.patch.
- Refresh patches.suse/powerpc-pseries-update-device-tree-before-ejecting-h.patch.
- commit 23f514c
* Mon Mar  1 2021 palcantara@suse.de
- cifs: fix nodfs mount option (bsc#1181710).
- commit 94844a1
* Mon Mar  1 2021 palcantara@suse.de
- cifs: introduce helper for finding referral server
  (bsc#1181710).
- commit f74681b
* Mon Mar  1 2021 palcantara@suse.de
- cifs: check all path components in resolved dfs target
  (bsc#1181710).
- commit 91cd435
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: gemini: Fix missing clk_disable_unprepare() in error path of gemini_ethernet_port_probe() (git-fixes).
- commit 401e086
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: nixge: fix potential memory leak in nixge_probe() (git-fixes).
- commit cdc643b
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: hns3: fix for VLAN config when reset failed (git-fixes).
- commit 4209fa0
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: hns3: add reset check for VF updating port based VLAN
  (git-fixes).
- commit 9609b2a
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: ethernet: ave: Fix error returns in ave_init (git-fixes).
- commit 166a8fe
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: ag71xx: add missed clk_disable_unprepare in error path
  of probe (git-fixes).
- commit cead210
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: smc91x: Fix possible memory leak in smc_drv_probe()
  (git-fixes).
- commit 342b694
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: macb: fix call to pm_runtime in the suspend/resume
  functions (git-fixes).
- commit e7fb27b
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: macb: mark device wake capable when "magic-packet"
  property present (git-fixes).
- commit 3e9fa11
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: macb: fix wakeup test in runtime suspend/resume routines
  (git-fixes).
- commit 0dfe6dc
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: hns3: fix for mishandle of asserting VF reset fail
  (git-fixes).
- commit 0c2ca01
* Mon Mar  1 2021 denis.kirjanov@suse.com
- smsc95xx: avoid memory leak in smsc95xx_bind (git-fixes).
- commit 11f5fde
* Mon Mar  1 2021 denis.kirjanov@suse.com
- smsc95xx: check return value of smsc95xx_reset (git-fixes).
- commit 02e26ea
* Mon Mar  1 2021 denis.kirjanov@suse.com
- net: bcmgenet: use hardware padding of runt frames (git-fixes).
- commit b2f215a
* Mon Mar  1 2021 msuchanek@suse.de
- powerpc/pseries/ras: Make init_ras_hotplug_IRQ() static
  (FATE#322022, bsc#1065729. git-fixes).
- powerpc/pseries/eeh: Make pseries_pcibios_bus_add_device()
  static (FATE#324970, bsc#1078720, git-fixes).
- commit 5742f0f
* Mon Mar  1 2021 lhenriques@suse.de
- docs: filesystems: vfs: correct flag name (bsc#1182856).
- commit 969c3e4
* Mon Mar  1 2021 lhenriques@suse.de
- blacklist.conf: d0995b53130e f2fs: add missing documents of reserve_root/resuid/resgid
- commit 95579b0
* Mon Mar  1 2021 lhenriques@suse.de
- ceph: fix flush_snap logic after putting caps (bsc#1182854).
- commit eacaa0a
* Mon Mar  1 2021 ohering@suse.de
- Drivers: hv: vmbus: Avoid use-after-free in vmbus_onoffer_rescind() (git-fixes).
- commit a24afd4
* Mon Mar  1 2021 tiwai@suse.de
- i2c: brcmstb: Fix brcmstd_send_i2c_cmd condition (git-fixes).
- HID: make arrays usage and value to be the same (git-fixes).
- usb: quirks: add quirk to start video capture on ELMO L-12F
  document camera reliable (git-fixes).
- USB: quirks: sort quirk entries (git-fixes).
- NET: usb: qmi_wwan: Adding support for Cinterion MV31
  (git-fixes).
- commit ae76757
* Sun Feb 28 2021 mkubecek@suse.cz
- misc: eeprom_93xx46: Add module alias to avoid breaking support
  for non device tree users (git-fixes).
- commit 761c100
* Sun Feb 28 2021 mkubecek@suse.cz
- config: refresh
  Previous armv7hl config update was done with gcc9 which may result in
  different config in general. Fortunately it was not the case here but we
  need to restore the header and CONFIG_GCC_VERSION value.
- commit 31d864a
* Fri Feb 26 2021 dfaggioli@suse.com
- KVM: x86: Gracefully handle __vmalloc() failure during VM allocation
  (bsc#1182801).
- commit 2b89cec
* Fri Feb 26 2021 dfaggioli@suse.com
- KVM: x86: Allocate new rmap and large page tracking when moving memslot
  (bsc#1182800).
- commit 4ea5d1c
* Fri Feb 26 2021 dfaggioli@suse.com
- KVM: VMX: Condition ENCLS-exiting enabling on CPU support for SGX1
  (bsc#1182798).
- commit 41a7998
* Fri Feb 26 2021 denis.kirjanov@suse.com
- net: phy: marvell10g: fix null pointer dereference (git-fixes).
- commit ba9ce5a
* Fri Feb 26 2021 denis.kirjanov@suse.com
- net: bcmgenet: re-remove bcmgenet_hfb_add_filter (git-fixes).
- commit 46d342e
* Thu Feb 25 2021 msuchanek@suse.de
- Cherry-pick ibmvnic patches from SP3 (jsc#SLE-17268).
- commit fc08b49
* Thu Feb 25 2021 dfaggioli@suse.com
- kvm: tracing: Fix unmatched kvm_entry and kvm_exit events
  (bsc#1182770).
- commit 0b40723
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: dsa: lantiq_gswip: fix and improve the unsupported
  interface error (git-fixes).
- commit 966d874
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: octeon: mgmt: Repair filling of RX ring (git-fixes).
- commit a1726f7
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: dsa: mt7530: set CPU port to fallback mode (git-fixes).
- commit 7c6d69a
* Thu Feb 25 2021 denis.kirjanov@suse.com
- drivers: net: davinci_mdio: fix potential NULL dereference in
  davinci_mdio_probe() (git-fixes).
- commit aad32ea
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: lpc-enet: fix error return code in lpc_mii_init()
  (git-fixes).
- commit 023e4aa
* Thu Feb 25 2021 denis.kirjanov@suse.com
- Revert "net: bcmgenet: remove unused function in bcmgenet.c"
  (git-fixes).
- commit 6e0622b
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: bcmgenet: Fix WoL with password after deep sleep
  (git-fixes).
- commit 8a76658
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: bcmgenet: set Rx mode before starting netif (git-fixes).
- commit 95bbb6f
* Thu Feb 25 2021 denis.kirjanov@suse.com
- net: phy: marvell10g: fix temperature sensor on 2110
  (git-fixes).
- commit 80b675a
* Thu Feb 25 2021 msuchanek@suse.de
- net: re-solve some conflicts after net -> net-next merge
  (bsc#1176855 ltc#187293).
- commit 1277782
* Thu Feb 25 2021 msuchanek@suse.de
- ibmvnic: fix a race between open and reset (bsc#1176855
  ltc#187293).
- commit 1d1c0f0
* Thu Feb 25 2021 mbrugger@suse.com
- armv7hl: lpae: Update config files.
  Disable KVM support (bsc#1182697)
- commit d0fa566
* Thu Feb 25 2021 tiwai@suse.de
- phy: rockchip-emmc: emmc_phy_init() always return 0 (git-fixes).
- mei: hbm: call mei_set_devstate() on hbm stop response
  (git-fixes).
- virt: vbox: Do not use wait_event_interruptible when called
  from kernel context (git-fixes).
- misc: eeprom_93xx46: Fix module alias to enable module autoprobe
  (git-fixes).
- commit f380250
* Wed Feb 24 2021 colyli@suse.de
- dm: fix bio splitting and its bio completion order for regular
  IO (git-fixes).
- bcache: fix overflow in offset_to_stripe() (git-fixes).
- dm crypt: avoid truncating the logical block size (git-fixes).
- include/linux/memremap.h: remove stale comments (git-fixes).
- commit f9b0dc3
* Wed Feb 24 2021 mkoutny@suse.com
- blacklist.conf: Add 8faeb1ffd795 mm: memcg/slab: fix root memcg vmstats
- commit 6424df5
* Wed Feb 24 2021 mkoutny@suse.com
- blacklist:conf: Add 67197a4f28d2 mm, oom_adj: don't loop through tasks in __set_oom_adj when not necessary
- commit c6bc092
* Wed Feb 24 2021 mkoutny@suse.com
- cgroup: fix psi monitor for root cgroup (bsc#1182686).
- commit 248e7d8
* Wed Feb 24 2021 mkoutny@suse.com
- cgroup-v1: add disabled controller check in
  cgroup1_parse_param() (bsc#1182684).
- commit 511e4ac
* Wed Feb 24 2021 mkoutny@suse.com
- cgroup: Fix memory leak when parsing multiple source parameters
  (bsc#1182683).
- commit 6c8979b
* Wed Feb 24 2021 mkoutny@suse.com
- cpuset: fix race between hotplug work and later CPU offline
  (bsc#1182676).
- commit dfdcc97
* Wed Feb 24 2021 msuchanek@suse.de
- macros.kernel-source: Use spec_install_pre for certificate installation (boo#1182672).
  Since rpm 4.16 files installed during build phase are lost.
- commit d0b887e
* Wed Feb 24 2021 msuchanek@suse.de
- Refresh patches.suse/powerpc-Fix-build-error-in-paravirt.h.patch.
  Update patch metadata.
- commit ca12b41
* Wed Feb 24 2021 jack@suse.cz
- quota: Fix memory leak when handling corrupted quota file
  (bsc#1182650).
- commit 2543668
* Wed Feb 24 2021 tiwai@suse.de
- dmaengine: hsu: disable spurious interrupt (git-fixes).
- dmaengine: owl-dma: Fix a resource leak in the remove function
  (git-fixes).
- dmaengine: fsldma: Fix a resource leak in an error handling
  path of the probe function (git-fixes).
- dmaengine: fsldma: Fix a resource leak in the remove function
  (git-fixes).
- Input: joydev - prevent potential read overflow in ioctl
  (git-fixes).
- Input: elo - fix an error code in elo_connect() (git-fixes).
- Input: sur40 - fix an error code in sur40_probe() (git-fixes).
- HID: core: detect and skip invalid inputs to snto32()
  (git-fixes).
- HID: wacom: Ignore attempts to overwrite the touch_max value
  from HID (git-fixes).
- commit 9e6160a
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Unlock extents in btrfs_zero_range in case of errors (bsc#1182047).
- commit bd5a9b2
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Simplify code flow in btrfs_delayed_inode_reserve_metadata (bsc#1182047).
- commit bf6dd14
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Remove btrfs_inode from btrfs_delayed_inode_reserve_metadata (bsc#1182047).
- commit fb6d272
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Cleanup try_flush_qgroup (bsc#1182047).
- commit 13881b3
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Don't flush from btrfs_delayed_inode_reserve_metadata (bsc#1182047).
- commit 942f628
* Wed Feb 24 2021 nborisov@suse.com
- btrfs: Free correct amount of space in btrfs_delayed_inode_reserve_metadata (bsc#1182047).
- commit 22ecef4
* Wed Feb 24 2021 fweisbecker@suse.de
- rcu/nocb: Trigger self-IPI on late deferred wake up before (git-fixes)
- commit 260172d
* Wed Feb 24 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/powerpc-perf-hv-24x7-Dont-create-sysfs-event-files-f.patch
  patches.suse/powerpc-pseries-dlpar-handle-ibm-configure-connector.patch
  patches.suse/scsi-lpfc-Enhancements-to-LOG_TRACE_EVENT-for-better.patch
  patches.suse/scsi-lpfc-Fix-FW-reset-action-if-I-Os-are-outstandin.patch
  patches.suse/scsi-lpfc-Fix-NVMe-recovery-after-mailbox-timeout.patch
  patches.suse/scsi-lpfc-Fix-PLOGI-S_ID-of-0-on-pt2pt-config.patch
  patches.suse/scsi-lpfc-Fix-auto-sli_mode-and-its-effect-on-CONFIG.patch
  patches.suse/scsi-lpfc-Fix-crash-when-a-fabric-node-is-released-p.patch
  patches.suse/scsi-lpfc-Fix-crash-when-nvmet-transport-calls-host_.patch
  patches.suse/scsi-lpfc-Fix-error-log-messages-being-logged-follow.patch
  patches.suse/scsi-lpfc-Fix-target-reset-failing.patch
  patches.suse/scsi-lpfc-Fix-vport-create-logging.patch
  patches.suse/scsi-lpfc-Implement-health-checking-when-aborting-I-.patch
  patches.suse/scsi-lpfc-Prevent-duplicate-requests-to-unregister-w.patch
  patches.suse/scsi-lpfc-Refresh-ndlp-when-a-new-PRLI-is-received-i.patch
  patches.suse/scsi-lpfc-Simplify-bool-comparison.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.7.patch
  patches.suse/scsi-lpfc-Use-the-nvme-fc-transport-supplied-timeout.patch
- commit ff0a90f
* Wed Feb 24 2021 fweisbecker@suse.de
- rcu/nocb: Perform deferred wake up before last idle's (git-fixes)
- commit f0bc502
* Wed Feb 24 2021 fweisbecker@suse.de
- rcu: Pull deferred rcuog wake up to rcu_eqs_enter() callers (git-fixes)
- commit 7a90fca
* Wed Feb 24 2021 fweisbecker@suse.de
- sched: Reenable interrupts in do_sched_yield() (git-fixes)
- commit 579dc67
* Tue Feb 23 2021 fdmanana@suse.com
- btrfs: run delayed iputs when remounting RO to avoid leaking
  them (bsc#1182626).
- btrfs: add assertion for empty list of transactions at late
  stage of umount (bsc#1182626).
- btrfs: fix race between RO remount and the cleaner task
  (bsc#1182626).
- btrfs: fix transaction leak and crash after cleaning up orphans
  on RO mount (bsc#1182626).
- btrfs: fix transaction leak and crash after RO remount caused
  by qgroup rescan (bsc#1182626).
- btrfs: lift read-write mount setup from mount and remount
  (bsc#1182626).
- commit 2361750
* Tue Feb 23 2021 jdelvare@suse.de
- arm64: Update config file.
  Set CONFIG_WATCHDOG_SYSFS to true (bsc#1182560)
- commit 0c02797
* Tue Feb 23 2021 pmladek@suse.com
- blacklist.conf: printk: not critical; allow to use the full buffer
  when using log dumpers
- commit 4e198dc
* Tue Feb 23 2021 msuchanek@suse.de
- Remove debug patch for boot failure (bsc#1182602 ltc#190924).
  Delete patches.suse/prom_init-enable-varbose-prints-bsc-1178142.patch.
- commit 55e7bdd
* Tue Feb 23 2021 ddiss@suse.de
- Update upstream reference and move into sorted section:
  patches.suse/target-fix-XCOPY-NAA-identifier-lookup.patch
- commit e8f510f
* Tue Feb 23 2021 ddiss@suse.de
- target: disallow emulate_legacy_capacity with RBD object-map
  (bsc#1177109).
- commit 9e5609a
* Tue Feb 23 2021 msuchanek@suse.de
- powerpc/prom: Fix "ibm,arch-vec-5-platform-support" scan
  (bsc#1182602 ltc#190924).
- commit f6d197a
* Tue Feb 23 2021 pmladek@suse.com
- lib/vsprintf: no_hash_pointers prints all addresses as unhashed
  (bsc#1182599).
- commit f0a1f3e
* Tue Feb 23 2021 tiwai@suse.de
- drm/amd/display: Fix HDMI deep color output for DCE 6-11
  (git-fixes).
- drm/amd/display: Fix 10/12 bpc setup in DCE output bit depth
  reduction (git-fixes).
- drm/amdgpu: Fix macro name _AMDGPU_TRACE_H_ in preprocessor
  if condition (git-fixes).
- gma500: clean up error handling in init (git-fixes).
- commit af18775
* Tue Feb 23 2021 tiwai@suse.de
- rtc: s5m: select REGMAP_I2C (git-fixes).
- spi: stm32: properly handle 0 byte transfer (git-fixes).
- spi: atmel: Put allocated master before return (git-fixes).
- spi: pxa2xx: Fix the controller numbering for Wildcat Point
  (git-fixes).
- spi: spi-synquacer: fix set_cs handling (git-fixes).
- regulator: core: Avoid debugfs: Directory ... already
  present! error (git-fixes).
- crypto: ecdh_helper - Ensure 'len >= secret.len' in decode_key()
  (git-fixes).
- crypto: talitos - Work around SEC6 ERRATA (AES-CTR mode data
  size error) (git-fixes).
- cpufreq: brcmstb-avs-cpufreq: Fix resource leaks in ->remove()
  (git-fixes).
- cpufreq: brcmstb-avs-cpufreq: Free resources in error path
  (git-fixes).
- commit fbcd516
* Tue Feb 23 2021 tiwai@suse.de
- power: reset: at91-sama5d2_shdwc: fix wkupdbc mask (git-fixes).
- regulator: s5m8767: Drop regulators OF node reference
  (git-fixes).
- regulator: s5m8767: Fix reference count leak (git-fixes).
- regulator: axp20x: Fix reference cout leak (git-fixes).
- mmc: renesas_sdhi_internal_dmac: Fix DMA buffer alignment from
  8 to 128-bytes (git-fixes).
- mmc: usdhi6rol0: Fix a resource leak in the error handling
  path of the probe (git-fixes).
- mmc: sdhci-sprd: Fix some resource leaks in the remove function
  (git-fixes).
- Revert "platform/x86: ideapad-laptop: Switch touchpad attribute
  to be RO" (git-fixes).
- commit 6d58f6a
* Tue Feb 23 2021 tiwai@suse.de
- gpio: pcf857x: Fix missing first interrupt (git-fixes).
- i3c: master: dw: Drop redundant disec call (git-fixes).
- linux/clk.h: use correct kernel-doc notation for 2 functions
  (git-fixes).
- mfd: wm831x-auxadc: Prevent use after free in
  wm831x_auxadc_read_irq() (git-fixes).
- mfd: bd9571mwv: Use devm_mfd_add_devices() (git-fixes).
- i2c: iproc: update slave isr mask (ISR_MASK_SLAVE) (git-fixes).
- i2c: iproc: handle only slave interrupts which are enabled
  (git-fixes).
- drm/fb-helper: Add missed unlocks in setcmap_legacy()
  (git-fixes).
- drm/gma500: Fix error return code in psb_driver_load()
  (git-fixes).
- commit e10cc76
* Tue Feb 23 2021 tiwai@suse.de
- amba: Fix resource leak for drivers without .remove (git-fixes).
- clocksource/drivers/ixp4xx: Select TIMER_OF when needed
  (git-fixes).
- clk: qcom: gcc-msm8998: Fix Alpha PLL type for all GPLLs
  (git-fixes).
- clk: meson: clk-pll: propagate the error from
  meson_clk_pll_set_rate() (git-fixes).
- clk: meson: clk-pll: make "ret" a signed integer (git-fixes).
- clk: meson: clk-pll: fix initializing the old rate (fallback)
  for a PLL (git-fixes).
- clk: sunxi-ng: h6: Fix clock divider range on some clocks
  (git-fixes).
- clk: sunxi-ng: h6: Fix CEC clock (git-fixes).
- auxdisplay: ht16k33: Fix refresh rate handling (git-fixes).
- commit 447d390
* Tue Feb 23 2021 colyli@suse.de
- libnvdimm/dimm: Avoid race between probe and
  available_slots_show() (bsc#1170442).
- Use the above upstream patch to replace the following in-house patch,
  patches.suse/nvdimm-Avoid-race-between-probe-and-reading-device-a.patch.
- commit ef2652a
* Tue Feb 23 2021 colyli@suse.de
- dm thin metadata: Fix use-after-free in dm_bm_set_read_only
  (bsc#1177529).
- dm thin metadata:  Avoid returning cmd->bm wild pointer on error
  (bsc#1177529).
- dm: use noio when sending kobject event (bsc#1177529).
- dm thin metadata: fix lockdep complaint (bsc#1177529).
- dm thin: fix use-after-free in metadata_pre_commit_callback
  (bsc#1177529).
- commit 3e2b6d9
* Tue Feb 23 2021 colyli@suse.de
- blacklist.conf: remove the following lines because it is time to have
  them now,
- a4a8d286586d4b28c8517a51db8d86954aadc74b
- 3918e0667bbac99400b44fa5aef3f8be2eeada4a
- commit e7046a1
* Tue Feb 23 2021 dfaggioli@suse.com
- KVM: nVMX: Handle pending #DB when injecting INIT VM-exit.
  Pulling in as a dependency of: "KVM: nVMX: Emulate MTF when performing
  instruction emulation" (bsc#1182380).
- commit df4cbaa
* Mon Feb 22 2021 aaptel@suse.com
- cifs: report error instead of invalid when revalidating a
  dentry fails (bsc#1177440).
- commit 2c3b276
* Mon Feb 22 2021 msuchanek@suse.de
- powerpc/book3s64/hash: Add cond_resched to avoid soft lockup
  warning (bsc#1182571 ltc#191345).
- commit a9f0cef
* Mon Feb 22 2021 tbogendoerfer@suse.de
- RDMA/efa: Use the correct current and new states in modify QP
  (git-fixes).
- commit f2d6e28
* Mon Feb 22 2021 denis.kirjanov@suse.com
- net: rmnet: do not allow to add multiple bridge interfaces
  (git-fixes).
- commit 4f39a57
* Mon Feb 22 2021 denis.kirjanov@suse.com
- net: rmnet: fix lower interface leak (git-fixes).
- commit d007718
* Mon Feb 22 2021 denis.kirjanov@suse.com
- net: rmnet: print error message when command fails (git-fixes).
- commit 9543352
* Mon Feb 22 2021 denis.kirjanov@suse.com
- net: qualcomm: rmnet: Allow configuration updates to existing
  devices (git-fixes).
- commit 8b01fa7
* Mon Feb 22 2021 denis.kirjanov@suse.com
- blacklist.conf: update the blacklist
- commit a0ee69e
* Mon Feb 22 2021 bp@suse.de
- x86/alternatives: Sync bp_patching update for avoiding NULL
  pointer exception (bsc#1152489).
- commit 8753fb5
* Mon Feb 22 2021 msuchanek@suse.de
- ibmvnic: Set to CLOSED state even on error (bsc#1084610
  ltc#165122 git-fixes).
- commit 7047a5a
* Mon Feb 22 2021 msuchanek@suse.de
- ibmvnic: serialize access to work queue on remove (bsc#1065729).
- commit 9671154
* Mon Feb 22 2021 msuchanek@suse.de
- mm: proc: Invalidate TLB after clearing soft-dirty page state
  (bsc#1163776 ltc#183929 git-fixes).
- commit c6ee8b1
* Mon Feb 22 2021 ailiop@suse.com
- xfs: reduce quota reservation when doing a dax unwritten extent
  conversion (git-fixes bsc#1182561).
- commit 229a330
* Mon Feb 22 2021 tbogendoerfer@suse.de
- RDMA/efa: Drop double zeroing for sg_init_table() (bsc#1176248).
- RDMA/efa: Remove redundant udata check from alloc ucontext
  response (bsc#1176248).
- RDMA/efa: Add EFA 0xefa1 PCI ID (bsc#1176248).
- RDMA/efa: User/kernel compatibility handshake mechanism
  (bsc#1176248).
- RDMA/efa: Expose minimum SQ size (bsc#1176248).
- RDMA/efa: Expose maximum TX doorbell batch (bsc#1176248).
- RDMA/efa: Report host information to the device (bsc#1176248).
- RDMA/efa: Fix setting of wrong bit in get/set_feature commands
  (bsc#1176248).
- RDMA/efa: Count admin commands errors (bsc#1176248).
- RDMA/efa: Count mmap failures (bsc#1176248).
- RDMA/efa: Report create CQ error counter (bsc#1176248).
- RDMA/efa: Use in-kernel offsetofend() to check field
  availability (bsc#1176248).
- RDMA/efa: Do not delay freeing of DMA pages (bsc#1176248).
- RDMA/efa: Properly document the interrupt mask register
  (bsc#1176248).
- RDMA/efa: Unified getters/setters for device structs bitmask
  access (bsc#1176248).
- commit f3e9801
* Mon Feb 22 2021 ailiop@suse.com
- xfs: fix an ABBA deadlock in xfs_rename (git-fixes bsc#1182558).
- commit 2a9e635
* Mon Feb 22 2021 tbogendoerfer@suse.de
- vmxnet3: Remove buf_info from device accessible structures
  (bsc#1181671).
- commit 7e4ecda
* Mon Feb 22 2021 dwagner@suse.de
- nvmet-tcp: Fix NULL dereference when a connect data comes in
  h2cdata pdu (bsc#1182547).
- commit 62bcd4c
* Mon Feb 22 2021 msuchanek@suse.de
- rpm/kernel-subpackage-build: Workaround broken bot
  (https://github.com/openSUSE/openSUSE-release-tools/issues/2439)
- commit b74d860
* Mon Feb 22 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/nvme-hwmon-rework-to-avoid-devm-allocation.patch
  patches.suse/perf-x86-intel-uncore-Store-the-logical-die-id-inste.patch
  patches.suse/perf-x86-intel-uncore-With-8-nodes-get-pci-bus-die-i.patch
- commit f696cf9
* Mon Feb 22 2021 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section
  patches.suse/mm-pmem-avoid-inserting-hugepage-pte-entry-with-fsdax-if-hugepage-support-is-disabled.patch
- commit b1cf681
* Mon Feb 22 2021 tiwai@suse.de
- ALSA: usb-audio: Add implicit fb quirk for BOSS GP-10
  (git-fixes).
- ALSA: hda: Add another CometLake-H PCI ID (git-fixes).
- ALSA: hda/hdmi: Drop bogus check at closing a stream
  (git-fixes).
- ALSA: hda/realtek: modify EAPD in the ALC886 (git-fixes).
- commit d3cd0e8
* Mon Feb 22 2021 tiwai@suse.de
- tpm: Remove tpm_dev_wq_lock (git-fixes).
- tpm_tis: Clean up locality release (git-fixes).
- tpm_tis: Fix check_locality for correct locality acquisition
  (git-fixes).
- USB: serial: mos7720: fix error code in mos7720_write()
  (git-fixes).
- USB: serial: mos7840: fix error code in mos7840_write()
  (git-fixes).
- USB: serial: mos7720: improve OOM-handling in read_mos_reg()
  (git-fixes).
- usb: musb: Fix runtime PM race in musb_queue_resume_work
  (git-fixes).
- usb: dwc2: Make "trimming xfer length" a debug message
  (git-fixes).
- usb: dwc2: Abort transaction after errors with unknown reason
  (git-fixes).
- usb: dwc2: Do not update data length if it is 0 on inbound
  transfers (git-fixes).
- usb: gadget: u_audio: Free requests only after callback
  (git-fixes).
- commit 024918e
* Mon Feb 22 2021 tiwai@suse.de
- hwrng: timeriomem - Fix cooldown period calculation (git-fixes).
- media: pxa_camera: declare variable when DEBUG is defined
  (git-fixes).
- media: cx25821: Fix a bug when reallocating some dma memory
  (git-fixes).
- media: qm1d1c0042: fix error return code in qm1d1c0042_init()
  (git-fixes).
- media: lmedm04: Fix misuse of comma (git-fixes).
- media: software_node: Fix refcounts in
  software_node_get_next_child() (git-fixes).
- media: aspeed: fix error return code in
  aspeed_video_setup_video() (git-fixes).
- media: pwc: Use correct device for DMA (bsc#1181133).
- media: tm6000: Fix memleak in tm6000_start_stream (git-fixes).
- media: media/pci: Fix memleak in empress_init (git-fixes).
- media: em28xx: Fix use-after-free in em28xx_alloc_urbs
  (git-fixes).
- media: vsp1: Fix an error handling path in the probe function
  (git-fixes).
- media: camss: missing error code in msm_video_register()
  (git-fixes).
- media: mt9v111: Remove unneeded device-managed puts (git-fixes).
- media: ipu3-cio2: Fix mbus_code processing in
  cio2_subdev_set_fmt() (git-fixes).
- media: i2c: ov5670: Fix PIXEL_RATE minimum value (git-fixes).
- ata: ahci_brcm: Add back regulators management (git-fixes).
- staging: rtl8723bs: wifi_regd.c: Fix incorrect number of
  regulatory rules (git-fixes).
- ata: sata_nv: Fix retrieving of active qcs (git-fixes).
- commit f91a4d1
* Mon Feb 22 2021 tiwai@suse.de
- ASoC: simple-card-utils: Fix device module clock (git-fixes).
- ASoC: cs42l56: fix up error handling in probe (git-fixes).
- ASoC: SOF: debug: Fix a potential issue on string buffer
  termination (git-fixes).
- ASoC: cpcap: fix microphone timeslot mask (git-fixes).
- ALSA: pcm: Don't call sync_stop if it hasn't been stopped
  (git-fixes).
- ALSA: pcm: Assure sync with the pending stop operation at
  suspend (git-fixes).
- ALSA: pcm: Call sync_stop at disconnection (git-fixes).
- ALSA: usb-audio: Don't avoid stopping the stream at
  disconnection (git-fixes).
- ALSA: usb-audio: More strict state change in EP (git-fixes).
- ALSA: usb-audio: Handle invalid running state at releasing EP
  (git-fixes).
- ALSA: usb-audio: Fix PCM buffer allocation in non-vmalloc mode
  (git-fixes).
- ALSA: usb-audio: Correct document for
  snd_usb_endpoint_free_all() (git-fixes).
- ACPI: configfs: add missing check after
  configfs_register_default_group() (git-fixes).
- ACPI: property: Satisfy kernel doc validator (part 2)
  (git-fixes).
- ACPI: property: Satisfy kernel doc validator (part 1)
  (git-fixes).
- ACPI: property: Fix fwnode string properties matching
  (git-fixes).
- ACPICA: Fix exception code class checks (git-fixes).
- commit 858c1eb
* Mon Feb 22 2021 tiwai@suse.de
- Move upstreamed uvcvideo fix into sorted esction
- commit e05eaec
* Mon Feb 22 2021 jgross@suse.com
- xen-blkback: fix error handling in xen_blkbk_map() (XSA-365
  CVE-2021-26930 bsc#1181843).
- commit e27d769
* Mon Feb 22 2021 jgross@suse.com
- xen-scsiback: don't "handle" error by BUG() (XSA-362
  CVE-2021-26931 bsc#1181753).
- commit 0c27363
* Mon Feb 22 2021 jgross@suse.com
- xen-netback: don't "handle" error by BUG() (XSA-362
  CVE-2021-26931 bsc#1181753).
- commit b515e6e
* Mon Feb 22 2021 jgross@suse.com
- xen-blkback: don't "handle" error by BUG() (XSA-362
  CVE-2021-26931 bsc#1181753).
- commit 092d419
* Mon Feb 22 2021 jgross@suse.com
- xen/arm: don't ignore return errors from set_phys_to_machine
  (XSA-361 CVE-2021-26932 bsc#1181747).
- commit 3c70c9d
* Mon Feb 22 2021 jgross@suse.com
- Xen/gntdev: correct error checking in gntdev_map_grant_pages()
  (XSA-361 CVE-2021-26932 bsc#1181747).
- commit ee9fcdf
* Mon Feb 22 2021 jgross@suse.com
- Xen/gntdev: correct dev_bus_addr handling in
  gntdev_map_grant_pages() (XSA-361 CVE-2021-26932 bsc#1181747).
- commit e4d325f
* Mon Feb 22 2021 jgross@suse.com
- Xen/x86: also check kernel mapping in set_foreign_p2m_mapping()
  (XSA-361 CVE-2021-26932 bsc#1181747).
- commit c07de95
* Mon Feb 22 2021 jgross@suse.com
- Xen/x86: don't bail early from clear_foreign_p2m_mapping()
  (XSA-361 CVE-2021-26932 bsc#1181747).
- commit 488df4e
* Mon Feb 22 2021 jgross@suse.com
- xen/netback: fix spurious event detection for common event case
  (bsc#1182175).
- commit 1ecc6fe
* Sun Feb 21 2021 tiwai@suse.de
- soc: aspeed: snoop: Add clock control logic (git-fixes).
- memory: ti-aemif: Drop child node when jumping out loop
  (git-fixes).
- reset: hisilicon: correct vendor prefix (git-fixes).
- r8169: fix resuming from suspend on RTL8105e if machine runs
  on battery (git-fixes).
- b43: N-PHY: Fix the update of coef for the PHY revision >=
  3case (git-fixes).
- mac80211: fix potential overflow when multiplying to u32
  integers (git-fixes).
- ath9k: fix data bus crash when setting nf_override via debugfs
  (git-fixes).
- Bluetooth: btusb: Fix memory leak in btusb_mtk_wmt_recv
  (git-fixes).
- Bluetooth: Put HCI device if inquiry procedure interrupts
  (git-fixes).
- Bluetooth: drop HCI device reference before return (git-fixes).
- Bluetooth: Fix initializing response id after clearing struct
  (git-fixes).
- Bluetooth: hci_uart: Fix a race for write_work scheduling
  (git-fixes).
- Bluetooth: btqcomsmd: Fix a resource leak in error handling
  paths in the probe function (git-fixes).
- ath10k: Fix error handling in case of CE pipe init failure
  (git-fixes).
- commit 8d04463
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: dsa: bcm_sf2: Fix overflow checks (git-fixes).
- commit 8931641
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: bcmgenet: keep MAC in reset until PHY is up (git-fixes).
- commit 1bd8cc0
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: mscc: ocelot: properly account for VLAN header length when setting MRU (git-fixes).
- commit 8ecb099
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: fix packet forwarding in rmnet bridge mode (git-fixes).
- commit a6a4d18
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: fix bridge mode bugs (git-fixes).
- commit 6828c73
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: use upper/lower device infrastructure (git-fixes).
- commit 604e5d6
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: do not allow to change mux id if mux id is duplicated (git-fixes).
- commit 358ab29
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: remove rcu_read_lock in rmnet_force_unassociate_device() (git-fixes).
- commit 4387992
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: fix suspicious RCU usage (git-fixes).
- commit 5258625
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: fix NULL pointer dereference in rmnet_changelink() (git-fixes).
- commit 8bdc771
* Sat Feb 20 2021 denis.kirjanov@suse.com
- net: rmnet: fix NULL pointer dereference in rmnet_newlink() (git-fixes).
- commit e563469
* Fri Feb 19 2021 dfaggioli@suse.com
- KVM: x86: allow KVM_STATE_NESTED_MTF_PENDING in kvm_state flags
  (bsc#1182490).
- commit d0034b8
* Fri Feb 19 2021 dfaggioli@suse.com
- KVM: nVMX: don't clear mtf_pending when nested events are blocked
  (bsc#1182489).
- commit c9e5f4e
* Fri Feb 19 2021 msuchanek@suse.de
- ibmvnic: skip send_request_unmap for timeout reset (bsc#1182485
  ltc#191591).
- ibmvnic: add memory barrier to protect long term buffer
  (bsc#1182485 ltc#191591).
- ibmvnic: change IBMVNIC_MAX_IND_DESCS to 16 (bsc#1182485
  ltc#191591).
- ibmvnic: Ensure that CRQ entry read are correctly ordered
  (bsc#1182485 ltc#191591).
- commit 8ab7740
* Thu Feb 18 2021 dfaggioli@suse.com
- kABI: repair, after "nVMX: Emulate MTF when performinginstruction  emulation"
  kvm_x86_ops is part of kABI as it's used by LTTng. But it's only read
  and never allocated in there, so growing it (without altering existing
  members' offsets) is fine.
- commit d47d125
* Thu Feb 18 2021 jack@suse.cz
- fscrypt: rename DCACHE_ENCRYPTED_NAME to DCACHE_NOKEY_NAME
  (bsc#1182446).
- commit 8620c20
* Thu Feb 18 2021 jack@suse.cz
- fscrypt: add fscrypt_is_nokey_name() (bsc#1182446).
- commit da2337f
* Thu Feb 18 2021 jack@suse.cz
- patches.suse/ext4-Avoid-freeing-inodes-on-dirty-list.patch: Move to
  sorted section, update tags
- commit d9f0c0d
* Thu Feb 18 2021 jack@suse.cz
- fs: fix lazytime expiration handling in
  __writeback_single_inode() (bsc#1182466).
- commit a4f4504
* Thu Feb 18 2021 jack@suse.cz
- ext4: fix superblock checksum failure when setting password salt
  (bsc#1182465).
- commit 1201ea7
* Thu Feb 18 2021 jack@suse.cz
- ext4: don't remount read-only with errors=continue on reboot
  (bsc#1182464).
- commit d554ce9
* Thu Feb 18 2021 jack@suse.cz
- ext4: fix deadlock with fs freezing and EA inodes (bsc#1182463).
- commit 2354cfd
* Thu Feb 18 2021 jack@suse.cz
- reiserfs: add check for an invalid ih_entry_count (bsc#1182462).
- commit 2c4183a
* Thu Feb 18 2021 jack@suse.cz
- quota: Sanity-check quota file headers on load (bsc#1182461).
- commit 5a95e11
* Thu Feb 18 2021 jack@suse.cz
- writeback: Drop I_DIRTY_TIME_EXPIRE (bsc#1182460).
- commit 6f11bc3
* Thu Feb 18 2021 jack@suse.cz
- ubifs: Fix error return code in ubifs_init_authentication()
  (bsc#1182459).
- commit 97d2ec0
* Thu Feb 18 2021 jack@suse.cz
- ubifs: wbuf: Don't leak kernel memory to flash (bsc#1182458).
- commit bce8f1a
* Thu Feb 18 2021 jack@suse.cz
- ubifs: prevent creating duplicate encrypted filenames
  (bsc#1182457).
- commit 80e0969
* Thu Feb 18 2021 jack@suse.cz
- ubifs: ubifs_add_orphan: Fix a memory leak bug (bsc#1182456).
- commit bf8f1af
* Thu Feb 18 2021 jack@suse.cz
- ubifs: ubifs_jnl_write_inode: Fix a memory leak bug
  (bsc#1182455).
  patches.suse/ubifs-xattr-Fix-some-potential-memory-leaks-while-it.patch:
  Refresh and add now relevant bits.
- commit 0b538c3
* Thu Feb 18 2021 jack@suse.cz
- ubifs: Fix ubifs_tnc_lookup() usage in do_kill_orphans()
  (bsc#1182454).
- commit fdbb549
* Thu Feb 18 2021 jack@suse.cz
- ext4: fix bug for rename with RENAME_WHITEOUT (bsc#1182449).
- commit 5f81ca3
* Thu Feb 18 2021 jack@suse.cz
- ext4: fix a memory leak of ext4_free_data (bsc#1182447).
- commit 798e94c
* Thu Feb 18 2021 msuchanek@suse.de
- mm: thp: kABI: move the added flag to the end of enum
  (bsc#1181896 ltc#191273).
- commit 5a6cff9
* Thu Feb 18 2021 jack@suse.cz
- ext4: prevent creating duplicate encrypted filenames
  (bsc#1182446).
- commit ebbed3b
* Thu Feb 18 2021 jack@suse.cz
- block: fix inflight statistics of part0 (bsc#1182445).
- commit 3645427
* Thu Feb 18 2021 jack@suse.cz
- blk-mq: move cancel of hctx->run_work to the front of
  blk_exit_queue (bsc#1182444).
- commit 25d39da
* Thu Feb 18 2021 jack@suse.cz
- blk-mq: insert request not through ->queue_rq into sw/scheduler
  queue (bsc#1182443).
- commit a0c44a1
* Thu Feb 18 2021 jack@suse.cz
- blk-mq: call commit_rqs while list empty but error happen
  (bsc#1182442).
- commit bc0709b
* Thu Feb 18 2021 jack@suse.cz
- block: respect queue limit of max discard segment (bsc#1182441).
- commit 78f8ad6
* Thu Feb 18 2021 jack@suse.cz
- block: virtio_blk: fix handling single range discard request
  (bsc#1182439).
- commit a829826
* Thu Feb 18 2021 ailiop@suse.com
- xfs: fix the forward progress assertion in
  xfs_iwalk_run_callbacks (git-fixes bsc#1182430).
- commit 251c330
* Thu Feb 18 2021 tiwai@suse.de
- drm/amd/display: Decrement refcount of dc_sink before
  reassignment (git-fixes).
- drm/amd/display: Free atomic state after drm_atomic_commit
  (git-fixes).
- drm/amd/display: Fix dc_sink kref count in emulated_link_detect
  (git-fixes).
- commit 0a02ed8
* Thu Feb 18 2021 tiwai@suse.de
- clk: sunxi-ng: mp: fix parent rate change flag check
  (git-fixes).
- firmware_loader: align .builtin_fw to 8 (git-fixes).
- platform/x86: hp-wmi: Disable tablet-mode reporting by default
  (git-fixes).
- commit 3ec7f46
* Thu Feb 18 2021 dfaggioli@suse.com
- KVM: nVMX: Emulate MTF when performing instruction emulation
  (bsc#1182380).
- commit d82f9c0
* Thu Feb 18 2021 mbenes@suse.cz
- tracing: Check length before giving out the filter buffer
  (git-fixes).
- commit d3dfea0
* Thu Feb 18 2021 mbenes@suse.cz
- tracing: Do not count ftrace events in top level enable output
  (git-fixes).
- commit 9eb30ee
* Thu Feb 18 2021 mbenes@suse.cz
- tracing/kprobe: Fix to support kretprobe events on unloaded
  modules (git-fixes).
- commit 19d30cc
* Thu Feb 18 2021 dfaggioli@suse.com
- KVM: x86: remove stale comment from struct x86_emulate_ctxt
  (bsc#1182406).
- commit 0a00f86
* Thu Feb 18 2021 msuchanek@suse.de
- mm/pmem: avoid inserting hugepage PTE entry with fsdax if
  hugepage support is disabled (bsc#1181896 ltc#191273).
- commit 5527d63
* Thu Feb 18 2021 mbenes@suse.cz
- fgraph: Initialize tracing_graph_pause at task creation
  (git-fixes).
- commit ac6ab62
* Thu Feb 18 2021 nmoreychaisemartin@suse.com
- RDMA/srp: Fix support for unpopulated and unbalanced NUMA nodes (bsc#1169709)
- commit f19dffe
* Wed Feb 17 2021 dfaggioli@suse.com
- KVM: x86: clear stale x86_emulate_ctxt->intercept value
  (bsc#1182381).
- commit ffa8b86
* Wed Feb 17 2021 tiwai@suse.de
- drm/i915/guc: Update to use firmware v49.0.1 (CVE-2020-12362
  CVE-2020-12363 CVE-2020-12364 CVE-2020-12373 bsc#1181720
  bsc#1181735 bsc#1181736 bsc#1181738).
- commit d2373bb
* Wed Feb 17 2021 dfaggioli@suse.com
- KVM: x86: don't notify userspace IOAPIC on edge-triggered interrupt EOI
  (bsc#1182374).
- commit c629183
* Wed Feb 17 2021 mbenes@suse.cz
- tracing/kprobes: Do the notrace functions check without kprobes
  on ftrace (git-fixes).
- Update config files.
- commit dd6e75e
* Wed Feb 17 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0003-caif-no-need-to-check-return-value-of-debugfs_create.patch
- commit f7a521f
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/sun4i: dw-hdmi: Fix max. frequency for H6 (bsc#1152472)
- commit acb3f2a
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/sun4i: Fix H6 HDMI PHY configuration (bsc#1152472)
- commit 039ccc9
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/sun4i: dw-hdmi: always set clock rate (bsc#1152472)
- commit 0e99073
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/sun4i: tcon: set sync polarity for tcon1 channel (bsc#1152472)
- commit 03d6bea
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/vc4: hvs: Fix buffer overflow with the dlist handling (bsc#1152489)
- commit b8a95b9
* Wed Feb 17 2021 tzimmermann@suse.de
- drm/meson: Unbind all connectors on module removal (bsc#1152472)
- commit b5e929b
* Wed Feb 17 2021 tzimmermann@suse.de
- matroxfb: avoid -Warray-bounds warning (bsc#1152472)
- commit f5716ba
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: dwmac-sunxi: Provide TX and RX fifo sizes
  (git-fixes).
- commit 2c2d766
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net/sonic: Add mutual exclusion for accessing shared state
  (git-fixes).
- commit 52ed672
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: Always arm TX Timer at end of transmission start
  (git-fixes).
- commit 6058ba7
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: Fix the TX IOC in xmit path (git-fixes).
- commit 0d8ff7f
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: Enable 16KB buffer size (git-fixes).
- commit c5a734b
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: 16KB buffer must be 16 byte aligned (git-fixes).
- commit c88cefc
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: RX buffer size must be 16 byte aligned (git-fixes).
- commit d10b760
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: xgmac: Clear previous RX buffer size (git-fixes).
- commit 53673df
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: Do not accept invalid MTU values (git-fixes).
- commit ac657b6
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: stmmac: selftests: Needs to check the number of Multicast
  regs (git-fixes).
- commit 8826854
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: caif: Fix debugfs on 64-bit platforms (git-fixes).
- commit 7a8758b
* Tue Feb 16 2021 denis.kirjanov@suse.com
- caif: no need to check return value of debugfs_create functions
  (git-fixes).
- commit 756b62e
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: axienet: Fix error return code in axienet_probe()
  (git-fixes).
- commit 6ec2abe
* Tue Feb 16 2021 denis.kirjanov@suse.com
- net: netsec: Correct dma sync for XDP_TX frames (git-fixes).
- commit 8040572
* Tue Feb 16 2021 tbogendoerfer@suse.de
- net: gro: do not keep too many GRO packets in napi->rx_list
  (bsc#1154353).
- commit 76fde4b
* Mon Feb 15 2021 msuchanek@suse.de
- kernel-binary.spec: Add back initrd and image symlink ghosts to
  filelist (bsc#1182140).
  Fixes: 76a9256314c3 ("rpm/kernel-{source,binary}.spec: do not include ghost symlinks (boo#1179082).")
- commit 606c9d1
* Mon Feb 15 2021 ailiop@suse.com
- xfs: ratelimit xfs_discard_page messages (bsc#1182283).
- commit 672719e
* Mon Feb 15 2021 ailiop@suse.com
- xfs: scrub should mark a directory corrupt if any entries
  cannot be iget'd (git-fixes bsc#1182278).
- commit 55cdbf1
* Mon Feb 15 2021 tiwai@suse.de
- Drop HID logitech patch that caused a regression (bsc#1182259)
  Delete patches.suse/HID-logitech-dj-add-the-G602-receiver.patch
  blacklist.conf: add the dropped entry
- commit fc205a0
* Mon Feb 15 2021 ailiop@suse.com
- xfs: fix parent pointer scrubber bailing out on unallocated
  inodes (git-fixes bsc#1182276).
- commit 68a744e
* Mon Feb 15 2021 ailiop@suse.com
- xfs: return corresponding errcode if xfs_initialize_perag()
  fail (git-fixes bsc#1182275).
- commit adf2653
* Mon Feb 15 2021 ailiop@suse.com
- xfs: fix the minrecs logic when dealing with inode root child
  blocks (git-fixes bsc#1182273).
- commit 5d5cd17
* Mon Feb 15 2021 ailiop@suse.com
- xfs: ensure inobt record walks always make forward progress
  (git-fixes bsc#1182272).
- commit 5d91094
* Mon Feb 15 2021 bp@suse.de
- x86/apic: Add extra serialization for non-serializing MSRs
  (bsc#1152489).
- commit 52e6a50
* Mon Feb 15 2021 ailiop@suse.com
- xfs: strengthen rmap record flags checking (git-fixes
  bsc#1182271).
- commit 0a8fcac
* Mon Feb 15 2021 ailiop@suse.com
- squashfs: add more sanity checks in xattr id lookup (git-fixes
  bsc#1182268).
- commit f6143c2
* Mon Feb 15 2021 ailiop@suse.com
- squashfs: add more sanity checks in inode lookup (git-fixes
  bsc#1182267).
- commit 81b879a
* Mon Feb 15 2021 ailiop@suse.com
- squashfs: add more sanity checks in id lookup (git-fixes
  bsc#1182266).
- commit a860e79
* Mon Feb 15 2021 ailiop@suse.com
- vfs: Convert squashfs to use the new mount API (git-fixes
  bsc#1182265).
- commit 961749a
* Mon Feb 15 2021 vbabka@suse.cz
- mm: thp: fix MADV_REMOVE deadlock on shmem THP (CVE-2020-29368,
  bsc#1179660.).
- commit 9d15b36
* Mon Feb 15 2021 vbabka@suse.cz
- mm: thp: make the THP mapcount atomic against
  __split_huge_pmd_locked() (CVE-2020-29368, bsc#1179660.).
- commit 842b18f
* Mon Feb 15 2021 tiwai@suse.de
- rpm/post.sh: Avoid purge-kernel for the first installed kernel (bsc#1180058)
- commit c29e77d
* Mon Feb 15 2021 bp@suse.de
- blacklist.conf: 20bf2b378729 x86/build: Disable CET instrumentation in the kernel
- commit ae0a855
* Sun Feb 14 2021 mkubecek@suse.cz
- fix patch metadata
- fix upstream reference:
  patches.suse/net-hns3-add-a-check-for-queue_id-in-hclge_reset_vf_.patch
- commit 33a1a9d
* Sun Feb 14 2021 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section
  patches.suse/powerpc-pseries-extract-host-bridge-from-pci_bus-pri.patch
- commit 05c22a3
* Sun Feb 14 2021 tiwai@suse.de
- regulator: Fix lockdep warning resolving supplies (git-fixes).
- commit 83723b8
* Sun Feb 14 2021 tiwai@suse.de
- i2c: stm32f7: fix configuration of the digital filter
  (git-fixes).
- i2c: mediatek: Move suspend and resume handling to NOIRQ phase
  (git-fixes).
- mac80211: 160MHz with extended NSS BW in CSA (git-fixes).
- iwlwifi: mvm: guard against device removal in reprobe
  (git-fixes).
- iwlwifi: mvm: invalidate IDs of internal stations at mvm start
  (git-fixes).
- iwlwifi: pcie: fix context info memory leak (git-fixes).
- iwlwifi: pcie: add a NULL check in iwl_pcie_txq_unmap
  (git-fixes).
- iwlwifi: mvm: take mutex for calling iwl_mvm_get_sync_time()
  (git-fixes).
- iwlwifi: mvm: skip power command when unbinding vif during CSA
  (git-fixes).
- regulator: core: avoid regulator_resolve_supply() race condition
  (git-fixes).
- commit c869ffc
* Sat Feb 13 2021 denis.kirjanov@suse.com
- net: mscc: ocelot: fix address ageing time (again) (git-fixes).
- commit 2561722
* Sat Feb 13 2021 denis.kirjanov@suse.com
- dpaa2-eth: fix return codes used in ndo_setup_tc (git-fixes).
- commit 14e0d91
* Sat Feb 13 2021 denis.kirjanov@suse.com
- qlcnic: fix missing release in qlcnic_83xx_interrupt_test
  (git-fixes).
- commit d3915bd
* Sat Feb 13 2021 denis.kirjanov@suse.com
- net: sun: fix missing release regions in cas_init_one()
  (git-fixes).
- commit 5243443
* Sat Feb 13 2021 denis.kirjanov@suse.com
- net: mscc: ocelot: ANA_AUTOAGE_AGE_PERIOD holds a value in
  seconds, not ms (git-fixes).
- commit 8f77ca6
* Sat Feb 13 2021 denis.kirjanov@suse.com
- net: moxa: Fix a potential double 'free_irq()' (git-fixes).
- commit 6d56ae2
* Fri Feb 12 2021 msuchanek@suse.de
- powerpc/pseries: extract host bridge from pci_bus prior to
  bus removal (bsc#1182171 ltc#190900).
- commit 9deaa93
* Fri Feb 12 2021 tbogendoerfer@suse.de
- cxgb4: fix the panic caused by non smac rewrite (git-fixes).
- commit 0f6aca4
* Fri Feb 12 2021 dwagner@suse.de
- nvme-hwmon: rework to avoid devm allocation (bsc#1177326).
- commit bc99792
* Fri Feb 12 2021 nsaenzjulienne@suse.de
- Update config files: armv7hl: Set ledtrig-default-on as builtin (bsc#1182128)
- commit 27d7915
* Fri Feb 12 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/ibmvnic-Clear-failover_pending-if-unable-to-schedule.patch
- commit f78f850
* Thu Feb 11 2021 msuchanek@suse.de
- powerpc/perf/hv-24x7: Dont create sysfs event files for dummy
  events (bsc#1182118 ltc#190624).
- commit 2178630
* Thu Feb 11 2021 nsaenzjulienne@suse.de
- Update config files: Set ledtrig-default-on as builtin (bsc#1182128)
- commit e422083
* Thu Feb 11 2021 tbogendoerfer@suse.de
- net: hns3: add a check for queue_id in hclge_reset_vf_queue()
  (git-fixes).
- net/mlx5e: Update max_opened_tc also when channels are closed
  (git-fixes).
- net: mvpp2: TCAM entry enable should be written after SRAM data
  (git-fixes).
- igc: check return value of ret_val in
  igc_config_fc_after_link_up (git-fixes).
- igc: set the default return value to -IGC_ERR_NVM in
  igc_write_nvm_srwr (git-fixes).
- igc: Report speed and duplex as unknown when device is runtime
  suspended (git-fixes).
- net/mlx5e: Reduce tc unsupported key print level (git-fixes).
- net/mlx5: Fix memory leak on flow table creation error flow
  (git-fixes).
- igc: fix link speed advertising (git-fixes).
- cxgb4/chtls: Fix tid stuck due to wrong update of qid
  (git-fixes).
- bnxt_en: Improve stats context resource accounting with RDMA
  driver loaded (git-fixes).
- net: mvpp2: Remove Pause and Asym_Pause support (git-fixes).
- mlxsw: core: Increase critical threshold for ASIC thermal zone
  (git-fixes).
- mlxsw: core: Add validation of transceiver temperature
  thresholds (git-fixes).
- net/mlx5e: Fix memleak in mlx5e_create_l2_table_groups
  (git-fixes).
- net/mlx5e: Fix two double free cases (git-fixes).
- net/mlx5: Use port_num 1 instead of 0 when delete a RoCE address
  (git-fixes).
- chtls: Fix chtls resources release sequence (git-fixes).
- chtls: Added a check to avoid NULL pointer dereference
  (git-fixes).
- chtls: Replace skb_dequeue with skb_peek (git-fixes).
- chtls: Fix panic when route to peer not configured (git-fixes).
- chtls: Remove invalid set_tcb call (git-fixes).
- chtls: Fix hardware tid leak (git-fixes).
- net: hns3: fix the number of queues actually used by ARQ
  (git-fixes).
- qed: select CONFIG_CRC32 (git-fixes).
- net: hns: fix return value check in __lb_other_process()
  (git-fixes).
- net: mvpp2: fix pkt coalescing int-threshold configuration
  (git-fixes).
- tun: fix return value when the number of iovs exceeds
  MAX_SKB_FRAGS (git-fixes).
- virtio_net: Fix recursive call to cpus_read_lock() (git-fixes).
- net: mvpp2: Fix GoP port 3 Networking Complex Control
  configurations (git-fixes).
- net: mvpp2: prs: fix PPPoE with ipv6 packet parse (git-fixes).
- net: mvpp2: Add TCAM entry to drop flow control pause frames
  (git-fixes).
- net: mvpp2: disable force link UP during port init procedure
  (git-fixes).
- iavf: fix double-release of rtnl_lock (git-fixes).
- i40e: Fix Error I40E_AQ_RC_EINVAL when removing VFs (git-fixes).
- virtio_net: Fix error code in probe() (git-fixes).
- ixgbe: avoid premature Rx buffer reuse (git-fixes).
- i40e: avoid premature Rx buffer reuse (git-fixes).
- net/mlx4_en: Handle TX error CQE (bsc#1181854).
- net/mlx4_en: Avoid scheduling restart task if it is already
  running (bsc#1181854).
- net/mlx5: Fix wrong address reclaim when command interface is
  down (git-fixes).
- net: mvpp2: Fix error return code in mvpp2_open() (git-fixes).
- chelsio/chtls: fix a double free in chtls_setkey() (git-fixes).
- cxgb3: fix error return code in t3_sge_alloc_qset() (git-fixes).
- net: broadcom CNIC: requires MMU (git-fixes).
- chelsio/chtls: fix panic during unload reload chtls (git-fixes).
- net: ena: set initial DMA width to avoid intel iommu issue
  (git-fixes).
- i40e: Fix removing driver while bare-metal VFs pass traffic
  (git-fixes).
- bnxt_en: Release PCI regions when DMA mask setup fails during
  probe (git-fixes).
- bnxt_en: fix error return code in bnxt_init_board() (git-fixes).
- bnxt_en: fix error return code in bnxt_init_one() (git-fixes).
- net/mlx4_core: Fix init_hca fields offset (git-fixes).
- net/mlx5: Disable QoS when min_rates on all VFs are zero
  (git-fixes).
- net/mlx5: Add handling of port type in rule deletion
  (git-fixes).
- mlxsw: core: Use variable timeout for EMAD retries (git-fixes).
- qed: fix error return code in qed_iwarp_ll2_start() (git-fixes).
- bnxt_en: read EEPROM A2h address using page 0 (git-fixes).
- net/mlx5: Fix deletion of duplicate rules (git-fixes).
- chelsio/chtls: fix always leaking ctrl_skb (git-fixes).
- chelsio/chtls: fix memory leaks caused by a race (git-fixes).
- chelsio/chtls: fix memory leaks in CPL handlers (git-fixes).
- chelsio/chtls: fix deadlock issue (git-fixes).
- cxgb4: set up filter action after rewrites (git-fixes).
- chelsio/chtls: fix tls record info to user (git-fixes).
- chelsio/chtls: correct function return and return type
  (git-fixes).
- chelsio/chtls: correct netdevice for vlan interface (git-fixes).
- chelsio/chtls: fix socket lock (git-fixes).
- commit f8ae7ea
* Thu Feb 11 2021 bp@suse.de
- blacklist.conf: 9ad22e165994 x86/debug: Fix DR6 handling
- commit b5c23b5
* Thu Feb 11 2021 jgross@suse.com
- xen/netback: avoid race in xenvif_rx_ring_slots_available()
  (bsc#1065600).
- commit b061a0d
* Thu Feb 11 2021 jgross@suse.com
- series.conf: cleanup
- update upstream references and move to sorted section:
  patches.suse/x86-xen-avoid-warning-in-Xen-pv-guest-with-CONFIG_AM.patch.
  patches.suse/xen-blkfront-allow-discard-nodes-to-be-optional.patch.
- commit 9ed652c
* Thu Feb 11 2021 tiwai@suse.de
- mt76: dma: fix a possible memory leak in mt76_add_fragment()
  (git-fixes).
- commit 8ae7076
* Wed Feb 10 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/0002-x86-msi-Only-use-high-bits-of-MSI-address-for-DMAR-u.patch
  patches.suse/0003-x86-ioapic-Handle-Extended-Destination-ID-field-in-R.patch
  patches.suse/0004-x86-apic-Support-15-bits-of-APIC-ID-in-IOAPIC-MSI-wh.patch
  patches.suse/0005-x86-kvm-Add-KVM_FEATURE_MSI_EXT_DEST_ID.patch
- commit e28768c
* Wed Feb 10 2021 tiwai@suse.de
- USB: serial: option: Adding support for Cinterion MV31
  (git-fixes).
- USB: serial: cp210x: add pid/vid for WSDA-200-USB (git-fixes).
- USB: serial: cp210x: add new VID/PID for supporting Teraoka
  AD2000 (git-fixes).
- USB: usblp: don't call usb_set_interface if there's a single
  alt (git-fixes).
- Input: xpad - sync supported devices with fork on GitHub
  (git-fixes).
- mmc: core: Limit retries when analyse of SDIO tuples fails
  (git-fixes).
- drm/amd/display: Revert "Fix EDID parsing after resume from
  suspend" (git-fixes).
- mac80211: fix station rate table updates on assoc (git-fixes).
- iwlwifi: mvm: don't send RFH_QUEUE_CONFIG_CMD with no queues
  (git-fixes).
- commit 2244f3a
* Tue Feb  9 2021 dwagner@suse.de
- nvme: re-read ANA log on NS CHANGED AEN (bsc#1179137).
- commit d65941e
* Tue Feb  9 2021 mbrugger@suse.com
- KVM: arm64: Remove S1PTW check from kvm_vcpu_dabt_iswrite()
  (bsc#1181818).
- KVM: arm64: Assume write fault on S1PTW permission fault on
  instruction fetch (bsc#1181818).
- commit 9e58921
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: fix some return value check of
  cpsw_ale_create() (git-fixes).
- commit c1f82b5
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net/mlx5e: Correctly handle changing the number of queues when
  the interface is down (git-fixes).
- commit 2e18a60
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: ale: fix allmulti for nu type ale
  (git-fixes).
- commit 1455e82
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: ale: ensure vlan/mdb deleted when no members
  (git-fixes).
- commit 6a115f1
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: ale: modify vlan/mdb api for switchdev
  (git-fixes).
- Refresh
  patches.suse/0009-net-ethernet-ti-ale-fix-seeing-unreg-mcast-packets-w.patch.
- commit 0cae8d9
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: cpsw: allow untagged traffic on host port
  (git-fixes).
- commit da85a01
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: ethernet: ti: ale: fix seeing unreg mcast packets with
  promisc and allmulti disabled (git-fixes).
- commit 6a2d8f8
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net/mlx5e: Fix configuration of XPS cpumasks and netdev queues
  in corner cases (git-fixes).
- Refresh
  patches.suse/net-mlx5e-Fix-CPU-mapping-after-function-reload-to-a.patch.
- commit ae37f4a
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net/mlx5e: Use preactivate hook to set the indirection table
  (git-fixes).
- commit a8003a3
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net/mlx5e: Rename hw_modify to preactivate (git-fixes).
- commit d8b9674
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net/mlx5e: Encapsulate updating netdev queues into a function
  (git-fixes).
- commit 0764cbf
* Tue Feb  9 2021 denis.kirjanov@suse.com
- sh_eth: check sh_eth_cpu_data::no_xdfar when dumping registers
  (git-fixes).
- commit ccdc470
* Tue Feb  9 2021 denis.kirjanov@suse.com
- sh_eth: check sh_eth_cpu_data::cexcr when dumping registers
  (git-fixes).
- commit 855923f
* Tue Feb  9 2021 denis.kirjanov@suse.com
- sh_eth: check sh_eth_cpu_data::no_tx_cntrs when dumping
  registers (git-fixes).
- commit 1115b43
* Tue Feb  9 2021 denis.kirjanov@suse.com
- net: dsa: mt7530: Change the LINK bit to reflect the link status
  (git-fixes).
- commit 7c5ca65
* Tue Feb  9 2021 msuchanek@suse.de
- powerpc/pseries/dlpar: handle ibm, configure-connector delay
  status (bsc#1181985 ltc#188074).
- commit 418b81d
* Tue Feb  9 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference:
  patches.suse/ibmvnic-Clear-failover_pending-if-unable-to-schedule.patch
- commit 85f2019
* Tue Feb  9 2021 mkubecek@suse.cz
- fix patch metadata
- fix upstream reference:
  patches.suse/io_uring-Fix-current-fs-handling-in-io_sq_wq_submit_.patch
- commit 90ec2ae
* Tue Feb  9 2021 dwagner@suse.de
- scsi: lpfc: Fix EEH encountering oops with NVMe traffic
  (bsc#1181958).
- commit 5afe23b
* Mon Feb  8 2021 msuchanek@suse.de
- powerpc/perf: Exclude kernel samples while counting events in
  user space (bsc#1065729).
- commit 50bd42d
* Mon Feb  8 2021 msuchanek@suse.de
- powerpc: Fix alignment bug within the init sections
  (bsc#1065729).
- commit 7810647
* Mon Feb  8 2021 msuchanek@suse.de
- powerpc/powernv/npu: Do not attempt NPU2 setup on POWER8NVL NPU
  (bsc#1156395).
- powerpc/powernv/memtrace: Fix crashing the kernel when enabling
  concurrently (bsc#1156395).
- powerpc/powernv/memtrace: Don't leak kernel memory to user space
  (bsc#1156395).
- powerpc/fpu: Drop cvt_fd() and cvt_df() (bsc#1156395).
- powerpc/boot: Delete unneeded .globl _zimage_start
  (bsc#1156395).
- commit 735e425
* Mon Feb  8 2021 msuchanek@suse.de
- ibmvnic: device remove has higher precedence over reset
  (bsc#1065729).
- commit 0b8e9f9
* Mon Feb  8 2021 msuchanek@suse.de
- ibmvnic: fix login buffer memory leak (bsc#1081134 ltc#164631).
- commit 5b8c72b
* Mon Feb  8 2021 msuchanek@suse.de
- ibmvnic: Clear failover_pending if unable to schedule
  (bsc#1181960 ltc#190997).
- commit fb1a56e
* Mon Feb  8 2021 tiwai@suse.de
- phy: cpcap-usb: Fix warning for missing regulator_disable
  (git-fixes).
- platform/x86: intel-vbtn: Support for tablet mode on Dell
  Inspiron 7352 (git-fixes).
- platform/x86: touchscreen_dmi: Add swap-x-y quirk for Goodix
  touchscreen on Estar Beauty HD tablet (git-fixes).
- drm/amd/display: Change function decide_dp_link_settings to
  avoid infinite looping (git-fixes).
- mac80211: fix fast-rx encryption check (git-fixes).
- commit 504e3c0
* Mon Feb  8 2021 oneukum@suse.com
- blacklist.conf: kABI extreely hard to work around
- commit e1f9604
* Mon Feb  8 2021 mbenes@suse.cz
- objtool: Don't fail on missing symbol table (bsc#1169514).
- commit 1518505
* Mon Feb  8 2021 nborisov@suse.com
- btrfs: Fix race between extent freeing/allocation when using bitmaps (bsc#1181574).
- commit 98010f2
* Mon Feb  8 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references of unsortable patches and sort them properly:
  patches.suse/perf-x86-intel-uncore-Store-the-logical-die-id-inste.patch
  patches.suse/perf-x86-intel-uncore-With-8-nodes-get-pci-bus-die-i.patch
- commit b4f0fcb
* Mon Feb  8 2021 mkubecek@suse.cz
- fix patch metadata and move it to correct section
- fix upstream reference of a non-mainline patch and move to correct section:
  patches.suse/net-sctp-filter-remap-copy_from_user-failure-error.patch
- commit fda606d
* Sun Feb  7 2021 tiwai@suse.de
- usb: dwc2: Fix endpoint direction check in ep_from_windex
  (git-fixes).
- usb: dwc3: fix clock issue during resume in OTG mode
  (git-fixes).
- xhci: fix bounce buffer usage for non-sg list case (git-fixes).
- usb: renesas_usbhs: Clear pipe running flag in usbhs_pkt_pop()
  (git-fixes).
- USB: gadget: legacy: fix an error code in eth_bind()
  (git-fixes).
- Input: i8042 - unbreak Pegatron C15B (git-fixes).
- commit bcaeec1
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: qca_spi: Move reset_count to struct qcaspi (git-fixes).
- commit 45b7fef
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: qca_spi: fix receive buffer size check (git-fixes).
- commit 5cd7e42
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: stmmac: fix disabling flexible PPS output (git-fixes).
- commit 20dce33
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: stmmac: fix length of PTP clock's name string (git-fixes).
- commit 9f89a73
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: phy: at803x: use operating parameters from PHY-specific
  status (git-fixes).
- commit e91964f
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: phy: extract pause mode (git-fixes).
- commit c81698a
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: phy: extract link partner advertisement reading
  (git-fixes).
- commit 18dc97f
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: phy: read MII_CTRL1000 in genphy_read_status only if needed
  (git-fixes).
- commit d5eb04d
* Sat Feb  6 2021 denis.kirjanov@suse.com
- net: stmmac: selftests: Flow Control test can also run with
  ASYM Pause (git-fixes).
- commit 26dfc56
* Sat Feb  6 2021 denis.kirjanov@suse.com
- cirrus: cs89x0: remove set but not used variable 'lp'
  (git-fixes).
- commit 0385a3f
* Sat Feb  6 2021 denis.kirjanov@suse.com
- cirrus: cs89x0: use devm_platform_ioremap_resource() to simplify
  code (git-fixes).
- commit f75aac5
* Sat Feb  6 2021 denis.kirjanov@suse.com
- blacklist.conf: update blacklist
- commit ca67b2c
* Fri Feb  5 2021 tabraham@suse.com
- perf/x86/intel/uncore: With > 8 nodes, get pci bus die id from
  NUMA info (bsc#1180989).
- perf/x86/intel/uncore: Store the logical die id instead of
  the physical die id (bsc#1180989).
- perf/x86/intel/uncore: Generic support for the PCI sub driver
  (bsc#1180989).
- perf/x86/intel/uncore: Factor out uncore_pci_pmu_unregister()
  (bsc#1180989).
- perf/x86/intel/uncore: Factor out uncore_pci_pmu_register()
  (bsc#1180989).
- perf/x86/intel/uncore: Factor out uncore_pci_find_dev_pmu()
  (bsc#1180989).
- perf/x86/intel/uncore: Factor out uncore_pci_get_dev_die_info()
  (bsc#1180989).
- commit 6e81128
* Fri Feb  5 2021 tbogendoerfer@suse.de
- bonding: wait for sysfs kobject destruction before freeing
  struct slave (git-fixes).
- net/mlx5: E-Switch, Use vport metadata matching by default
  (git-fixes).
- cxgb4: fix all-mask IP address comparison (git-fixes).
- cxgb4: fix set but unused variable when DCB is disabled
  (git-fixes).
- commit 8f53029
* Fri Feb  5 2021 glin@suse.com
- bpf, cgroup: Fix problematic bounds check (bsc#1155518).
- bpf, cgroup: Fix optlen WARN_ON_ONCE toctou (bsc#1155518).
- commit 3ab5222
* Fri Feb  5 2021 glin@suse.com
- net, sctp, filter: remap copy_from_user failure error
  (bsc#1181637).
- commit 32551e1
* Thu Feb  4 2021 tbogendoerfer@suse.de
- i40e: Revert "i40e: don't report link up for a VF who hasn't
  enabled queues" (jsc#SLE-8025).
- igc: Fix returning wrong statistics (git-fixes).
- i40e: Fix MAC address setting for a VF via Host/VM (git-fixes).
- mlxsw: core: Fix use-after-free in mlxsw_emad_trans_finish()
  (git-fixes).
- mlxsw: core: Fix memory leak on module removal (git-fixes).
- net/mlx5: Don't call timecounter cyc2time directly from 1PPS
  flow (git-fixes).
- net: ethernet: mlx4: Avoid assigning a value to ring_cons but
  not used it anymore in mlx4_en_xmit() (git-fixes).
- net: team: fix memory leak in __team_options_register
  (git-fixes).
- net/mlx5e: Fix VLAN create flow (git-fixes).
- net/mlx5e: Fix VLAN cleanup flow (git-fixes).
- net/mlx5: Fix request_irqs error flow (git-fixes).
- mlxsw: spectrum_acl: Fix mlxsw_sp_acl_tcam_group_add()'s error
  path (git-fixes).
- team: set dev->needed_headroom in team_setup_by_port()
  (git-fixes).
- bonding: set dev->needed_headroom in bond_setup_by_slave()
  (git-fixes).
- net: qed: RDMA personality shouldn't fail VF load (git-fixes).
- net: thunderx: initialize VF's mailbox mutex before first usage
  (git-fixes).
- net: mvpp2: fix memory leak in mvpp2_rx (git-fixes).
- iavf: Fix updating statistics (git-fixes).
- iavf: fix error return code in iavf_init_get_resources()
  (git-fixes).
- net/mlx5e: vxlan: Use RCU for vxlan table lookup (git-fixes).
- vxlan: fix memleak of fdb (git-fixes).
- net/mlx5e: fix bpf_prog reference count leaks in mlx5e_alloc_rq
  (git-fixes).
- mlxsw: core: Free EMAD transactions using kfree_rcu()
  (git-fixes).
- mlxsw: core: Increase scope of RCU read-side critical section
  (git-fixes).
- net/mlx5: Query PPS pin operational status before registering it
  (git-fixes).
- net/mlx5: Verify Hardware supports requested ptp function on
  a given pin (git-fixes).
- net/mlx5: Fix a bug of using ptp channel index as pin index
  (git-fixes).
- net/mlx5e: Fix error path of device attach (git-fixes).
- net/mlx5: E-switch, Destroy TSAR after reload interface
  (git-fixes).
- net: hns3: fix aRFS FD rules leftover after add a user FD rule
  (git-fixes).
- net: hns3: fix a TX timeout issue (git-fixes).
- net: hns3: fix desc filling bug when skb is expanded or lineared
  (git-fixes).
- qed: Populate nvm-file attributes while reading nvm config
  partition (git-fixes).
- net: hns3: fix use-after-free when doing self test (git-fixes).
- net: hns3: add a missing uninit debugfs when unload driver
  (git-fixes).
- net: cxgb4: fix return error value in t4_prep_fw (git-fixes).
- cxgb4vf: update kernel-doc line comments (git-fixes).
- cxgb4: update kernel-doc line comments (git-fixes).
- cxgb4: move DCB version extern to header file (git-fixes).
- cxgb4: remove cast when saving IPv4 partial checksum
  (git-fixes).
- cxgb4: fix SGE queue dump destination buffer context
  (git-fixes).
- cxgb4: use correct type for all-mask IP address comparison
  (git-fixes).
- cxgb4: fix endian conversions for L4 ports in filters
  (git-fixes).
- cxgb4: parse TC-U32 key values and masks natively (git-fixes).
- cxgb4: use unaligned conversion for fetching timestamp
  (git-fixes).
- cxgb4: move PTP lock and unlock to caller in Tx path
  (git-fixes).
- cxgb4: move handling L2T ARP failures to caller (git-fixes).
- net: qed: fix "maybe uninitialized" warning (git-fixes).
- net: qede: fix use-after-free on recovery and AER handling
  (git-fixes).
- net: qede: fix PTP initialization on recovery (git-fixes).
- net: qed: fix excessive QM ILT lines consumption (git-fixes).
- net: qed: fix NVMe login fails over VFs (git-fixes).
- net: qede: stop adding events on an already destroyed workqueue
  (git-fixes).
- net: qed: fix async event callbacks unregistering (git-fixes).
- iavf: fix speed reporting over virtchnl (git-fixes).
- net/mlx5e: IPoIB, Drop multicast packets that this interface
  sent (git-fixes).
- ixgbe: Fix XDP redirect on archs with PAGE_SIZE above 4K
  (git-fixes).
- veth: Adjust hard_start offset on redirect XDP frames
  (git-fixes).
- net/mlx5e: Set of completion request bit should not clear
  other adjacent bits (git-fixes).
- net/mlx5e: en_accel, Add missing net/geneve.h include
  (git-fixes).
- bonding: Fix reference count leak in bond_sysfs_slave_add
  (git-fixes).
- bnxt_en: Fix accumulation of bp->net_stats_prev (git-fixes).
- net/mlx5: Annotate mutex destroy for root ns (git-fixes).
- net/mlx5: Don't maintain a case of del_sw_func being null
  (git-fixes).
- net/mlx4_core: fix a memory leak bug (git-fixes).
- mlxsw: spectrum: Fix use-after-free of split/unsplit/type_set
  in case reload fails (git-fixes).
- net/mlx5e: Get the latest values from counters in switchdev mode
  (git-fixes).
- net/mlx5e: Don't trigger IRQ multiple times on XSK wakeup to
  avoid WQ overruns (git-fixes).
- net/mlx5: Fix failing fw tracer allocation on s390 (git-fixes).
- net/cxgb4: Check the return from t4_query_params properly
  (git-fixes).
- net: hns3: fix set and get link ksettings issue (git-fixes).
- net: hns3: fix RSS config lost after VF reset (git-fixes).
- qed: Fix race condition between scheduling and destroying the
  slowpath workqueue (git-fixes).
- net/mlx5: E-Switch, Hold mutex when querying drop counter in
  legacy mode (git-fixes).
- net/mlx5: E-Switch, Use vport metadata matching only when
  mandatory (git-fixes).
- net/liquidio: Delete non-working LIQUIDIO_PACKAGE check
  (git-fixes).
- virtio_net: Keep vnet header zeroed if XDP is loaded for small
  buffer (git-fixes).
- net/mlx5: Clear LAG notifier pointer after unregister
  (git-fixes).
- net/mlx5e: Fix endianness handling in pedit mask (git-fixes).
- net/mlx5e: kTLS, Fix wrong value in record tracker enum
  (git-fixes).
- net: hns3: clear port base VLAN when unload PF (git-fixes).
- net: hns3: fix VF VLAN table entries inconsistent issue
  (git-fixes).
- net: hns3: fix "tc qdisc del" failed issue (git-fixes).
- cxgb4: fix checks for max queues to allocate (git-fixes).
- commit a805d8f
* Thu Feb  4 2021 bp@suse.de
- blacklist.conf: Blacklist two 32-bit only fixes
  50fe7ebb6475 bpf, x86_32: Fix clobbering of dst for BPF_JSET
  5ca1ca01fae1 bpf, x86_32: Fix logic error in BPF_LDX zero-extension
- commit 55cadfc
* Thu Feb  4 2021 dwagner@suse.de
- nvme-multipath: Early exit if no path is available
  (bsc#1180964).
- commit 1c96465
* Thu Feb  4 2021 jroedel@suse.de
- kABI: Fix kABI after AMD SEV PCID fixes (bsc#1178995).
- commit bf72ec9
* Thu Feb  4 2021 tiwai@suse.de
- mac80211: pause TX while changing interface type (git-fixes).
- wext: fix NULL-ptr-dereference with cfg80211's lack of commit()
  (git-fixes).
- iwlwifi: pcie: reschedule in long-running memory reads
  (git-fixes).
- iwlwifi: pcie: use jiffies for memory read spin time limit
  (git-fixes).
- net: usb: qmi_wwan: added support for Thales Cinterion PLSx3
  modem family (git-fixes).
- drivers: soc: atmel: add null entry at the end of
  at91_soc_allowed_list[] (git-fixes).
- drivers: soc: atmel: Avoid calling at91_soc_init on non AT91
  SoCs (git-fixes).
- commit 023b5c2
* Thu Feb  4 2021 msuchanek@suse.de
- powerpc/mm/pkeys: Make pkey access check work on execute_only_key
  (bsc#1181544 ltc#191080 git-fixes).
- Refresh patches.suse/powerpc-book3s64-pkeys-Fix-pkey_access_permitted-for.patch.
- commit 7508356
* Wed Feb  3 2021 msuchanek@suse.de
- powerpc/pkeys: Check vma before returning key fault error to
  the user (bsc#1181544 ltc#191080).
- powerpc/pkeys: Avoid using lockless page table walk (bsc#1181544
  ltc#191080).
- commit 8cb9fab
* Wed Feb  3 2021 pjakobsson@suse.de
- Add no-fix tag to drm cherry-picks
  Add a no-fix tag to drm patches that are cherry-picks and are not
  already blacklisted.
- Refresh
  patches.suse/0001-drm-i915-Preload-LUTs-if-the-hw-isn-t-currently-usin.patch.
- Refresh
  patches.suse/0001-drm-i915-Update-drm-i915-bug-filing-URL.patch.
- Refresh
  patches.suse/0001-drm-i915-execlists-Always-force-a-context-reload-whe.patch.
- Refresh
  patches.suse/0001-drm-i915-icl-Fix-hotplug-interrupt-disabling-after-s.patch.
- Refresh
  patches.suse/0003-drm-i915-Correctly-set-SFC-capability-for-video-engi.patch.
- Refresh
  patches.suse/0029-drm-i915-gem-Avoid-implicit-vmap-for-highmem-on-x86-.patch.
- Refresh
  patches.suse/drm-i915-Perform-GGTT-restore-much-earlier-during-re.patch.
- Refresh
  patches.suse/drm-i915-Whitelist-COMMON_SLICE_CHICKEN2.patch.
- Refresh
  patches.suse/drm-i915-pmu-Frequency-is-reported-as-accumulated-cy.patch.
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- Refresh
  patches.suse/drm-i915-update-rawclk-also-on-resume.patch.
- Refresh
  patches.suse/drm-i915-userptr-Never-allow-userptr-into-the-mappab.patch.
- commit 46ba73b
* Wed Feb  3 2021 jroedel@suse.de
- KVM: SVM: Update cr3_lm_rsvd_bits for AMD SEV guests
  (bsc#1178995).
- KVM: x86: Introduce cr3_lm_rsvd_bits in kvm_vcpu_arch
  (bsc#1178995).
- commit 49749c4
* Wed Feb  3 2021 tiwai@suse.de
- r8169: fix WoL on shutdown if CONFIG_DEBUG_SHIRQ is set
  (git-fixes).
- commit ab82b36
* Wed Feb  3 2021 mkubecek@suse.cz
- Update kabi files.
- update from February 2021 maintenance update submission (commit 1e925eb08318)
- commit 97b2a1f
* Wed Feb  3 2021 msuchanek@suse.de
- powerpc: kABI: add back suspend_disable_cpu in machdep_calls
  (bsc#1181674 ltc#189159).
- commit 09376cb
* Tue Feb  2 2021 rgoldwyn@suse.com
- exfat: Avoid allocating upcase table using kcalloc()
  (git-fixes).
- exec: Always set cap_ambient in cap_bprm_set_creds  (git-fixes).
- commit eb2e605
* Tue Feb  2 2021 nstange@suse.de
- io_uring: Fix current->fs handling in io_sq_wq_submit_work()
  (bsc#1179434 CVE-2020-29373).
- commit 3f561ee
* Tue Feb  2 2021 ptesarik@suse.cz
- blacklist.conf: no change to /sys/firmware/uv/query/max_cpus
- commit 737a803
* Tue Feb  2 2021 ptesarik@suse.cz
- s390/vfio-ap: No need to disable IRQ after queue reset
  (git-fixes).
- s390/vfio-ap: clean up vfio_ap resources when KVM pointer
  invalidated (git-fixes).
- commit d91ae22
* Tue Feb  2 2021 msuchanek@suse.de
- powerpc/pseries/mobility: refactor node lookup during DT update
  (bsc#1181674 ltc#189159).
- powerpc/rtas: remove unused rtas_suspend_me_data (bsc#1181674
  ltc#189159).
- powerpc/pseries/hibernation: remove prepare_late() callback
  (bsc#1181674 ltc#189159).
- powerpc/pseries/hibernation: perform post-suspend fixups later
  (bsc#1181674 ltc#189159).
- powerpc/rtas: remove unused rtas_suspend_last_cpu() (bsc#1181674
  ltc#189159).
- powerpc/pseries/hibernation: switch to rtas_ibm_suspend_me()
  (bsc#1181674 ltc#189159).
- powerpc/rtas: remove rtas_suspend_cpu() (bsc#1181674
  ltc#189159).
- powerpc/machdep: remove suspend_disable_cpu() (bsc#1181674
  ltc#189159).
- powerpc/pseries/hibernation: remove pseries_suspend_cpu()
  (bsc#1181674 ltc#189159).
- powerpc/pseries/hibernation: pass stream id via function
  arguments (bsc#1181674 ltc#189159).
- Refresh patches.suse/powerpc-pseries-hibernation-remove-redundant-cachein.patch
- powerpc/pseries/hibernation: drop pseries_suspend_begin()
  from suspend ops (bsc#1181674 ltc#189159).
- powerpc/rtas: remove rtas_ibm_suspend_me_unsafe() (bsc#1181674
  ltc#189159).
- powerpc/rtas: dispatch partition migration requests to pseries
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: retry partition suspend after error
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: signal suspend cancellation to
  platform (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: use stop_machine for join/suspend
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: extract VASI session polling logic
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: use rtas_activate_firmware() on resume
  (bsc#1181674 ltc#189159).
- Refresh patches.suse/powerpc-pseries-mobility-notify-network-peers-after-.patch
- powerpc/pseries/mobility: error message improvements
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: add missing break to default case
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: don't error on absence of ibm,
  update-nodes (bsc#1181674 ltc#189159).
- powerpc/hvcall: add token and codes for H_VASI_SIGNAL
  (bsc#1181674 ltc#189159).
- powerpc/rtas: add rtas_activate_firmware() (bsc#1181674
  ltc#189159).
- powerpc/rtas: add rtas_ibm_suspend_me() (bsc#1181674
  ltc#189159).
- powerpc/rtas: rtas_ibm_suspend_me -> rtas_ibm_suspend_me_unsafe
  (bsc#1181674 ltc#189159).
- powerpc/rtas: complete ibm,suspend-me status codes (bsc#1181674
  ltc#189159).
- powerpc/rtas: prevent suspend-related sys_rtas use on LE
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: Add pr_debug() for device tree changes
  (bsc#1181674 ltc#189159).
- powerpc/pseries/mobility: Set pr_fmt() (bsc#1181674 ltc#189159).
- powerpc/pseries: remove obsolete memory hotplug DT notifier code
  (bsc#1181674 ltc#189159).
- Refresh patches.suse/powerpc-pseries-update-device-tree-before-ejecting-h.patch
- powerpc/pseries: remove dlpar_cpu_readd() (bsc#1181674
  ltc#189159).
- powerpc/pseries: remove memory "re-add" implementation
  (bsc#1181674 ltc#189159).
- powerpc/pseries: remove prrn special case from DT update path
  (bsc#1181674 ltc#189159).
- powerpc/numa: remove arch_update_cpu_topology (bsc#1181674
  ltc#189159).
- powerpc/numa: remove prrn_is_enabled() (bsc#1181674 ltc#189159).
- powerpc/rtasd: simplify handle_rtas_event(), emit message on
  events (bsc#1181674 ltc#189159).
- powerpc/numa: remove start/stop_topology_update() (bsc#1181674
  ltc#189159).
- powerpc/numa: remove timed_topology_update() (bsc#1181674
  ltc#189159).
- powerpc/numa: stub out numa_update_cpu_topology() (bsc#1181674
  ltc#189159).
- powerpc/numa: remove vphn_enabled and prrn_enabled internal
  flags (bsc#1181674 ltc#189159).
- powerpc/numa: remove unreachable topology workqueue code
  (bsc#1181674 ltc#189159).
- powerpc/numa: remove unreachable topology timer code
  (bsc#1181674 ltc#189159).
- powerpc/numa: make vphn_enabled, prrn_enabled flags const
  (bsc#1181674 ltc#189159).
- powerpc/numa: remove unreachable topology update code
  (bsc#1181674 ltc#189159).
- powerpc/numa: remove ability to enable topology updates
  (bsc#1181674 ltc#189159).
- powerpc/numa: Remove late request for home node associativity
  (bsc#1181674 ltc#189159).
- commit 88bd021
* Tue Feb  2 2021 bp@suse.de
- Refresh patches.suse/edac-amd64-set-grain-per-dimm.patch.
  Readd the second hunk which wasn't needed during the original git-fixes
  backport.
- commit 9c3639f
* Mon Feb  1 2021 tbogendoerfer@suse.de
- rxrpc: Fix memory leak in rxrpc_lookup_local (bsc#1154353
  bnc#1151927 5.3.9).
- net/mlx5e: E-switch, Fix rate calculation for overflow
  (jsc#SLE-8464).
- i40e: acquire VSI pointer only after VF is initialized
  (jsc#SLE-8025).
- ice: Fix MSI-X vector fallback logic (jsc#SLE-7926).
- ice: Don't allow more channels than LAN MSI-X available
  (jsc#SLE-7926).
- Revert "RDMA/mlx5: Fix devlink deadlock on net namespace
  deletion" (jsc#SLE-8464).
- commit 76b9a3a
* Mon Feb  1 2021 ematsumiya@suse.de
- scsi: qla2xxx: Fix description for parameter
  ql2xenforce_iocb_limit (bsc#1179142).
- commit f3ce867
* Mon Feb  1 2021 jroedel@suse.de
- kABI: Fix kABI for extended APIC-ID support (bsc#1181259,
  jsc#ECO-3191).
- x86/kvm: Add KVM_FEATURE_MSI_EXT_DEST_ID (bsc#1181259,
  jsc#ECO-3191).
- commit 0e40024
* Mon Feb  1 2021 jroedel@suse.de
- x86/apic: Support 15 bits of APIC ID in IOAPIC/MSI where
  available (bsc#1181259, jsc#ECO-3191).
- x86/ioapic: Handle Extended Destination ID field in RTE
  (bsc#1181259, jsc#ECO-3191).
- x86/msi: Only use high bits of MSI address for DMAR unit
  (bsc#1181259, jsc#ECO-3191).
- commit 077256e
* Mon Feb  1 2021 jroedel@suse.de
- x86/kvm: Reserve KVM_FEATURE_MSI_EXT_DEST_ID (bsc#1181259
  jsc#ECO-3191).
- commit 0deae09
* Mon Feb  1 2021 ptesarik@suse.cz
- blacklist.conf: no need to fix code for CONFIG_KEXEC_JUMP
- commit 3abe54d
* Mon Feb  1 2021 bp@suse.de
- blacklist.conf: e45122893a98 x86/fpu: Add kernel_fpu_begin_mask() to selectively initialize state
- commit f36235a
* Mon Feb  1 2021 mkubecek@suse.cz
- nbd: freeze the queue while we're adding connections
  (CVE-2021-3348 bsc#1181504).
- commit 78453ee
* Mon Feb  1 2021 tiwai@suse.de
- leds: trigger: fix potential deadlock with libata (git-fixes).
- commit d410ad0
* Mon Feb  1 2021 dbueso@suse.de
-  Update patch References tags for futex fixes (bsc#1181349 CVE-2021-3347)
- commit b3fac23
* Sun Jan 31 2021 tiwai@suse.de
- HID: wacom: Correct NULL dereference on AES pen proximity
  (git-fixes).
- HID: wacom: Fix memory leakage caused by kfifo_alloc
  (git-fixes).
- HID: wacom: Constify attribute_groups (git-fixes).
- HID: wacom: do not call hid_set_drvdata(hdev, NULL) (git-fixes).
- commit c0ccdd7
* Sat Jan 30 2021 tiwai@suse.de
- ACPI/IORT: Do not blindly trust DMA masks from firmware
  (git-fixes).
- PM: hibernate: flush swap writer after marking (git-fixes).
- ACPI: sysfs: Prefer "compatible" modalias (git-fixes).
- drm/i915: Check for all subplatform bits (git-fixes).
- drm/nouveau/svm: fail NOUVEAU_SVM_INIT ioctl on unsupported
  devices (git-fixes).
- commit 274cf96
* Sat Jan 30 2021 ailiop@suse.com
- iomap: fix WARN_ON_ONCE() from unprivileged users (bsc#1181494).
- commit 2958b80
* Fri Jan 29 2021 ptesarik@suse.cz
- net/smc: fix direct access to ib_gid_addr->ndev in
  smc_ib_determine_gid() (git-fixes).
- net/smc: fix valid DMBE buffer sizes (git-fixes).
- net/smc: fix sock refcounting in case of termination
  (git-fixes).
- net/smc: reset sndbuf_desc if freed (git-fixes).
- net/smc: set rx_off for SMCR explicitly (git-fixes).
- net/smc: fix dmb buffer shortage (git-fixes).
- net/smc: remove freed buffer from list (git-fixes).
- net/smc: switch smcd_dev_list spinlock to mutex (git-fixes).
- net/smc: fix sleep bug in smc_pnet_find_roce_resource()
  (git-fixes).
- net/smc: cancel event worker during device removal (git-fixes).
- net/smc: check for valid ib_client_data (git-fixes).
- net/smc: fix cleanup for linkgroup setup failures (git-fixes).
- net/smc: no peer ID in CLC decline for SMCD (git-fixes).
- net/smc: transfer fasync_list in case of fallback (git-fixes).
- commit a9e7337
* Fri Jan 29 2021 mkoutny@suse.com
- mm: memcontrol: fix missing wakeup polling thread (bsc#1181584).
- commit c0272b7
* Fri Jan 29 2021 mkoutny@suse.com
- blacklist.conf: Add 4230e2deaa48 stop_machine, rcu: Mark functions as notrace
- commit 9596511
* Fri Jan 29 2021 mkoutny@suse.com
- blacklist.conf: Add 15ec0fcff6da kernel/sys.c: replace do_brk with do_brk_flags in comment of prctl_set_mm_map()
- commit 7773384
* Fri Jan 29 2021 mkoutny@suse.com
- ptrace: Set PF_SUPERPRIV when checking capability (bsc#1163930).
- ptrace: reintroduce usage of subjective credentials in
  ptrace_has_cap() (bsc#1163930).
- commit 1d6137d
* Fri Jan 29 2021 jeyu@suse.de
- module: delay kobject uevent until after module init call (bsc#1178631).
- Refresh patches.suse/supported-flag
- commit 2796828
* Fri Jan 29 2021 ptesarik@suse.cz
- vfio iommu: Add dma available capability (bsc#1179572
  LTC#190110).
- commit 6544fbc
* Fri Jan 29 2021 tiwai@suse.de
- HID: multitouch: Remove MT_CLS_WIN_8_DUAL (git-fixes).
- Refresh
  patches.suse/HID-quirks-Always-poll-three-more-Lenovo-PixArt-mice.patch.
- commit bed41ce
* Fri Jan 29 2021 tiwai@suse.de
- can: dev: prevent potential information leak in can_fill_info()
  (git-fixes).
- mt7601u: fix kernel crash unplugging the device (git-fixes).
- mt7601u: fix rx buffer refcounting (git-fixes).
- NFC: fix resource leak when target index is invalid (git-fixes).
- NFC: fix possible resource leak (git-fixes).
- firmware: imx: select SOC_BUS to fix firmware build (git-fixes).
- HID: multitouch: Apply MT_QUIRK_CONFIDENCE quirk for multi-input
  devices (git-fixes).
- media: rc: ensure that uevent can be read directly after rc
  device register (git-fixes).
- HID: multitouch: do not filter mice nodes (git-fixes).
- commit f7694e1
* Fri Jan 29 2021 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/0001-futex-Ensure-the-correct-return-value-from-futex_loc.patch
  patches.suse/0002-futex-Replace-pointless-printk-in-fixup_owner.patch
  patches.suse/0003-futex-Provide-and-use-pi_state_update_owner.patch
  patches.suse/0004-rtmutex-Remove-unused-argument-from-rt_mutex_proxy_u.patch
  patches.suse/0005-futex-Use-pi_state_update_owner-in-put_pi_state.patch
  patches.suse/0006-futex-Simplify-fixup_pi_state_owner.patch
  patches.suse/0007-futex-Handle-faults-correctly-for-PI-futexes.patch
- commit 16c5d87
* Thu Jan 28 2021 tiwai@suse.de
- Move upstreamed sound patches into sorted section
- commit 84af2ff
* Thu Jan 28 2021 tiwai@suse.de
- ALSA: hda/via: Apply the workaround generically for Clevo
  machines (git-fixes).
- ASoC: ak4458: correct reset polarity (git-fixes).
- ALSA: hda/realtek: Enable headset of ASUS B1400CEPE with ALC256
  (git-fixes).
- commit e5943b7
* Thu Jan 28 2021 ailiop@suse.com
- xfs: show the proper user quota options (bsc#1181538).
- commit e34397a
* Thu Jan 28 2021 dbueso@suse.de
- futex: Handle faults correctly for PI futexes (bsc#1181349
  bsc#1149032).
- futex: Simplify fixup_pi_state_owner() (bsc#1181349
  bsc#1149032).
- futex: Use pi_state_update_owner() in put_pi_state()
  (bsc#1181349 bsc#1149032).
- rtmutex: Remove unused argument from rt_mutex_proxy_unlock()
  (bsc#1181349 bsc#1149032).
- futex: Provide and use pi_state_update_owner() (bsc#1181349
  bsc#1149032).
- futex: Replace pointless printk in fixup_owner() (bsc#1181349
  bsc#1149032).
- futex: Ensure the correct return value from futex_lock_pi()
  (bsc#1181349 bsc#1149032).
- futex: Remove unused empty compat_exit_robust_list()
  (bsc#1149032).
- futex: Remove needless goto's (bsc#1149032).
- commit 8a00d32
* Thu Jan 28 2021 ohering@suse.de
- x86/hyperv: Fix kexec panic/hang issues (bsc#1176831).
- refresh patches.suse/suse-hv-kabi.patch
- commit 3bdfdcf
* Thu Jan 28 2021 fdmanana@suse.com
- btrfs: send: fix invalid clone operations when cloning from
  the same file and root (bsc#1181511).
- commit 090f75a
* Thu Jan 28 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/nfsd4-readdirplus-shouldn-t-return-parent-of-export.patch
- commit 2f3e2e1
* Thu Jan 28 2021 tiwai@suse.de
- xhci: tegra: Delay for disabling LFPS detector (git-fixes).
- xhci: make sure TRB is fully written before giving it to the
  controller (git-fixes).
- USB: ehci: fix an interrupt calltrace error (git-fixes).
- ehci: fix EHCI host controller initialization sequence
  (git-fixes).
- i2c: bpmp-tegra: Ignore unknown I2C_M flags (git-fixes).
- platform/x86: ideapad-laptop: Disable touchpad_switch for
  ELAN0634 (git-fixes).
- drm/nouveau/kms/nv50-: fix case where notifier buffer is at
  offset 0 (git-fixes).
- drm/nouveau/mmu: fix vram heap sizing (git-fixes).
- drm/nouveau/i2c/gm200: increase width of aux semaphore owner
  fields (git-fixes).
- drm/nouveau/privring: ack interrupts the same way as RM
  (git-fixes).
- drm/nouveau/bios: fix issue shadowing expansion ROMs
  (git-fixes).
- drm/amdgpu/psp: fix psp gfx ctrl cmds (git-fixes).
- HID: Ignore battery for Elan touchscreen on ASUS UX550
  (git-fixes).
- HID: logitech-dj: add the G602 receiver (git-fixes).
- HID: multitouch: Enable multi-input for Synaptics
  pointstick/touchpad device (git-fixes).
- commit 6194af6
* Thu Jan 28 2021 neilb@suse.de
- blacklist.conf: unwanted NFS patches
- commit 6f9f1d0
* Thu Jan 28 2021 neilb@suse.de
- nfsd4: readdirplus shouldn't return parent of export
  (git-fixes).
- commit 5e9f700
* Wed Jan 27 2021 ematsumiya@suse.de
- nvme-tcp: avoid request double completion for concurrent
  nvme_tcp_timeout (bsc#1181161).
- nvme-rdma: avoid request double completion for concurrent
  nvme_rdma_timeout (bsc#1181161).
- commit 7760e28
* Wed Jan 27 2021 jgross@suse.com
- x86/xen: avoid warning in Xen pv guest with
  CONFIG_AMD_MEM_ENCRYPT enabled (bsc#1181335).
- commit ada97e4
* Wed Jan 27 2021 jgross@suse.com
- xen-blkfront: allow discard-* nodes to be optional
  (bsc#1181346).
- commit 958c625
* Wed Jan 27 2021 jgross@suse.com
- xen/privcmd: allow fetching resource sizes (bsc#1065600).
- commit 21fc6aa
* Wed Jan 27 2021 msuchanek@suse.de
- scsi: ibmvfc: Set default timeout to avoid crash during
  migration (bsc#1181425 ltc#188252).
- commit 9a4138b
* Wed Jan 27 2021 mkubecek@suse.cz
- series.conf: cleanup
- rename patches to get rid of numeric prefix (for easier resolve of merge conflict)
  patches.suse/0001-drm-rockchip-Avoid-uninitialized-use-of-endpoint-id-.patch -> patches.suse/drm-rockchip-Avoid-uninitialized-use-of-endpoint-id-.patch
  patches.suse/0002-drm-gma500-fix-double-free-of-gma_connector.patch -> patches.suse/drm-gma500-fix-double-free-of-gma_connector.patch
  patches.suse/0003-drm-aspeed-Fix-Kconfig-warning-subsequent-build-erro.patch -> patches.suse/drm-aspeed-Fix-Kconfig-warning-subsequent-build-erro.patch
  patches.suse/0004-drm-dp_aux_dev-check-aux_dev-before-use-in-drm_dp_au.patch -> patches.suse/drm-dp_aux_dev-check-aux_dev-before-use-in-drm_dp_au.patch
  patches.suse/0005-drm-mcde-Fix-handling-of-platform_get_irq-error.patch -> patches.suse/drm-mcde-Fix-handling-of-platform_get_irq-error.patch
  patches.suse/0006-drm-tve200-Fix-handling-of-platform_get_irq-error.patch -> patches.suse/drm-tve200-Fix-handling-of-platform_get_irq-error.patch
  (no effect on expanded tree)
- commit 772573f
* Wed Jan 27 2021 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section
  patches.suse/floppy-reintroduce-O_NDELAY-fix.patch
- commit 39bee61
* Tue Jan 26 2021 bp@suse.de
- arch/x86/lib/usercopy_64.c: fix __copy_user_flushcache()
  cache writeback (bsc#1152489).
- commit 852fa4b
* Tue Jan 26 2021 dwagner@suse.de
- scsi: lpfc: Simplify bool comparison (bsc#1180891).
- scsi: lpfc: Update lpfc version to 12.8.0.7 (bsc#1180891).
- scsi: lpfc: Enhancements to LOG_TRACE_EVENT for better
  readability (bsc#1180891).
- scsi: lpfc: Implement health checking when aborting I/O
  (bsc#1180891).
- scsi: lpfc: Fix crash when nvmet transport calls host_release
  (bsc#1180891).
- scsi: lpfc: Fix vport create logging (bsc#1180891).
- scsi: lpfc: Fix NVMe recovery after mailbox timeout
  (bsc#1180891).
- scsi: lpfc: Fix target reset failing (bsc#1180891).
- scsi: lpfc: Fix error log messages being logged following SCSI
  task mgnt (bsc#1180891).
- scsi: lpfc: Prevent duplicate requests to unregister with
  cpuhp framework (bsc#1180891).
- scsi: lpfc: Fix FW reset action if I/Os are outstanding
  (bsc#1180891).
- scsi: lpfc: Use the nvme-fc transport supplied timeout for LS
  requests (bsc#1180891).
- scsi: lpfc: Fix crash when a fabric node is released prematurely
  (bsc#1180891).
- scsi: lpfc: Refresh ndlp when a new PRLI is received in the
  PRLI issue state (bsc#1180891).
- scsi: lpfc: Fix auto sli_mode and its effect on CONFIG_PORT
  for SLI3 (bsc#1180891).
- scsi: lpfc: Fix PLOGI S_ID of 0 on pt2pt config (bsc#1180891).
- commit cdea5d0
* Tue Jan 26 2021 bp@suse.de
- x86/topology: Make __max_die_per_package available
  unconditionally (bsc#1152489).
- commit 0e0c8a8
* Tue Jan 26 2021 bp@suse.de
- x86/cpu/amd: Set __max_die_per_package on AMD (bsc#1152489).
- commit 3044309
* Mon Jan 25 2021 tiwai@suse.de
- drm/i915/gt: Declare gen9 has 64 mocs entries! (git-fixes).
- drm/etnaviv: always start/stop scheduler in timeout processing
  (git-fixes).
- commit 6ef999c
* Mon Jan 25 2021 tiwai@suse.de
- drm/i915/dsi: Use unconditional msleep for the panel_on_delay
  when there is no reset-deassert MIPI-sequence (git-fixes).
- drm/i915: clear the gpu reloc batch (git-fixes).
- drm/amdgpu: fix a GPU hang issue when remove device (git-fixes).
- drm/i915: Fix mismatch between misplaced vma check and vma
  insert (git-fixes).
- commit cc8174e
* Mon Jan 25 2021 tiwai@suse.de
- drm/amdkfd: Fix leak in dmabuf import (git-fixes).
- drm/msm/dsi_phy_10nm: implement PHY disabling (git-fixes).
- drm/msm/dsi_pll_10nm: restore VCO rate during restore_state
  (git-fixes).
- drm/msm/dpu: Add newline to printks (git-fixes).
- drm/meson: dw-hdmi: Register a callback to disable the regulator
  (git-fixes).
- drm/omap: dmm_tiler: fix return error code in omap_dmm_probe()
  (git-fixes).
- drm/amdgpu: fix build_coefficients() argument (git-fixes).
- drm/amd/display: remove useless if/else (git-fixes).
- drm/tve200: Fix handling of platform_get_irq() error
  (git-fixes).
- drm/mcde: Fix handling of platform_get_irq() error (git-fixes).
- drm/dp_aux_dev: check aux_dev before use in
  drm_dp_aux_dev_get_by_minor() (git-fixes).
- drm/aspeed: Fix Kconfig warning & subsequent build errors
  (git-fixes).
- drm/gma500: fix double free of gma_connector (git-fixes).
- drm/i915/display/dp: Compute the correct slice count for VDSC
  on DP (git-fixes).
- drm/rockchip: Avoid uninitialized use of endpoint id in LVDS
  (git-fixes).
- drm/i915/gt: Program mocs:63 for cache eviction on gen9
  (git-fixes).
- drm/tegra: sor: Disable clocks on error in tegra_sor_init()
  (git-fixes).
- drm/tegra: replace idr_init() by idr_init_base() (git-fixes).
- drm/i915/gt: Free stale request on destroying the virtual engine
  (git-fixes).
- drm/i915/gvt: return error when failing to take the module
  reference (git-fixes).
- drm/i915/gvt: Set ENHANCED_FRAME_CAP bit (git-fixes).
- drm/i915: Handle max_bpc==16 (git-fixes).
- drm/i915: Avoid memory leak with more than 16 workarounds on
  a list (git-fixes).
- drm/amd/display: Add missing pflip irq for dcn2.0 (git-fixes).
- drm/gma500: Fix out-of-bounds access to struct
  drm_device.vblank[] (git-fixes).
- drm/amdgpu: perform srbm soft reset always on SDMA resume
  (git-fixes).
- commit bd76ab9
* Mon Jan 25 2021 tiwai@suse.de
- drm/nouveau/nouveau: fix the start/end range for migration
  (git-fixes).
- drm/vc4: drv: Add error handding for bind (git-fixes).
- drm/sun4i: frontend: Fix the scaler phase on A33 (git-fixes).
- drm/sun4i: frontend: Reuse the ch0 phase for RGB formats
  (git-fixes).
- drm/sun4i: frontend: Rework a bit the phase data (git-fixes).
- drm/amd/display: Don't invoke kgdb_breakpoint() unconditionally
  (git-fixes).
- drm/amdgpu: increase the reserved VM size to 2MB (git-fixes).
- drm/amdgpu: don't map BO in reserved region (git-fixes).
- drm/amdgpu: add DID for navi10 blockchain SKU (git-fixes).
- drm/i915: Drop runtime-pm assert from vgpu io accessors
  (git-fixes).
- drm/i915: Force VT'd workarounds when running as a guest OS
  (git-fixes).
- drm/i915/gt: Delay execlist processing for tgl (git-fixes).
- commit d9edd32
* Mon Jan 25 2021 tiwai@suse.de
- drm/amdkfd: Use same SQ prefetch setting as amdgpu (git-fixes).
- drm/amd/display: Avoid MST manager resource leak (git-fixes).
- drm/amdgpu: correct the gpu reset handling for job != NULL case
  (git-fixes).
- drm/ttm: fix eviction valuable range check (git-fixes).
- drm/amd/display: HDMI remote sink need mode validation for Linux
  (git-fixes).
- drm/amd/display: Increase timeout for DP Disable (git-fixes).
- drm/i915: Break up error capture compression loops with
  cond_resched() (git-fixes).
- drm/msm/a6xx: fix a potential overflow issue (git-fixes).
- drm/panfrost: add amlogic reset quirk callback (git-fixes).
- drm/bridge/synopsys: dsi: add support for non-continuous HS
  clock (git-fixes).
- commit 3790415
* Mon Jan 25 2021 tiwai@suse.de
- drm/brige/megachips: Add checking if ge_b850v3_lvds_init()
  is working correctly (git-fixes).
- drm/nouveau/mem: guard against NULL pointer access in mem_del
  (git-fixes).
- drm/amdgpu: prevent double kfree ttm->sg (git-fixes).
- drm/sun4i: mixer: Extend regmap max_register (git-fixes).
- commit f36768e
* Mon Jan 25 2021 tiwai@suse.de
- drm/i915: Filter wake_flags passed to default_wake_function
  (git-fixes).
- drm/amdgpu/dc: Require primary plane to be enabled whenever
  the CRTC is (git-fixes).
- drm/amd/display: update nv1x stutter latencies (git-fixes).
- drm/amdkfd: fix a memory leak issue (git-fixes).
- drm/tve200: Stabilize enable/disable (git-fixes).
- drm/msm: Disable preemption on all 5xx targets (git-fixes).
- drm/amdgpu: Fix bug in reporting voltage for CIK (git-fixes).
- drm/amd/pm: avoid false alarm due to confusing
  softwareshutdowntemp setting (git-fixes).
- drm/omap: fix incorrect lock state (git-fixes).
- drm/amd/display: Fix memleak in amdgpu_dm_mode_config_init
  (git-fixes).
- drm/amd/display: Retry AUX write when fail occurs (git-fixes).
- drm/amd/display: Reject overlay plane configurations in
  multi-display scenarios (git-fixes).
- drm/msm/a6xx: fix gmu start on newer firmware (git-fixes).
- drm/msm: add shutdown support for display platform_driver
  (git-fixes).
- drm/msm/dpu: Fix scale params in plane validation (git-fixes).
- drm/i915/selftests: Avoid passing a random 0 into ilog2
  (git-fixes).
- drm/amdgpu: Fix bug where DPM is not enabled after hibernate
  and resume (git-fixes).
- drm/amd/display: dchubbub p-state warning during surface planes
  switch (git-fixes).
- commit 64cc324
* Mon Jan 25 2021 tiwai@suse.de
- drm: Added orientation quirk for ASUS tablet model T103HAF
  (git-fixes).
- drm/amdkfd: fix restore worker race condition (git-fixes).
- drm/nouveau/dispnv50: fix runtime pm imbalance on error
  (git-fixes).
- drm/nouveau: fix runtime pm imbalance on error (git-fixes).
- drm/nouveau/debugfs: fix runtime pm imbalance on error
  (git-fixes).
- commit 406e9f7
* Mon Jan 25 2021 tiwai@suse.de
- drm/exynos: dsi: Remove bridge node reference in error handling
  path in probe function (git-fixes).
- drm: rcar-du: Set primary plane zpos immutably at initializing
  (git-fixes).
- drm/amdgpu/sriov add amdgpu_amdkfd_pre_reset in gpu reset
  (git-fixes).
- drm/msm/a5xx: Always set an OPP supported hardware value
  (git-fixes).
- drm/msm: fix leaks if initialization fails (git-fixes).
- drm/amd/display: Stop if retimer is not available (git-fixes).
- drm/amdgpu: increase atombios cmd timeout (git-fixes).
- drm/omap: dss: Cleanup DSS ports on initialisation failure
  (git-fixes).
- commit db34b82
* Mon Jan 25 2021 tiwai@suse.de
- drm/amd/display: dal_ddc_i2c_payloads_create can fail causing
  panic (git-fixes).
- drm/omap: fix possible object reference leak (git-fixes).
- drm/amdgpu: fix calltrace during kmd unload(v3) (git-fixes).
- drm/scheduler: Avoid accessing freed bad job (git-fixes).
- drm/amdgpu/powerplay/smu7: fix AVFS handling with custom
  powerplay table (git-fixes).
- drm/amdgpu/powerplay: fix AVFS handling with custom powerplay
  table (git-fixes).
- drm/amd/display: Free gamma after calculating legacy transfer
  function (git-fixes).
- drm/amd/display: Do not double-buffer DTO adjustments
  (git-fixes).
- commit c18126a
* Mon Jan 25 2021 tiwai@suse.de
- drm/i915/gt: Prevent use of engine->wa_ctx after error
  (git-fixes).
- drm/syncobj: Fix use-after-free (git-fixes).
- drm/atomic: put state on error path (git-fixes).
- commit 4cd1094
* Mon Jan 25 2021 tiwai@suse.de
- ACPI: scan: Make acpi_bus_get_device() clear return pointer
  on error (git-fixes).
- cachefiles: Drop superfluous readpages aops NULL check
  (git-fixes).
- ACPI: scan: Harden acpi_device_add() against device ID overflows
  (git-fixes).
- commit 963543c
* Mon Jan 25 2021 tbogendoerfer@suse.de
- net/mlx5e: ethtool, Fix restriction of autoneg with 56G
  (jsc#SLE-8464).
- net: hns3: fix a phy loopback fail issue (bsc#1154353).
- net: vlan: avoid leaks on register_vlan_dev() failures
  (bsc#1154353).
- bnxt_en: Fix AER recovery (jsc#SLE-8371 bsc#1153274).
- e1000e: bump up timeout to wait when ME un-configures ULP mode
  (jsc#SLE-8100).
- ionic: account for vlan tag len in rx buffer len (bsc#1167773).
- ice, xsk: clear the status bits for the next_to_use descriptor
  (jsc#SLE-7926).
- net: fix proc_fs init handling in af_packet and tls
  (bsc#1154353).
- ice: avoid premature Rx buffer reuse (jsc#SLE-7926).
- net: hns3: remove a misused pragma packed (bsc#1154353).
- commit 465e7d7
* Mon Jan 25 2021 msuchanek@suse.de
- blacklist.conf: Add 08685be7761d powerpc/64s: fix scv entry fallback flush vs interrupt
  No scv support.
- commit 7e491e5
* Mon Jan 25 2021 jslaby@suse.cz
- selftests: net: fib_tests: remove duplicate log test
  (git-fixes).
- net: mscc: ocelot: allow offloading of bridge on top of LAG
  (git-fixes).
- udp: Prevent reuseport_select_sock from reading uninitialized
  socks (git-fixes).
- pNFS: Mark layout for return if return-on-close was not sent
  (git-fixes).
- commit 87c48df
* Mon Jan 25 2021 mkubecek@suse.cz
- series.conf: cleanup
- move kabi workaround into patches.kabi:
  patches.suse/ALSA-pcm-fix-hw_rule-deps-kABI.patch
- commit 3eee3e1
* Mon Jan 25 2021 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/scsi-scsi_transport_srp-Don-t-block-target-in-failfa.patch
  patches.suse/selftests-powerpc-Only-test-lwm-stmw-on-big-endian.patch
- commit 5218f70
* Mon Jan 25 2021 mkubecek@suse.cz
- series.conf: cleanup
- move an unsortable patch out of sorted section
  patches.suse/powerpc-Fix-build-error-in-paravirt.h.patch
- commit 0f64295
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/tve200: Fix handling of platform_get_irq() error (bsc#1152472)
- commit 8541d40
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/mcde: Fix handling of platform_get_irq() error (bsc#1152472)
- commit 60b9525
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/dp_aux_dev: check aux_dev before use in (bsc#1152472)
- commit 21532d2
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/aspeed: Fix Kconfig warning & subsequent build errors (bsc#1152472)
- commit 3d14ba8
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/gma500: fix double free of gma_connector (bsc#1152472)
  Backporting notes:
  * context changes
- commit 2ce14eb
* Mon Jan 25 2021 tzimmermann@suse.de
- drm/rockchip: Avoid uninitialized use of endpoint id in LVDS (bsc#1152472)
- commit 103a121
* Mon Jan 25 2021 tiwai@suse.de
- iio: ad5504: Fix setting power-down state (git-fixes).
- serial: mvebu-uart: fix tx lost characters at power off
  (git-fixes).
- usb: udc: core: Use lock when write to soft_connect (git-fixes).
- usb: gadget: aspeed: fix stop dma register setting (git-fixes).
- commit 4d850d2
* Mon Jan 25 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vc4: gem: Add a managed action to cleanup the job queue'
- commit ce3d22f
* Mon Jan 25 2021 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vc4: bo: Add a managed action to cleanup the cache'
- commit 2cf161b
* Mon Jan 25 2021 glin@suse.com
- bpf: Fix helper bpf_map_peek_elem_proto pointing to wrong
  callback (bsc#1155518).
- bpf: Don't leak memory in bpf getsockopt when optlen == 0
  (bsc#1155518).
- commit 609f544
* Sun Jan 24 2021 tiwai@suse.de
- i2c: octeon: check correct size of maximum RECV_LEN packet
  (git-fixes).
- commit 54a675e
* Sat Jan 23 2021 tiwai@suse.de
- ALSA: pcm: fix hw_rule deps kABI (bsc#1181014).
- commit 3c80769
* Sat Jan 23 2021 tiwai@suse.de
- ALSA: pcm: One more dependency for hw constraints (bsc#1181014).
- commit d71290f
* Sat Jan 23 2021 tiwai@suse.de
- mmc: core: don't initialize block size from ext_csd if not
  present (git-fixes).
- mmc: sdhci-xenon: fix 1.8v regulator stabilization (git-fixes).
- platform/x86: intel-vbtn: Drop HP Stream x360 Convertible PC
  11 from allow-list (git-fixes).
- platform/x86: i2c-multi-instantiate: Don't create platform
  device for INT3515 ACPI nodes (git-fixes).
- commit 9c2a03f
* Sat Jan 23 2021 dbueso@suse.de
- timers: Use only bucket expiry for base->next_expiry value
  (bsc#1181318).
- timers: Preserve higher bits of expiration on index calculation
  (bsc#1181318).
- commit f60f618
* Fri Jan 22 2021 ptesarik@suse.cz
- s390/cio: fix use-after-free in ccw_device_destroy_console
  (git-fixes).
- commit d3e26e8
* Fri Jan 22 2021 ptesarik@suse.cz
- KVM: s390: pv: Mark mm as protected after the set secure
  parameters and improve cleanup (jsc#SLE-7512 bsc#1165545).
- commit 719d24b
* Fri Jan 22 2021 ptesarik@suse.cz
- net/af_iucv: set correct sk_protocol for child sockets
  (git-fixes).
- net/af_iucv: fix null pointer dereference on shutdown
  (bsc#1179567 LTC#190111).
- commit ddc328b
* Fri Jan 22 2021 ptesarik@suse.cz
- s390/dasd: fix hanging device offline processing (bsc#1181169
  LTC#190914).
- commit 9b7644e
* Fri Jan 22 2021 tiwai@suse.de
- ALSA: hda: Add Cometlake-R PCI ID (git-fixes).
- ALSA: seq: oss: Fix missing error check in
  snd_seq_oss_synth_make_info() (git-fixes).
- ALSA: hda/via: Add minimum mute flag (git-fixes).
- ALSA: hda/realtek - Limit int mic boost on Acer Aspire E5-575T
  (git-fixes).
- commit 70d9202
* Fri Jan 22 2021 tiwai@suse.de
- Move upstreamed sound patches into sorted section
- commit f5195da
* Thu Jan 21 2021 tiwai@suse.de
- blacklist.conf: Add entries for platform/x86/intel-vbtn that are reverted
- commit 5482ef1
* Thu Jan 21 2021 tiwai@suse.de
- platform/x86: intel-vbtn: Fix SW_TABLET_MODE always reporting
  1 on some HP x360 models (git-fixes).
- commit d6ac163
* Thu Jan 21 2021 tiwai@suse.de
- power: vexpress: add suppress_bind_attrs to true (git-fixes).
- commit bb22b7b
* Thu Jan 21 2021 fdmanana@suse.com
- btrfs: send: fix wrong file path when there is an inode with
  a pending rmdir (bsc#1181237).
- commit be4e71d
* Thu Jan 21 2021 tiwai@suse.de
- media: dvb-usb: Fix use-after-free access (bsc#1181104).
- media: dvb-usb: Fix memory leak at error in
  dvb_usb_device_init() (bsc#1181104).
- commit 3a92626
* Thu Jan 21 2021 tiwai@suse.de
- can: vxcan: vxcan_xmit: fix use after free bug (git-fixes).
- mac80211: check if atf has been disabled in
  __ieee80211_schedule_txq (git-fixes).
- mac80211: do not drop tx nulldata packets on encrypted links
  (git-fixes).
- commit dfeeb94
* Thu Jan 21 2021 jroedel@suse.de
- vfio-pci: Use io_remap_pfn_range() for PCI IO memory
  (bsc#1181220).
- iommu/vt-d: Fix a bug for PDP check in prq_event_thread
  (bsc#1181217).
- vfio/pci: Implement ioeventfd thread handler for contended
  memory lock (bsc#1181219).
- KVM: nVMX: Reload vmcs01 if getting vmcs12's pages fails
  (bsc#1181218).
- commit 517d1e9
* Thu Jan 21 2021 msuchanek@suse.de
- Update patches.suse/selftests-ftrace-Select-an-existing-function-in-kpro.patch (bsc#1181203 ltc#190909).
- commit e5512d0
* Thu Jan 21 2021 tzimmermann@suse.de
- drm/sun4i: dw-hdmi: fix error return code in sun8i_dw_hdmi_bind() (bsc#1152472)
- commit d0d0905
* Thu Jan 21 2021 tzimmermann@suse.de
- drm: bridge: dw-hdmi: Avoid resetting force in the detect function (bsc#1152472)
- commit 9ad528c
* Thu Jan 21 2021 tzimmermann@suse.de
- drm/i915: Correctly set SFC capability for video engines (bsc#1152489)
  Backporting notes:
  * context changes
- commit d15d9b1
* Wed Jan 20 2021 tiwai@suse.de
- ALSA: usb-audio: Fix hw constraints dependencies (bsc#1181014).
- commit 58d7b94
* Wed Jan 20 2021 tiwai@suse.de
- spi: cadence: cache reference clock rate during probe
  (git-fixes).
- r8152: Add Lenovo Powered USB-C Travel Hub (git-fixes).
- usb: typec: Fix copy paste error for NVIDIA alt-mode description
  (git-fixes).
- hwmon: (pwm-fan) Ensure that calculation doesn't discard big
  period values (git-fixes).
- ACPI: scan: add stub acpi_create_platform_device() for
  !CONFIG_ACPI (git-fixes).
- misdn: dsp: select CONFIG_BITREVERSE (git-fixes).
- commit 01db302
* Wed Jan 20 2021 msuchanek@suse.de
- selftests/ftrace: Select an existing function in
  kprobe_eventname test (bsc#1179396 ltc#185738).
- commit 3e9ea6f
* Wed Jan 20 2021 msuchanek@suse.de
- selftests/powerpc: spectre_v2 test must be built 64-bit
  (bsc#1181158 ltc#190851).
- commit 52f3d6b
* Wed Jan 20 2021 jgross@suse.com
- Update
  patches.suse/0001-xen-events-add-a-proper-barrier-to-2-level-uevent-un.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0002-xen-events-fix-race-in-evtchn_fifo_unmask.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0003-xen-events-add-a-new-late-EOI-evtchn-framework.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0004-xen-blkback-use-lateeoi-irq-binding.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0005-xen-netback-use-lateeoi-irq-binding.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0006-xen-scsiback-use-lateeoi-irq-binding.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0007-xen-pvcallsback-use-lateeoi-irq-binding.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0008-xen-pciback-use-lateeoi-irq-binding.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0009-xen-events-switch-user-event-channels-to-lateeoi-mod.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0010-xen-events-use-a-common-cpu-hotplug-hook-for-event-c.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0011-xen-events-defer-eoi-in-case-of-excessive-number-of-.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/0012-xen-events-block-rogue-events-for-some-time.patch
  (CVE-2020-27673 XSA-332 bsc#1177411).
- Update
  patches.suse/xen-events-avoid-removing-an-event-channel-while-han.patch
  (CVE-2020-27675 XSA-331 bsc#1177410).
- Added CVE numbers for above patches.
- commit 3b60580
* Wed Jan 20 2021 msuchanek@suse.de
- selftests/powerpc: Move set_dscr() into rfi_flush.c (bsc#1181158
  ltc#190851).
- selftests/powerpc: Move Hash MMU check to utilities (bsc#1181158
  ltc#190851).
- selftests/powerpc: Add a test of bad (out-of-range) accesses
  (bsc#1181158 ltc#190851).
- Refresh patches.suse/selftests-powerpc-Add-tlbie_test-in-.gitignore.patch.
- selftests/powerpc: Add a test of spectre_v2 mitigations
  (bsc#1181158 ltc#190851).
- Refresh patches.suse/selftests-powerpc-entry-flush-test.patch.
- selftests/powerpc: Ignore generated files (bsc#1181158
  ltc#190851).
- commit f53f10b
* Wed Jan 20 2021 msuchanek@suse.de
- selftests/powerpc: Only test lwm/stmw on big endian (bsc#1180412
  ltc#190579).
- commit 21bd682
* Wed Jan 20 2021 msuchanek@suse.de
- powerpc: Fix build error in paravirt.h (bsc#1181148 ltc#190702).
- commit 251d2f4
* Wed Jan 20 2021 msuchanek@suse.de
- Exclude Symbols.list again.
  Removing the exclude builds vanilla/linux-next builds.
  Fixes: 55877625c800 ("kernel-binary.spec.in: Package the obj_install_dir as explicit filelist.")
- commit a1728f2
* Wed Jan 20 2021 msuchanek@suse.de
- powerpc/paravirt: Use is_kvm_guest() in vcpu_is_preempted()
  (bsc#1181148 ltc#190702).
- powerpc: Reintroduce is_kvm_guest() as a fast-path check
  (bsc#1181148 ltc#190702).
- powerpc: Rename is_kvm_guest() to check_kvm_guest() (bsc#1181148
  ltc#190702).
- powerpc: Refactor is_kvm_guest() declaration to new header
  (bsc#1181148 ltc#190702).
- commit 17fe8f8
* Tue Jan 19 2021 msuchanek@suse.de
- floppy: reintroduce O_NDELAY fix (boo#1181018).
- commit ab10a7d
* Tue Jan 19 2021 ykaukab@suse.de
- arm64: pgtable: Ensure dirty bit is preserved across
  pte_wrprotect() (bsc#1180130).
- arm64: pgtable: Fix pte_accessible() (bsc#1180130).
- commit 585bbd5
* Tue Jan 19 2021 tiwai@suse.de
- Revive usb-audio Keep Interface mixer (bsc#1181014).
- commit 80020db
* Tue Jan 19 2021 mkubecek@suse.cz
- netfilter: ctnetlink: add a range check for l3/l4 protonum
  (CVE-2020-25211 bsc#1176395).
- commit ebf5e43
* Tue Jan 19 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/NFS-nfs_delegation_find_inode_server-must-first-refe.patch
  patches.suse/NFS-nfs_igrab_and_active-must-first-reference-the-su.patch
  patches.suse/NFS-pNFS-Fix-a-leak-of-the-layout-plh_outstanding-co.patch
  patches.suse/NFS-pNFS-Fix-a-typo-in-ff_layout_resend_pnfs_read.patch
  patches.suse/NFS-switch-nfsiod-to-be-an-UNBOUND-workqueue.patch
  patches.suse/NFS4-Fix-use-after-free-in-trace_event_raw_event_nfs.patch
  patches.suse/NFSv4-Fix-the-alignment-of-page-data-in-the-getdevic.patch
  patches.suse/NFSv4.2-condition-READDIR-s-mask-for-security-label-.patch
  patches.suse/Revert-nfsd4-support-change_attr_type-attribute.patch
  patches.suse/SUNRPC-Clean-up-the-handling-of-page-padding-in-rpc_.patch
  patches.suse/SUNRPC-rpc_wake_up-should-wake-up-tasks-in-the-corre.patch
  patches.suse/lockd-don-t-use-interval-based-rebinding-over-TCP.patch
  patches.suse/md-fix-a-warning-caused-by-a-race-between-concurrent.patch
  patches.suse/net-sunrpc-Fix-snprintf-return-value-check-in-do_xpr.patch
  patches.suse/net-sunrpc-interpret-the-return-value-of-kstrtou32-c.patch
  patches.suse/nfs_common-need-lock-during-iterate-through-the-list.patch
  patches.suse/nfsd-Fix-message-level-for-normal-termination.patch
  patches.suse/sunrpc-fix-xs_read_xdr_buf-for-partial-pages-receive.patch
- commit f5dfabc
* Tue Jan 19 2021 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/kprobes-tracing-kprobes-Fix-to-kill-kprobes-on-initmem-after-boot.patch
  patches.suse/mm-vmalloc-Fix-unlock-order-in-s_stop.patch
- commit 8ea9f59
* Tue Jan 19 2021 jslaby@suse.cz
- Refresh
  patches.suse/0011-x86-hpet-Move-MSI-support-into-hpet.c.patch.
- Update
  patches.suse/msft-hv-2119-irqdomain-treewide-Keep-firmware-node-unconditionall.patch
  (git-fixes bsc#1180889).
  Add missing hunks in the e3beca48a45b's backport.
- commit 977a539
* Tue Jan 19 2021 tbogendoerfer@suse.de
- Update
  patches.suse/tun-correct-header-offsets-in-napi-frags-mode.patch
  (git-fixes bsc#1180812 CVE-2021-0342).
  Added CVE reference
- commit 0059c1d
* Tue Jan 19 2021 neilb@suse.de
- NFS: nfs_igrab_and_active must first reference the superblock
  (for-next).
- NFS: nfs_delegation_find_inode_server must first reference
  the superblock (for-next).
- NFS/pNFS: Fix a leak of the layout 'plh_outstanding' counter
  (for-next).
- net: sunrpc: interpret the return value of kstrtou32 correctly
  (for-next).
- NFS4: Fix use-after-free in trace_event_raw_event_nfs4_set_lock
  (for-next).
- NFS/pNFS: Fix a typo in ff_layout_resend_pnfs_read() (for-next).
- sunrpc: fix xs_read_xdr_buf for partial pages receive
  (for-next).
- NFS: switch nfsiod to be an UNBOUND workqueue (for-next).
- lockd: don't use interval-based rebinding over TCP (for-next).
- net: sunrpc: Fix 'snprintf' return value check in
  'do_xprt_debugfs' (for-next).
- SUNRPC: Clean up the handling of page padding in
  rpc_prepare_reply_pages() (for-next).
- NFSv4: Fix the alignment of page data in the getdeviceinfo reply
  (for-next).
- NFSv4.2: condition READDIR's mask for security label based on
  LSM state (for-next).
- SUNRPC: rpc_wake_up() should wake up tasks in the correct order
  (for-next).
- md: fix a warning caused by a race between concurrent
  md_ioctl()s (for-next).
- Revert "nfsd4: support change_attr_type attribute" (for-next).
- nfs_common: need lock during iterate through the list
  (for-next).
- nfsd: Fix message level for normal termination (for-next).
- commit 685e8f2
* Mon Jan 18 2021 bp@suse.de
- x86/cpu/amd: Call init_amd_zn() om Family 19h processors too
  (bsc#1181077).
- commit a71f120
* Mon Jan 18 2021 mgorman@suse.de
- blacklist.conf: No in-tree users of the table
- commit 9c6c6be
* Mon Jan 18 2021 mgorman@suse.de
- kprobes: tracing/kprobes: Fix to kill kprobes on initmem after
  boot (git fixes (kernel/kprobe)).
- commit 47f3848
* Mon Jan 18 2021 mgorman@suse.de
- blacklist.conf: UP not enabled in kernel config
- commit c97848a
* Mon Jan 18 2021 mgorman@suse.de
- mm/vmalloc: Fix unlock order in s_stop() (git fixes
  (mm/vmalloc)).
- commit 70dafb3
* Mon Jan 18 2021 mgorman@suse.de
- blacklist.conf: nilfs2 not enabled in kernel config
- commit 409ae2f
* Mon Jan 18 2021 ptesarik@suse.cz
- s390/qeth: fix L2 header access in qeth_l3_osa_features_check()
  (git-fixes).
- s390/qeth: fix locking for discipline setup / removal
  (git-fixes).
- s390/qeth: fix deadlock during recovery (git-fixes).
- s390/dasd: fix list corruption of lcu list (git-fixes).
- s390/dasd: fix list corruption of pavgroup group list
  (git-fixes).
- s390/dasd: prevent inconsistent LCU device data (git-fixes).
- s390/smp: perform initial CPU reset also for SMT siblings
  (git-fixes).
- s390/kexec_file: fix diag308 subcode when loading crash kernel
  (git-fixes).
- s390/qeth: consolidate online/offline code (git-fixes).
- s390/qeth: don't raise NETDEV_REBOOT event from L3 offline path
  (git-fixes).
- commit 22371f9
* Mon Jan 18 2021 bp@suse.de
- blacklist.conf: 78762b0e79bc x86/asm/32: Add ENDs to some functions and relabel with SYM_CODE_*
- commit 2b5cd2a
* Mon Jan 18 2021 tiwai@suse.de
- ALSA: usb-audio: Avoid implicit feedback on Pioneer devices
  (bsc#1181014).
- ALSA: usb-audio: Set sample rate for all sharing EPs on UAC1
  (bsc#1181014).
- ALSA: usb-audio: Fix UAC1 rate setup for secondary endpoints
  (bsc#1181014).
- ALSA: usb-audio: Always apply the hw constraints for implicit
  fb sync (bsc#1181014).
- commit b78b9c6
* Fri Jan 15 2021 mkubecek@suse.cz
- Revert dwc3 series.
  As of now, this recently merged series fails to build without the kabi
  workaround which would break SLE15-SP3 merge. Drop the patches until the
  build failure is fixed.
- commit a8aaab2
* Fri Jan 15 2021 mbrugger@suse.com
- drivers/perf: Fix kernel panic when rmmod PMU modules during
  perf sampling (bsc#1180848).
- commit 8584e95
* Fri Jan 15 2021 tiwai@suse.de
- Drop incorrectly re-backported radeon patch again (bsc#1180971)
  Also add cherry-picked commit ids in the two relevant patches
- commit bb3221b
* Fri Jan 15 2021 aabdallah@suse.de
- KVM: SVM: Initialize prev_ga_tag before use (bsc#1180809).
- commit 953316b
* Thu Jan 14 2021 bp@suse.de
- blacklist.conf: 035fff1f7aab x86/PCI: Fix intel_mid_pci.c build error when ACPI is not enabled
- commit e52f15d
* Thu Jan 14 2021 bp@suse.de
- x86/kprobes: Restore BTF if the single-stepping is cancelled
  (bsc#1152489).
- commit f89b6b0
* Thu Jan 14 2021 oneukum@suse.com
- kABI fixup for dwc3 introduction of DWC_usb32 (git-fixes).
- commit 03d1108
* Thu Jan 14 2021 tiwai@suse.de
- ALSA: doc: Fix reference to mixart.rst (git-fixes).
- commit b4c3583
* Thu Jan 14 2021 tiwai@suse.de
- ASoC: meson: axg-tdm-interface: fix loopback (git-fixes).
- ASoC: dapm: remove widget from dirty list on free (git-fixes).
- ASoC: Intel: fix error code cnl_set_dsp_D0() (git-fixes).
- commit 04a1c91
* Thu Jan 14 2021 tiwai@suse.de
- ALSA: hda/hdmi - enable runtime pm for CI AMD display audio
  (git-fixes).
- ALSA: firewire-tascam: Fix integer overflow in midi_port_work()
  (git-fixes).
- ALSA: fireface: Fix integer overflow in transmit_midi_msg()
  (git-fixes).
- ALSA: hda/tegra: fix tegra-hda on tegra30 soc (git-fixes).
- clk: tegra30: Add hda clock default rates to clock driver
  (git-fixes).
- ALSA: usb-audio: Fix implicit feedback sync setup for Pioneer
  devices (git-fixes).
- ALSA: usb-audio: Annotate the endpoint index in audioformat
  (git-fixes).
- ALSA: usb-audio: Avoid unnecessary interface re-setup
  (git-fixes).
- ALSA: usb-audio: Choose audioformat of a counter-part substream
  (git-fixes).
- ALSA: usb-audio: Fix the missing endpoints creations for quirks
  (git-fixes).
- ALSA: hda/realtek: fix right sounds and mute/micmute LEDs for
  HP machines (git-fixes).
- commit db30ae4
* Thu Jan 14 2021 bp@suse.de
- x86/apic: Fix x2apic enablement without interrupt remapping
  (bsc#1152489).
- commit a8a5227
* Wed Jan 13 2021 tbogendoerfer@suse.de
- netfilter: add and use nf_hook_slow_list() (bsc#1180765
  CVE-2021-20177).
- commit 465dae1
* Wed Jan 13 2021 bp@suse.de
- Refresh patches.suse/edac-amd64-add-amd-family-17h-model-60h-pci-ids.patch.
  Complete the backport now that
  5e4c55276ae8 ("EDAC/amd64: Save max number of controllers to family type")
  has been backported too.
- commit f6cb75f
* Wed Jan 13 2021 oneukum@suse.com
- usb: dwc3: Add support for DWC_usb32 IP (git-fixes).
- commit f699093
* Wed Jan 13 2021 oneukum@suse.com
- usb: dwc3: Update soft-reset wait polling rate (git-fixes).
- commit 227b9e8
* Wed Jan 13 2021 mbrugger@suse.com
- drivers/perf: hisi: Permit modular builds of HiSilicon uncore drivers (bsc#1180848). - Update config files. - supported.conf:
- commit 3ceea3c
* Wed Jan 13 2021 martin.wilck@suse.com
- scsi: scsi_transport_srp: Don't block target in failfast state
  (bsc#1172355).
- commit 4d51a17
* Wed Jan 13 2021 jgross@suse.com
- xen: support having only one event pending per watch
  (bsc#1179508 XSA-349 CVE-2020-29568).
- commit b454020
* Wed Jan 13 2021 jgross@suse.com
- xen: revert Allow watches discard events before queueing
  (bsc#1179508 XSA-349 CVE-2020-29568).
- commit 7a45cd4
* Wed Jan 13 2021 jgross@suse.com
- xen: revert Add 'will_handle' callback support in
  xenbus_watch_path() (bsc#1179508 XSA-349 CVE-2020-29568).
- commit b9e03df
* Wed Jan 13 2021 jgross@suse.com
- xen: revert Support will_handle watch callback (bsc#1179508
  XSA-349 CVE-2020-29568).
- commit 3082598
* Wed Jan 13 2021 jgross@suse.com
- xen: revert Count pending messages for each watch (bsc#1179508
  XSA-349 CVE-2020-29568).
- commit 9d4ca48
* Wed Jan 13 2021 tiwai@suse.de
- video: fbdev: atmel_lcdfb: fix return error code in
  atmel_lcdfb_of_init() (git-fixes).
- video: fbdev: vga16fb: fix setting of pixclock because a
  pass-by-value error (git-fixes).
- video: fbdev: pvr2fb: initialize variables (git-fixes).
- video: fbdev: fix OOB read in vga_8planes_imageblit()
  (git-fixes).
- commit 7cdcf45
* Wed Jan 13 2021 jgross@suse.com
- xen: revert Disallow pending watch messages (bsc#1179508
  XSA-349 CVE-2020-29568).
- commit a948c9f
* Wed Jan 13 2021 tiwai@suse.de
- usb: gadget: enable super speed plus (git-fixes).
- USB: serial: option: add LongSung M5710 module support
  (git-fixes).
- USB: serial: option: add Quectel EM160R-GL (git-fixes).
- usb: uas: Add PNY USB Portable SSD to unusual_uas (git-fixes).
- usb: gadget: configfs: Fix use-after-free issue with udc_name
  (git-fixes).
- USB: usblp: fix DMA to stack (git-fixes).
- usb: gadget: Fix spinlock lockup on usb_function_deactivate
  (git-fixes).
- usb: gadget: function: printer: Fix a memory leak for interface
  descriptor (git-fixes).
- USB: cdc-wdm: Fix use after free in
  service_outstanding_interrupt() (git-fixes).
- USB: cdc-acm: blacklist another IR Droid device (git-fixes).
- crypto: asym_tpm: correct zero out potential secrets
  (git-fixes).
- net: usb: qmi_wwan: add Quectel EM160R-GL (git-fixes).
- CDC-NCM: remove "connected" log message (git-fixes).
- ethernet: ucc_geth: fix use-after-free in ucc_geth_remove()
  (git-fixes).
- lib/genalloc: fix the overflow when size is too big (git-fixes).
- Bluetooth: revert: hci_h5: close serdev device and free hu in
  h5_close (git-fixes).
- commit 052b915
* Tue Jan 12 2021 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/sched-fair-Check-for-idle-core-in-wake_affine.patch
- commit b5830a4
* Tue Jan 12 2021 bp@suse.de
- blacklist.conf: 4f8af077a02e docs: Fix reST markup when linking to sections
- commit 28e1ebf
* Tue Jan 12 2021 oneukum@suse.com
- usb: dwc3: core: Properly default unspecified speed (git-fixes).
- commit 777b42e
* Mon Jan 11 2021 bp@suse.de
- x86/resctrl: Don't move a task to the same resource group
  (bsc#1152489).
- commit 8a696c5
* Mon Jan 11 2021 bp@suse.de
- x86/resctrl: Use an IPI instead of task_work_add() to update
  PQR_ASSOC MSR (bsc#1152489).
- commit 309f3cb
* Mon Jan 11 2021 bp@suse.de
- x86/mtrr: Correct the range check before performing MTRR type
  lookups (bsc#1152489).
- commit 41cceca
* Mon Jan 11 2021 bp@suse.de
- x86/mm: Fix leak of pmd ptlock (bsc#1152489).
- commit cb571f0
* Mon Jan 11 2021 fdmanana@suse.com
- btrfs: fix missing delalloc new bit for new delalloc ranges
  (bsc#1180773).
- btrfs: make btrfs_dirty_pages take btrfs_inode (bsc#1180773).
- btrfs: make btrfs_set_extent_delalloc take btrfs_inode
  (bsc#1180773).
- commit fba9b10
* Mon Jan 11 2021 tbogendoerfer@suse.de
- IB/hfi1: Ensure correct mm is used at all times (bsc#1179878
  CVE-2020-27835).
- IB/hfi1: Remove module parameter for KDETH qpns (bsc#1179878).
- IB/hfi1: Remove kobj from hfi1_devdata (bsc#1179878).
- commit 79bac5c
* Mon Jan 11 2021 tiwai@suse.de
- regmap: debugfs: Fix a reversed if statement in
  regmap_debugfs_init() (git-fixes).
- commit 6e1e482
* Mon Jan 11 2021 tiwai@suse.de
- USB: serial: iuu_phoenix: fix DMA from stack (git-fixes).
- usb: gadget: configfs: Preserve function ordering after bind
  failure (git-fixes).
- usb: gadget: select CONFIG_CRC32 (git-fixes).
- usb: usbip: vhci_hcd: protect shift size (git-fixes).
- usb: gadget: f_uac2: reset wMaxPacketSize (git-fixes).
- usb: dwc3: ulpi: Use VStsDone to detect PHY regs access
  completion (git-fixes).
- USB: yurex: fix control-URB timeout handling (git-fixes).
- usb: chipidea: ci_hdrc_imx: add missing put_device() call in
  usbmisc_get_init_data() (git-fixes).
- usb: gadget: u_ether: Fix MTU size mismatch with RX packet size
  (git-fixes).
- USB: gadget: legacy: fix return error code in acm_ms_bind()
  (git-fixes).
- USB: xhci: fix U1/U2 handling for hardware with XHCI_INTEL_HOST
  quirk set (git-fixes).
- staging: mt7621-dma: Fix a resource leak in an error handling
  path (git-fixes).
- dmaengine: xilinx_dma: fix mixed_enum_type coverity warning
  (git-fixes).
- dmaengine: xilinx_dma: fix incompatible param warning in
  _child_probe() (git-fixes).
- dmaengine: xilinx_dma: check dma_async_device_register return
  value (git-fixes).
- dmaengine: dw-edma: Fix use after free in dw_edma_alloc_chunk()
  (git-fixes).
- dmaengine: mediatek: mtk-hsdma: Fix a resource leak in the
  error handling path of the probe function (git-fixes).
- i2c: i801: Fix the i2c-mux gpiod_lookup_table not being properly
  terminated (git-fixes).
- i2c: sprd: use a specific timeout to avoid system hang up issue
  (git-fixes).
- wan: ds26522: select CONFIG_BITREVERSE (git-fixes).
- wil6210: select CONFIG_CRC32 (git-fixes).
- crypto: ecdh - avoid buffer overflow in ecdh_set_secret()
  (git-fixes).
- spi: stm32: FIFO threshold level - fix align packet size
  (git-fixes).
- regmap: debugfs: Fix a memory leak when calling
  regmap_attach_dev (git-fixes).
- dmaengine: at_hdmac: add missing kfree() call in at_dma_xlate()
  (git-fixes).
- dmaengine: at_hdmac: add missing put_device() call in
  at_dma_xlate() (git-fixes).
- dmaengine: at_hdmac: Substitute kzalloc with kmalloc
  (git-fixes).
- commit da0ba2f
* Mon Jan 11 2021 mgorman@suse.de
- sched/fair: Check for idle core in wake_affine (git fixes
  (sched)).
- commit 2caffed
* Mon Jan 11 2021 nsaenzjulienne@suse.de
- arm64: mm: Fix ARCH_LOW_ADDRESS_LIMIT when !CONFIG_ZONE_DMA
  (git-fixes).
- commit 52bc22f
* Mon Jan 11 2021 nsaenzjulienne@suse.de
- blacklist.conf: 2c2b3ad2c4c8 ("spi: spi-fsl-dspi: Use max_native_cs
  instead of num_chipselect to set SPI_MCR")
  Depends on 7d93aecdb58d4 ("spi: Add generic support for unused native cs
  with cs-gpios") which at the moment is not worth back-porting as it'll
  break kABI.
- commit bafcdfd
* Mon Jan 11 2021 jgross@suse.com
- xen-blkback: set ring->xenblkd to NULL after kthread_stop()
  (bsc#1179509 XSA-350 CVE-2020-29569).
- commit 552ca06
* Mon Jan 11 2021 jgross@suse.com
- xenbus/xenbus_backend: Disallow pending watch messages
  (bsc#1179508 XSA-349 CVE-2020-29568).
- commit b293dfc
* Mon Jan 11 2021 jgross@suse.com
- xen/xenbus: Count pending messages for each watch (bsc#1179508
  XSA-349 CVE-2020-29568).
- commit d8a62d9
* Mon Jan 11 2021 jgross@suse.com
- xen/xenbus/xen_bus_type: Support will_handle watch callback
  (bsc#1179508 XSA-349 CVE-2020-29568).
- commit 8be4352
* Mon Jan 11 2021 jgross@suse.com
- xen/xenbus: Add 'will_handle' callback support in
  xenbus_watch_path() (bsc#1179508 XSA-349 CVE-2020-29568).
- commit 4383a8c
* Mon Jan 11 2021 jgross@suse.com
- xen/xenbus: Allow watches discard events before queueing
  (bsc#1179508 XSA-349 CVE-2020-29568).
- commit ec8d064
* Fri Jan  8 2021 tiwai@suse.de
- drm: bail out of nouveau_channel_new if channel init fails
  (CVE-2020-25639 bsc#1176846).
- commit 1ef70aa
* Fri Jan  8 2021 dwagner@suse.de
- nvme-multipath: fix bogus request queue reference put
  (bsc#1175389).
- commit ef51578
* Fri Jan  8 2021 wqu@suse.com
- Move "btrfs: qgroup: don't try to wait flushing if we're already holding
  a transaction (bsc#1179575)." to sorted section
- commit 464edf7
* Thu Jan  7 2021 msuchanek@suse.de
- Refresh patches.suse/nvdimm-Avoid-race-between-probe-and-reading-device-a.patch.
  Refresh to v2 URL
- commit 82e37f2
* Thu Jan  7 2021 bp@suse.de
- blacklist.conf: 44623b2818f4 crypto: x86/crc32c - fix building with clang ias
- commit 4260c52
* Thu Jan  7 2021 bp@suse.de
- x86/mm/numa: Remove uninitialized_var() usage (bsc#1152489).
- commit ec737c3
* Thu Jan  7 2021 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ibmvnic-continue-fatal-error-reset-after-passive-ini.patch
- commit c554179
* Thu Jan  7 2021 mkubecek@suse.cz
- Update kabi files.
- update from January 2021 maintenance update submission (commit 4ff469b6e1a0)
- commit a9bc2aa
* Thu Jan  7 2021 tiwai@suse.de
- bus/fsl_mc: Do not rely on caller to provide non NULL mc_io
  (git-fixes).
- commit e4eab60
* Thu Jan  7 2021 tiwai@suse.de
- ALSA: hda/realtek - Modify Dell platform name (git-fixes).
- ALSA: hda/realtek - Supported Dell fixed type headset
  (git-fixes).
- ALSA: hda/realtek: Remove dummy lineout on Acer TravelMate
  P648/P658 (git-fixes).
- commit 5e10442
* Thu Jan  7 2021 tiwai@suse.de
- r8169: work around power-saving bug on some chip versions
  (git-fixes).
- ALSA: pcm: Clear the full allocated memory at hw_params
  (git-fixes).
- rtc: pl031: fix resource leak in pl031_probe (git-fixes).
- rtc: sun6i: Fix memleak in sun6i_rtc_clk_init (git-fixes).
- i3c master: fix missing destroy_workqueue() on error in
  i3c_master_register (git-fixes).
- misc: vmw_vmci: fix kernel info-leak by initializing dbells
  in vmci_ctx_get_chkpt_doorbells() (git-fixes).
- xhci: Give USB2 ports time to enter U3 in bus suspend
  (git-fixes).
- USB: dummy-hcd: Fix uninitialized array use in init()
  (git-fixes).
- Bluetooth: hci_h5: close serdev device and free hu in h5_close
  (git-fixes).
- media: gp8psk: initialize stats at power control logic
  (git-fixes).
- staging: wlan-ng: fix out of bounds read in
  prism2sta_probe_usb() (git-fixes).
- commit 57824b9
* Thu Jan  7 2021 tiwai@suse.de
- ALSA: hda/via: Fix runtime PM for Clevo W35xSS (git-fixes).
- ALSA: usb-audio: Add quirk for RC-505 (git-fixes).
- ALSA: hda/realtek: Enable mute and micmute LED on HP EliteBook
  850 G7 (git-fixes).
- ALSA: hda/realtek: Add two "Intel Reference board" SSID in
  the ALC256 (git-fixes).
- ALSA: hda/realtek: Add mute LED quirk for more HP laptops
  (git-fixes).
- ALSA: hda/conexant: add a new hda codec CX11970 (git-fixes).
- ALSA: usb-audio: Add quirk for BOSS AD-10 (git-fixes).
- ALSA: usb-audio: Fix UBSAN warnings for MIDI jacks (git-fixes).
- ALSA: hda/realtek - Fix speaker volume control on Lenovo C940
  (git-fixes).
- commit 3b01e24
* Wed Jan  6 2021 msuchanek@suse.de
- Refresh patches.suse/nvme-fc-avoid-calling-_nvme_fc_abort_outstanding_ios-from-interrupt-context.patch
  Fix commit hash
- commit fdfd462
* Wed Jan  6 2021 msuchanek@suse.de
- Refresh patch metadata.
- Refresh patches.suse/ibmvnic-fix-NULL-pointer-dereference.patch.
- commit 45ce7d1
* Wed Jan  6 2021 dbueso@suse.de
- lib/string: remove unnecessary #undefs (git-fixes).
- bitmap: remove unused function declaration (git-fixes).
- swiotlb: using SIZE_MAX needs limits.h included (git-fixes).
- swiotlb: fix "x86: Don't panic if can not alloc buffer for
  swiotlb" (git-fixes).
- kdb: Fix pager search for multi-line strings (git-fixes).
- kgdb: Drop malformed kernel doc comment (git-fixes).
- commit 28d99cb
* Wed Jan  6 2021 bp@suse.de
- EDAC/amd64: Fix PCI component registration (bsc#1152489).
- commit 6c4ae9b
* Tue Jan  5 2021 ddiss@suse.de
- target: fix XCOPY NAA identifier lookup (CVE-2020-28374,
  bsc#1178372).
- commit 3e5427c
* Tue Jan  5 2021 tiwai@suse.de
- mwifiex: Fix possible buffer overflows in
  mwifiex_cmd_802_11_ad_hoc_start (CVE-2020-36158 bsc#1180559).
- commit 3e80605
* Tue Jan  5 2021 fdmanana@suse.com
- btrfs: do not commit logs and transactions during link and
  rename operations (bsc#1180566).
- btrfs: do not take the log_mutex of the subvolume when pinning
  the log (bsc#1180566).
- btrfs: delete duplicated words + other fixes in comments
  (bsc#1180566).
- commit 916e8ac
* Tue Jan  5 2021 heming.zhao@suse.com
- md/cluster: fix deadlock when node is doing resync job
  (bsc#1163727).
- md/cluster: block reshape with remote resync job (bsc#1163727).
- md/bitmap: fix memory leak of temporary bitmap (bsc#1163727).
- md/bitmap: md_bitmap_get_counter returns wrong blocks
  (bsc#1163727).
- md/bitmap: md_bitmap_read_sb uses wrong bitmap blocks
  (bsc#1163727).
- md-cluster: fix rmmod issue when md_cluster convert bitmap to
  none (bsc#1163727).
- md-cluster: fix safemode_delay value when converting to
  clustered bitmap (bsc#1163727).
- md-cluster: fix wild pointer of unlock_all_bitmaps()
  (bsc#1163727).
- commit 7522976
* Mon Jan  4 2021 rgoldwyn@suse.com
- btrfs: add missing check for nocow and compression inode flags (bsc#1178780).
- commit 98b0ffc
* Mon Jan  4 2021 lhenriques@suse.de
- Revert "ceph: allow rename operation under different quota
  realms" (bsc#1180541).
- commit 1a2a0a7
* Mon Jan  4 2021 lhenriques@suse.de
- Refresh
  patches.suse/ceph-downgrade-warning-from-mdsmap-decode-to-debug.patch.
- Refresh
  patches.suse/ceph-fix-race-in-concurrent-_ceph_remove_cap-invocations.patch.
  Patches have been merged into mainline; refreshing Git-commit and Path-mainline
  tags in patches.
- commit d338d00
* Mon Jan  4 2021 msuchanek@suse.de
- powerpc/pci: Remove LSI mappings on device teardown (bsc#1172145
  ltc#184630).
- commit a2fd2d8
* Mon Jan  4 2021 mbenes@suse.cz
- blacklist.conf: adab66b71abf ("Revert: "ring-buffer: Remove HAVE_64BIT_ALIGNED_ACCESS"")
  We do not support metag and sparc64 archs.
- commit 99ad074
* Mon Jan  4 2021 mbenes@suse.cz
- blacklist.conf: d9a9280a0d0a ("seq_buf: Avoid type mismatch for seq_buf_init")
  It breaks kABI. It is not worth the hassle to backport.
- commit 7c29506
* Mon Jan  4 2021 mbenes@suse.cz
- bpf: Fix bpf_put_raw_tracepoint()'s use of __module_address()
  (git-fixes).
- commit e888e29
* Mon Jan  4 2021 mbenes@suse.cz
- blacklist.conf: 310e3a4b5a4f ("tracing: Remove WARN_ON in start_thread()")
  CONFIG_HWLAT_TRACER is not set anywhere.
- commit 4f64022
* Mon Jan  4 2021 ghe@suse.com
- ocfs2: fix unbalanced locking (bsc#1180506).
- commit b54b08a
* Mon Jan  4 2021 tiwai@suse.de
- remoteproc: qcom: Fix potential NULL dereference in
  adsp_init_mmio() (git-fixes).
- remoteproc: qcom: fix reference leak in adsp_start (git-fixes).
- remoteproc: q6v5-mss: fix error handling in q6v5_pds_enable
  (git-fixes).
- serial_core: Check for port state when tty is in error state
  (git-fixes).
- usb: gadget: f_fs: Re-use SS descriptors for SuperSpeedPlus
  (git-fixes).
- USB: gadget: f_midi: setup SuperSpeed Plus descriptors
  (git-fixes).
- USB: gadget: f_acm: add support for SuperSpeed Plus (git-fixes).
- USB: gadget: f_rndis: fix bitrate for SuperSpeed and above
  (git-fixes).
- media: gspca: Fix memory leak in probe (git-fixes).
- media: saa7146: fix array overflow in vidioc_s_audio()
  (git-fixes).
- media: max2175: fix max2175_set_csm_mode() error code
  (git-fixes).
- media: imx214: Fix stop streaming (git-fixes).
- media: msi2500: assign SPI bus number dynamically (git-fixes).
- media: siano: fix memory leak of debugfs members in
  smsdvb_hotplug (git-fixes).
- media: sunxi-cir: ensure IR is handled when it is continuous
  (git-fixes).
- media: solo6x10: fix missing snd_card_free in error handling
  case (git-fixes).
- media: ipu3-cio2: Remove traces of returned buffers (git-fixes).
- media: ipu3-cio2: Make the field on subdev format
  V4L2_FIELD_NONE (git-fixes).
- media: ipu3-cio2: Validate mbus format in setting subdev format
  (git-fixes).
- media: ipu3-cio2: Serialise access to pad format (git-fixes).
- media: ipu3-cio2: Return actual subdev format (git-fixes).
- media: mtk-vcodec: add missing put_device() call in
  mtk_vcodec_init_enc_pm() (git-fixes).
- media: mtk-vcodec: add missing put_device() call in
  mtk_vcodec_release_dec_pm() (git-fixes).
- media: mtk-vcodec: add missing put_device() call in
  mtk_vcodec_init_dec_pm() (git-fixes).
- media: tm6000: Fix sizeof() mismatches (git-fixes).
- iwlwifi: pcie: add one missing entry for AX210 (git-fixes).
- commit 1e25d62
* Mon Jan  4 2021 tiwai@suse.de
- gpio: mvebu: update Armada XP per-CPU comment (git-fixes).
- dmaengine: mv_xor_v2: Fix error return code in mv_xor_v2_probe()
  (git-fixes).
- HID: i2c-hid: add Vero K147 to descriptor override (git-fixes).
- iio:imu:bmi160: Fix too large a buffer (git-fixes).
- crypto: atmel-i2c - select CONFIG_BITREVERSE (git-fixes).
- crypto: ecdh - avoid unaligned accesses in ecdh_set_secret()
  (git-fixes).
- crypto: omap-aes - Fix PM disable depth imbalance in
  omap_aes_probe (git-fixes).
- crypto: crypto4xx - Replace bitwise OR with logical OR in
  crypto4xx_build_pd (git-fixes).
- Input: goodix - add upside-down quirk for Teclast X98 Pro tablet
  (git-fixes).
- Input: cros_ec_keyb - send 'scancodes' in addition to key events
  (git-fixes).
- commit 48f3c1f
* Mon Jan  4 2021 tiwai@suse.de
- ALSA/hda: apply jack fixup for the Acer Veriton
  N4640G/N6640G/N2510G (git-fixes).
- ALSA: hda/realtek: Apply jack fixup for Quanta NL3 (git-fixes).
- ALSA: hda/realtek: Add quirk for MSI-GP73 (git-fixes).
- ALSA: pcm: oss: Fix a few more UBSAN fixes (git-fixes).
- ALSA: usb-audio: Disable sample read check if firmware doesn't
  give back (git-fixes).
- ALSA: usb-audio: Add VID to support native DSD reproduction
  on FiiO devices (git-fixes).
- ALSA: core: memalloc: add page alignment for iram (git-fixes).
- ACPI: PNP: compare the string length in the matching_id()
  (git-fixes).
- clocksource/drivers/arm_arch_timer: Correct fault programming
  of CNTKCTL_EL1.EVNTI (git-fixes).
- clocksource/drivers/arm_arch_timer: Use stable count reader
  in erratum sne (git-fixes).
- clocksource/drivers/cadence_ttc: Fix memory leak in
  ttc_setup_clockevent() (git-fixes).
- clocksource/drivers/orion: Add missing clk_disable_unprepare()
  on error path (git-fixes).
- crypto: af_alg - avoid undefined behavior accessing salg_name
  (git-fixes).
- crypto: inside-secure - Fix sizeof() mismatch (git-fixes).
- crypto: talitos - Fix return type of current_desc_hdr()
  (git-fixes).
- crypto: talitos - Endianess in current_desc_hdr() (git-fixes).
- cfg80211: initialize rekey_data (git-fixes).
- commit 57d3bee
* Thu Dec 31 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section:
  patches.suse/ibmvnic-fix-NULL-pointer-dereference.patch
- update upstream reference:
  patches.suse/ibmvnic-continue-fatal-error-reset-after-passive-ini.patch
- commit a0b2ce7
* Wed Dec 30 2020 msuchanek@suse.de
- ibmvnic: continue fatal error reset after passive init
  (bsc#1171078 ltc#184239 git-fixes).
- commit e6ea824
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/bitops: Fix possible undefined behaviour with fls()
  and fls64() (bsc#1156395).
- commit e90809a
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc: Fix incorrect stw{, ux, u, x} instructions in
  __set_pte_at (bsc#1065729).
- commit b5cc99b
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/xmon: Change printk() to pr_cont() (bsc#1065729).
- commit 9125964
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/64: Set up a kernel stack for secondaries before
  cpu_restore() (bsc#1065729).
- commit 7bcd26b
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/eeh_cache: Fix a possible debugfs deadlock
  (bsc#1156395).
- commit bfd7479
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc: Avoid broken GCC __attribute__((optimize))
  (bsc#1156395).
- commit 3d98ea5
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/smp: Add __init to init_big_cores() (bsc#1109695
  ltc#171067 git-fixes).
- commit 88fe3ed
* Wed Dec 30 2020 msuchanek@suse.de
- Refresh patches.suse/powerpc-rtas-fix-typo-of-ibm-open-errinjct-in-rtas-f.patch
  Refresh to upstream version.
- commit f0055e2
* Wed Dec 30 2020 msuchanek@suse.de
- powerpc/pseries/hibernation: remove redundant cacheinfo update
  (bsc#1138374 ltc#178199 git-fixes).
- commit e904a78
* Wed Dec 30 2020 msuchanek@suse.de
- Revert "powerpc/pseries/hotplug-cpu: Remove double free in
  error path" (bsc#1065729).
- commit 243e39e
* Wed Dec 30 2020 msuchanek@suse.de
- blacklist.conf: Add e91d8d78237d mm/zsmalloc.c: drop ZSMALLOC_PGTABLE_MAPPING
  The option is not enabled.
- commit 65fee6f
* Wed Dec 30 2020 oneukum@suse.com
- PCI: Fix overflow in command-line resource alignment requests
  (git-fixes).
- commit 1dd80ec
* Wed Dec 30 2020 msuchanek@suse.de
- ibmvnic: fix: NULL pointer dereference (bsc#1044767 ltc#155231
  git-fixes).
- commit 59feb80
* Wed Dec 30 2020 oneukum@suse.com
- Refresh
  patches.suse/powercap-Restrict-energy-meter-to-root-access.patch.
  Now in mainline
- commit 414492a
* Wed Dec 30 2020 oneukum@suse.com
- blacklist.conf: fix already added by other patch
- commit ed48336
* Wed Dec 30 2020 oneukum@suse.com
- blacklist.conf: already gone in by another ID
- commit 7020218
* Wed Dec 30 2020 oneukum@suse.com
- usb: host: ehci-tegra: Fix error handling in tegra_ehci_probe()
  (git-fixes).
- commit 6f94554
* Wed Dec 30 2020 oneukum@suse.com
- blacklist.conf: fix not relevant for our config
- commit 47a12a9
* Tue Dec 29 2020 oneukum@suse.com
- USB: UAS: introduce a quirk to set no_write_same (git-fixes).
- commit bda3ea7
* Tue Dec 29 2020 oneukum@suse.com
- USB: add RESET_RESUME quirk for Snapscan 1212 (git-fixes).
- commit 0912116
* Tue Dec 29 2020 dwagner@suse.de
- blk-mq: Remove 'running from the wrong CPU' warning
  (bsc#1174486).
- commit 5a12d1c
* Tue Dec 29 2020 tiwai@suse.de
- watchdog: coh901327: add COMMON_CLK dependency (git-fixes).
- watchdog: qcom: Avoid context switch in restart handler
  (git-fixes).
- watchdog: Fix potential dereferencing of null pointer
  (git-fixes).
- watchdog: sprd: change to use usleep_range() instead of busy
  loop (git-fixes).
- watchdog: sprd: check busy bit before new loading rather than
  after that (git-fixes).
- watchdog: sprd: remove watchdog disable from resume fail path
  (git-fixes).
- watchdog: sirfsoc: Add missing dependency on HAS_IOMEM
  (git-fixes).
- watchdog: armada_37xx: Add missing dependency on HAS_IOMEM
  (git-fixes).
- commit 705ed83
* Tue Dec 29 2020 tiwai@suse.de
- media: uvcvideo: Accept invalid bFormatIndex and bFrameIndex
  values (bsc#1180117).
- commit 2f3db03
* Tue Dec 29 2020 tiwai@suse.de
- Re-import the upstream uvcvideo fix; one more fix will be added later (bsc#1180117)
- commit 0da5ae4
* Mon Dec 28 2020 mkubecek@suse.cz
- rpm/constraints.in: more disk space for aarch64 binary builds (bsc#1180261)
  Tumbleweed KotD builds already consume ~30 GB of disk space and SLE15-SP3
  builds sometimes exceed even 32 GB, resulting in build failures. Thus the
  exception providing only 30 GB for aarch64 binary builds is no longer
  sustainable and if requiring 35 GB limits the portfolio of available
  builders, we need to address that.
- commit 07b084b
* Mon Dec 28 2020 bp@suse.de
- x86/topology: Set cpu_die_id only if DIE_TYPE found
  (bsc#1152489).
- commit 6e7d005
* Mon Dec 28 2020 bp@suse.de
- EDAC/mce_amd: Use struct cpuinfo_x86.cpu_die_id for AMD NodeId
  (bsc#1152489).
- commit 72ce98e
* Mon Dec 28 2020 bp@suse.de
- x86/CPU/AMD: Remove amd_get_nb_id() (bsc#1152489).
- commit be1bad6
* Mon Dec 28 2020 bp@suse.de
- x86/CPU/AMD: Save AMD NodeId as cpu_die_id (bsc#1152489).
- commit af076e7
* Mon Dec 28 2020 bp@suse.de
- EDAC/amd64: Do not load on family 0x15, model 0x13 (bsc#1179763).
- commit 877e64a
* Mon Dec 28 2020 mkubecek@suse.cz
- rpm: drop /usr/bin/env in interpreter specification
  OBS checks don't like /usr/bin/env in script interpreter lines but upstream
  developers tend to use it. A proper solution would be fixing the depedency
  extraction and drop the OBS check error but that's unlikely to happen so
  that we have to work around the problem on our side and rewrite the
  interpreter lines in scripts before collecting files for packages instead.
- commit 0ec5324
* Wed Dec 23 2020 tabraham@suse.com
- nvmet-tcp: fix maxh2cdata icresp parameter (bsc#1179892).
- commit 8a7b72b
* Wed Dec 23 2020 bp@suse.de
- x86/ima: use correct identifier for SetupMode variable
  (bsc#1152489).
- commit 9b27f4f
* Tue Dec 22 2020 bp@suse.de
- blacklist.conf: 3d51507f29f2 x86/entry/32: Add missing ASM_CLAC to general_protection entry
- commit 1aa31e3
* Tue Dec 22 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/mm-memory_failure-always-pin-the-page-in-madvise_inj.patch
- commit 4f786fa
* Tue Dec 22 2020 glin@suse.com
- selftests/bpf: Print reason when a tester could not run a
  program (bsc#1155518).
- selftests/bpf: Fix invalid use of strncat in test_sockmap
  (bsc#1155518).
- samples: bpf: Refactor test_cgrp2_sock2 program with libbpf
  (bsc#1155518).
- samples/bpf: Remove unused test_ipip.sh (bsc#1155518).
- selftest/bpf: Add missed ip6ip6 test back (bsc#1155518).
- selftests/bpf/test_offload.py: Reset ethtool features after
  failed setting (bsc#1155518).
- commit 82533c7
* Tue Dec 22 2020 tiwai@suse.de
- clk: mvebu: a3700: fix the XTAL MODE pin to MPP1_9 (git-fixes).
- clk: sunxi-ng: Make sure divider tables have sentinel
  (git-fixes).
- clk: s2mps11: Fix a resource leak in error handling paths in
  the probe function (git-fixes).
- clk: ingenic: Fix divider calculation with div tables
  (git-fixes).
- clk: at91: sam9x60: remove atmel,osc-bypass support (git-fixes).
- clk: ti: Fix memleak in ti_fapll_synth_setup (git-fixes).
- clk: mediatek: Make mtk_clk_register_mux() a static function
  (git-fixes).
- clk: tegra: Fix duplicated SE clock entry (git-fixes).
- clk: tegra: Do not return 0 on failure (git-fixes).
- lan743x: fix for potential NULL pointer dereference with bare
  card (git-fixes).
- commit 21d14d2
* Tue Dec 22 2020 firo.yang@suse.com
- drivers/base/memory.c: indicate all memory blocks as removable
  (bsc#1180264).
- commit 64673b1
* Mon Dec 21 2020 osalvador@suse.de
- mm,memory_failure: always pin the page in madvise_inject_error
  (bsc#1180258).
- commit 7fb306a
* Mon Dec 21 2020 bp@suse.de
- x86/mm/ident_map: Check for errors from ident_pud_init()
  (bsc#1152489).
- commit 37afaed
* Mon Dec 21 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/IB-isert-Fix-unaligned-immediate-data-handling.patch
  patches.suse/IB-mthca-fix-return-value-of-error-branch-in-mthca_i.patch
  patches.suse/IB-rdmavt-Fix-sizeof-mismatch.patch
  patches.suse/IB-srpt-Fix-memory-leak-in-srpt_add_one.patch
  patches.suse/IB-uverbs-Set-IOVA-on-IB-MR-in-uverbs-layer.patch
  patches.suse/RDMA-bnxt_re-Do-not-add-user-qps-to-flushlist.patch
  patches.suse/RDMA-core-Fix-bogus-WARN_ON-during-ib_unregister_dev.patch
  patches.suse/RDMA-core-Fix-reported-speed-and-width.patch
  patches.suse/RDMA-core-Fix-return-error-value-in-_ib_modify_qp-to.patch
  patches.suse/RDMA-core-Free-DIM-memory-in-error-unwind.patch
  patches.suse/RDMA-core-Stop-DIM-before-destroying-CQ.patch
  patches.suse/RDMA-counter-Allow-manually-bind-QPs-with-different-.patch
  patches.suse/RDMA-counter-Only-bind-user-QPs-in-auto-mode.patch
  patches.suse/RDMA-hns-Bugfix-for-memory-window-mtpt-configuration.patch
  patches.suse/RDMA-netlink-Remove-CAP_NET_RAW-check-when-dump-a-ra.patch
  patches.suse/RDMA-pvrdma-Fix-missing-kfree-in-pvrdma_register_dev.patch
  patches.suse/RDMA-qedr-Endianness-warnings-cleanup.patch
  patches.suse/RDMA-qedr-Fix-memory-leak-in-iWARP-CM.patch
  patches.suse/RDMA-qedr-SRQ-s-bug-fixes.patch
  patches.suse/RDMA-rxe-Drop-pointless-checks-in-rxe_init_ports.patch
  patches.suse/RDMA-rxe-Fix-memleak-in-rxe_mem_init_user.patch
  patches.suse/RDMA-rxe-Fix-skb-lifetime-in-rxe_rcv_mcast_pkt.patch
  patches.suse/RDMA-rxe-Fix-the-parent-sysfs-read-when-the-interfac.patch
  patches.suse/RDMA-rxe-Handle-skb_clone-failure-in-rxe_recv.c.patch
  patches.suse/RDMA-rxe-Prevent-access-to-wr-next-ptr-afrer-wr-is-p.patch
  patches.suse/RDMA-rxe-Remove-unused-rxe_mem_map_pages.patch
  patches.suse/RDMA-rxe-Return-void-from-rxe_init_port_param.patch
  patches.suse/RDMA-rxe-Return-void-from-rxe_mem_init_dma.patch
  patches.suse/RDMA-rxe-Skip-dgid-check-in-loopback-mode.patch
  patches.suse/RDMA-srpt-Fix-typo-in-srpt_unregister_mad_agent-docs.patch
- commit 2dad798
* Mon Dec 21 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/scsi-mpt3sas-add-bypass_dirty_port_flag-parameter
  patches.suse/scsi-mpt3sas-add-module-parameter-multipath_on_hba
  patches.suse/scsi-mpt3sas-allocate-memory-for-hba_port-objects
  patches.suse/scsi-mpt3sas-bump-driver-version-to-35-101-00-00
  patches.suse/scsi-mpt3sas-define-hba_port-structure
  patches.suse/scsi-mpt3sas-get-device-objects-using-sas_address-portid
  patches.suse/scsi-mpt3sas-get-sas_device-objects-using-device-s-rphy
  patches.suse/scsi-mpt3sas-handle-vses-vphy-object-during-hba-reset
  patches.suse/scsi-mpt3sas-handling-hba-vses-device
  patches.suse/scsi-mpt3sas-rearrange-scsih_mark_responding_sas_device
  patches.suse/scsi-mpt3sas-rename-transport_del_phy_from_an_existing_port
  patches.suse/scsi-mpt3sas-set-valid-physicalport-in-smppassthrough
  patches.suse/scsi-mpt3sas-update-hba_port-objects-after-host-reset
  patches.suse/scsi-mpt3sas-update-hba_port-s-sas_address-phy_mask
- commit a2950eb
* Mon Dec 21 2020 bp@suse.de
- EDAC/i10nm: Use readl() to access MMIO registers (bsc#1152489).
- commit a3a0100
* Mon Dec 21 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/powerpc-perf-Fix-crash-with-is_sier_available-when-p.patch
- commit adb35a0
* Mon Dec 21 2020 tiwai@suse.de
- rtc: ep93xx: Fix NULL pointer dereference in
  ep93xx_rtc_read_time (git-fixes).
- rtc: hym8563: enable wakeup when applicable (git-fixes).
- commit 52e449a
* Sun Dec 20 2020 tiwai@suse.de
- power: supply: bq24190_charger: fix reference leak (git-fixes).
- power: supply: axp288_charger: Fix HP Pavilion x2 10 DMI
  matching (git-fixes).
- HSI: omap_ssi: Don't jump to free ID in ssi_add_controller()
  (git-fixes).
- pwm: lp3943: Dynamically allocate PWM chip base (git-fixes).
- pwm: zx: Add missing cleanup in error path (git-fixes).
- commit 22a0fb4
* Fri Dec 18 2020 martin.wilck@suse.com
- scsi: core: Fix VPD LUN ID designator priorities (bsc#1178049).
- commit efdf30e
* Fri Dec 18 2020 lduncan@suse.com
- scsi: mpt3sas: Bump driver version to 35.101.00.00
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Add module parameter multipath_on_hba
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Handle vSES vphy object during HBA reset
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Add bypass_dirty_port_flag parameter
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Handling HBA vSES device (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Set valid PhysicalPort in SMPPassThrough
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Update hba_port objects after host reset
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Get sas_device objects using device's rphy
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Rename transport_del_phy_from_an_existing_port()
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Get device objects using sas_address & portID
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Update hba_port's sas_address & phy_mask
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Rearrange _scsih_mark_responding_sas_device()
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Allocate memory for hba_port objects
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Define hba_port structure (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: A small correction in _base_process_reply_queue
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Fix sync irqs (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Detect tampered Aero and Sea adapters
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Remove pci-dma-compat wrapper API (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Remove superfluous memset() (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Update driver version to 35.100.00.00
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Postprocessing of target and LUN reset
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Add functions to check if any cmd is outstanding
  on Target and LUN (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Rename and export interrupt mask/unmask functions
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Cancel the running work during host reset
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Dump system registers for debugging
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Memset config_cmds.reply buffer with zeros
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Don't call disable_irq from IRQ poll handler
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Fix set but unused variable (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Fix error returns in BRM_status_show
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Fix unlock imbalance (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Fix memset() in non-RDPQ mode (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Fix reply queue count in non RDPQ mode
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Fix double free warnings (jsc#SLE-16914,
  bsc#1177733).
- scsi: mpt3sas: Disable DIF when prot_mask set to zero
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Capture IOC data for debugging purposes
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Use true, false for ioc->use_32bit_dma
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Remove NULL check before freeing function
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Update mpt3sas version to 33.101.00.00
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Handle RDPQ DMA allocation in same 4G region
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Separate out RDPQ allocation to new function
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Rename function name is_MSB_are_same
  (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: Don't change the DMA coherent mask after
  allocations (jsc#SLE-16914, bsc#1177733).
- scsi: mpt3sas: use true,false for bool variables (jsc#SLE-16914,
  bsc#1177733).
- commit 5bf7889
* Thu Dec 17 2020 mbenes@suse.cz
- tracing: Fix race in trace_open and buffer resize call
  (CVE-2020-27825 bsc#1179960).
- commit c590ed4
* Thu Dec 17 2020 mbenes@suse.cz
- ring-buffer: speed up buffer resets by avoiding synchronize_rcu
  for each CPU (CVE-2020-27825 bsc#1179960).
- commit d308278
* Thu Dec 17 2020 mbenes@suse.cz
- ring-buffer: Make resize disable per cpu buffer instead of
  total buffer (CVE-2020-27825 bsc#1179960).
- commit 95e9004
* Thu Dec 17 2020 tiwai@suse.de
- Drop a backported uvcvideo patch that caused a regression (bsc#1180117)
  Also blacklisting the commit
- commit b185b93
* Thu Dec 17 2020 bp@suse.de
- x86/resctrl: Fix incorrect local bandwidth when mba_sc is
  enabled (bsc#1152489).
- x86/resctrl: Remove unused struct mbm_state::chunks_bw
  (bsc#1152489).
- commit b4996a1
* Thu Dec 17 2020 dwagner@suse.de
- nvmet-fc: fix missing check for no hostport struct
  (bsc#1176942).
- commit 7fab8fc
* Thu Dec 17 2020 dwagner@suse.de
- scsi: qla2xxx: Update version to 10.02.00.104-k (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Fix device loss on 4G and older HBAs (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: If fcport is undergoing deletion complete I/O
  with retry (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix the call trace for flush workqueue
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix flash update in 28XX adapters on big endian
  machines (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Handle aborts correctly for port undergoing
  deletion (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix N2N and NVMe connect retry failure
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix FW initialization error on big endian
  machines (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix crash during driver load on big endian
  machines (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Fix compilation issue in PPC systems (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Don't check for fw_started while posting NVMe
  command (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Tear down session if FW say it is down
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Limit interrupt vectors to number of CPUs
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Change post del message from debug level to
  log level (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Remove in_interrupt() from qla83xx-specific code
  (bsc#1171688 bsc#1172733).
- scsi: target: tcm_qla2xxx: Remove BUG_ON(in_interrupt())
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Remove in_interrupt() from qla82xx-specific code
  (bsc#1171688 bsc#1172733).
- commit 298833c
* Thu Dec 17 2020 dwagner@suse.de
- scsi: qla2xxx: Move sess cmd list/lock to driver (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Drop TARGET_SCF_LOOKUP_LUN_FROM_TAG (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Return EBUSY on fcport deletion (bsc#1171688
  bsc#1172733).
  Replace patches.suse/qla2xxx-return-ebusy-on-fcport-deletion.patch
  with upstream version.
- scsi: qla2xxx: remove incorrect sparse #ifdef (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Fix return of uninitialized value in rval
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Convert to DEFINE_SHOW_ATTRIBUTE (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Initialize variable in qla8044_poll_reg()
  (bsc#1171688 bsc#1172733).
- scsi: qla2xxx: Do not consume srb greedily (bsc#1171688
  bsc#1172733).
- scsi: qla2xxx: Handle incorrect entry_type entries (bsc#1171688
  bsc#1172733).
- commit 3c29fc6
* Thu Dec 17 2020 bp@suse.de
- x86/mm/mem_encrypt: Fix definition of PMD_FLAGS_DEC_WP
  (bsc#1152489).
- commit 994c3ae
* Thu Dec 17 2020 dwagner@suse.de
- scsi: qla2xxx: Use constant when it is known (bsc#1171688
  bsc#1172733).
  Refresh:
  - patches.suse/qla2xxx-return-ebusy-on-fcport-deletion.patch
- commit cfc1ae5
* Thu Dec 17 2020 dwagner@suse.de
- scsi: lpfc: Fix fall-through warnings for Clang (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Correct null ndlp reference on routine exit
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Use generic power management (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix variable 'vport' set but not used in
  lpfc_sli4_abts_err_handler() (bsc#1175480 bsc#1176396
  bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix missing prototype for
  lpfc_nvmet_prep_abort_wqe() (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Fix set but unused variables
  in lpfc_dev_loss_tmo_handler() (bsc#1175480 bsc#1176396
  bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix set but not used warnings from Rework remote
  port lock handling (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Fix missing prototype warning for
  lpfc_fdmi_vendor_attr_mi() (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Fix memory leak on lcb_context (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Remove dead code on second !ndlp check (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix pointer defereference before it is null checked
  issue (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Update changed file copyrights for 2020 (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Update lpfc version to 12.8.0.6 (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Convert abort handling to SLI-3 and SLI-4 handlers
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Convert SCSI I/O completions to SLI-3 and SLI-4
  handlers (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Convert SCSI path to use common I/O submission path
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Enable common send_io interface for SCSI and NVMe
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Enable common wqe_template support for both SCSI
  and NVMe (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Refactor WQE structure definitions for common use
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix NPIV Fabric Node reference counting (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix NPIV discovery and Fabric Node detection
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Unsolicited ELS leaves node in incorrect state while
  dropping it (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Remove ndlp when a PLOGI/ADISC/PRLI/REG_RPI
  ultimately fails (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Rework remote port lock handling (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix refcounting around SCSI and NVMe transport APIs
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix removal of SCSI transport device get and put on
  dev structure (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Rework locations of ndlp reference taking
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Rework remote port ref counting and node freeing
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_nvmet: Fix-up some formatting and doc-rot
  issues (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_nvme: Fix some kernel-doc related issues
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_nvme: Remove unused variable 'phba'
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_bsg: Provide correct documentation for a bunch
  of functions (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_debugfs: Fix a couple of function documentation
  issues (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_attr: Fix-up a bunch of kernel-doc
  misdemeanours (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_attr: Demote kernel-doc format for redefined
  functions (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: lpfc_scsi: Fix a whole host of kernel-doc issues
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Update lpfc version to 12.8.0.5 (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Reject CT request for MIB commands (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Add FDMI Vendor MIB support (bsc#1175480 bsc#1176396
  bsc#1176942 bsc#1177500).
- scsi: lpfc: Enlarge max_sectors in scsi host templates
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix duplicate wq_create_version check (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Removed unused macros in lpfc_attr.c (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Re-fix use after free in lpfc_rq_buf_free()
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix scheduling call while in softirq context
  in lpfc_unreg_rpi (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Fix invalid sleeping context in
  lpfc_sli4_nvmet_alloc() (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: Remove unneeded break statements (bsc#1175480 bsc#1176396
  bsc#1176942 bsc#1177500).
- scsi: lpfc: Remove unneeded variable 'status' in
  lpfc_fcp_cpu_map_store() (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Drop nodelist reference on error in lpfc_gen_req()
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Remove set but not used 'qp' (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix spelling mistake "Cant" -> "Can't" (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Fix initial FLOGI failure due to BBSCN not supported
  (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Update lpfc version to 12.8.0.4 (bsc#1175480
  bsc#1176396 bsc#1176942 bsc#1177500).
- scsi: lpfc: Extend the RDF FPIN Registration descriptor
  for additional events (bsc#1175480 bsc#1176396 bsc#1176942
  bsc#1177500).
- scsi: lpfc: Fix FLOGI/PLOGI receive race condition in pt2pt
  discovery (bsc#1175480 bsc#1176396 bsc#1176942 bsc#1177500).
- commit 6c7ebde
* Thu Dec 17 2020 tiwai@suse.de
- soc: amlogic: canvas: add missing put_device() call in
  meson_canvas_get() (git-fixes).
- drivers: soc: ti: knav_qmss_queue: Fix error return code in
  knav_queue_probe (git-fixes).
- soc: ti: Fix reference imbalance in knav_dma_probe (git-fixes).
- soc: ti: knav_qmss: fix reference leak in knav_queue_probe
  (git-fixes).
- soc: qcom: smp2p: Safely acquire spinlock without IRQs
  (git-fixes).
- soc: mediatek: Check if power domains can be powered on at
  boot time (git-fixes).
- soc/tegra: fuse: Fix index bug in get_process_id (git-fixes).
- soc: renesas: rmobile-sysc: Fix some leaks in
  rmobile_init_pm_domains() (git-fixes).
- soc: fsl: dpio: Get the cpumask through cpumask_of(cpu)
  (git-fixes).
- spi: spi-nxp-fspi: fix fspi panic by unexpected interrupts
  (git-fixes).
- commit 37de46f
* Thu Dec 17 2020 tiwai@suse.de
- platform/x86: intel-vbtn: Support for tablet mode on HP Pavilion
  13 x360 PC (git-fixes).
- Refresh
  patches.suse/platform-x86-intel-vbtn-Allow-switch-events-on-Acer-.patch.
- commit b789099
* Thu Dec 17 2020 tiwai@suse.de
- pinctrl: falcon: add missing put_device() call in
  pinctrl_falcon_probe() (git-fixes).
- mtd: rawnand: gpmi: Fix the random DMA timeout issue
  (git-fixes).
- mtd: rawnand: meson: Fix a resource leak in init (git-fixes).
- pinctrl: amd: remove debounce filter setting in IRQ type setting
  (git-fixes).
- platform/x86: touchscreen_dmi: Add info for the Irbis TW118
  tablet (git-fixes).
- platform/x86: acer-wmi: add automatic keyboard background
  light toggle key as KEY_LIGHTS_TOGGLE (git-fixes).
- platform/x86: thinkpad_acpi: Add BAT1 is primary battery quirk
  for Thinkpad Yoga 11e 4th gen (git-fixes).
- platform/x86: thinkpad_acpi: Do not report SW_TABLET_MODE on
  Yoga 11e (git-fixes).
- commit 3fd302b
* Thu Dec 17 2020 tiwai@suse.de
- mtd: rawnand: gpmi: fix reference count leak in gpmi ops
  (git-fixes).
- mtd: rawnand: meson: fix meson_nfc_dma_buffer_release()
  arguments (git-fixes).
- mtd: rawnand: qcom: Fix DMA sync on FLASH_STATUS register read
  (git-fixes).
- mtd: spinand: Fix OOB read (git-fixes).
- mfd: rt5033: Fix errorneous defines (git-fixes).
- Input: cm109 - do not stomp on control URB (git-fixes).
- Input: i8042 - add Acer laptops to the i8042 reset list
  (git-fixes).
- iwlwifi: mvm: fix kernel panic in case of assert during CSA
  (git-fixes).
- iwlwifi: pcie: limit memory read spin time (git-fixes).
- commit d3789b9
* Thu Dec 17 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/scsi-fnic-avoid-looping-in-trans-eth-on-unload
  patches.suse/scsi-fnic-change-shost_printk-to-fnic_fcs_dbg
  patches.suse/scsi-fnic-change-shost_printk-to-fnic_main_dbg
  patches.suse/scsi-fnic-set-scsi_set_resid-only-for-underflow
  patches.suse/scsi-fnic-validate-io_req-before-others
- commit 3190615
* Thu Dec 17 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ibmvnic-add-some-debugs.patch
- commit 5542884
* Wed Dec 16 2020 rgoldwyn@suse.com
- fix regression in "epoll: Keep a reference on files added to the check list"  (bsc#1180031, git-fixes).
- commit 775fe31
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/srpt: Fix typo in srpt_unregister_mad_agent docstring (bsc#1152489)
- commit b808e1d
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Handle skb_clone() failure in rxe_recv.c (bsc#1152489)
- commit ad662c6
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Endianness warnings cleanup (bsc#1152489)
- commit c3cca6a
* Wed Dec 16 2020 rgoldwyn@suse.com
- do_epoll_ctl(): clean the failure exits up a bit
  (bsc#1180031,CVE-2020-0466).
- epoll: Keep a reference on files added to the check list
  (bsc#1180031).
- commit 5e9b787
* Wed Dec 16 2020 mbenes@suse.cz
- blacklist.conf: bcee52789588 ("tracing: Fix userstacktrace option for instances")
  The kernel is missing many prerequisities. It is not worth it as it is.
- commit e39f16a
* Wed Dec 16 2020 tiwai@suse.de
- Update patch reference for wireless fix (CVE-2020-27068 bsc#1180086)
- commit 170f743
* Wed Dec 16 2020 tiwai@suse.de
- platform/x86: mlx-platform: remove an unused variable
  (git-fixes).
- USB: serial: option: add interface-number sanity check to flag
  handling (git-fixes).
- commit bff4f99
* Wed Dec 16 2020 tiwai@suse.de
- USB: serial: mos7720: fix parallel-port state restore
  (git-fixes).
- xhci-pci: Allow host runtime PM as default for Intel Alpine
  Ridge LP (git-fixes).
- commit f265436
* Wed Dec 16 2020 tiwai@suse.de
- USB: serial: digi_acceleport: fix write-wakeup deadlocks
  (git-fixes).
- USB: serial: keyspan_pda: fix write unthrottling (git-fixes).
- USB: serial: keyspan_pda: fix tx-unthrottle use-after-free
  (git-fixes).
- USB: serial: keyspan_pda: fix write-wakeup use-after-free
  (git-fixes).
- USB: serial: keyspan_pda: fix stalled writes (git-fixes).
- USB: serial: keyspan_pda: fix write deadlock (git-fixes).
- USB: serial: keyspan_pda: fix dropped unthrottle interrupts
  (git-fixes).
- usb: oxu210hp-hcd: Fix memory leak in oxu_create (git-fixes).
- usb: ehci-omap: Fix PM disable depth umbalance in
  ehci_hcd_omap_probe (git-fixes).
- usb: mtu3: fix memory corruption in mtu3_debugfs_regset()
  (git-fixes).
- commit 7596d48
* Wed Dec 16 2020 tiwai@suse.de
- spi: atmel-quadspi: Fix AHB memory accesses (git-fixes).
- spi: mt7621: Disable clock in probe error path (git-fixes).
- usb: chipidea: ci_hdrc_imx: Pass DISABLE_DEVICE_STREAMING flag
  to imx6ul (git-fixes).
- usb/max3421: fix return error code in max3421_probe()
  (git-fixes).
- commit 6c576b3
* Wed Dec 16 2020 tiwai@suse.de
- spi: davinci: Fix use-after-free on unbind (git-fixes).
- spi: fix resource leak for drivers without .remove callback
  (git-fixes).
- spi: mxs: fix reference leak in mxs_spi_probe (git-fixes).
- spi: st-ssc4: Fix unbalanced pm_runtime_disable() in probe
  error path (git-fixes).
- spi: pic32: Don't leak DMA channels in probe error path
  (git-fixes).
- spi: synquacer: Disable clock in probe error path (git-fixes).
- wimax: fix duplicate initializer warning (git-fixes).
- commit 51e204b
* Wed Dec 16 2020 tiwai@suse.de
- spi: sprd: fix reference leak in sprd_spi_remove (git-fixes).
- spi: atmel-quadspi: Disable clock in probe error path
  (git-fixes).
- spi: bcm63xx-hsspi: fix missing clk_disable_unprepare() on
  error in bcm63xx_hsspi_resume (git-fixes).
- spi: tegra114: fix reference leak in tegra spi ops (git-fixes).
- spi: tegra20-sflash: fix reference leak in tegra_sflash_resume
  (git-fixes).
- spi: tegra20-slink: fix reference leak in slink ops of tegra20
  (git-fixes).
- spi: mt7621: fix missing clk_disable_unprepare() on error in
  mt7621_spi_probe (git-fixes).
- spi: spi-ti-qspi: fix reference leak in ti_qspi_setup
  (git-fixes).
- spi: stm32: fix reference leak in stm32_spi_resume (git-fixes).
- spi: spi-mem: fix reference leak in spi_mem_access_start
  (git-fixes).
- commit 51236be
* Wed Dec 16 2020 tiwai@suse.de
- soc: qcom: geni: More properly switch to DMA mode (git-fixes).
- spi: spi-mem: Fix passing zero to 'PTR_ERR' warning (git-fixes).
- spi: img-spfi: fix reference leak in img_spfi_resume
  (git-fixes).
- regulator: mcp16502: add linear_min_sel (git-fixes).
- regulator: axp20x: Fix DLDO2 voltage control register mask
  for AXP22x (git-fixes).
- speakup: fix uninitialized flush_lock (git-fixes).
- slimbus: qcom-ngd-ctrl: Avoid sending power requests without
  QMI (git-fixes).
- serial: 8250_omap: Avoid FIFO corruption caused by MDR1 access
  (git-fixes).
- rsi: fix error return code in rsi_reset_card() (git-fixes).
- commit 8a400aa
* Wed Dec 16 2020 tiwai@suse.de
- PCI: iproc: Fix out-of-bound array accesses (git-fixes).
- platform/x86: mlx-platform: Fix item counter assignment for
  MSN2700, MSN24xx systems (git-fixes).
- platform/x86: dell-smbios-base: Fix error return code in
  dell_smbios_init (git-fixes).
- platform/x86: intel-vbtn: Allow switch events on Acer Switch
  Alpha 12 (git-fixes).
- platform/x86: mlx-platform: Remove PSU EEPROM from MSN274x
  platform configuration (git-fixes).
- platform/x86: mlx-platform: Remove PSU EEPROM from default
  platform configuration (git-fixes).
- Revert "platform/x86: wmi: Destroy on cleanup rather than
  unregister" (git-fixes).
- platform/chrome: cros_ec_spi: Don't overwrite spi::mode
  (git-fixes).
- regmap: Remove duplicate `type` field from regmap
  `regcache_sync` trace event (git-fixes).
- qtnfmac: fix error return code in qtnf_pcie_probe() (git-fixes).
- commit 4690027
* Wed Dec 16 2020 tiwai@suse.de
- PCI: brcmstb: Initialize "tmp" before use (git-fixes).
- PCI: Fix pci_slot_release() NULL pointer dereference
  (git-fixes).
- memstick: r592: Fix error return in r592_probe() (git-fixes).
- mmc: pxamci: Fix error return code in pxamci_probe (git-fixes).
- memstick: fix a double-free bug in memstick_check (git-fixes).
- staging: olpc_dcon: Do not call platform_device_unregister()
  in dcon_probe() (git-fixes).
- nfc: s3fwrn5: Release the nfc firmware (git-fixes).
- orinoco: Move context allocation after processing the skb
  (git-fixes).
- mwifiex: fix mwifiex_shutdown_sw() causing sw reset failure
  (git-fixes).
- commit e021aed
* Wed Dec 16 2020 tiwai@suse.de
- Input: cyapa_gen6 - fix out-of-bounds stack access (git-fixes).
- Input: omap4-keypad - fix runtime PM error handling (git-fixes).
- Input: ads7846 - fix unaligned access on 7845 (git-fixes).
- Input: ads7846 - fix integer overflow on Rt calculation
  (git-fixes).
- Input: ads7846 - fix race that causes missing releases
  (git-fixes).
- iio: adc: rockchip_saradc: fix missing clk_disable_unprepare()
  on error in rockchip_saradc_resume (git-fixes).
- iio:adc:ti-ads124s08: Fix alignment and data leak issues
  (git-fixes).
- iio:adc:ti-ads124s08: Fix buffer being too long (git-fixes).
- iwlwifi: mvm: hook up missing RX handlers (git-fixes).
- mac80211: don't set set TDLS STA bandwidth wider than possible
  (git-fixes).
- commit 2fd9b35
* Wed Dec 16 2020 tiwai@suse.de
- cpufreq: vexpress-spc: Add missing MODULE_ALIAS (git-fixes).
- Revert "i2c: i2c-qcom-geni: Fix DMA transfer race" (git-fixes).
- iio:pressure:mpl3115: Force alignment of buffer (git-fixes).
- iio:magnetometer:mag3110: Fix alignment and data leak issues
  (git-fixes).
- iio:light:st_uvis25: Fix timestamp alignment and prevent data
  leak (git-fixes).
- iio:light:rpr0521: Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio: buffer: Fix demux update (git-fixes).
- extcon: max77693: Fix modalias string (git-fixes).
- cw1200: fix missing destroy_workqueue() on error in
  cw1200_init_common (git-fixes).
- commit 59cf4f4
* Wed Dec 16 2020 tiwai@suse.de
- cpufreq: scpi: Add missing MODULE_ALIAS (git-fixes).
- cpufreq: loongson1: Add missing MODULE_ALIAS (git-fixes).
- cpufreq: st: Add missing MODULE_DEVICE_TABLE (git-fixes).
- cpufreq: mediatek: Add missing MODULE_DEVICE_TABLE (git-fixes).
- cpufreq: highbank: Add missing MODULE_DEVICE_TABLE (git-fixes).
- cpufreq: ap806: Add missing MODULE_DEVICE_TABLE (git-fixes).
- staging: comedi: mf6x4: Fix AI end-of-conversion detection
  (git-fixes).
- bus: fsl-mc: fix error return code in fsl_mc_object_allocate()
  (git-fixes).
- commit 172d8d6
* Wed Dec 16 2020 tiwai@suse.de
- Bluetooth: btmtksdio: Add the missed release_firmware() in
  mtk_setup_firmware() (git-fixes).
- Bluetooth: btusb: Add the missed release_firmware() in
  btusb_mtk_setup_firmware() (git-fixes).
- Bluetooth: hci_h5: fix memory leak in h5_close (git-fixes).
- Bluetooth: Fix slab-out-of-bounds read in
  hci_le_direct_adv_report_evt() (git-fixes).
- Bluetooth: Fix null pointer dereference in hci_event_packet()
  (git-fixes).
- ath10k: Release some resources in an error handling path
  (git-fixes).
- ath10k: Fix an error handling path (git-fixes).
- ath6kl: fix enum-conversion warning (git-fixes).
- commit 35aef63
* Wed Dec 16 2020 tiwai@suse.de
- Revert "ACPI / resources: Use AE_CTRL_TERMINATE to terminate
  resources walks" (git-fixes).
- commit 2779aa4
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- IB/srpt: Fix memory leak in srpt_add_one (bsc#1152489)
- commit da75bee
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/hns: Bugfix for memory window mtpt configuration (bsc#1152489)
- commit 4f3475b
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- IB/mthca: fix return value of error branch in mthca_init_cq() (bsc#1152489)
- commit c98a089
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/pvrdma: Fix missing kfree() in pvrdma_register_device() (bsc#1152489)
- commit baad43e
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix memory leak in iWARP CM (bsc#1152489)
- commit db44ceb
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix skb lifetime in rxe_rcv_mcast_pkt() (bsc#1152489)
- commit 1de4514
* Wed Dec 16 2020 nmoreychaisemartin@suse.com
- IB/rdmavt: Fix sizeof mismatch (bsc#1152489)
- commit 677c5ba
* Wed Dec 16 2020 jslaby@suse.cz
- inet_ecn: Fix endianness of checksum update when setting ECT(1)
  (git-fixes).
- commit 492cf46
* Wed Dec 16 2020 tiwai@suse.de
- ASoC: amd: change clk_get() to devm_clk_get() and add missed
  checks (git-fixes).
- ASoC: cx2072x: Fix doubly definitions of Playback and Capture
  streams (git-fixes).
- ASoC: meson: fix COMPILE_TEST error (git-fixes).
- ASoC: arizona: Fix a wrong free in wm8997_probe (git-fixes).
- ASoC: wm8998: Fix PM disable depth imbalance on error
  (git-fixes).
- ASoC: pcm: DRAIN support reactivation (git-fixes).
- ASoC: ti: davinci-mcasp: remove always zero of
  davinci_mcasp_get_dt_params (git-fixes).
- ASoC: sun4i-i2s: Fix lrck_period computation for I2S justified
  mode (git-fixes).
- ASoC: tegra20-spdif: remove "default m" (git-fixes).
- ASoC: wm_adsp: remove "ctl" from list on error in
  wm_adsp_create_control() (git-fixes).
- ASoC: jz4740-i2s: add missed checks for clk_get() (git-fixes).
- ASoC: SOF: control: fix size checks for ext_bytes control .get()
  (git-fixes).
- commit 8f99a8a
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: hda/ca0132 - Change Input Source enum strings (git-fixes).
- ALSA: hda/ca0132 - Fix AE-5 rear headphone pincfg (git-fixes).
- commit 4d4db90
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: hda: Fix regressions on clear and reconfig sysfs
  (git-fixes).
- commit f6ae090
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: pcm: oss: Fix potential out-of-bounds shift (git-fixes).
- ALSA: rawmidi: Access runtime->avail always in spinlock
  (git-fixes).
- ALSA: seq: remove useless function (git-fixes).
- commit 87f324b
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: hda/realtek - Add supported for more Lenovo ALC285
  Headset Button (git-fixes).
- ALSA: hda/realtek - Enable headset mic of ASUS Q524UQK with
  ALC255 (git-fixes).
- ALSA: hda/realtek - Enable headset mic of ASUS X430UN with
  ALC256 (git-fixes).
- ALSA: hda/realtek: make bass spk volume adjustable on a yoga
  laptop (git-fixes).
- ALSA: hda/hdmi: packet buffer index must be set before reading
  value (git-fixes).
- ALSA: hda/hdmi: always print pin NIDs as hexadecimal
  (git-fixes).
- ALSA: hda/proc - print DP-MST connections (git-fixes).
- commit b46aa44
* Wed Dec 16 2020 tiwai@suse.de
- ALSA: usb-audio: Fix potential out-of-bounds shift (git-fixes).
- ALSA: usb-audio: Fix control 'access overflow' errors from chmap
  (git-fixes).
- ALSA: usb-audio: Add implicit fb support for Steinberg UR22
  (git-fixes).
- ALSA: usb-audio: Add quirk for Pioneer DJ DDJ-SR2 (git-fixes).
- ALSA: usb-audio: Add support for Pioneer DJ DDJ-RR controller
  (git-fixes).
- commit cbe79ef
* Wed Dec 16 2020 tiwai@suse.de
- Move upstreamed USB-audio patches into sorted section
- commit 6078fcf
* Wed Dec 16 2020 lduncan@suse.com
- scsi: fnic: Validate io_req before others (bsc#1175079).
- scsi: fnic: Set scsi_set_resid() only for underflow
  (bsc#1175079).
- scsi: fnic: Change shost_printk() to FNIC_MAIN_DBG()
  (bsc#1175079).
- scsi: fnic: Avoid looping in TRANS ETH on unload (bsc#1175079).
- scsi: fnic: Change shost_printk() to FNIC_FCS_DBG()
  (bsc#1175079).
- commit 140fd58
* Wed Dec 16 2020 fweisbecker@suse.de
- sched/fair: Fix overutilized update in enqueue_task_fair() (git-fixes)
- commit aad16e5
* Wed Dec 16 2020 fweisbecker@suse.de
- sched: correct SD_flags returned by tl->sd_flags() (git-fixes)
- commit 323fa02
* Wed Dec 16 2020 fweisbecker@suse.de
- sched/fair: Refill bandwidth before scaling (git-fixes)
- commit 6f148d9
* Tue Dec 15 2020 fweisbecker@suse.de
- sched/fair: Fix race between runtime distribution and (git-fixes)
- commit 73cd7f5
* Tue Dec 15 2020 fweisbecker@suse.de
- sched/fair: Fix wrong cpu selecting from isolated domain (git-fixes)
- commit c4c367e
* Tue Dec 15 2020 oneukum@suse.com
- Update
  patches.suse/HID-Fix-slab-out-of-bounds-read-in-hid_field_extract.patch
  (bsc#1180052).
  Patch identified as security issue. bsc added.
- commit 88ee41b
* Tue Dec 15 2020 vbabka@suse.cz
- mm: memcg: fix memcg reclaim soft lockup (VM Functionality,
  bsc#1180056).
- commit 3a73547
* Tue Dec 15 2020 oneukum@suse.com
- crypto: qat - fix status check in qat_hal_put_rel_rd_xfer()
  (git-fixes).
- commit e1943c2
* Tue Dec 15 2020 tiwai@suse.de
- Update patch reference for audit security fix (CVE-2020-0444 bsc#1180027)
- commit 8236de7
* Tue Dec 15 2020 tiwai@suse.de
- Update patch reference for HID security fix (CVE-2020-0465 bsc#1180029)
- commit c0d38cb
* Mon Dec 14 2020 mpdesouza@suse.com
- btrfs: qgroup: don't try to wait flushing if we're already holding a transaction (bsc#1179575).
- commit 7eae617
* Mon Dec 14 2020 ptesarik@suse.cz
- s390/pci: fix CPU address in MSI for directed IRQ (git-fixes).
- s390/qeth: fix tear down of async TX buffers (git-fixes).
- s390/qeth: fix af_iucv notification race (git-fixes).
- s390/qeth: delay draining the TX buffers (git-fixes).
- s390: add 3f program exception handler (git-fixes).
- s390/cpuinfo: show processor physical address (git-fixes).
- commit 15840e9
* Mon Dec 14 2020 ptesarik@suse.cz
- s390/qeth: make af_iucv TX notification call more robust
  (bsc#1179604 LTC#190151).
- commit 1d3596d
* Mon Dec 14 2020 shung-hsi.yu@suse.com
- x86/apic/vector: Fix ordering in vector assignment (bsc#1156315).
- genirq/matrix: Deal with the sillyness of for_each_cpu() on UP (bsc#1156315).
- commit 108604c
* Mon Dec 14 2020 neilb@suse.de
- blacklist.conf: two git-fixes that break kabi too much
- commit 7df1e74
* Mon Dec 14 2020 neilb@suse.de
- blacklist.conf: Add a duplicate
- commit 5592171
* Sun Dec 13 2020 tiwai@suse.de
- ALSA: usb-audio: workaround for iface reset issue (bsc#1178203).
- commit 4121b01
* Sun Dec 13 2020 tiwai@suse.de
- mmc: block: Fixup condition for CMD13 polling for RPMB requests
  (git-fixes).
- pinctrl: aspeed: Fix GPIO requests on pass-through banks
  (git-fixes).
- pinctrl: baytrail: Avoid clearing debounce value when turning
  it off (git-fixes).
- pinctrl: merrifield: Set default bias in case no particular
  value given (git-fixes).
- gpio: mvebu: fix potential user-after-free on probe (git-fixes).
- clk: renesas: r9a06g032: Drop __packed for portability
  (git-fixes).
- USB: serial: ch341: sort device-id entries (git-fixes).
- USB: serial: ch341: add new Product ID for CH341A (git-fixes).
- USB: serial: option: add support for Thales Cinterion EXS82
  (git-fixes).
- USB: serial: option: add Fibocom NL668 variants (git-fixes).
- commit 4d00577
* Fri Dec 11 2020 fdmanana@suse.com
- btrfs: fix readahead hang and use-after-free after removing
  a device (bsc#1179963).
- commit 170193e
* Fri Dec 11 2020 fdmanana@suse.com
- btrfs: fix use-after-free on readahead extent after failure
  to create it (bsc#1179963).
- commit 1429b0b
* Fri Dec 11 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream repository URL:
  patches.suse/ibmvnic-add-some-debugs.patch
- move unsortable patches out of sorted section:
  patches.suse/cifs-set_root_ses-ipc.patch
  patches.suse/powerpc-rtas-fix-typo-of-ibm-open-errinjct-in-rtas-f.patch
- commit 059dfec
* Fri Dec 11 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into "almost mainline" section:
  patches.suse/nvme-fc-avoid-calling-_nvme_fc_abort_outstanding_ios-from-interrupt-context.patch
- commit e446234
* Fri Dec 11 2020 osalvador@suse.de
- mm/memory_hotplug: shrink zones when offlining memory
  (bsc#1177679).
- commit ffb1814
* Fri Dec 11 2020 tiwai@suse.de
- Revert "geneve: pull IP header before ECN decapsulation"
  (git-fixes).
- can: softing: softing_netdev_open(): fix error handling
  (git-fixes).
- mac80211: mesh: fix mesh_pathtbl_init() error path (git-fixes).
- commit dff69af
* Fri Dec 11 2020 tzimmermann@suse.de
- drm: panel: Fix bpc for OrtusTech COM43H4M85ULC panel (bsc#1152489)
- commit 68423a3
* Fri Dec 11 2020 msuchanek@suse.de
- ibmvnic: fix rx buffer tracking and index management in
  replenish_rx_pool partial success (bsc#1179929 ltc#189960).
- commit 53d60d5
* Fri Dec 11 2020 jslaby@suse.cz
- Update patches.suse/tty-Fix-pgrp-locking-in-tiocspgrp.patch
  (git-fixes bsc#1179745 CVE-2020-29661).
- Update patches.suse/tty-Fix-session-locking.patch (bsc#1179745
  CVE-2020-29660).
  Add CVE numbers.
- commit 034f28b
* Thu Dec 10 2020 dbueso@suse.de
- fail_function: Remove a redundant mutex unlock (bsc#1149032).
- locking/percpu-rwsem: Use this_cpu_{inc,dec}() for read_count
  (bsc#1149032).
- commit 7d88c68
* Thu Dec 10 2020 dbueso@suse.de
- blacklist.conf: Blacklist some lockdep updates
- commit 2f42c43
* Thu Dec 10 2020 msuchanek@suse.de
- kABI: genirq: add back irq_create_mapping (bsc#1065729).
- commit 0788f47
* Thu Dec 10 2020 msuchanek@suse.de
- genirq/irqdomain: Add an irq_create_mapping_affinity() function
  (bsc#1065729).
- commit 1e1b021
* Thu Dec 10 2020 msuchanek@suse.de
- powerpc/64s: Trim offlined CPUs from mm_cpumasks (bsc#1055117
  ltc#159753 git-fixes bsc#1179888 ltc#190253).
- kernel/cpu: add arch override for clear_tasks_mm_cpumask()
  mm handling (bsc#1055117 ltc#159753 git-fixes bsc#1179888
  ltc#190253).
- powerpc/64s/pseries: Fix hash tlbiel_all_isa300 for guest
  kernels (bsc#1179888 ltc#190253).
- powerpc/64s: Fix hash ISA v3.0 TLBIEL instruction generation
  (bsc#1055117 ltc#159753 git-fixes bsc#1179888 ltc#190253).
- commit 8cba4ab
* Thu Dec 10 2020 msuchanek@suse.de
- powerpc/64s/powernv: Fix memory corruption when saving SLB
  entries on MCE (jsc#SLE-9246 git-fixes).
- commit a63cfa4
* Thu Dec 10 2020 msuchanek@suse.de
- powerpc/pseries: Pass MSI affinity to irq_create_mapping()
  (bsc#1065729).
- ibmvnic: delay next reset if hard reset fails (bsc#1094840
  ltc#167098 git-fixes).
- ibmvnic: restore adapter state on failed reset (bsc#1152457
  ltc#174432 git-fixes).
- ibmvnic: avoid memset null scrq msgs (bsc#1044767 ltc#155231
  git-fixes).
- ibmvnic: enhance resetting status check during module exit
  (bsc#1065729).
- ibmvnic: fix NULL pointer dereference in reset_sub_crq_queues
  (FATE#322021 bsc#1040855 ltc#155067 git-fixes).
- ibmvnic: notify peers when failover and migration happen
  (bsc#1044120 ltc#155423 git-fixes).
- ibmvnic: fix call_netdevice_notifiers in do_reset (bsc#1115431
  ltc#171853 git-fixes).
- commit 00d731f
* Thu Dec 10 2020 msuchanek@suse.de
- powerpc/64s: Fix allnoconfig build since uaccess flush
  (bsc#1177666 git-fixes).
- commit 87d1aa2
* Thu Dec 10 2020 msuchanek@suse.de
- KVM: PPC: Book3S HV: XIVE: Fix possible oops when accessing
  ESB page (bsc#1156395).
- commit be0ace4
* Thu Dec 10 2020 msuchanek@suse.de
- ibmvnic: add some debugs (bsc#1179896 ltc#190255).
- commit 0ec6de5
* Thu Dec 10 2020 msuchanek@suse.de
- powerpc/rtas: fix typo of ibm,open-errinjct in rtas filter
  (CVE-2020-27777 bsc#1179107 bsc#1179887 ltc#190092).
- commit 8fcc087
* Thu Dec 10 2020 dwagner@suse.de
- nvme-fc: avoid calling _nvme_fc_abort_outstanding_ios from
  interrupt context (bsc#1177326).
- commit c6fa2f3
* Thu Dec 10 2020 mbenes@suse.cz
- ftrace: Fix updating FTRACE_FL_TRAMP (git-fixes).
- commit e552615
* Thu Dec 10 2020 mbenes@suse.cz
- blacklist.conf: 310e3a4b5a4f ("tracing: Remove WARN_ON in start_thread()")
  Not really necessary. Just a WARN_ON(). We may reevaluate if someone
  reports it.
- commit b62e034
* Thu Dec 10 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/0001-HMAT-Register-memory-side-cache-after-parsing.patch
  patches.suse/0001-HMAT-Skip-publishing-target-info-for-nodes-with-no-o.patch
  patches.suse/0001-mm-userfaultfd-do-not-access-vma-vm_mm-after-calling.patch
- commit 35937c0
* Wed Dec  9 2020 ematsumiya@suse.de
- iommu/amd: Set DTE[IntTabLen] to represent 512 IRTEs
  (bsc#1179652).
- commit fc46361
* Wed Dec  9 2020 hare@suse.de
- nvme-fabrics: allow to queue requests for live queues
  (git-fixes).
- nvme-tcp: cancel async events before freeing event struct
  (git-fixes).
- nvme-rdma: cancel async events before freeing event struct
  (git-fixes).
- nvme-fc: cancel async events before freeing event struct
  (git-fixes).
- commit bd7db2d
* Wed Dec  9 2020 hare@suse.de
- nvme: Revert: Fix controller creation races with teardown
  (git-fixes).
- Delete patches.kabi/nvme-kABI-fixes-for-nvme_ctrl.patch.
- commit 6f82fb0
* Wed Dec  9 2020 hare@suse.de
- nvme-multipath: fix deadlock due to head->lock (git-fixes).
- nvme: don't protect ns mutation with ns->head->lock (git-fixes).
- nvme-multipath: fix deadlock between ana_work and scan_work
  (git-fixes).
- commit d1a90c1
* Wed Dec  9 2020 hare@suse.de
- nvme-fc: remove nvme_fc_terminate_io() (bsc#1177326).
- nvme-fc: eliminate terminate_io use by nvme_fc_error_recovery
  (bsc#1177326).
- nvme-fc: remove err_work work item (bsc#1177326).
- nvme-fc: track error_recovery while connecting (bsc#1177326).
- nvme-fc: shorten reconnect delay if possible for FC (git-fixes).
- nvme-fc: wait for queues to freeze before calling (git-fixes).
- nvme-fc: fix error loop in create_hw_io_queues (git-fixes).
- nvme-fc: fix io timeout to abort I/O (bsc#1177326).
- nvme-pci: properly print controller address (git-fixes).
- commit 42e24bd
* Wed Dec  9 2020 hare@suse.de
- nvme-tcp: optimize queue io_cpu assignment for multiple queue
  (git-fixes).
- Refresh
  patches.suse/nvme-tcp-have-queue-prod-cons-send-list-become-a-lli.patch.
- commit b1bde16
* Wed Dec  9 2020 hare@suse.de
- nvme-tcp: fix possible leakage during error flow (git-fixes).
- commit a68cfb4
* Wed Dec  9 2020 tiwai@suse.de
- Input: xpad - support Ardwiino Controllers (git-fixes).
- Input: i8042 - add ByteSpeed touchpad to noloop table
  (git-fixes).
- usbnet: ipheth: fix connectivity with iOS 14 (git-fixes).
- commit 8f84738
* Tue Dec  8 2020 bp@suse.de
- x86/insn-eval: Use new for_each_insn_prefix() macro to loop
  over prefixes bytes (bsc#1152489).
- commit 73ffec0
* Tue Dec  8 2020 bp@suse.de
- x86/uprobes: Do not use prefixes.nbytes when looping over
  prefixes.bytes (bsc#1152489).
- commit 0b28903
* Tue Dec  8 2020 bp@suse.de
- x86/resctrl: Fix AMD L3 QOS CDP enable/disable (bsc#1152489).
- commit d839ba5
* Tue Dec  8 2020 jack@suse.cz
- io_uring: grab ->fs as part of async offload (bsc#1179434
  CVE-2020-29373).
- commit b260e71
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Avoid mixing integer types during batch copies'
- commit 7318e0c
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Clear the repeater bit on HDCP disable'
- commit c9b3793
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix sha_text population code'
- commit 3c40ed1
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gem: Delay tracking the GEM context until it is registered'
- commit 57a9af9
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: Fix hardmins not being sent to SMU for RV'
- commit 3708b97
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Prevent kernel-infoleak in amdgpu_info_ioctl()'
- commit 13ab26a
* Tue Dec  8 2020 oneukum@suse.com
- Update
  patches.suse/media-xirlink_cit-add-missing-descriptor-sanity-chec.patch
  (bsc#1168952 CVE-2020-11668).
  Added CVE number
- commit a0ec304
* Tue Dec  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gem: Delay tracking the GEM context until it is registered'
- commit b9b8698
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/imx: tve remove extraneous type qualifier (bsc#1152489)
- commit ef93a79
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/vc4: hdmi: Avoid sleeping in atomic context (bsc#1152489)
  Backporting changes:
  * context fixes
- commit 507bd66
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/panfrost: increase readl_relaxed_poll_timeout values (bsc#1152472)
  Backporting changes:
  * context fixes
- commit c82949a
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/i915/gem: Avoid implicit vmap for highmem on x86-32 (bsc#1152489)
  Backporting changes:
  * context fixes
- commit 56c13b8
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/vc4: crtc: Rework a bit the CRTC state code (bsc#1152472)
  Backporting changes:
  * context fixes
- commit e8c9179
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/msm: Drop debug print in _dpu_crtc_setup_lm_bounds() (bsc#1152489)
  Backporting changes:
  * context fixes
- commit 620be39
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/msm: Avoid div-by-zero in dpu_crtc_atomic_check() (bsc#1152489)
- commit fa753cd
* Tue Dec  8 2020 tzimmermann@suse.de
- drm: mxsfb: check framebuffer pitch (bsc#1152472)
  Backporting changes:
  * context fixes
- commit 0dd9c60
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/panfrost: Ensure GPU quirks are always initialised (bsc#1152489)
- commit c088e37
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/crc-debugfs: Fix memleak in crc_control_write (bsc#1152472)
- commit 7cf7f8b
* Tue Dec  8 2020 tzimmermann@suse.de
- drm: rcar-du: Put reference to VSP device (bsc#1152489)
- commit 3aca956
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/radeon: Prefer lower feedback dividers (bsc#1152489)
- commit 7479884
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/amdgpu: pass NULL pointer instead of 0 (bsc#1152489)
  Backporting changes:
  * context fixes
- commit 7cc3993
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/amd/display: Fix wrong return value in dm_update_plane_state() (bsc#1152489)
- commit 7638845
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/gma500: fix error check (bsc#1152472)
  Backporting changes:
  * context fixes
- commit e0b3dc4
* Tue Dec  8 2020 tzimmermann@suse.de
- drm: panel: Fix bus format for OrtusTech COM43H4M85ULC panel (bsc#1152472)
  Backporting changes:
  * context fixes
- commit aaeda6a
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/vkms: fix xrgb on compute crc (bsc#1152472)
  Backporting changes:
  * changed filename from vkms_composer.c to vkms_crc.c
  * context fixes
- commit 84538b3
* Tue Dec  8 2020 tzimmermann@suse.de
- drm: mxsfb: Remove fbdev leftovers (bsc#1152472)
  Backporting changes:
  * context fixes
- commit 7b29584
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/sun4i: sun8i-csc: Secondary CSC register correction (bsc#1152489)
- commit c09dba1
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/vc4/vc4_hdmi: fill ASoC card owner (bsc#1152489)
- commit afa801d
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/mediatek: Add missing put_device() call in (bsc#1152472)
- commit 2465a49
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/mediatek: Add missing put_device() call in mtk_drm_kms_init() (bsc#1152472)
  Backporting changes:
  * context fixes
  * adapted to function layout
- commit 187e3d3
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/mediatek: Add exception handing in mtk_drm_probe() if component (bsc#1152472)
- commit 39014a3
* Tue Dec  8 2020 tzimmermann@suse.de
- drm/i915: Fix sha_text population code (bsc#1152489)
  Backporting changes:
  * context fixes
  * adapted I/O functions to old driver
- commit d501c26
* Tue Dec  8 2020 tzimmermann@suse.de
- fbcon: Remove the superfluous break (bsc#1152472)
- commit e00dc98
* Tue Dec  8 2020 tzimmermann@suse.de
- video: fbdev: radeon: Fix memleak in radeonfb_pci_register (bsc#1152472)
- commit 9657792
* Tue Dec  8 2020 tzimmermann@suse.de
- video: fbdev: sis: fix null ptr dereference (bsc#1152472)
- commit d833a20
* Tue Dec  8 2020 tiwai@suse.de
- speakup: Reject setting the speakup line discipline outside
  of speakup (CVE-2020-27830 bsc#1179656).
- commit ec50953
* Tue Dec  8 2020 jslaby@suse.cz
- tty: Fix ->session locking (bsc#1179745).
- commit a9a2af9
* Tue Dec  8 2020 jslaby@suse.cz
- Update patches.suse/tty-Fix-pgrp-locking-in-tiocspgrp.patch
  (git-fixes bsc#1179745).
- commit 556ded3
* Mon Dec  7 2020 vbabka@suse.cz
- Update
  patches.suse/mm-slub-add-missing-tid-bump-in-kmem_cache_alloc_bulk.patch
  (CVE-2020-29370, bsc#1179435, bsc#1167657, VM functionality).
- add reference to CVE and its bsc
- commit cc58091
* Mon Dec  7 2020 ematsumiya@suse.de
- patches.suse/iommu-amd-Increase-interrupt-remapping-table-limit-t.patch:
  (bsc#1179652).
- commit 34c2dd2
* Mon Dec  7 2020 jack@suse.cz
- blacklist.conf: Blacklist fdeb17c70c9e
- commit 392d677
* Mon Dec  7 2020 jack@suse.cz
- ext4: fix bogus warning in ext4_update_dx_flag() (bsc#1179716).
- commit c86f418
* Mon Dec  7 2020 jack@suse.cz
- reiserfs: Fix oops during mount (bsc#1179715).
- commit 89f9917
* Mon Dec  7 2020 jack@suse.cz
- quota: clear padding in v2r1_mem2diskdqb() (bsc#1179714).
- commit 20af897
* Mon Dec  7 2020 jack@suse.cz
- reiserfs: Initialize inode keys properly (bsc#1179713).
- commit 2b68a22
* Mon Dec  7 2020 jack@suse.cz
- udf: Fix memory leak when mounting (bsc#1179712).
- commit 816f9a3
* Mon Dec  7 2020 jack@suse.cz
- fs: Don't invalidate page buffers in block_write_full_page()
  (bsc#1179711).
- commit 8f6f5ed
* Mon Dec  7 2020 jack@suse.cz
- mm/error_inject: Fix allow_error_inject function signatures
  (bsc#1179710).
- commit 2c7612f
* Mon Dec  7 2020 jack@suse.cz
- libfs: fix error cast of negative value in simple_attr_write()
  (bsc#1179709).
- commit 246e7d7
* Mon Dec  7 2020 jack@suse.cz
- jbd2: fix up sparse warnings in checkpoint code (bsc#1179707).
- commit 15002ce
* Mon Dec  7 2020 jack@suse.cz
- ubifs: journal: Make sure to not dirty twice for auth nodes
  (bsc#1179704).
- commit 0185a1d
* Mon Dec  7 2020 jack@suse.cz
- ubifs: dent: Fix some potential memory leaks while iterating
  entries (bsc#1179703).
- commit 32b7d27
* Mon Dec  7 2020 jack@suse.cz
- ubifs: xattr: Fix some potential memory leaks while iterating
  entries (bsc#1179690).
- commit 950038e
* Mon Dec  7 2020 jack@suse.cz
- ubifs: mount_ubifs: Release authentication resource in error
  handling path (bsc#1179689).
- commit 0b68da4
* Mon Dec  7 2020 jack@suse.cz
- ubifs: Don't parse authentication mount options in remount
  process (bsc#1179688).
- commit 391f198
* Mon Dec  7 2020 jack@suse.cz
- ubifs: Fix a memleak after dumping authentication mount options
  (bsc#1179687).
- commit 3c605f4
* Mon Dec  7 2020 jack@suse.cz
- iomap: Set all uptodate bits for an Uptodate page (bsc#1179685).
- commit 8e539c4
* Mon Dec  7 2020 jack@suse.cz
- iomap: Mark read blocks uptodate in write_begin (bsc#1179684).
- commit d032f23
* Mon Dec  7 2020 jack@suse.cz
- iomap: Clear page error before beginning a write (bsc#1179683).
- commit da58998
* Mon Dec  7 2020 jack@suse.cz
- blacklist.conf: Blacklist 50b7d8568008
- commit cc769c4
* Mon Dec  7 2020 jack@suse.cz
- fs/ufs: avoid potential u32 multiplication overflow
  (bsc#1179682).
- commit 8289be8
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: remove expected error message in block_to_path()
  (bsc#1179681).
- commit 0ea255e
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: fix block limit check for V1 filesystems
  (bsc#1179680).
- commit 06199cf
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: set s_maxbytes correctly (bsc#1179679).
- commit 69dd22c
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: reject too-large maximum file size (bsc#1179678).
- commit c5b4a77
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: don't allow getting deleted inodes (bsc#1179677).
- commit cbd9376
* Mon Dec  7 2020 jack@suse.cz
- fs/minix: check return value of sb_getblk() (bsc#1179676).
- commit 86706a5
* Mon Dec  7 2020 jack@suse.cz
- ubifs: Fix wrong orphan node deletion in ubifs_jnl_update|rename
  (bsc#1179675).
- commit 7055a2f
* Mon Dec  7 2020 jack@suse.cz
- ext4: unlock xattr_sem properly in ext4_inline_data_truncate()
  (bsc#1179673).
- commit d17d948
* Mon Dec  7 2020 jack@suse.cz
- ext4: correctly report "not supported" for {usr,grp}jquota
  when !CONFIG_QUOTA (bsc#1179672).
- commit ace06ac
* Mon Dec  7 2020 jack@suse.cz
- ext4: limit entries returned when counting fsmap records
  (bsc#1179671).
- commit 869362f
* Mon Dec  7 2020 jack@suse.cz
- ext4: fix leaking sysfs kobject after failed mount
  (bsc#1179670).
- commit 2855c18
* Mon Dec  7 2020 bp@suse.de
- x86/mce: Do not overwrite no_way_out if mce_end() fails
  (bsc#1152489).
- commit 016650c
* Mon Dec  7 2020 mkubecek@suse.cz
- net/x25: prevent a couple of overflows (bsc#1178590).
- commit 9618139
* Mon Dec  7 2020 mkubecek@suse.cz
- Update patches.suse/xfrm-Fix-memleak-on-xfrm-state-destroy.patch
  references (add bsc#1158775).
- commit f5ca88c
* Mon Dec  7 2020 mkubecek@suse.cz
- ethtool: fix error handling in ethtool_phys_id (git-fixes).
- commit 62d5d56
* Mon Dec  7 2020 oneukum@suse.com
- blacklist.conf: breaks kABI and is only needed on 32 bit
- commit b613713
* Mon Dec  7 2020 oneukum@suse.com
- blacklist.conf: cleanup, no functional change
- commit f5a48eb
* Mon Dec  7 2020 oneukum@suse.com
- USB: serial: kl5kusb105: fix memleak on open (git-fixes).
- commit 5939355
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/bnxt_re: Fix sizeof mismatch for allocation of pbl_tbl. (bsc#1152489)
- commit b293ffc
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/ipoib: Set rtnl_link_ops for ipoib interfaces (bsc#1152489)
- commit 2686c41
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/addr: Fix race with netevent_callback()/rdma_addr_cancel() (bsc#1152489)
- commit e7b302f
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/hns: Fix missing sq_sig_type when querying QP (bsc#1152489)
- commit 428c91c
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/hns: Add check for the validity of sl configuration (bsc#1152489)
- commit 1cb3ce0
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/hns: Correct typo of hns_roce_create_cq() (bsc#1152489)
- commit 8c66138
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/mlx5: Disable IB_DEVICE_MEM_MGT_EXTENSIONS if IB_WR_REG_MR can't work (bsc#1152489)
- commit a38a25c
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/hns: Set the unsupported wr opcode (bsc#1152489)
- commit e06fae1
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix iWARP active mtu display (bsc#1152489)
- commit d610dee
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- qede: Notify qedr when mtu has changed (bsc#1152489)
- commit 98fc763
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix resource leak in qedr_create_qp (bsc#1152489)
- commit bdb50f5
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix inline size returned for iWARP (bsc#1152489)
- commit 1a57d92
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix use of uninitialized field (bsc#1152489)
- commit 6926fdb
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix doorbell setting (bsc#1152489)
- commit 7085d43
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: Fix qp structure memory leak (bsc#1152489)
- commit 15f0227
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/umem: Prevent small pages from being returned by ib_umem_find_best_pgsz() (bsc#1152489)
- commit 6fda3ed
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/umem: Fix ib_umem_find_best_pgsz() for mappings that cross a page boundary (bsc#1152489)
- commit e3d4c09
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/mlx4: Adjust delayed work when a dup is observed (bsc#1152489)
- commit f007f05
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/mlx4: Fix starvation in paravirt mux/demux (bsc#1152489)
- commit b4a4680
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/mlx4: Add support for MRA (bsc#1152489)
- commit d8e693f
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/mlx4: Add and improve logging (bsc#1152489)
- commit d9fbac5
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/isert: Fix unaligned immediate-data handling (bsc#1152489)
- commit ff723af
* Mon Dec  7 2020 msuchanek@suse.de
- powerpc/numa: Fix a regression on memoryless node 0 (bsc#1179639
  ltc#189002).
- commit 3324f59
* Mon Dec  7 2020 hare@suse.de
- nvme-rdma: handle unexpected nvme completion data length
  (bsc#1178612).
- commit 302adf9
* Mon Dec  7 2020 tiwai@suse.de
- tty: Fix ->pgrp locking in tiocspgrp() (git-fixes).
- usb: gadget: f_fs: Use local copy of descriptors for userspace
  copy (git-fixes).
- USB: serial: kl5kusb105: fix memleak on open (git-fixes).
- USB: serial: option: fix Quectel BG96 matching (git-fixes).
- thunderbolt: Fix use-after-free in remove_unplugged_switch()
  (git-fixes).
- coredump: fix core_pattern parse error (git-fixes).
- commit c18ac30
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: avoid repeated request completion (bsc#1179519).
- nvme-rdma: avoid repeated request completion (bsc#1179519).
- nvme-tcp: avoid race between time out and tear down
  (bsc#1179519).
- nvme-rdma: avoid race between time out and tear down
  (bsc#1179519).
- nvme: introduce nvme_sync_io_queues (bsc#1179519).
- nvme-rdma: fix reset hang if controller died in the middle of
  a reset (bsc#1179519).
- nvme-rdma: fix timeout handler (bsc#1179519).
- nvme-rdma: serialize controller teardown sequences
  (bsc#1179519).
- nvme-tcp: fix reset hang if controller died in the middle of
  a reset (bsc#1179519).
- nvme-tcp: fix timeout handler (bsc#1179519).
- nvme-tcp: serialize controller teardown sequences (bsc#1179519).
- nvme: have nvme_wait_freeze_timeout return if it timed out
  (bsc#1179519).
- nvme-fabrics: don't check state NVME_CTRL_NEW for request
  acceptance (bsc#1179519).
- nvme-rdma: fix controller reset hang during traffic
  (bsc#1179519).
- nvme-tcp: fix controller reset hang during traffic
  (bsc#1179519).
- nvme-tcp: optimize network stack with setting msg flags
  (bsc#1179519).
- nvme-tcp: leverage request plugging (bsc#1179519).
- nvme-tcp: have queue prod/cons send list become a llist
  (bsc#1179519).
- commit 2ed3c82
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/core: Fix reported speed and width (bsc#1152489)
- commit 8c599c6
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix memleak in rxe_mem_init_user (bsc#1152489)
- commit cc6aac8
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Fix the parent sysfs read when the interface has 15 chars (bsc#1152489)
- commit e9e9418
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/bnxt_re: Do not add user qps to flushlist (bsc#1152489)
- commit 940898b
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/netlink: Remove CAP_NET_RAW check when dump a raw QP (bsc#1152489)
- commit ccd3388
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/core: Fix return error value in _ib_modify_qp() to negative (bsc#1152489)
- commit 687bd9b
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Prevent access to wr->next ptr afrer wr is posted to send queue (bsc#1152489)
- commit 4299c93
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/qedr: SRQ's bug fixes (bsc#1152489)
- commit 9e7f793
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: set MSG_SENDPAGE_NOTLAST with MSG_MORE when we have
  (bsc#1179519).
- Refresh
  patches.suse/0004-nvme-tcp-check-page-by-sendpage_ok-before-calling-ke.patch.
- commit 32b2bc0
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: try to send request in queue_rq context (bsc#1179519).
- nvme-tcp: avoid scheduling io_work if we are already polling
  (bsc#1179519).
- nvme-tcp: use bh_lock in data_ready (bsc#1179519).
- commit 0a88b1e
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Return void from rxe_mem_init_dma() (bsc#1152489)
- commit 3d531e1
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Return void from rxe_init_port_param() (bsc#1152489)
- commit d46a4c5
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Drop pointless checks in rxe_init_ports (bsc#1152489)
- commit 2094aae
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/counter: Allow manually bind QPs with different pids to same counter (bsc#1152489)
- commit 309f664
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: fix possible crash in recv error flow (bsc#1179519).
- commit 4c08b72
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/counter: Only bind user QPs in auto mode (bsc#1152489)
- commit 72cbdac
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Skip dgid check in loopback mode (bsc#1152489)
- commit e2d95da
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- IB/uverbs: Set IOVA on IB MR in uverbs layer (bsc#1152489)
- commit b8a964a
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: don't poll a non-live queue (bsc#1179519).
- Refresh
  patches.suse/net-use-skb_queue_empty_lockless-in-busy-poll-contex.patch.
- commit f682d57
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/core: Fix bogus WARN_ON during ib_unregister_device_queued() (bsc#1152489)
- commit 3cc3811
* Mon Dec  7 2020 hare@suse.de
- nvme-tcp: break from io_work loop if recv failed (bsc#1179519).
- nvme-tcp: move send failure to nvme_tcp_try_send (bsc#1179519).
- commit c56582a
* Mon Dec  7 2020 nmoreychaisemartin@suse.com
- RDMA/rxe: Remove unused rxe_mem_map_pages (bsc#1152489)
- commit e074cd4
* Mon Dec  7 2020 ohering@suse.de
- scsi: storvsc: Fix error return in storvsc_probe() (git-fixes).
- commit 83d54ae
* Sun Dec  6 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/ALSA-usb-audio-Use-ALC1220-VB-DT-mapping-for-ASUS-RO.patch
- commit 2b35630
* Sun Dec  6 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/cifs-allow-syscalls-to-be-restarted-in-__smb_send_rqst-.patch
  patches.suse/cifs-fix-potential-use-after-free-in-cifs_echo_request-.patch
- commit f9b149a
* Sun Dec  6 2020 tiwai@suse.de
- Input: i8042 - fix error return code in i8042_setup_aux()
  (git-fixes).
- i2c: qup: Fix error return code in qup_i2c_bam_schedule_desc()
  (git-fixes).
- commit 74aa114
* Fri Dec  4 2020 mkoutny@suse.com
- blacklist.conf: 586b58cac8b4 exit: Move preemption fixup up, move blocking operations down
- commit 280ad3c
* Fri Dec  4 2020 palcantara@suse.de
- cifs: fix DFS mount with cifsacl/modefromsid (bsc#1178270).
- commit c824489
* Fri Dec  4 2020 palcantara@suse.de
- cifs: fix check of tcon dfs in smb1 (bsc#1178270).
- commit ff315b4
* Fri Dec  4 2020 palcantara@suse.de
- cifs: Fix an error pointer dereference in cifs_mount()
  (bsc#1178270).
- commit e5a8cdb
* Fri Dec  4 2020 palcantara@suse.de
- cifs: document and cleanup dfs mount (bsc#1178270).
- commit de6694e
* Fri Dec  4 2020 palcantara@suse.de
- cifs: only update prefix path of DFS links in
  cifs_tree_connect() (bsc#1178270).
- commit 1f46cb8
* Fri Dec  4 2020 palcantara@suse.de
- cifs: fix double free error on share and prefix (bsc#1178270).
- commit bf4c8ab
* Fri Dec  4 2020 palcantara@suse.de
- cifs: handle RESP_GET_DFS_REFERRAL.PathConsumed in reconnect
  (bsc#1178270).
- commit 947bd74
* Fri Dec  4 2020 palcantara@suse.de
- cifs: handle empty list of targets in cifs_reconnect()
  (bsc#1178270).
- commit 846daee
* Fri Dec  4 2020 palcantara@suse.de
- cifs: rename reconn_inval_dfs_target() (bsc#1178270).
- commit 12d8cf3
* Fri Dec  4 2020 palcantara@suse.de
- cifs: reduce number of referral requests in DFS link lookups
  (bsc#1178270).
- commit cc7ec21
* Fri Dec  4 2020 palcantara@suse.de
- cifs: merge __{cifs,smb2}_reconnect[_tcon]() into
  cifs_tree_connect() (bsc#1178270).
- commit b6f05ac
* Fri Dec  4 2020 palcantara@suse.de
- cifs: get rid of unused parameter in reconn_setup_dfs_targets()
  (bsc#1178270).
- commit a6a1916
* Fri Dec  4 2020 tiwai@suse.de
- Update patch reference for rawmidi security fix (CVE-2020-27786 bsc#1179601)
- commit 1c4c1fd
* Fri Dec  4 2020 palcantara@suse.de
- cifs: handle hostnames that resolve to same ip in failover
  (bsc#1178270).
- commit cd8e61d
* Fri Dec  4 2020 palcantara@suse.de
- cifs: set up next DFS target before generic_ip_connect()
  (bsc#1178270).
- commit 1099aff
* Fri Dec  4 2020 palcantara@suse.de
- cifs: fix leaked reference on requeued write (bsc#1178270).
- commit f474970
* Fri Dec  4 2020 palcantara@suse.de
- cifs: fix uninitialised lease_key in open_shroot()
  (bsc#1178270).
- commit dbce315
* Fri Dec  4 2020 palcantara@suse.de
- cifs: ensure correct super block for DFS reconnect
  (bsc#1178270).
- commit 5350fc5
* Fri Dec  4 2020 palcantara@suse.de
- cifs: do not share tcons with DFS (bsc#1178270).
- commit c8f7b47
* Fri Dec  4 2020 msuchanek@suse.de
- powerpc/perf: Fix crash with is_sier_available when pmu is
  not set (bsc#1179578 ltc#189313).
- commit 26fc4d5
* Fri Dec  4 2020 tiwai@suse.de
- rtw88: debug: Fix uninitialized memory in debugfs code
  (git-fixes).
- geneve: pull IP header before ECN decapsulation (git-fixes).
- can: c_can: c_can_power_up(): fix error handling (git-fixes).
- can: sun4i_can: sun4i_can_err(): don't count arbitration lose
  as an error (git-fixes).
- can: sja1000: sja1000_err(): don't count arbitration lose as
  an error (git-fixes).
- batman-adv: Don't always reallocate the fragmentation skb head
  (git-fixes).
- batman-adv: Reserve needed_*room for fragments (git-fixes).
- batman-adv: Consider fragmentation for needed_headroom
  (git-fixes).
- commit 5d0aad4
* Fri Dec  4 2020 palcantara@suse.de
- cifs: allow syscalls to be restarted in __smb_send_rqst()
  (bsc#1176956).
- commit 5ae286e
* Fri Dec  4 2020 palcantara@suse.de
- cifs: fix potential use-after-free in cifs_echo_request()
  (bsc#1139944).
- commit 1723321
* Thu Dec  3 2020 mkubecek@suse.cz
- Delete patches.suse/fs-select.c-batch-user-writes-in-do_sys_poll.patch (bsc#1179419)
  This patch causes a regression and while we are not 100%% sure it does not
  just trigger a bug somewhere else, as it's only a performance optimization,
  dropping it for now is the safer option.
- commit b48bf35
* Thu Dec  3 2020 aaptel@suse.com
- cifs: add NULL check for ses->tcon_ipc (bsc#1178270).
- commit 0e24399
* Thu Dec  3 2020 ailiop@suse.com
- Revert "xfs: complain if anyone tries to create a too-large buffer"
  This reverts commit 293e483ad8434ee10a65f76743a0a654e34e76c6.
  References: bsc#1179425, bsc#1179550
- commit d88fa75
* Thu Dec  3 2020 bp@suse.de
- x86/speculation: Fix prctl() when
  spectre_v2_user={seccomp,prctl},ibpb (bsc#1152489).
- commit bc73dfb
* Thu Dec  3 2020 bp@suse.de
- x86/resctrl: Add necessary kernfs_put() calls to prevent
  refcount leak (bsc#1152489).
- commit 506cd70
* Thu Dec  3 2020 bp@suse.de
- x86/resctrl: Remove superfluous kernfs_get() calls to prevent
  refcount leak (bsc#1152489).
- commit 5e0ddcd
* Thu Dec  3 2020 tiwai@suse.de
- USB: quirks: Add USB_QUIRK_DISCONNECT_SUSPEND quirk for Lenovo
  A630Z TIO built-in usb-audio card (git-fixes).
- HID: Add Logitech Dinovo Edge battery quirk (git-fixes).
- HID: logitech-hidpp: Add HIDPP_CONSUMER_VENDOR_KEYS quirk for
  the Dinovo Edge (git-fixes).
- HID: add HID_QUIRK_INCREMENT_USAGE_ON_DUPLICATE for Gamevice
  devices (git-fixes).
- HID: hid-sensor-hub: Fix issue with devices with no report ID
  (git-fixes).
- HID: add support for Sega Saturn (git-fixes).
- HID: cypress: Support Varmilo Keyboards' media hotkeys
  (git-fixes).
- HID: ite: Replace ABS_MISC 120/121 events with touchpad on/off
  keypresses (git-fixes).
- HID: uclogic: Add ID for Trust Flex Design Tablet (git-fixes).
- Input: i8042 - allow insmod to succeed on devices without an
  i8042 controller (git-fixes).
- commit 79be581
* Thu Dec  3 2020 tiwai@suse.de
- kABI workaround for HD-audio generic parser (git-fixes).
- commit 233e3cc
* Thu Dec  3 2020 tiwai@suse.de
- ALSA: hda/realtek: Add mute LED quirk to yet another HP x360
  model (git-fixes).
- ALSA: hda/realtek: Fix bass speaker DAC assignment on Asus
  Zephyrus G14 (git-fixes).
- ALSA: hda/generic: Add option to enforce preferred_dacs pairs
  (git-fixes).
- ASoC: wm_adsp: fix error return code in wm_adsp_load()
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Fix HP Pavilion x2 Detachable quirks
  (git-fixes).
- ALSA: usb-audio: US16x08: fix value count for level meters
  (git-fixes).
- ALSA: hda/realtek - Add new codec supported for ALC897
  (git-fixes).
- ALSA: hda/realtek: Enable headset of ASUS UX482EG & B9400CEA
  with ALC294 (git-fixes).
- ALSA: hda/realtek - Fixed Dell AIO wrong sound tone (git-fixes).
- commit c480457
* Wed Dec  2 2020 msuchanek@suse.de
- ibmvnic: Fix TX completion error handling (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: Ensure that SCRQ entry reads are correctly ordered
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- Refresh patches.suse/ibmvnic-Correctly-re-enable-interrupts-in-NAPI-polli.patch
- Refresh patches.suse/ibmvnic-Introduce-xmit_more-support-using-batched-su.patch
- commit 02ce2a8
* Wed Dec  2 2020 mhocko@suse.com
- mm/userfaultfd: do not access vma->vm_mm after calling
  handle_userfault() (bsc#1179204).
- commit 6bb3d8f
* Wed Dec  2 2020 oneukum@suse.com
- crypto: sun4i-ss - add the A33 variant of SS (git-fixes).
- commit efe059b
* Wed Dec  2 2020 mkubecek@suse.cz
- Update kabi files.
- update to December 2020 maintenance update submission (commit 1069cd144905)
- commit 7054e5b
* Wed Dec  2 2020 wqu@suse.com
- btrfs: qgroup: don't commit transaction when we already hold
  the handle (bsc#1178634).
- commit a88c82a
* Tue Dec  1 2020 ailiop@suse.com
- xfs: prohibit fs freezing when using empty transactions
  (bsc#1179442).
- commit e04335b
* Tue Dec  1 2020 mcgrof@suse.com
- patches.suse/nvme-force-complete-cancelled-requests.patch:
  (bsc#1175995,bsc#1178756,jsc#SLE-15608).
  Without this we can end up with a series of nvme QID timeouts,
  regardless of filesystem when fstests is used or any error injection
  mechanism is used. Without this fix, we end up with 9 failures on xfs,
  but due to its generic nature, will likely end up with other failures
  on other filesystems. This does not allow a clean slate reliable
  fstests run. This fixes that issue.
  Through code inspection I found these changes were already present
  on SLE15-SP3 but not on SLE15-SP2.
- commit 9b6b1bb
* Tue Dec  1 2020 mcgrof@suse.com
- patches.suse/blk-mq-blk-mq-provide-forced-completion-method.patch:
  (bsc#1175995,jsc#SLE-15608,bsc#1178756).
- commit 88f0b07
* Tue Dec  1 2020 mhocko@suse.com
- HMAT: Skip publishing target info for nodes with no online
  memory (bsc#1178660).
- HMAT: Register memory-side cache after parsing (bsc#1178660).
- commit c10070c
* Tue Dec  1 2020 wqu@suse.com
- btrfs: allow btrfs_truncate_block() to fallback to nocow for
  data space reservation (bsc#1161099).
- commit 9a9387d
* Tue Dec  1 2020 msuchanek@suse.de
- rpm/kernel-{source,binary}.spec: do not include ghost symlinks
  (boo#1179082).
- commit 76a9256
* Tue Dec  1 2020 pmladek@suse.com
- blacklist.conf: Remove duplicate entry (git-fixes)
- commit 9169068
* Tue Dec  1 2020 tbogendoerfer@suse.de
- devlink: Make sure devlink instance and port are in same net
  namespace (bsc#1154353).
- net: ena: fix packet's addresses for rx_offset feature
  (bsc#1174852).
- net: ena: handle bad request id in ena_netdev (bsc#1174852).
- RDMA/hns: Fix retry_cnt and rnr_cnt when querying QP
  (jsc#SLE-8449).
- RDMA/hns: Fix wrong field of SRQ number the device supports
  (jsc#SLE-8449).
- commit e8d7cf3
* Tue Dec  1 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/mm-gup-allow-FOLL_FORCE-for-get_user_pages_fast.patch
  patches.suse/mm-ksm-fix-NULL-pointer-dereference-when-KSM-zero-page-is-enabled.patch
  patches.suse/mm-mempolicy-require-at-least-one-nodeid-for-MPOL_PREFERRED.patch
  patches.suse/mm-swap-make-page_evictable-inline.patch
  patches.suse/mm-swap-use-smp_mb__after_atomic-to-order-LRU-bit-set.patch
- commit 6289c65
* Tue Dec  1 2020 mhocko@suse.com
- Update
  patches.suse/mm-mmap-c-close-race-between-munmap-and-expand_upwards-downwards.patch
  (bsc#1174527, bsc#1179432, CVE-2020-29369).
- commit f55babe
* Mon Nov 30 2020 tiwai@suse.de
- romfs: fix uninitialized memory leak in romfs_dev_read()
  (CVE-2020-29371 bsc#1179429).
- commit aaf36e7
* Mon Nov 30 2020 jack@suse.cz
- patches.suse/block-Fix-use-after-free-in-blkdev_get.patch: Update tags
  (bsc#1173834 bsc#1179141 CVE-2020-15436).
- commit 6c1fbdb
* Mon Nov 30 2020 aaptel@suse.com
- cifs: Return the error from crypt_message when enc/dec key
  not found (bsc#1179426).
- commit b7a0fce
* Mon Nov 30 2020 aaptel@suse.com
- Convert trailing spaces and periods in path components
  (bsc#1179424).
- commit 88891c3
* Mon Nov 30 2020 aaptel@suse.com
- cifs: remove bogus debug code (bsc#1179427).
- commit 8a0ced9
* Mon Nov 30 2020 msuchanek@suse.de
- ibmvnic: reduce wait for completion time (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: no reset timeout for 5 seconds after reset
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: send_login should check for crq errors (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: track pending login (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- ibmvnic: stop free_all_rwi on failed reset (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- Refresh patches.suse/ibmvnic-restore-adapter-state-on-failed-reset.patch.
- ibmvnic: handle inconsistent login with reset (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- commit ce6d916
* Mon Nov 30 2020 pmladek@suse.com
- blacklist.conf: printk: cosmetic; documentation
- commit 609fe64
* Mon Nov 30 2020 pmladek@suse.com
- blacklist.conf: printk: just a preparation step for lockless ringbuffer.
- commit 8515274
* Mon Nov 30 2020 ohering@suse.de
- scripts/lib/SUSE/MyBS.pm: properly close prjconf Macros: section
- commit 965157e
* Mon Nov 30 2020 nmoreychaisemartin@suse.com
- RDMA/core: Free DIM memory in error unwind (bsc#1152489)
- commit 21b1eaa
* Mon Nov 30 2020 nmoreychaisemartin@suse.com
- RDMA/core: Stop DIM before destroying CQ (bsc#1152489)
- commit 5bb1399
* Mon Nov 30 2020 ohering@suse.de
- video: hyperv_fb: Fix the cache type when mapping the VRAM (git-fixes).
- commit 1b3b221
* Mon Nov 30 2020 ohering@suse.de
- hv_balloon: disable warning when floor reached (git-fixes).
- commit 09540b9
* Mon Nov 30 2020 mgorman@suse.de
- mm/ksm: fix NULL pointer dereference when KSM zero page is
  enabled (git fixes (mm/ksm)).
- commit d498a49
* Mon Nov 30 2020 mgorman@suse.de
- mm: mempolicy: require at least one nodeid for MPOL_PREFERRED
  (git fixes (mm/mempolicy)).
- commit 82f5309
* Mon Nov 30 2020 mgorman@suse.de
- mm: swap: use smp_mb__after_atomic() to order LRU bit set
  (git fixes (mm/vmscan)).
- mm: swap: make page_evictable() inline (git fixes (mm/vmscan)).
- commit b3e8c49
* Mon Nov 30 2020 mgorman@suse.de
- blacklist.conf: KASAN is not enabled
- commit b3c7026
* Mon Nov 30 2020 mgorman@suse.de
- blacklist.conf: Supported arches enable SPARSEMEM_VMEMMAP
- commit 928fb30
* Mon Nov 30 2020 mgorman@suse.de
- mm/gup: allow FOLL_FORCE for get_user_pages_fast() (git fixes
  (mm/gup)).
- commit b4797b5
* Mon Nov 30 2020 mgorman@suse.de
- blacklist.conf: GUP benchmark not enabled in Kconfig
- commit d60c94e
* Mon Nov 30 2020 tiwai@suse.de
- efi/x86: Fix the deletion of variables in mixed mode
  (git-fixes).
- commit dd05038
* Mon Nov 30 2020 tiwai@suse.de
- efi: EFI_EARLYCON should depend on EFI (git-fixes).
- efivarfs: revert "fix memory leak in efivarfs_create()"
  (git-fixes).
- efi/efivars: Set generic ops before loading SSDT (git-fixes).
- efi/x86: Free efi_pgd with free_pages() (git-fixes).
- efi: efibc: check for efivars write capability (git-fixes).
- efi: add missed destroy_workqueue when efisubsys_init fails
  (git-fixes).
- efi: provide empty efi_enter_virtual_mode implementation
  (git-fixes).
- efi/esrt: Fix reference count leak in esre_create_sysfs_entry
  (git-fixes).
- efi/libstub/x86: Work around LLVM ELF quirk build regression
  (git-fixes).
- efi/x86: Ignore the memory attributes table on i386 (git-fixes).
- efi/x86: Handle by-ref arguments covering multiple pages in
  mixed mode (git-fixes).
- efi/x86: Align GUIDs to their size in the mixed mode runtime
  wrapper (git-fixes).
- efi/x86: Don't panic or BUG() on non-critical error conditions
  (git-fixes).
- efi/x86: Map the entire EFI vendor string before copying it
  (git-fixes).
- commit aaf9d90
* Sun Nov 29 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/s390-cpum_sf-c-fix-file-permission-for-cpum_sfb_size
  patches.suse/s390-dasd-fix-null-pointer-dereference-for-erp-requests
  patches.suse/s390-pkey-fix-paes-selftest-failure-with-paes-and-pkey-static-build
- commit c3e5681
* Sun Nov 29 2020 tiwai@suse.de
- USB: core: Change %%pK for __user pointers to %%px (git-fixes).
- USB: core: Fix regression in Hercules audio card (git-fixes).
- usb: gadget: Fix memleak in gadgetfs_fill_super (git-fixes).
- usb: gadget: f_midi: Fix memleak in f_midi_alloc (git-fixes).
- commit ae495c3
* Sat Nov 28 2020 tiwai@suse.de
- can: m_can: fix nominal bitiming tseg2 min for version >= 3.1
  (git-fixes).
- can: gs_usb: fix endianess problem with candleLight firmware
  (git-fixes).
- batman-adv: set .owner to THIS_MODULE (git-fixes).
- nfc: s3fwrn5: use signed integer for parsing GPIO numbers
  (git-fixes).
- iwlwifi: mvm: write queue_sync_state only for sync (git-fixes).
- platform/x86: toshiba_acpi: Fix the wrong variable assignment
  (git-fixes).
- platform/x86: thinkpad_acpi: Send tablet mode switch at wakeup
  time (git-fixes).
- commit 767fda0
* Fri Nov 27 2020 ailiop@suse.com
- xfs: revert "xfs: fix rmap key and record comparison functions"
  (git-fixes).
- commit 308ebc7
* Thu Nov 26 2020 lhenriques@suse.de
- ceph: downgrade warning from mdsmap decode to debug
  (bsc#1178653).
- ceph: fix race in concurrent __ceph_remove_cap invocations
  (bsc#1178635).
- commit b0ab459
* Thu Nov 26 2020 ptesarik@suse.cz
- s390/dasd: fix null pointer dereference for ERP requests
  (git-fixes).
- s390/cpum_sf.c: fix file permission for cpum_sfb_size
  (git-fixes).
- s390/pkey: fix paes selftest failure with paes and pkey static
  build (git-fixes).
- s390/bpf: Fix multiple tail calls (git-fixes).
- commit d7dbfa4
* Thu Nov 26 2020 msuchanek@suse.de
- powerpc/pseries: new lparcfg key/value pair:
  partition_affinity_score (jsc#SLE-16360 jsc#SLE-16915).
- powerpc/perf: consolidate GPCI hcall structs into asm/hvcall.h
  (jsc#SLE-16360 jsc#SLE-16915).
- commit 918cff8
* Thu Nov 26 2020 msuchanek@suse.de
- MAINTAINERS: remove John Allen from ibmvnic (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- commit 223af9b
* Thu Nov 26 2020 oneukum@suse.com
- tpm: efi: Don't create binary_bios_measurements file for an
  empty log (git-fixes).
- x86/i8259: Use printk_deferred() to prevent deadlock
  (git-fixes).
- commit 91b284d
* Thu Nov 26 2020 martin.wilck@suse.com
- scsi: core: Return BLK_STS_AGAIN for ALUA transitioning
  (bsc#1165933, bsc#1171000).
- commit 56a64e3
* Thu Nov 26 2020 msuchanek@suse.de
- ibmvnic: Do not replenish RX buffers after every polling loop
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Use netdev_alloc_skb instead of alloc_skb to replenish
  RX buffers (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Correctly re-enable interrupts in NAPI polling routine
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Ensure that device queue memory is cache-line aligned
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Remove send_subcrq function (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- ibmvnic: Clean up TX code and TX buffer data structure
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Introduce xmit_more support using batched subCRQ hcalls
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Introduce batched RX buffer descriptor transmission
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Introduce indirect subordinate Command Response Queue
  buffer (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: fix NULL pointer dereference in ibmvic_reset_crq
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: skip tx timeout reset while in resetting (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: create send_control_ip_offload (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: create send_query_ip_offload (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- ibmvnic: rename send_map_query to send_query_map (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: rename ibmvnic_send_req_caps to send_request_cap
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: rename send_cap_queries to send_query_cap
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- Revert "ibmvnic: remove never executed if statement"
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Harden device Command Response Queue handshake
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: merge ibmvnic_reset_init and ibmvnic_init
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- Refresh patches.suse/ibmvnic-restore-adapter-state-on-failed-reset.patch.
- ibmvnic: remove never executed if statement (jsc#SLE-17043
  bsc#1179243 ltc#189290).
- ibmvnic: improve ibmvnic_init and ibmvnic_reset_init
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: compare adapter->init_done_rc with more readable
  ibmvnic_rc_codes (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: Fix use-after-free of VNIC login response buffer
  (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: store RX and TX subCRQ handle array in ibmvnic_adapter
  struct (jsc#SLE-17043 bsc#1179243 ltc#189290).
- ibmvnic: update MAINTAINERS (jsc#SLE-17043 bsc#1179243
  ltc#189290).
- commit a8dadbf
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: fix relocation failure due to race with fallocate
  (bsc#1179217).
- commit e680b1d
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: rename btrfs_insert_clone_extent() to a more generic name
  (bsc#1179217).
- commit 27c703c
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: imx8mm: fix voltage for 1.6GHz CPU operating point
  (git-fixes).
- commit 36b05ae
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: h5: OrangePi Prime: Fix ethernet node
  (git-fixes).
- commit 858be95
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: a64: bananapi-m64: Enable RGMII RX/TX
  delay on PHY (git-fixes).
- commit 5a17bb5
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: h5: OrangePi PC2: Fix ethernet node
  (git-fixes).
- commit b4307bb
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: a64: Pine64 Plus: Fix ethernet node
  (git-fixes).
- commit dfebf26
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: a64: OrangePi Win: Fix ethernet node
  (git-fixes).
- commit 4eec57a
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: Pine H64: Enable both RGMII RX/TX delay
  (git-fixes).
- commit 8bd0d47
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: allwinner: beelink-gs1: Enable both RGMII RX/TX
  delay (git-fixes).
- commit 62c9be4
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: fsl: DPAA FMan DMA operations are coherent
  (git-fixes).
- commit b68f0fe
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: zynqmp: Remove additional compatible string for
  i2c IPs (git-fixes).
- commit 99df01c
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: imx8mq: Add missing interrupts to GPC (git-fixes).
- commit 1af8481
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: dts: imx8mq: Fix TMU interrupt property (git-fixes).
- commit de53464
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: tegra: Add missing timeout clock to Tegra194 SDMMC nodes
  (git-fixes).
- commit 6169028
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: rename btrfs_punch_hole_range() to a more generic name
  (bsc#1179217).
- commit ae0b28b
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: tegra: Add missing timeout clock to Tegra186 SDMMC nodes
  (git-fixes).
- commit 044ef73
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: tegra: Add missing timeout clock to Tegra210 SDMMC
  (git-fixes).
- commit f6b3b97
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: rename struct btrfs_clone_extent_info to a more generic
  name (bsc#1179217).
- commit de43bbe
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: vdso: Add --eh-frame-hdr to ldflags (git-fixes).
- commit 937dc61
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: vdso: Add '-Bsymbolic' to ldflags (git-fixes).
- commit 96e1736
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: remove item_size member of struct btrfs_clone_extent_info
  (bsc#1179217).
- commit d01ef40
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: kprobe: add checks for ARMv8.3-PAuth combined
  instructions (git-fixes).
- commit c7c922c
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: fix metadata reservation for fallocate that leads to
  transaction aborts (bsc#1179217).
- commit 68ec4df
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: bpf: Fix branch offset in JIT (git-fixes).
- commit dcf0a55
* Wed Nov 25 2020 fdmanana@suse.com
- btrfs: fix bytes_may_use underflow in prealloc error condtition
  (bsc#1179217).
- commit c6b65e2
* Wed Nov 25 2020 aaptel@suse.com
- cifs: Fix incomplete memory allocation on setxattr path
  (bsc#1179211).
- commit 17e4326
* Wed Nov 25 2020 tiwai@suse.de
- Fix wrongly set CONFIG_SOUNDWIRE=y (bsc#1179201)
  CONFIG_SOUNDWIRE was mistakenly set as built-in.  Mark it as module.
- commit 8298c55
* Wed Nov 25 2020 tiwai@suse.de
- ACPICA: Add NHLT table signature (bsc#1176200).
- commit c68e192
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: Run ARCH_WORKAROUND_2 enabling code on all CPUs
  (git-fixes).
- commit 2b0db2e
* Wed Nov 25 2020 mbrugger@suse.com
- arm64: Run ARCH_WORKAROUND_1 enabling code on all CPUs
  (git-fixes).
- commit 8d1bf8e
* Wed Nov 25 2020 mbrugger@suse.com
- KVM: arm64: ARM_SMCCC_ARCH_WORKAROUND_1 doesn't return
  SMCCC_RET_NOT_REQUIRED (git-fixes).
- commit 3fc2241
* Wed Nov 25 2020 dwagner@suse.de
- qla2xxx: Add MODULE_VERSION back to driver (bsc#1179160).
- commit 5e4a1f7
* Wed Nov 25 2020 tiwai@suse.de
- efivarfs: fix memory leak in efivarfs_create() (git-fixes).
- staging: rtl8723bs: Add 024c:0627 to the list of SDIO device-ids
  (git-fixes).
- mmc: sdhci-pci: Prefer SDR25 timing for High Speed mode for
  BYT-based Intel controllers (git-fixes).
- hwmon: (pwm-fan) Fix RPM calculation (git-fixes).
- ACPI: button: Add DMI quirk for Medion Akoya E2228T (git-fixes).
- commit 0493181
* Wed Nov 25 2020 jlee@suse.com
- Documentation/admin-guide/module-signing.rst: add openssl
  command option example for CodeSign EKU (bsc#1177353,
  bsc#1179076).
- modsign: Add codeSigning EKU when generating X.509 key
  generation config (bsc#1177353, bsc#1179076).
- commit 09c2c7d
* Tue Nov 24 2020 mkubecek@suse.cz
- Update patches.suse/icmp-randomize-the-global-rate-limiter.patch
  references (add CVE-2020-25705 bsc#1175721).
- commit 302c097
* Tue Nov 24 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/sched-Fix-rq-nr_iowait-ordering.patch
  patches.suse/sched-fair-Ensure-tasks-spreading-in-LLC-during-LB.patch
  patches.suse/sched-fair-Fix-unthrottle_cfs_rq-for-leaf_cfs_rq-list.patch
- commit 07cd2c9
* Tue Nov 24 2020 mgorman@suse.de
- blacklist.conf: Kernel building with clang is not supported
- commit 66e9cbf
* Tue Nov 24 2020 mgorman@suse.de
- sched/fair: Fix unthrottle_cfs_rq() for leaf_cfs_rq list
  (git fixes (sched)).
- commit 155f594
* Tue Nov 24 2020 mgorman@suse.de
- sched: Fix rq->nr_iowait ordering (git fixes (sched)).
- commit 0f2faa6
* Tue Nov 24 2020 mgorman@suse.de
- sched/fair: Ensure tasks spreading in LLC during LB (git fixes
  (sched)).
- commit f2af668
* Tue Nov 24 2020 mgorman@suse.de
- blacklist.conf: Alternative KABI-safe fix used instead (bnc#1178227)
- commit 307bf60
* Tue Nov 24 2020 tiwai@suse.de
- net: sctp: Rename fallthrough label to unhandled (bsc#1178203).
- commit 6ea8e73
* Tue Nov 24 2020 oneukum@suse.com
- blacklist.conf: breaks kABI
- commit c7c8b0d
* Tue Nov 24 2020 oneukum@suse.com
- timer: Fix wheel index calculation on last level (git-fixes).
- commit 7f8a2b1
* Tue Nov 24 2020 oneukum@suse.com
- timer: Prevent base->clk from moving backward (git-fixes).
- commit 48a61b6
* Tue Nov 24 2020 tiwai@suse.de
- Update patch reference for serial security fix (CVE-2020-15437 bsc#1179140)
- commit 195abfd
* Tue Nov 24 2020 ptesarik@suse.cz
- s390/zcrypt: Fix ZCRYPT_PERDEV_REQCNT ioctl (bsc#1177070
  LTC#188342).
- s390/zcrypt: fix kmalloc 256k failure (bsc#1177066 LTC#188341).
- commit 0bca1b7
* Tue Nov 24 2020 ptesarik@suse.cz
- s390/cpum_cf,perf: change DFLT_CCERROR counter name (bsc#1175918
  LTC#187935).
- commit 142fe1e
* Tue Nov 24 2020 ohering@suse.de
- video: hyperv_fb: include vmalloc.h (git-fixes).
- commit 9598448
* Tue Nov 24 2020 tiwai@suse.de
- compiler_attributes.h: Add 'fallthrough' pseudo keyword for
  switch/case use (bsc#1178203).
- commit 83cd53c
* Tue Nov 24 2020 tiwai@suse.de
- ALSA: usb-audio: Fix MOTU M-Series quirks (bsc#1178203).
- ALSA: usb-audio: Fix quirks for other BOSS devices
  (bsc#1178203).
- ALSA: usb-audio: Add implicit_fb module option (bsc#1178203).
- ALSA: usb-audio: Add generic implicit fb parsing (bsc#1178203).
- ALSA: usb-audio: Factor out the implicit feedback quirk code
  (bsc#1178203).
- ALSA: usb-audio: Quirk for BOSS GT-001 (bsc#1178203).
- ALSA: usb-audio: Show sync endpoint information in proc outputs
  (bsc#1178203).
- ALSA: usb-audio: Use unsigned char for iface and altsettings
  fields (bsc#1178203).
- ALSA: usb-audio: Replace slave/master terms (bsc#1178203).
- ALSA: usb-audio: Simplify rate_min/max and rates set up
  (bsc#1178203).
- ALSA: usb-audio: Unify the code for the next packet size
  calculation (bsc#1178203).
- ALSA: usb-audio: Drop unneeded snd_usb_substream fields
  (bsc#1178203).
- ALSA: usb-audio: Refactoring endpoint URB deactivation
  (bsc#1178203).
- ALSA: usb-audio: Use atomic_t for endpoint use_count
  (bsc#1178203).
- ALSA: usb-audio: Constify audioformat pointer references
  (bsc#1178203).
- ALSA: usb-audio: Fix possible stall of implicit fb packet
  ring-buffer (bsc#1178203).
- ALSA: usb-audio: Refactor endpoint management (bsc#1178203).
- ALSA: usb-audio: Fix EP matching for continuous rates
  (bsc#1178203).
- ALSA: usb-audio: Always set up the parameters after resume
  (bsc#1178203).
- ALSA: usb-audio: Set callbacks via
  snd_usb_endpoint_set_callback() (bsc#1178203).
- ALSA: usb-audio: Stop both endpoints properly at error
  (bsc#1178203).
- ALSA: usb-audio: Simplify snd_usb_init_pitch() arguments
  (bsc#1178203).
- ALSA: usb-audio: Simplify snd_usb_init_sample_rate() arguments
  (bsc#1178203).
- ALSA: usb-audio: Pass snd_usb_audio object to quirk functions
  (bsc#1178203).
- ALSA: usb-audio: Don't set altsetting before initializing
  sample rate (bsc#1178203).
- ALSA: usb-audio: Add snd_usb_get_host_interface() helper
  (bsc#1178203).
- ALSA: usb-audio: Drop keep_interface flag again (bsc#1178203).
- ALSA: usb-audio: Create endpoint objects at parsing phase
  (bsc#1178203).
- ALSA: usb-audio: Avoid doubly initialization for implicit fb
  (bsc#1178203).
- ALSA: usb-audio: Drop debug.h (bsc#1178203).
- ALSA: usb-audio: Simplify hw_params rules (bsc#1178203).
- ALSA: usb-audio: Add hw constraint for implicit fb sync
  (bsc#1178203).
- ALSA: usb-audio: Move snd_usb_autoresume() call out of
  setup_hw_info() (bsc#1178203).
- ALSA: usb-audio: Track implicit fb sync endpoint in audioformat
  list (bsc#1178203).
- ALSA: usb-audio: Improve some debug prints (bsc#1178203).
- ALSA: usb-audio: Set and clear sync EP link properly
  (bsc#1178203).
- ALSA: usb-audio: Add snd_usb_get_endpoint() helper
  (bsc#1178203).
- ALSA: usb-audio: Check implicit feedback EP generically for UAC2
  (bsc#1178203).
- ALSA: usb-audio: Check valid altsetting at parsing rates for
  UAC2/3 (bsc#1178203).
- ALSA: usb-audio: Don't call usb_set_interface() at trigger
  callback (bsc#1178203).
- ALSA: usb-audio: Handle discrete rates properly in hw
  constraints (bsc#1178203).
- commit 25f15d1
* Mon Nov 23 2020 msuchanek@suse.de
- powerpc/rtas: Restrict RTAS requests from userspace
  (CVE-2020-27777 bsc#1179107).
  Update config files.
- commit 4d9370a
* Mon Nov 23 2020 tbogendoerfer@suse.de
- net/mlx5: E-Switch, Fail mlx5_esw_modify_vport_rate if qos
  disabled (jsc#SLE-8464).
- net/mlx5: Clear bw_share upon VF disable (jsc#SLE-8464).
- ionic: check port ptr before use (bsc#1167773).
- bnxt_en: Send HWRM_FUNC_RESET fw command unconditionally
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Check abort error state in bnxt_open_nic()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Invoke cancel_delayed_work_sync() for PFs also
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix regression in workqueue cleanup logic in
  bnxt_remove_one() (jsc#SLE-8371 bsc#1153274).
- RDMA/mlx5: Fix devlink deadlock on net namespace deletion
  (jsc#SLE-8464).
- SUNRPC: fix copying of multiple pages in gss_read_proxy_verf()
  (bsc#1154353).
- RDMA/hns: Fix the wrong value of rnr_retry when querying qp
  (jsc#SLE-8449).
- RDMA/hns: Solve the overflow of the calc_pg_sz() (jsc#SLE-8449).
- RDMA/qedr: Fix return code if accept is called on a destroyed qp
  (jsc#SLE-8215).
- RDMA/ucma: Add missing locking around rdma_leave_multicast()
  (git-fixes).
- net: fix pos incrementment in ipv6_route_seq_next (bsc#1154353).
- bnxt_en: return proper error codes in bnxt_show_temp
  (git-fixes).
- igc: Fix not considering the TX delay for timestamps
  (bsc#1160634).
- igc: Fix wrong timestamp latency numbers (bsc#1160634).
- bnxt_en: Fix NULL ptr dereference crash in bnxt_fw_reset_task()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Avoid sending firmware messages when AER error is
  detected (jsc#SLE-8371 bsc#1153274).
- commit b757d92
* Mon Nov 23 2020 tiwai@suse.de
- Update patch reference tag for fbcon fix (CVE-2020-28974 bsc#1178589)
- commit 4526eab
* Mon Nov 23 2020 msuchanek@suse.de
- powerpc/uaccess: Evaluate macro arguments once, before user access is
  allowed (CVE-2020-4788 bsc#1177666).
- commit 3a6dc74
* Mon Nov 23 2020 oneukum@suse.com
- usb: core: driver: fix stray tabs in error messages (git-fixes).
- commit a37b0ae
* Mon Nov 23 2020 oneukum@suse.com
- Revert "cdc-acm: hardening against malicious devices"
  (git-fixes).
- commit 1bc383a
* Mon Nov 23 2020 bp@suse.de
- x86/microcode/intel: Check patch signature before saving
  microcode for early loading (bsc#1152489).
- commit 8621df1
* Mon Nov 23 2020 msuchanek@suse.de
- powerpc/pseries: Add KVM guest doorbell restrictions
  (jsc#SLE-15869 jsc#SLE-16321).
- powerpc/pseries: Use doorbells even if XIVE is available
  (jsc#SLE-15869 jsc#SLE-16321).
- powerpc: Inline doorbell sending functions (jsc#SLE-15869
  jsc#SLE-16321).
- commit 1caac5a
* Mon Nov 23 2020 bp@suse.de
- x86/speculation: Allow IBPB to be conditionally enabled on
  CPUs with always-on STIBP (bsc#1152489).
- commit 7689d05
* Mon Nov 23 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: use grep -E instead of egrep (bsc#1179045)
  egrep is only a deprecated bash wrapper for "grep -E". So use the latter
  instead.
- commit 63d7072
* Mon Nov 23 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/scsi-libiscsi-fix-nop-race-condition
- commit 8f31344
* Mon Nov 23 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-mm-THP-swap-fix-allocating-cluster-for-swapfile-by-m.patch
- commit 47f49e5
* Mon Nov 23 2020 bp@suse.de
- blacklist.conf: ffedeeb780dc linkage: Introduce new macros for assembler symbols
- commit 3f22bb2
* Mon Nov 23 2020 jslaby@suse.cz
- kernel-{binary,source}.spec.in: do not create loop symlinks (bsc#1179082)
- commit adf56a8
* Mon Nov 23 2020 tiwai@suse.de
- mac80211: free sta in sta_info_insert_finish() on errors
  (git-fixes).
- commit 61bc819
* Mon Nov 23 2020 tiwai@suse.de
- HID: logitech-dj: Fix Dinovo Mini when paired with a MX5x00
  receiver (git-fixes).
- HID: logitech-dj: Fix an error in mse_bluetooth_descriptor
  (git-fixes).
- HID: logitech-dj: Handle quad/bluetooth keyboards with a
  builtin trackpad (git-fixes).
- HID: logitech-hidpp: Add PID for MX Anywhere 2 (git-fixes).
- iio: accel: kxcjk1013: Add support for KIOX010A ACPI DSM for
  setting tablet-mode (git-fixes).
- iio: accel: kxcjk1013: Replace is_smo8500_device with an
  acpi_type enum (git-fixes).
- iio: light: fix kconfig dependency bug for VCNL4035 (git-fixes).
- iio: adc: mediatek: fix unset field (git-fixes).
- tty: serial: imx: keep console clocks always on (git-fixes).
- tty: serial: imx: fix potential deadlock (git-fixes).
- mac80211: always wind down STA state (git-fixes).
- commit 0772cb9
* Mon Nov 23 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: avoid using more barewords (bsc#1179014)
  %%split_extra still contained two.
- commit d9b4c40
* Mon Nov 23 2020 tiwai@suse.de
- speakup: Do not let the line discipline be used several times
  (CVE-2020-28941 bsc#1178740).
- commit 94aeaf9
* Mon Nov 23 2020 glin@suse.com
- blacklist.conf: add two more bpf commits
  197afc631413 libbpf: Don‘t attempt to load unused subprog as an entry-point BPF program
  2acc3c1bc8e9 selftests/bpf: Fix error return code in run_getsockopt_test()
- commit d1b0a66
* Mon Nov 23 2020 glin@suse.com
- lib/strncpy_from_user.c: Mask out bytes after NUL terminator (bsc#1155518).
- commit c5101f8
* Sun Nov 22 2020 tiwai@suse.de
- kABI workaround for USB audio driver (bsc#1178203).
- commit 9a89b5e
* Sat Nov 21 2020 bp@suse.de
- EDAC/amd64: Support asymmetric dual-rank DIMMs (bsc#1179001).
- EDAC/amd64: Cache secondary Chip Select registers (bsc#1179001).
- commit 5ad6aa8
* Sat Nov 21 2020 bp@suse.de
- EDAC/amd64: Find Chip Select memory size using Address Mask
  (bsc#1179001).
- Refresh
  patches.suse/edac-amd64-add-amd-family-17h-model-60h-pci-ids.patch.
- Refresh
  patches.suse/edac-amd64-add-family-ops-for-family-19h-models-00h-0fh.patch.
- Refresh
  patches.suse/edac-amd64-add-pci-device-ids-for-family-17h-model-70h.patch.
- Refresh
  patches.suse/edac-amd64-save-max-number-of-controllers-to-family-type.patch.
- commit 889ea68
* Sat Nov 21 2020 tiwai@suse.de
- ALSA: usb-audio: Support PCM sync_stop (bsc#1178203).
- Refresh
  patches.suse/ALSA-usb-audio-Fix-potential-use-after-free-of-strea.patch.
- Refresh
  patches.suse/ALSA-usb-audio-set-the-interface-format-after-resume.patch.
- commit 0f18878
* Sat Nov 21 2020 tiwai@suse.de
- ALSA: usb-audio: Use ALC1220-VB-DT mapping for ASUS ROG Strix
  TRX40 mobo (bsc#1178203).
- ALSA: usb-audio: Correct wrongly matching entries with audio
  class (bsc#1178203).
- ALSA: usb-audio: Properly match with audio interface class
  (bsc#1178203).
- ALSA: usb-audio: Simplify quirk entries with a macro
  (bsc#1178203).
- ALSA: usb-audio: Move device rename and profile quirks to an
  internal table (bsc#1178203).
- ALSA: usb-audio: Use managed buffer allocation (bsc#1178203).
- ALSA: usb-audio: Convert to the common vmalloc memalloc
  (bsc#1178203).
- commit 535b061
* Sat Nov 21 2020 tiwai@suse.de
- ASoC: qcom: lpass-platform: Fix memory leak (git-fixes).
- ALSA: mixart: Fix mutex deadlock (git-fixes).
- ALSA: usb-audio: Add delay quirk for all Logitech USB devices
  (git-fixes).
- ALSA: firewire: Clean up a locking issue in copy_resp_to_buf()
  (git-fixes).
- ALSA: ctl: fix error path at adding user-defined element set
  (git-fixes).
- ALSA: hda/realtek - HP Headset Mic can't detect after boot
  (git-fixes).
- ALSA: hda/realtek - Add supported mute Led for HP (git-fixes).
- ALSA: hda/realtek: Add some Clove SSID in the ALC293(ALC1220)
  (git-fixes).
- ALSA: hda/realtek - Add supported for Lenovo ThinkPad Headset
  Button (git-fixes).
- commit 55dbb32
* Sat Nov 21 2020 bp@suse.de
- EDAC/amd64: Initialize DIMM info for systems with more than
  two channels (bsc#1179001).
- commit 263a905
* Sat Nov 21 2020 bp@suse.de
- EDAC/amd64: Gather hardware information early (bsc#1179001).
- Refresh
  patches.suse/edac-amd64-save-max-number-of-controllers-to-family-type.patch.
- commit 23c7468
* Sat Nov 21 2020 bp@suse.de
- EDAC/amd64: Save max number of controllers to family type
  (bsc#1179001).
  Refresh patches.suse/edac-amd64-add-family-ops-for-family-19h-models-00h-0fh.patch.
- EDAC/amd64: Make struct amd64_family_type global (bsc#1179001).
- commit 7a2a5fc
* Fri Nov 20 2020 msuchanek@suse.de
- kernel-source.spec: Fix build with rpm 4.16 (boo#1179015).
  RPM_BUILD_ROOT is cleared before %%%%install. Do the unpack into
  RPM_BUILD_ROOT in %%%%install
- commit 13bd533
* Fri Nov 20 2020 msuchanek@suse.de
- powerpc/32s: Prepare prevent_user_access() for user_access_end()
  (CVE-2020-4788 bsc#1177666).
- commit 2118998
* Fri Nov 20 2020 msuchanek@suse.de
- powerpc/32s: Drop NULL addr verification (CVE-2020-4788
  bsc#1177666).
- commit 764b74e
* Fri Nov 20 2020 jslaby@suse.cz
- rpm/kernel-binary.spec.in: avoid using barewords (bsc#1179014)
  Author: Dominique Leuenberger <dimstar@opensuse.org>
- commit 21f8205
* Fri Nov 20 2020 jslaby@suse.cz
- rpm/mkspec: do not build kernel-obs-build on x86_32
  We want to use 64bit kernel due to various bugs (bsc#1178762 to name
  one).
  There is:
  ExportFilter: ^kernel-obs-build.*\.x86_64.rpm$ . i586
  in Factory's prjconf now. No other actively maintained distro (i.e.
  merging packaging branch) builds a x86_32 kernel, hence pushing to
  packaging directly.
- commit 8099b4b
* Fri Nov 20 2020 msuchanek@suse.de
- fs/select.c: batch user writes in do_sys_poll (CVE-2020-4788
  bsc#1177666).
- commit e2a69e2
* Fri Nov 20 2020 lhenriques@suse.de
- ceph: check session state after bumping session->s_seq
  (bsc#1179012).
- ceph: check the sesion state and return false in case it is
  closed (bsc#1179012).
- ceph: add check_session_state() helper and make it global
  (bsc#1179012).
- commit d99bb08
* Fri Nov 20 2020 glin@suse.com
- Restore the header of series.conf
  The header of series.conf was accidentally changed by abb50be8e6bc
  "(kABI: revert use_mm name change (MM Functionality, bsc#1178426))".
  The scripts/git_sort/lib.py script matches the upper-case "K" in the
  header.
- commit cec3f48
* Fri Nov 20 2020 msuchanek@suse.de
- selftests/powerpc: entry flush test (CVE-2020-4788 bsc#1177666).
- powerpc/64s: flush L1D after user accesses (CVE-2020-4788
  bsc#1177666).
- powerpc/64s: flush L1D on kernel entry (CVE-2020-4788
  bsc#1177666).
- selftests/powerpc: rfi_flush: disable entry flush if present
  (CVE-2020-4788 bsc#1177666).
- commit e2755de
* Fri Nov 20 2020 tiwai@suse.de
- Fonts: Replace discarded const qualifier (CVE-2020-28915
  bsc#1178886).
- commit 1896c0d
* Fri Nov 20 2020 tiwai@suse.de
- fbcon: Fix global-out-of-bounds read in fbcon_get_font()
  (CVE-2020-28915 bsc#1178886).
- Fonts: Support FONT_EXTRA_WORDS macros for built-in fonts
  (CVE-2020-28915 bsc#1178886).
- commit cf5442f
* Fri Nov 20 2020 tiwai@suse.de
- Refresh patch reference for font fix patch (CVE-2020-28915 bsc#1178886)
- commit 1add793
* Fri Nov 20 2020 msuchanek@suse.de
- selftests/powerpc: Skip security tests on older CPUs
  (CVE-2020-4788 bsc#1177666).
- commit 1bc32c0
* Fri Nov 20 2020 jslaby@suse.cz
- blacklist.conf: add RISC V patch
- commit 42e5de9
* Fri Nov 20 2020 tiwai@suse.de
- can: kvaser_usb: kvaser_usb_hydra: Fix KCAN bittiming limits
  (git-fixes).
- can: m_can: m_can_stop(): set device to software init mode
  before closing (git-fixes).
- can: m_can: m_can_handle_state_change(): fix state change
  (git-fixes).
- can: flexcan: flexcan_setup_stop_mode(): add missing "req_bit"
  to stop mode property comment (git-fixes).
- can: peak_usb: fix potential integer overflow on shift of a int
  (git-fixes).
- can: mcba_usb: mcba_usb_start_xmit(): first fill skb, then
  pass to can_put_echo_skb() (git-fixes).
- can: dev: can_restart(): post buffer from the right context
  (git-fixes).
- can: af_can: prevent potential access of uninitialized member
  in canfd_rcv() (git-fixes).
- can: af_can: prevent potential access of uninitialized member
  in can_rcv() (git-fixes).
- lan743x: prevent entire kernel HANG on open, for some platforms
  (git-fixes).
- lan743x: fix issue causing intermittent kernel log warnings
  (git-fixes).
- mac80211: minstrel: fix tx status processing corner case
  (git-fixes).
- mac80211: minstrel: remove deferred sampling code (git-fixes).
- rfkill: Fix use-after-free in rfkill_resume() (git-fixes).
- spi: lpspi: Fix use-after-free on unbind (git-fixes).
- regulator: ti-abb: Fix array out of bound read access on the
  first transition (git-fixes).
- regulator: workaround self-referent regulators (git-fixes).
- regulator: avoid resolve_supply() infinite recursion
  (git-fixes).
- regulator: fix memory leak with repeated
  set_machine_constraints() (git-fixes).
- regulator: pfuze100: limit pfuze-support-disable-sw to
  pfuze{100,200} (git-fixes).
- commit 3d08124
* Thu Nov 19 2020 tiwai@suse.de
- uio: Fix use-after-free in uio_unregister_device() (git-fixes).
- mei: protect mei_cl_mtu from null dereference (git-fixes).
- usb: cdc-acm: Add DISABLE_ECHO for Renesas USB Download mode
  (git-fixes).
- pinctrl: amd: use higher precision for 512 RtcClk (git-fixes).
- pinctrl: amd: fix incorrect way to disable debounce filter
  (git-fixes).
- usb: gadget: goku_udc: fix potential crashes in probe
  (git-fixes).
- i2c: sh_mobile: implement atomic transfers (git-fixes).
- i2c: mediatek: move dma reset before i2c reset (git-fixes).
- tpm_tis: Disable interrupts on ThinkPad T490s (git-fixes).
- cfg80211: regulatory: Fix inconsistent format argument
  (git-fixes).
- cfg80211: initialize wdev data earlier (git-fixes).
- mac80211: fix use of skb payload instead of header (git-fixes).
- mfd: sprd: Add wakeup capability for PMIC IRQ (git-fixes).
- commit 0ba4e11
* Thu Nov 19 2020 dbueso@suse.de
- futex: Don't enable IRQs unconditionally in put_pi_state()
  (bsc#1149032).
- futex: Handle transient "ownerless" rtmutex state correctly
  (bsc#1149032).
- commit 15c899a
* Thu Nov 19 2020 tiwai@suse.de
- kABI workaround for HD-audio (git-fixes).
- commit 97e2fbf
* Thu Nov 19 2020 tiwai@suse.de
- ALSA: hda: Reinstate runtime_allow() for all hda controllers
  (git-fixes).
- ALSA: hda: fix jack detection with Realtek codecs when in D3
  (git-fixes).
- commit 6f153b9
* Thu Nov 19 2020 mbenes@suse.cz
- SUNRPC: Fix general protection fault in trace_rpc_xdr_overflow()
  (git-fixes).
- commit 0640a68
* Thu Nov 19 2020 mhocko@suse.com
- mm/gup: fix gup_fast with dynamic page table folding
  (bnc#1176586, LTC#188235).
- commit b2a9d8e
* Thu Nov 19 2020 lduncan@suse.com
- scsi: libiscsi: Fix NOP race condition (bsc#1176481).
- commit ed80277
* Wed Nov 18 2020 ggherdovich@suse.cz
- intel_idle: Customize IceLake server support (bsc#1178286).
- commit eac5b5e
* Wed Nov 18 2020 mhocko@suse.com
- mm, THP, swap: fix allocating cluster for swapfile by mistake
  (bsc#1178755).
- commit ba1483e
* Wed Nov 18 2020 ohering@suse.de
- Add bug reference to two hv_netvsc patches (bsc#1178853).
- commit 2fdc798
* Wed Nov 18 2020 ohering@suse.de
- x86/hyperv: Clarify comment on x2apic mode (git-fixes).
- commit 47d9c63
* Wed Nov 18 2020 ohering@suse.de
- hv: clocksource: Add notrace attribute to
  read_hv_sched_clock_*() functions (git-fixes).
- commit 803c2b1
* Wed Nov 18 2020 msuchanek@suse.de
- powerpc/pmem: Initialize pmem device on newer hardware
  (jsc#SLE-16402 jsc#SLE-16497 bsc#1176109 ltc#187964).
- powerpc/pmem: Avoid the barrier in flush routines (jsc#SLE-16402
  jsc#SLE-16497 bsc#1176109 ltc#187964).
- powerpc/pmem: Update ppc64 to use the new barrier instruction
  (jsc#SLE-16402 jsc#SLE-16497 bsc#1176109 ltc#187964).
- libnvdimm/nvdimm/flush: Allow architecture to override the flush
  barrier (jsc#SLE-16402 jsc#SLE-16497 bsc#1176109 ltc#187964).
- powerpc/pmem: Add flush routines using new pmem store and sync
  instruction (jsc#SLE-16402 jsc#SLE-16497 bsc#1176109 ltc#187964).
- powerpc/pmem: Add new instructions for persistent storage and
  sync (jsc#SLE-16402 jsc#SLE-16497 bsc#1176109 ltc#187964).
- powerpc/pmem: Restrict papr_scm to P8 and above (jsc#SLE-16402
  jsc#SLE-16497 bsc#1176109 ltc#187964).
- commit 5a4cff0
* Wed Nov 18 2020 tiwai@suse.de
- Input: resistive-adc-touch - fix kconfig dependency on
  IIO_BUFFER (git-fixes).
- Input: adxl34x - clean up a data type in adxl34x_probe()
  (git-fixes).
- commit 35dd120
* Wed Nov 18 2020 tiwai@suse.de
- Input: sunkbd - avoid use-after-free in teardown paths
  (CVE-2020-25669 bsc#1178182).
- commit bafe1db
* Tue Nov 17 2020 oneukum@suse.com
- docs: ABI: sysfs-c2port: remove a duplicated entry (git-fixes).
- commit 436b016
* Tue Nov 17 2020 oneukum@suse.com
- kgdb: Fix spurious true from in_dbg_master() (git-fixes).
- commit 1e8d73b
* Tue Nov 17 2020 glin@suse.com
- bpf: Zero-fill re-used per-cpu map element (bsc#1155518).
- libbpf, hashmap: Fix undefined behavior in hash_bits
  (bsc#1155518).
- bpf: Don't rely on GCC __attribute__((optimize)) to disable GCSE
  (bsc#1155518).
- bpf: Fix comment for helper bpf_current_task_under_cgroup()
  (bsc#1155518).
- commit fb71c62
* Mon Nov 16 2020 mgorman@suse.de
- sched: Fix loadavg accounting race on arm64 kabi (bnc#1178227).
- commit a595855
* Mon Nov 16 2020 mkoutny@suse.com
- blacklist.conf: 11d6761218d1 mm, memcg: fix error return value of mem_cgroup_css_alloc()
- commit 0ae5ae6
* Mon Nov 16 2020 mkoutny@suse.com
- blacklist.conf: 8380ce479010 mm: fork: fix kernel_stack memcg stats for various stack implementations
- commit 5d6fe57
* Mon Nov 16 2020 bp@suse.de
- blacklist.conf: 4d6ffa27b8e5 x86/lib: Change .weak to SYM_FUNC_START_WEAK for arch/x86/lib/mem*_64.S
- commit 95f1309
* Mon Nov 16 2020 bp@suse.de
- blacklist.conf: e81e07244325 objtool: Support Clang non-section symbols in ORC generation
- commit b650d28
* Mon Nov 16 2020 dwagner@suse.de
- nvme: do not update disk info for multipathed device
  (bsc#1171558).
- commit 72db678
* Mon Nov 16 2020 ailiop@suse.com
- xfs: fix a missing unlock on error in xfs_fs_map_blocks
  (git-fixes).
- commit cc2433b
* Mon Nov 16 2020 ailiop@suse.com
- xfs: fix brainos in the refcount scrubber's rmap fragment
  processor (git-fixes).
- commit 3faadca
* Mon Nov 16 2020 ailiop@suse.com
- xfs: fix rmap key and record comparison functions (git-fixes).
- commit 7b24498
* Mon Nov 16 2020 ailiop@suse.com
- xfs: set the unwritten bit in rmap lookup flags in
  xchk_bmap_get_rmapextents (git-fixes).
- commit ac90c4a
* Mon Nov 16 2020 ailiop@suse.com
- xfs: fix flags argument to rmap lookup when converting shared
  file rmaps (git-fixes).
- commit ed43f56
* Mon Nov 16 2020 tbogendoerfer@suse.de
- drivers/net/ethernet: remove incorrectly formatted doc
  (bsc#1177397).
- net: ena: Fix all static chekers' warnings (bsc#1177397).
- net: ena: Change RSS related macros and variables names
  (bsc#1177397).
- net: ena: Remove redundant print of placement policy
  (bsc#1177397).
- net: ena: Capitalize all log strings and improve code
  readability (bsc#1177397).
- net: ena: Change log message to netif/dev function
  (bsc#1177397).
- net: ena: Change license into format to SPDX in all files
  (bsc#1177397).
- net: ena: xdp: add queue counters for xdp actions (bsc#1177397).
- net: ena: ethtool: add stats printing to XDP queues
  (bsc#1177397).
- net: ena: ethtool: Add new device statistics (bsc#1177397).
- net: ena: ethtool: convert stat_offset to 64 bit resolution
  (bsc#1177397).
- commit 3fe7896
* Mon Nov 16 2020 tiwai@suse.de
- virtio: virtio_console: fix DMA memory allocation for rproc
  serial (git-fixes).
- xhci: hisilicon: fix refercence leak in xhci_histb_probe
  (git-fixes).
- thunderbolt: Fix memory leak if ida_simple_get() fails in
  enumerate_services() (git-fixes).
- thunderbolt: Add the missed ida_simple_remove() in
  ring_request_msix() (git-fixes).
- kernel/watchdog: fix watchdog_allowed_mask not used warning
  (git-fixes).
- reboot: fix overflow parsing reboot cpu number (git-fixes).
- Revert "kernel/reboot.c: convert simple_strtoul to kstrtoint"
  (git-fixes).
- clk: define to_clk_regmap() as inline function (git-fixes).
- xhci: Fix sizeof() mismatch (git-fixes).
- commit a563406
* Mon Nov 16 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/ACPI-GED-fix-Wformat.patch
  patches.suse/cosa-Add-missing-kfree-in-error-path-of-cosa_write.patch
  patches.suse/gpio-pcie-idio-24-Enable-PEX8311-interrupts.patch
  patches.suse/gpio-pcie-idio-24-Fix-IRQ-Enable-Register-value.patch
  patches.suse/gpio-pcie-idio-24-Fix-irq-mask-when-masking.patch
  patches.suse/lan743x-fix-BUG-invalid-wait-context-when-setting-rx.patch
  patches.suse/mmc-renesas_sdhi_core-Add-missing-tmio_mmc_host_free.patch
  patches.suse/mmc-sdhci-of-esdhc-Handle-pulse-width-detection-erra.patch
  patches.suse/pinctrl-aspeed-Fix-GPI-only-function-problem.patch
  patches.suse/pinctrl-intel-Set-default-bias-in-case-no-particular.patch
- commit e7295f4
* Mon Nov 16 2020 mkubecek@suse.cz
- update patch metadata
  patches.suse/SUNRPC-Revert-241b1f419f0e-SUNRPC-Remove-xdr_buf_tri.patch was
  replaced by a no-op stub only preserving kABI but the upstream reference
  was left in place. Our kbuild checks complain because the same commit id is
  also blacklisted. Drop the mainline reference which is no longer
  appropriate and refer to the commit id in commit message instead.
- commit c39115f
* Mon Nov 16 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/NFSv4-Handle-NFS4ERR_OLD_STATEID-in-CLOSE-OPEN_DOWNG.patch
  patches.suse/NFSv4-Wait-for-stateid-updates-after-CLOSE-OPEN_DOWN.patch
  patches.suse/NFSv4.x-recover-from-pre-mature-loss-of-openstateid.patch
  patches.suse/svcrdma-fix-bounce-buffers-for-unaligned-offsets-and.patch
- commit 6b62933
* Mon Nov 16 2020 mkubecek@suse.cz
- series.conf: whitespace cleanup
- commit 3581101
* Mon Nov 16 2020 neilb@suse.de
- NFS: only invalidate dentrys that are clearly invalid
  (bsc#1178669 bsc#1170139).
- commit f10a996
* Sat Nov 14 2020 colyli@suse.de
- dax: Fix stack overflow when mounting fsdax pmem device
  (bsc#1171073).
- dax: fix detection of dax support for non-persistent memory
  block devices (bsc#1171073).
- commit 91904e0
* Sat Nov 14 2020 colyli@suse.de
- libceph: use sendpage_ok() in ceph_tcp_sendpage() (bsc#1172873).
- scsi: libiscsi: use sendpage_ok() in iscsi_tcp_segment_map()
  (bsc#1172873).
- drbd: code cleanup by using sendpage_ok() to check page for
  kernel_sendpage() (bsc#1172873).
- tcp: use sendpage_ok() to detect misused .sendpage
  (bsc#1172873).
- nvme-tcp: check page by sendpage_ok() before calling
  kernel_sendpage() (bsc#1172873).
- net: add WARN_ONCE in kernel_sendpage() for improper zero-copy
  send (bsc#1172873).
- net: introduce helper sendpage_ok() in include/linux/net.h
  (bsc#1172873).
  kABI workaround for including mm.h in include/linux/net.h
  (bsc#1172873).
- commit 5b20669
* Sat Nov 14 2020 tiwai@suse.de
- pinctrl: intel: Set default bias in case no particular value
  given (git-fixes).
- pinctrl: aspeed: Fix GPI only function problem (git-fixes).
- gpio: pcie-idio-24: Enable PEX8311 interrupts (git-fixes).
- gpio: pcie-idio-24: Fix IRQ Enable Register value (git-fixes).
- gpio: pcie-idio-24: Fix irq mask when masking (git-fixes).
- mmc: sdhci-of-esdhc: Handle pulse width detection erratum for
  more SoCs (git-fixes).
- mmc: renesas_sdhi_core: Add missing tmio_mmc_host_free()
  at remove (git-fixes).
- cosa: Add missing kfree in error path of cosa_write (git-fixes).
- lan743x: fix "BUG: invalid wait context" when setting rx mode
  (git-fixes).
- ACPI: GED: fix -Wformat (git-fixes).
- commit 4dd9cfa
* Sat Nov 14 2020 tiwai@suse.de
- vt: Disable KD_FONT_OP_COPY (bsc#1178589).
- commit a819dc3
* Fri Nov 13 2020 mbrugger@suse.com
- mm/memory-failure: Add memory_failure_queue_kick()
  (jsc#SLE-16610).
- commit 58bbb5e
* Thu Nov 12 2020 msuchanek@suse.de
- prom_init: enable verbose prints (bsc#1178142 bsc#1180759).
- commit c0bbedb
* Thu Nov 12 2020 msuchanek@suse.de
- powerpc/vnic: Extend "failover pending" window (bsc#1176855
  ltc#187293).
- commit 8c35da0
* Thu Nov 12 2020 mkoutny@suse.com
- mm/memcg: fix refcount error while moving and swapping
  (bsc#1178686).
- commit cbd5a59
* Thu Nov 12 2020 tiwai@suse.de
- USB: serial: option: add Telit FN980 composition 0x1055
  (git-fixes).
- USB: serial: option: add LE910Cx compositions 0x1203, 0x1230,
  0x1231 (git-fixes).
- USB: serial: option: add Quectel EC200T module support
  (git-fixes).
- USB: Add NO_LPM quirk for Kingston flash drive (git-fixes).
- net: usb: qmi_wwan: add Telit LE910Cx 0x1230 composition
  (git-fixes).
- kthread_worker: prevent queuing delayed work from timer_fn
  when it is being canceled (git-fixes).
- lib/crc32test: remove extra local_irq_disable/enable
  (git-fixes).
- tty: serial: fsl_lpuart: LS1021A has a FIFO size of 16 words,
  like LS1028A (git-fixes).
- usb: typec: tcpm: reset hard_reset_count for any disconnect
  (git-fixes).
- usb: host: fsl-mph-dr-of: check return of dma_set_mask()
  (git-fixes).
- ACPI: dock: fix enum-conversion warning (git-fixes).
- ACPI: NFIT: Fix comparison to '-ENXIO' (git-fixes).
- 9P: Cast to loff_t before multiplying (git-fixes).
- fbdev, newport_con: Move FONT_EXTRA_WORDS macros into
  linux/font.h (git-fixes).
- tty: serial: fsl_lpuart: add LS1028A support (git-fixes).
- commit af1d39a
* Wed Nov 11 2020 ohering@suse.de
- hv_netvsc: make recording RSS hash depend on feature flag
  (bsc#1177820).
- commit 84f7284
* Wed Nov 11 2020 nborisov@suse.com
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev. (bsc#1176983)
  It had a missing hunk in prof_namespace.c so simply add it, this fixes
  the issue reported in bsc#1176983
- commit 4999b20
* Wed Nov 11 2020 ohering@suse.de
- hv_netvsc: Fix XDP refcnt for synthetic and VF NICs
  (bsc#1177820).
- commit c7e2d68
* Wed Nov 11 2020 mkoutny@suse.com
- mm/memcontrol.c: add missed css_put() (bsc#1178661).
- commit 50e1826
* Wed Nov 11 2020 ohering@suse.de
- hv_netvsc: Add XDP support (bsc#1177820).
- refresh patches.suse/msft-hv-2073-hv_netvsc-Fix-netvsc_start_xmit-s-return-type.patch
- commit e1c99b4
* Wed Nov 11 2020 ohering@suse.de
- hv_netvsc: record hardware hash in skb (bsc#1177820).
- refresh patches.suse/suse-hv-kabi.patch b/patches.suse/suse-hv-kabi.patch
  (drop chunks which are in patches.suse/msft-hv-1962-hv_netvsc-record-hardware-hash-in-skb.patch)
- commit f89c5c0
* Wed Nov 11 2020 mkoutny@suse.com
- mm, memcg: fix inconsistent oom event behavior (bsc#1178659).
- commit 9f54445
* Wed Nov 11 2020 mbenes@suse.cz
- ring-buffer: Fix recursion protection transitions between
  interrupt context (git-fixes).
- commit 5a991eb
* Tue Nov 10 2020 mbenes@suse.cz
- ftrace: Handle tracing when switching between context
  (git-fixes).
- commit ae03fad
* Tue Nov 10 2020 mbenes@suse.cz
- ftrace: Fix recursion check for NMI test (git-fixes).
- commit 030da09
* Tue Nov 10 2020 mbenes@suse.cz
- tracing: Fix out of bounds write in get_trace_buf (git-fixes).
- commit 67e9ee9
* Tue Nov 10 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/exfat-fix-name_hash-computation-on-big-endian-systems.patch
  patches.suse/exfat-fix-overflow-issue-in-exfat_cluster_to_sector.patch
  patches.suse/exfat-fix-possible-memory-leak-in-exfat_find.patch
  patches.suse/exfat-fix-use-of-uninitialized-spinlock-on-error-path.patch
  patches.suse/exfat-fix-wrong-hint_stat-initialization-in-exfat_find_dir_entry.patch
  patches.suse/exfat-fix-wrong-size-update-of-stream-entry-by-typo.patch
  patches.suse/mmswapfile.c-fix-potential-memory-leak-in-sys_swapon.patch
- commit 37fd1b5
* Mon Nov  9 2020 rgoldwyn@suse.com
- mm/swapfile.c: fix potential memory leak in sys_swapon
  (git-fixes).
- exfat: fix use of uninitialized spinlock on error path
  (git-fixes).
- exfat: fix name_hash computation on big endian systems
  (git-fixes).
- exfat: fix wrong size update of stream entry by typo
  (git-fixes).
- exfat: fix wrong hint_stat initialization in
  exfat_find_dir_entry()  (git-fixes).
- exfat: fix overflow issue in exfat_cluster_to_sector()
  (git-fixes).
- exfat: fix possible memory leak in exfat_find()  (git-fixes).
- commit 97624cb
* Mon Nov  9 2020 fdmanana@suse.com
- btrfs: reschedule if necessary when logging directory items
  (bsc#1178585).
- commit 5a09bb7
* Mon Nov  9 2020 fdmanana@suse.com
- btrfs: cleanup cow block on error (bsc#1178584).
- commit 080ee21
* Mon Nov  9 2020 fdmanana@suse.com
- btrfs: send, recompute reference path after orphanization of
  a directory (bsc#1178581).
- commit 1067aa3
* Mon Nov  9 2020 fdmanana@suse.com
- btrfs: send, orphanize first all conflicting inodes when
  processing references (bsc#1178579).
- commit 972ec4e
* Mon Nov  9 2020 tonyj@suse.de
- perf/core: Fix a memory leak in perf_event_parse_addr_filter()
  (bsc#1178393, CVE-2020-25704).
- commit ec449ad
* Mon Nov  9 2020 mbenes@suse.cz
- Refresh
  patches.suse/x86-unwind-orc-Fix-inactive-tasks-with-stack-pointer.patch.
  "series_sort -u" applied
- commit 3711acc
* Mon Nov  9 2020 mbrugger@suse.com
- arm64: acpi: Make apei_claim_sea() synchronise with APEI's irq work (jsc#SLE-16610).
- commit 5f689d9
* Mon Nov  9 2020 mbrugger@suse.com
- ACPI: APEI: Kick the memory_failure() queue for synchronous errors (jsc#SLE-16610).
- commit 36dbacd
* Mon Nov  9 2020 mbrugger@suse.com
- firmware: arm_sdei: Document the motivation behind these set_fs() calls (jsc#SLE-16610).
- commit 7d33342
* Mon Nov  9 2020 ailiop@suse.com
- xfs: fix scrub flagging rtinherit even if there is no rt device
  (git-fixes).
- commit abfd9e4
* Mon Nov  9 2020 ailiop@suse.com
- xfs: flush new eof page on truncate to avoid post-eof corruption
  (git-fixes).
- commit 8dd6e4b
* Mon Nov  9 2020 ailiop@suse.com
- xfs: set xefi_discard when creating a deferred agfl free log
  intent item (git-fixes).
- commit 9130952
* Mon Nov  9 2020 tiwai@suse.de
- serial: txx9: add missing platform_driver_unregister() on
  error in serial_txx9_init (git-fixes).
- serial: 8250_mtk: Fix uart_get_baud_rate warning (git-fixes).
- USB: serial: cyberjack: fix write-URB completion race
  (git-fixes).
- usb: mtu3: fix panic in mtu3_gadget_stop() (git-fixes).
- can: flexcan: flexcan_remove(): disable wakeup completely
  (git-fixes).
- can: flexcan: remove FLEXCAN_QUIRK_DISABLE_MECR quirk for
  LS1021A (git-fixes).
- can: peak_canfd: pucan_handle_can_rx(): fix echo management
  when loopback is on (git-fixes).
- can: peak_usb: peak_usb_get_ts_time(): fix timestamp wrapping
  (git-fixes).
- can: peak_usb: add range checking in decode operations
  (git-fixes).
- can: can_create_echo_skb(): fix echo skb generation: always
  use skb_clone() (git-fixes).
- can: dev: __can_get_echo_skb(): fix real payload length return
  value for RTR frames (git-fixes).
- can: dev: can_get_echo_skb(): prevent call to kfree_skb()
  in hard IRQ context (git-fixes).
- can: rx-offload: don't call kfree_skb() from IRQ context
  (git-fixes).
- commit efd4e46
* Sun Nov  8 2020 tiwai@suse.de
- ASoC: codecs: wcd9335: Set digital gain range correctly
  (git-fixes).
- ASoC: cs42l51: manage mclk shutdown delay (git-fixes).
- ASoC: qcom: sdm845: set driver name correctly (git-fixes).
- ASoC: Intel: kbl_rt5663_max98927: Fix kabylake_ssp_fixup
  function (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for Qu-16
  (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for MODX
  (git-fixes).
- ALSA: usb-audio: add usb vendor id as DSD-capable for Khadas
  devices (git-fixes).
- ALSA: hda/realtek - Enable headphone for ASUS TM420 (git-fixes).
- ALSA: hda: prevent undefined shift in
  snd_hdac_ext_bus_get_link() (git-fixes).
- ALSA: hda/realtek - Fixed HP headset Mic can't be detected
  (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for Zoom UAC-2
  (git-fixes).
- ALSA: fix kernel-doc markups (git-fixes).
- commit 91a799a
* Fri Nov  6 2020 ohering@suse.de
- hyperv_fb: Update screen_info after removing old framebuffer
  (bsc#1175306).
- x86/kexec: Use up-to-dated screen_info copy to fill boot params
  (bsc#1175306).
- video: hyperv: hyperv_fb: Use physical memory for fb on HyperV
  Gen 1 VMs (bsc#1175306).
- video: hyperv: hyperv_fb: Support deferred IO for Hyper-V
  frame buffer driver (bsc#1175306).
- video: hyperv: hyperv_fb: Obtain screen resolution from Hyper-V
  host (bsc#1175306).
- commit 6359015
* Fri Nov  6 2020 mkoutny@suse.com
- memcg: fix NULL pointer dereference in
  __mem_cgroup_usage_unregister_event (bsc#1177703).
- commit 676737e
* Fri Nov  6 2020 tiwai@suse.de
- regulator: defer probe when trying to get voltage from
  unresolved supply (git-fixes).
- usb: cdc-acm: fix cooldown mechanism (git-fixes).
- drivers: watchdog: rdc321x_wdt: Fix race condition bugs
  (git-fixes).
- power: supply: test_power: add missing newlines when printing
  parameters by sysfs (git-fixes).
- uio: free uio id after uio file node is freed (git-fixes).
- usb: xhci: omit duplicate actions when suspending a runtime
  suspended host (git-fixes).
- USB: adutux: fix debugging (git-fixes).
- usb: typec: tcpm: During PR_SWAP, source caps should be sent
  only after tSwapSourceStart (git-fixes).
- commit 87c92c0
* Fri Nov  6 2020 tiwai@suse.de
- PM: runtime: Drop runtime PM references to supplier on link
  removal (git-fixes).
- staging: octeon: Drop on uncorrectable alignment or FCS error
  (git-fixes).
- staging: octeon: repair "fixed-link" support (git-fixes).
- power: supply: bq27xxx: report "not charging" on all types
  (git-fixes).
- p54: avoid accessing the data mapped to streaming DMA
  (git-fixes).
- PCI/ACPI: Whitelist hotplug ports for D3 if power managed by
  ACPI (git-fixes).
- media: uvcvideo: Fix dereference of out-of-bound list iterator
  (git-fixes).
- media: uvcvideo: Fix uvc_ctrl_fixup_xu_info() not having any
  effect (git-fixes).
- media: imx274: fix frame interval handling (git-fixes).
- commit abe310e
* Fri Nov  6 2020 tiwai@suse.de
- staging: comedi: cb_pcidas: Allow 2-channel commands for AO
  subdevice (git-fixes).
- ath10k: fix VHT NSS calculation when STBC is enabled
  (git-fixes).
- ath10k: start recovery process when payload length exceeds
  max htc length for sdio (git-fixes).
- leds: bcm6328, bcm6358: use devres LED registering function
  (git-fixes).
- ACPI / extlog: Check for RDMSR failure (git-fixes).
- ACPI: video: use ACPI backlight for HP 635 Notebook (git-fixes).
- media: tw5864: check status of tw5864_frameinterval_get
  (git-fixes).
- media: platform: Improve queue set up flow for bug fixing
  (git-fixes).
- commit 12c4dfb
* Thu Nov  5 2020 mbenes@suse.cz
- Do not create null.i000.ipa-clones file (bsc#1178330)
  Kbuild cc-option compiles /dev/null file to test for an option
  availability. Filter out -fdump-ipa-clones so that null.i000.ipa-clones
  file is not generated in the process.
- commit 1425d4e
* Thu Nov  5 2020 varad.gautam@suse.com
- net: mscc: ocelot: fix race condition with TX timestamping
  (bsc#1178461).
- commit 9045c8f
* Wed Nov  4 2020 ailiop@suse.com
- xfs: don't update mtime on COW faults (bsc#1167030).
- commit cbce094
* Wed Nov  4 2020 ailiop@suse.com
- xfs: complain if anyone tries to create a too-large buffer
  log item (bsc#1166146).
- commit 293e483
* Wed Nov  4 2020 msuchanek@suse.de
- kABI: revert use_mm name change (MM Functionality, bsc#1178426).
- commit abb50be
* Wed Nov  4 2020 ailiop@suse.com
- xfs: remove unused variable 'done' (bsc#1166166).
- commit 61fcffc
* Wed Nov  4 2020 ailiop@suse.com
- xfs: truncate should remove all blocks, not just to the end
  of the page cache (bsc#1166166).
- commit e2d039c
* Wed Nov  4 2020 ailiop@suse.com
- xfs: introduce XFS_MAX_FILEOFF (bsc#1166166).
- commit 76c1570
* Wed Nov  4 2020 vbabka@suse.cz
- powerpc/64s/radix: Fix mm_cpumask trimming race vs
  kthread_use_mm (MM Functionality, bsc#1178426).
- commit 7298443
* Wed Nov  4 2020 vbabka@suse.cz
- powerpc: select ARCH_WANT_IRQS_OFF_ACTIVATE_MM (MM
  Functionality, bsc#1178426).
- Update config files. Select the new option for ppc64le.
- commit 39e4bbd
* Wed Nov  4 2020 vbabka@suse.cz
- mm: fix exec activate_mm vs TLB shootdown and lazy tlb switching
  race (MM Functionality, bsc#1178426).
- commit bae6aac
* Wed Nov  4 2020 vbabka@suse.cz
- mm: fix kthread_use_mm() vs TLB invalidate (MM Functionality,
  bsc#1178426).
- commit ebe1e96
* Wed Nov  4 2020 vbabka@suse.cz
- kernel: better document the use_mm/unuse_mm API contract
  (MM Functionality, bsc#1178426).
- Refresh patches.suse/amdgpu-a-NULL-mm-does-not-mean-a-thread-is-a-kthread.patch.
- commit e0e83ba
* Wed Nov  4 2020 jslaby@suse.cz
- tty: make FONTX ioctl use the tty pointer they were actually
  passed (bsc#1178123 CVE-2020-25668).
- commit fda631f
* Wed Nov  4 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section:
  patches.suse/powercap-Restrict-energy-meter-to-root-access.patch
- commit a552ff6
* Wed Nov  4 2020 tiwai@suse.de
- Updated Copyright line in rpm templates with SUSE LLC
- commit 39a1fcf
* Wed Nov  4 2020 tiwai@suse.de
- rpm/kernel-obs-build.spec.in: Add -q option to modprobe calls (bsc#1178401)
- commit 33ded45
* Wed Nov  4 2020 mkubecek@suse.cz
- icmp: randomize the global rate limiter (git-fixes).
- commit 3f6a76f
* Wed Nov  4 2020 neilb@suse.de
- svcrdma: fix bounce buffers for unaligned offsets and multiple
  pages (git-fixes).
- commit 3c46e04
* Wed Nov  4 2020 neilb@suse.de
- NFSv4: Wait for stateid updates after CLOSE/OPEN_DOWNGRADE
  (bsc#1176180).
- NFSv4.x recover from pre-mature loss of openstateid
  (bsc#1176180).
- NFSv4: Handle NFS4ERR_OLD_STATEID in CLOSE/OPEN_DOWNGRADE
  (bsc#1176180).
- commit ae88090
* Wed Nov  4 2020 neilb@suse.de
- blacklist.conf:
- Delete
  patches.suse/SUNRPC-Revert-241b1f419f0e-SUNRPC-Remove-xdr_buf_tri.patch.
  This patch causes a regression - bsc1178304 - and "fixing" it properly
  requires backporting patches which break kabi.  So just drop for now.
- commit 548f6fe
* Tue Nov  3 2020 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix compressed module handling for in-tree KMP (jsc#SLE-10886)
  The in-tree KMP that is built with SLE kernels have a different scriptlet
  that is embedded in kernel-binary.spec.in rather than *.sh files.
- commit e32ee2c
* Tue Nov  3 2020 nborisov@suse.com
- btrfs: Account for merged patches upstream
  Move below patches to sorted section.
- Refresh patches.suse/btrfs-account-for-trans_block_rsv-in-may_commit_transaction.patch.
- Refresh atches.suse/btrfs-allow-us-to-use-up-to-90-of-the-global-rsv-for-unlink.patch.
- Refresh patches.suse/btrfs-force-chunk-allocation-if-our-global-rsv-is-larger-than-metadata.patch.
- Refresh patches.suse/btrfs-improve-global-reserve-stealing-logic.patch.
- Refresh patches.suse/btrfs-only-check-priority-tickets-for-priority-flushing.patch.
- Refresh patches.suse/btrfs-run-btrfs_try_granting_tickets-if-a-priority-ticket-fails.patch.
  Also add 3 new patches to follow upstream as much as possible, one of
  them is a git-fixes requirements the others are prerequisites for it:
  - patches.suse/btrfs-account-ticket-size-at-add-delete-time.patch
  - patches.suse/btrfs-fix-reclaim-counter-leak-of-space_info-objects.patch
  - patches.suse/btrfs-fix-reclaim_size-counter-leak-after-stealing-from-global-reserve.patch
- commit b193add
* Tue Nov  3 2020 fdmanana@suse.com
- btrfs: fix filesystem corruption after a device replace
  (bsc#1178395).
- commit ece2bc8
* Tue Nov  3 2020 fdmanana@suse.com
- btrfs: move btrfs_rm_dev_replace_free_srcdev outside of all
  locks (bsc#1178395).
- commit 9f5adb5
* Tue Nov  3 2020 fdmanana@suse.com
- btrfs: move btrfs_scratch_superblocks into
  btrfs_dev_replace_finishing (bsc#1178395).
- commit 8818530
* Tue Nov  3 2020 jslaby@suse.cz
- vt: keyboard, extend func_buf_lock to readers (bnc#1177766
  CVE-2020-25656).
- vt: keyboard, simplify vt_kdgkbsent (bnc#1177766
  CVE-2020-25656).
- commit d1af3a9
* Tue Nov  3 2020 tiwai@suse.de
- Disable ipa-clones dump for KMP builds (bsc#1178330)
  The feature is not really useful for KMP, and rather confusing,
  so let's disable it at building out-of-tree codes
- commit ba5c338
* Tue Nov  3 2020 dbueso@suse.de
- time: Prevent undefined behaviour in timespec64_to_ns()
  (bsc#1164648).
- futex: Fix incorrect should_fail_futex() handling (bsc#1149032).
- futex: Adjust absolute futex timeouts with per time namespace
  offset (bsc#1164648).
- futex: Remove unused or redundant includes (bsc#1149032).
- futex: Consistently use fshared as boolean (bsc#1149032).
- futex: Remove put_futex_key() (bsc#1149032).
- commit a86c28d
* Mon Nov  2 2020 ohering@suse.de
- kbuild: enforce -Werror=return-type (bsc#1177281).
- commit 1efe79d
* Mon Nov  2 2020 ptesarik@suse.cz
- s390/dasd: Fix zero write for FBA devices (bsc#1177801
  LTC#188735).
- s390/cio: add cond_resched() in the slow_eval_known_fn() loop
  (bsc#1177799 LTC#188733).
- commit 8d8c67c
* Mon Nov  2 2020 mkubecek@suse.cz
- update patch metadata
- update Patch-mainline:
  patches.suse/ibmveth-Fix-use-of-ibmveth-in-a-bridge.patch
- commit 32664f1
* Mon Nov  2 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/scsi-ibmvscsi-Fix-potential-race-after-loss-of-trans.patch
- commit a1665a9
* Fri Oct 30 2020 msuchanek@suse.de
- Disable module compression on SLE15 SP2 (bsc#1178307)
- commit 6e769e1
* Fri Oct 30 2020 msuchanek@suse.de
- Refresh patches.suse/ibmveth-Fix-use-of-ibmveth-in-a-bridge.patch.
  Update to upstream version.
- commit 69ab55e
* Fri Oct 30 2020 msuchanek@suse.de
- ibmvnic: fix ibmvnic_set_mac (bsc#1066382 ltc#160943 git-fixes).
- commit 4e8525b
* Fri Oct 30 2020 jslaby@suse.cz
- blacklist.conf: add two more
- commit 4c2096a
* Fri Oct 30 2020 jslaby@suse.cz
- tipc: fix memory leak caused by tipc_buf_append() (git-fixes).
- commit 22daff6
* Fri Oct 30 2020 jslaby@suse.cz
- KVM: x86/mmu: Commit zap of remaining invalid pages when
  recovering lpages (git-fixes).
- net/core: check length before updating Ethertype in
  skb_mpls_{push,pop} (git-fixes).
- bnxt_en: Protect bnxt_set_eee() and bnxt_set_pauseparam()
  with mutex (git-fixes).
- block: Set same_page to false in __bio_try_merge_page if ret
  is false (git-fixes).
- selftests/timers: Turn off timeout setting (git-fixes).
- mm: madvise: fix vma user-after-free (git-fixes).
- commit ba14726
* Fri Oct 30 2020 tiwai@suse.de
- usb: cdc-acm: add quirk to blacklist ETAS ES58X devices
  (git-fixes).
- usb: gadget: f_ncm: allow using NCM in SuperSpeed Plus gadgets
  (git-fixes).
- usb: gadget: function: printer: fix use-after-free in
  __lock_acquire (git-fixes).
- usb: dwc3: simple: add support for Hikey 970 (git-fixes).
- USB: cdc-wdm: Make wdm_flush() interruptible and add wdm_fsync()
  (git-fixes).
- USB: cdc-acm: handle broken union descriptors (git-fixes).
- usb: ohci: Default to per-port over-current protection
  (git-fixes).
- usb: core: Solve race condition in anchor cleanup functions
  (git-fixes).
- commit 3a141c3
* Fri Oct 30 2020 tiwai@suse.de
- r8169: fix issue with forced threading in combination with
  shared interrupts (git-fixes).
- rtw88: increse the size of rx buffer size (git-fixes).
- rtl8xxxu: prevent potential memory leak (git-fixes).
- tty: serial: fsl_lpuart: fix lpuart32_poll_get_char (git-fixes).
- tty: ipwireless: fix error handling (git-fixes).
- PM: hibernate: remove the bogus call to get_gendisk() in
  software_resume() (git-fixes).
- spi: spi-s3c64xx: Check return values (git-fixes).
- spi: spi-s3c64xx: swap s3c64xx_spi_set_cs() and
  s3c64xx_enable_datapath() (git-fixes).
- net: usb: rtl8150: set random MAC address when
  set_ethernet_addr() fails (git-fixes).
- commit 53b1fbc
* Fri Oct 30 2020 tiwai@suse.de
- mwifiex: don't call del_timer_sync() on uninitialized timer
  (git-fixes).
- mic: vop: copy data to kernel space then write to io memory
  (git-fixes).
- misc: vop: add round_up(x,4) for vring_size to avoid kernel
  panic (git-fixes).
- misc: rtsx: Fix memory leak in rtsx_pci_probe (git-fixes).
- media: firewire: fix memory leak (git-fixes).
- media: ati_remote: sanity check for both endpoints (git-fixes).
- media: st-delta: Fix reference count leak in delta_run_work
  (git-fixes).
- media: sti: Fix reference count leaks (git-fixes).
- mmc: sdio: Check for CISTPL_VERS_1 buffer size (git-fixes).
- net: usb: qmi_wwan: add Cellient MPL200 card (git-fixes).
- commit 9642953
* Fri Oct 30 2020 tiwai@suse.de
- media: exynos4-is: Fix several reference count leaks due to
  pm_runtime_get_sync (git-fixes).
- media: exynos4-is: Fix a reference count leak due to
  pm_runtime_get_sync (git-fixes).
- media: exynos4-is: Fix a reference count leak (git-fixes).
- media: vsp1: Fix runtime PM imbalance on error (git-fixes).
- media: platform: s3c-camif: Fix runtime PM imbalance on error
  (git-fixes).
- media: platform: sti: hva: Fix runtime PM imbalance on error
  (git-fixes).
- media: bdisp: Fix runtime PM imbalance on error (git-fixes).
- media: media/pci: prevent memory leak in bttv_probe (git-fixes).
- media: rcar_drif: Allocate v4l2_async_subdev dynamically
  (git-fixes).
- media: rcar_drif: Fix fwnode reference leak when parsing DT
  (git-fixes).
- commit ff98d93
* Fri Oct 30 2020 tiwai@suse.de
- mailbox: avoid timer start from callback (git-fixes).
- mac80211: handle lack of sband->bitrates in rates (git-fixes).
- HID: ite: Add USB id match for Acer One S1003 keyboard dock
  (git-fixes).
- eeprom: at25: set minimum read/write access stride to 1
  (git-fixes).
- media: i2c: ov5640: Enable data pins on poweron for DVP mode
  (git-fixes).
- media: i2c: ov5640: Separate out mipi configuration from s_power
  (git-fixes).
- media: i2c: ov5640: Remain in power down for DVP mode unless
  streaming (git-fixes).
- media: uvcvideo: Ensure all probed info is returned to v4l2
  (git-fixes).
- media: saa7134: avoid a shift overflow (git-fixes).
- media: venus: core: Fix runtime PM imbalance in venus_probe
  (git-fixes).
- commit 1c003ee
* Fri Oct 30 2020 tiwai@suse.de
- Bluetooth: Only mark socket zapped after unlocking (git-fixes).
- Bluetooth: btusb: Fix memleak in btusb_mtk_submit_wmt_recv_urb
  (git-fixes).
- ath9k: hif_usb: fix race condition between usb_get_urb()
  and usb_kill_anchored_urbs() (git-fixes).
- can: flexcan: flexcan_chip_stop(): add error handling and
  propagate error value (git-fixes).
- brcmsmac: fix memory leak in wlc_phy_attach_lcnphy (git-fixes).
- ath10k: check idx validity in __ath10k_htt_rx_ring_fill_n()
  (git-fixes).
- brcm80211: fix possible memleak in brcmf_proto_msgbuf_attach
  (git-fixes).
- dmaengine: dw: Activate FIFO-mode for memory peripherals only
  (git-fixes).
- crypto: ccp - fix error handling (git-fixes).
- commit faa1609
* Fri Oct 30 2020 mkubecek@suse.cz
- dm/dax: Fix table reference counts (bsc#1178246).
- commit 89a1d25
* Thu Oct 29 2020 mhocko@suse.com
- mm: fix a race during THP splitting (bsc#1178255).
- commit d99807e
* Thu Oct 29 2020 nborisov@suse.com
- btrfs: don't force read-only after error in drop snapshot (bsc#1176354).
- commit 92bd157
* Thu Oct 29 2020 tiwai@suse.de
- rpm/kernel-module-subpackage: make Group tag optional (bsc#1163592)
- commit 552ec97
* Wed Oct 28 2020 ailiop@suse.com
- xfs: fix high key handling in the rt allocator's query_range
  function (git-fixes).
- commit cdff05f
* Wed Oct 28 2020 ailiop@suse.com
- xfs: limit entries returned when counting fsmap records
  (git-fixes).
- commit 6ab6787
* Wed Oct 28 2020 ailiop@suse.com
- xfs: fix xfs_bmap_validate_extent_raw when checking attr fork
  of rt files (git-fixes).
- commit 4c9c85b
* Wed Oct 28 2020 jgross@suse.com
- x86/alternative: Don't call text_poke() in lazy TLB mode
  (bsc#1175749).
- commit 50e105d
* Wed Oct 28 2020 jgross@suse.com
- xen/gntdev.c: Mark pages as dirty (bsc#1065600).
- commit dbb5e22
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: fix overflow when copying corrupt csums for a message
  (bsc#1178191).
- commit c3fc339
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: fix NULL pointer dereference after failure to create
  snapshot (bsc#1178190).
- commit 28eef23
* Tue Oct 27 2020 msuchanek@suse.de
- ibmveth: Identify ingress large send packets (bsc#1178185
  ltc#188897).
- commit 3aff6b0
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: set the lockdep class for log tree extent buffers
  (bsc#1178186).
- commit bf70248
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: set the correct lockdep class for new nodes
  (bsc#1178184).
- commit 986c67e
* Tue Oct 27 2020 jeyu@suse.de
- blacklist.conf: blacklist commit 7359608a271c ("scripts/gdb: fix
  lx-symbols 'gdb.error' while loading modules")
  This does not apply since CONFIG_GDB_SCRIPTS isn't enabled in our configs.
- commit 0c385df
* Tue Oct 27 2020 jeyu@suse.de
- module: Correctly truncate sysfs sections output (git-fixes).
- commit 65be42f
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: allocate scrub workqueues outside of locks (bsc#1178183).
- commit f9617fb
* Tue Oct 27 2020 lhenriques@suse.com
- libceph: clear con->out_msg on Policy::stateful_server faults
  (bsc#1178177).
- ceph: promote to unsigned long long before shifting
  (bsc#1178175).
- commit 0c4763b
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: drop path before adding new uuid tree entry
  (bsc#1178176).
- commit dd3432e
* Tue Oct 27 2020 jeyu@suse.de
- module: statically initialize init section freeing data (git-fixes).
- commit 22c6399
* Tue Oct 27 2020 fdmanana@suse.com
- btrfs: fix space cache memory leak after transaction abort
  (bsc#1178173).
- commit 980210c
* Tue Oct 27 2020 jeyu@suse.de
- module: Do not expose section addresses to non-CAP_SYSLOG (git-fixes).
- commit a568add
* Tue Oct 27 2020 jeyu@suse.de
- module: Refactor section attr into bin attribute (git-fixes).
- commit c081e5b
* Tue Oct 27 2020 jeyu@suse.de
- kallsyms: Refactor kallsyms_show_value() to take cred (git-fixes).
- commit f113536
* Tue Oct 27 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/ipv4-Restore-flowi4_oif-update-before-call-to-xfrm_l.patch
  patches.suse/tipc-fix-the-skb_unshare-in-tipc_buf_append.patch
- commit 70545ba
* Tue Oct 27 2020 mkubecek@suse.cz
- Update kabi files.
- update to second October 2020 maintenance update (commit 78b2b83f5f09)
- commit f4767b1
* Tue Oct 27 2020 msuchanek@suse.de
- scsi: ibmvscsi: Fix potential race after loss of transport
  (bsc#1178166 ltc#188226).
- commit 45b7f66
* Mon Oct 26 2020 dwagner@suse.de
- nvme-rdma: fix crash due to incorrect cqe (bsc#1174748).
- nvme-rdma: fix crash when connect rejected (bsc#1174748).
- commit 066b1e6
* Mon Oct 26 2020 tiwai@suse.de
- ata: sata_rcar: Fix DMA boundary mask (git-fixes).
- reset: sti: reset-syscfg: fix struct description warnings
  (git-fixes).
- soc: fsl: qbman: Fix return value on success (git-fixes).
- memory: fsl-corenet-cf: Fix handling of platform_get_irq()
  error (git-fixes).
- memory: omap-gpmc: Fix build error without CONFIG_OF
  (git-fixes).
- memory: omap-gpmc: Fix a couple off by ones (git-fixes).
- docs: driver-api: remove a duplicated index entry (git-fixes).
- ACPI: debug: don't allow debugging when ACPI is disabled
  (git-fixes).
- acpi-cpufreq: Honor _PSD table setting on new AMD CPUs
  (git-fixes).
- Input: sun4i-ps2 - fix handling of platform_get_irq() error
  (git-fixes).
- Input: twl4030_keypad - fix handling of platform_get_irq()
  error (git-fixes).
- Input: omap4-keypad - fix handling of platform_get_irq() error
  (git-fixes).
- Input: ep93xx_keypad - fix handling of platform_get_irq()
  error (git-fixes).
- Input: stmfts - fix a & vs && typo (git-fixes).
- Input: imx6ul_tsc - clean up some errors in imx6ul_tsc_resume()
  (git-fixes).
- nfc: Ensure presence of NFC_ATTR_FIRMWARE_NAME attribute in
  nfc_genl_fw_download() (git-fixes).
- r8169: fix operation under forced interrupt threading
  (git-fixes).
- commit 7585044
* Mon Oct 26 2020 tiwai@suse.de
- ntb: intel: Fix memleak in intel_ntb_pci_probe (git-fixes).
- NTB: hw: amd: fix an issue about leak system resources
  (git-fixes).
- i2c: core: Restore acpi_walk_dep_device_list() getting called
  after registering the ACPI i2c devs (git-fixes).
- commit cb55b2a
* Mon Oct 26 2020 mbenes@suse.cz
- ring-buffer: Return 0 on success from ring_buffer_resize()
  (git-fixes).
- commit 720b2ea
* Mon Oct 26 2020 msuchanek@suse.de
- powerpc/powernv/dump: Fix race while processing OPAL dump
  (bsc#1065729).
- commit b42269b
* Mon Oct 26 2020 msuchanek@suse.de
- cxl: Rework error message for incompatible slots (bsc#1055014
  git-fixes).
- commit 2fd3e91
* Mon Oct 26 2020 mhocko@suse.com
- mm/hugetlb: fix a race between hugetlb sysctl handlers
  (bsc#1176485, CVE-2020-25285).
- commit 2afa8d8
* Mon Oct 26 2020 msuchanek@suse.de
- powerpc/pseries: Avoid using addr_to_pfn in real mode
  (jsc#SLE-9246 git-fixes).
- commit 2dc2a0c
* Mon Oct 26 2020 tiwai@suse.de
- PM: hibernate: Batch hibernate and resume IO requests
  (bsc#1178079).
- commit 3742aaa
* Mon Oct 26 2020 msuchanek@suse.de
- Refresh patches.suse/powerpc-Fix-undetected-data-corruption-with-P9N-DD2..patch.
  refresh patch metadata
- commit 006e264
* Mon Oct 26 2020 msuchanek@suse.de
- ibmvnic: save changed mac address to adapter->mac_addr
  (bsc#1134760 ltc#177449 git-fixes).
- commit 1e71262
* Sun Oct 25 2020 mkubecek@suse.cz
- kernel-binary.spec.in: pack scripts/module.lds into kernel-$flavor-devel
  Since mainline commit 596b0474d3d9 ("kbuild: preprocess module linker
  script") in 5.10-rc1, scripts/module.lds linker script is needed to build
  out of tree modules. Add it into kernel-$flavor-devel subpackage.
- commit fe37c16
* Sun Oct 25 2020 jlee@suse.com
- kABI: Fix kABI after add CodeSigning extended key usage
  (bsc#1177353).
- commit b9f566d
* Sun Oct 25 2020 jlee@suse.com
- PKCS#7: Check codeSigning EKU for kernel module and kexec pe
  verification (bsc#1177353).
- PKCS#7: Check codeSigning EKU for kernel module and kexec pe
  verification.
- Add CONFIG_CHECK_CODESIGN_EKU
- X.509: Add CodeSigning extended key usage parsing (bsc#1177353).
- commit 4dbabee
* Sat Oct 24 2020 bp@suse.de
- x86/ioapic: Unbreak check_timer() (bsc#1152489).
- commit 520671d
* Sat Oct 24 2020 bp@suse.de
- blacklist.conf: 5fa9a98fb103 bpf, x86_32: Fix incorrect encoding in BPF_LDX zero-extension
- commit 7f6fdc7
* Sat Oct 24 2020 tiwai@suse.de
- ALSA: hda - Fix the return value if cb func is already
  registered (git-fixes).
- ALSA: usb-audio: Line6 Pod Go interface requires static clock
  rate quirk (git-fixes).
- ALSA: sparc: dbri: fix repeated word 'the' (git-fixes).
- commit ac47bec
* Fri Oct 23 2020 mkubecek@suse.cz
- blacklist.conf: commit 9def3b1a07c4 not needed
  Mainline commit 9def3b1a07c4 ("iommu/vt-d: Don't dereference iommu_device
  if IOMMU_API is not built") is a build fix which is only needed for config
  with CONFIG_IOMMU_API disabled. As both SLE15-SP2 and openSUSE-15.2 have
  CONFIG_IOMMU_API=y in all configs where applicable, we don't need this
  build fix.
- commit 28bc04c
* Fri Oct 23 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/powerpc-numa-Offline-memoryless-cpuless-node-0.patch
  patches.suse/powerpc-numa-Prefer-node-id-queried-from-vphn.patch
  patches.suse/powerpc-numa-Set-numa_node-for-all-possible-cpus.patch
- commit b2e8401
* Fri Oct 23 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/tracing-check-return-value-of-_create_val_fields-before-using-its-result.patch
  patches.suse/tracing-save-normal-string-variables.patch
- commit 164cdc8
* Fri Oct 23 2020 tiwai@suse.de
- clk: bcm2835: add missing release if devm_clk_hw_register fails
  (git-fixes).
- clk: qcom: gcc-sdm660: Fix wrong parent_map (git-fixes).
- clk: imx8mq: Fix usdhc parents order (git-fixes).
- clk: at91: clk-main: update key before writing AT91_CKGR_MOR
  (git-fixes).
- clk: at91: remove the checking of parent_name (git-fixes).
- clk: keystone: sci-clk: fix parsing assigned-clock data during
  probe (git-fixes).
- clk: meson: g12a: mark fclk_div2 as critical (git-fixes).
- pwm: img: Fix null pointer access in probe (git-fixes).
- PCI: aardvark: Check for errors from pci_bridge_emul_init()
  call (git-fixes).
- watchdog: sp5100: Fix definition of EFCH_PM_DECODEEN3
  (git-fixes).
- watchdog: Use put_device on error (git-fixes).
- watchdog: Fix memleak in watchdog_cdev_register (git-fixes).
- rtc: rx8010: don't modify the global rtc ops (git-fixes).
- i2c: imx: Fix external abort on interrupt in exit paths
  (git-fixes).
- i2c: rcar: Auto select RESET_CONTROLLER (git-fixes).
- ida: Free allocated bitmap in error path (git-fixes).
- commit affb66d
* Fri Oct 23 2020 jslaby@suse.cz
- ipv4: Restore flowi4_oif update before call to xfrm_lookup_route
  (git-fixes).
- tipc: fix the skb_unshare() in tipc_buf_append() (git-fixes).
- commit 1834339
* Thu Oct 22 2020 mhocko@suse.com
- mm: don't panic when links can't be created in sysfs
  (bsc#1178002).
- mm: don't rely on system state to detect hot-plug operations
  (bsc#1178002).
- mm: replace memmap_context by meminit_context (bsc#1178002).
- commit 77a655e
* Thu Oct 22 2020 jslaby@suse.cz
- blacklist.conf: add a cleanup
- commit 5a26435
* Thu Oct 22 2020 jslaby@suse.cz
- net: bridge: br_vlan_get_pvid_rcu() should dereference the
  VLAN group under RCU (networking-stable-20_09_24).
- net/mlx5e: TLS, Do not expose FPGA TLS counter if not supported
  (networking-stable-20_09_24).
- net/mlx5e: Enable adding peer miss rules only if merged eswitch
  is supported (networking-stable-20_09_24).
- net/mlx5: Fix FTE cleanup (networking-stable-20_09_24).
- net: sctp: Fix IPv6 ancestor_size calc in sctp_copy_descendant
  (networking-stable-20_09_24).
- net: ipv6: fix kconfig dependency warning for IPV6_SEG6_HMAC
  (networking-stable-20_09_24).
- nfp: use correct define to return NONE fec
  (networking-stable-20_09_24).
- net: phy: Do not warn in phy_stop() on PHY_DOWN
  (networking-stable-20_09_24).
- net: phy: Avoid NPD upon phy_detach() when driver is unbound
  (networking-stable-20_09_24).
- cxgb4: fix memory leak during module unload
  (networking-stable-20_09_24).
- ipv4: Update exception handling for multipath routes via same
  device (networking-stable-20_09_24).
- tipc: use skb_unshare() instead in tipc_buf_append()
  (networking-stable-20_09_24).
- tipc: Fix memory leak in tipc_group_create_member()
  (networking-stable-20_09_24).
- ipv4: Initialize flowi4_multipath_hash in data path
  (networking-stable-20_09_24).
- net: lantiq: Disable IRQs only if NAPI gets scheduled
  (networking-stable-20_09_24).
- net: lantiq: Use napi_complete_done()
  (networking-stable-20_09_24).
- net: lantiq: use netif_tx_napi_add() for TX NAPI
  (networking-stable-20_09_24).
- net: lantiq: Wake TX queue again (networking-stable-20_09_24).
- taprio: Fix allowing too small intervals
  (networking-stable-20_09_24).
- net: DCB: Validate DCB_ATTR_DCB_BUFFER argument
  (networking-stable-20_09_24).
- net: Fix bridge enslavement failure
  (networking-stable-20_09_24).
- tipc: fix shutdown() of connection oriented socket
  (networking-stable-20_09_24).
- ip: fix tos reflection in ack and reset packets
  (networking-stable-20_09_24).
- ipv6: avoid lockdep issue in fib6_del()
  (networking-stable-20_09_24).
- net: dsa: rtl8366: Properly clear member config
  (networking-stable-20_09_24).
- cxgb4: Fix offset when clearing filter byte counters
  (networking-stable-20_09_24).
- act_ife: load meta modules before tcf_idr_check_alloc()
  (networking-stable-20_09_24).
- tipc: fix shutdown() of connectionless socket
  (networking-stable-20_09_11).
- ipv6: Fix sysctl max for fib_multipath_hash_policy
  (networking-stable-20_09_11).
- net: usb: dm9601: Add USB ID of Keenetic Plus DSL
  (networking-stable-20_09_11).
- net: disable netpoll on fresh napis
  (networking-stable-20_09_11).
- gtp: add GTPA_LINK info to msg sent to userspace
  (networking-stable-20_09_11).
- netlabel: fix problems with mapping removal
  (networking-stable-20_09_11).
- sctp: not disable bh in the whole sctp_get_port_local()
  (networking-stable-20_09_11).
- net: systemport: Fix memleak in bcm_sysport_probe
  (networking-stable-20_09_11).
- net: hns: Fix memleak in hns_nic_dev_probe
  (networking-stable-20_09_11).
- net: dsa: b53: check for timeout (networking-stable-20_08_24).
- net/sched: act_ct: Fix skb double-free
  in tcf_ct_handle_fragments() error flow
  (networking-stable-20_08_24).
- net: sctp: Fix negotiation of the number of data streams
  (networking-stable-20_08_24).
- gre6: Fix reception with IP6_TNL_F_RCV_DSCP_COPY
  (networking-stable-20_08_24).
- net/smc: Prevent kernel-infoleak in __smc_diag_dump()
  (networking-stable-20_08_24).
- net: qrtr: fix usage of idr in port assignment to socket
  (networking-stable-20_08_24).
- tipc: fix uninit skb->data in tipc_nl_compat_dumpit()
  (networking-stable-20_08_24).
- net: Fix potential wrong skb->protocol in skb_vlan_untag()
  (networking-stable-20_08_24).
- ipvlan: fix device features (networking-stable-20_08_24).
- bonding: show saner speed for broadcast mode
  (networking-stable-20_08_24).
- net: fec: correct the error path for regulator disable in probe
  (networking-stable-20_08_24).
- commit 913985f
* Wed Oct 21 2020 bp@suse.de
- blacklist.conf: 66077adb70a2 EDAC/ti: Fix handling of platform_get_irq() error
- commit d4a0b74
* Wed Oct 21 2020 msuchanek@suse.de
- blacklist.conf: add unnecessary fix
  5b905d77987d powerpc/watchpoint: Fix exception handling for
  CONFIG_HAVE_HW_BREAKPOINT=N
- commit 900b37a
* Wed Oct 21 2020 msuchanek@suse.de
- powerpc/perf/hv-gpci: Fix starting index value (bsc#1065729).
- powerpc/powernv/elog: Fix race while processing OPAL error
  log event (bsc#1065729).
- powerpc/irq: Drop forward declaration of struct irqaction
  (bsc#1065729).
- powerpc/hwirq: Remove stale forward irq_chip declaration
  (bsc#1065729).
- powerpc/icp-hv: Fix missing of_node_put() in success path
  (bsc#1065729).
- powerpc/pseries: Fix missing of_node_put() in rng_init()
  (bsc#1065729).
- commit eb769ab
* Wed Oct 21 2020 msuchanek@suse.de
- blacklist.conf: Requires powerpc-utils fix.
  a02f6d42357a powerpc: Warn about use of smt_snooze_delay
- commit 3c3b02c
* Wed Oct 21 2020 msuchanek@suse.de
- blacklist.conf: add fixes for unused sensor driver
  66943005cc41 powerpc/tau: Use appropriate temperature sample interval
  5e3119e15fed powerpc/tau: Check processor type before enabling TAU interrupt
  e63d6fb5637e powerpc/tau: Disable TAU between measurements
- commit a434fe6
* Wed Oct 21 2020 msuchanek@suse.de
- blacklist.conf: Add config fix
  8659a0e0efdd powerpc/64s: Disable STRICT_KERNEL_RWX
  only applies to config, and we don't even have the patch to enable
  STRICT_KERNEL_RWX in config
- commit f4e1850
* Wed Oct 21 2020 msuchanek@suse.de
- powerpc/pseries: explicitly reschedule during drmem_lmb list
  traversal (bsc#1077428 ltc#163882 FATE#324825 git-fixes).
- commit f96b864
* Wed Oct 21 2020 msuchanek@suse.de
- powerpc/papr_scm: Fix warning triggered by perf_stats_show()
  (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769 git-fixes).
- commit e9b4893
* Wed Oct 21 2020 msuchanek@suse.de
- powerpc/book3s64/radix: Make radix_mem_block_size 64bit
  (bsc#1055186 ltc#153436 FATE#323286 git-fixes).
- commit 1f2d815
* Wed Oct 21 2020 oneukum@suse.com
- blacklist.conf: already added
- commit ee45286
* Wed Oct 21 2020 oneukum@suse.com
- usblp: fix race between disconnect() and read() (git-fixes).
- commit 94633e7
* Wed Oct 21 2020 jgross@suse.com
- xen/events: block rogue events for some time (XSA-332
  bsc#1177411).
- commit 014f26b
* Wed Oct 21 2020 jgross@suse.com
- xen/events: defer eoi in case of excessive number of events
  (XSA-332 bsc#1177411).
- commit 956b6f3
* Wed Oct 21 2020 jgross@suse.com
- xen/events: use a common cpu hotplug hook for event channels
  (XSA-332 bsc#1177411).
- commit b9ecbeb
* Wed Oct 21 2020 jgross@suse.com
- xen/events: switch user event channels to lateeoi model
  (XSA-332 bsc#1177411).
- commit 0b00983
* Wed Oct 21 2020 jgross@suse.com
- xen/pciback: use lateeoi irq binding (XSA-332 bsc#1177411).
- commit 47100e6
* Wed Oct 21 2020 jgross@suse.com
- xen/pvcallsback: use lateeoi irq binding (XSA-332 bsc#1177411).
- commit ec73318
* Wed Oct 21 2020 jgross@suse.com
- xen/scsiback: use lateeoi irq binding (XSA-332 bsc#1177411).
- commit 76fa7f0
* Wed Oct 21 2020 jgross@suse.com
- xen/netback: use lateeoi irq binding (XSA-332 bsc#1177411).
- commit 8631138
* Wed Oct 21 2020 jgross@suse.com
- xen/blkback: use lateeoi irq binding (XSA-332 bsc#1177411).
- commit 2689ef1
* Wed Oct 21 2020 jgross@suse.com
- xen/events: add a new "late EOI" evtchn framework (XSA-332
  bsc#1177411).
- commit cd230ce
* Wed Oct 21 2020 jgross@suse.com
- xen/events: fix race in evtchn_fifo_unmask() (XSA-332
  bsc#1177411).
- commit bd30bae
* Wed Oct 21 2020 jgross@suse.com
- xen/events: add a proper barrier to 2-level uevent unmasking
  (XSA-332 bsc#1177411).
- commit e9a9556
* Wed Oct 21 2020 jgross@suse.com
- xen/events: avoid removing an event channel while handling it
  (XSA-331 bsc#1177410).
- commit 0dd2046
* Tue Oct 20 2020 bp@suse.de
- perf/x86: Fix n_pair for cancelled txn (bsc#1152489).
- commit adef112
* Tue Oct 20 2020 bp@suse.de
- perf/x86/amd: Fix sampling Large Increment per Cycle events
  (bsc#1152489).
- commit c8a7d34
* Tue Oct 20 2020 bp@suse.de
- x86/fpu: Allow multiple bits in clearcpuid= parameter
  (bsc#1152489).
- commit 3d42971
* Tue Oct 20 2020 msuchanek@suse.de
- powerpc: Fix undetected data corruption with P9N DD2.1 VSX CI
  load emulation (bsc#1065729).
- commit d2da200
* Tue Oct 20 2020 bp@suse.de
- blacklist.conf: 5da8e4a65810 x86/copy_mc: Introduce copy_mc_enhanced_fast_string()
- commit 579d619
* Tue Oct 20 2020 mhocko@suse.com
- perf/core: Fix race in the perf_mmap_close() function
  (bsc#1177086, CVE-2020-14351).
- commit 1ee0e96
* Tue Oct 20 2020 tiwai@suse.de
- Move upstreamed BT patch into sorted section
- commit 27a1c18
* Tue Oct 20 2020 jdelvare@suse.de
- blacklist.conf: add duplicate commit 3514521ccbd2
  Same as a39d0d7bdf8c21ac7645c02e9676b5cb2b804c31 ("drm/amdgpu: restore
  proper ref count in amdgpu_display_crtc_set_config).
- commit e083639
* Tue Oct 20 2020 jroedel@suse.de
- iommu/vt-d: Gracefully handle DMAR units with no supported address widths (bsc#1177739).
- commit 8780752
* Mon Oct 19 2020 msuchanek@suse.de
- scsi: ibmvfc: Fix error return in ibmvfc_probe() (bsc#1065729).
- commit a848d53
* Mon Oct 19 2020 vbabka@suse.cz
- percpu: fix first chunk size calculation for populated bitmap
  (git-fixes (mm/percpu)).
- commit fc914cf
* Mon Oct 19 2020 vbabka@suse.cz
- mm/rmap: fixup copying of soft dirty and uffd ptes (git-fixes
  (mm/rmap)).
- commit 57e33c0
* Mon Oct 19 2020 vbabka@suse.cz
- mm/huge_memory.c: use head to check huge zero page (git-fixes
  (mm/thp)).
- commit b768968
* Mon Oct 19 2020 vbabka@suse.cz
- mm/mempolicy.c: fix out of bounds write in mpol_parse_str()
  (git-fixes (mm/mempolicy)).
- commit af27a44
* Mon Oct 19 2020 vbabka@suse.cz
- mm/page-writeback.c: improve arithmetic divisions (git-fixes
  (mm/writeback)).
- commit 0efed25
* Mon Oct 19 2020 vbabka@suse.cz
- mm/page-writeback.c: avoid potential division by zero in
  wb_min_max_ratio() (git-fixes (mm/writeback)).
- commit 3e8dbda
* Mon Oct 19 2020 vbabka@suse.cz
- mm/zsmalloc.c: fix the migrated zspage statistics (git-fixes
  (mm/zsmalloc)).
- commit 0aec7d2
* Mon Oct 19 2020 mbenes@suse.cz
- tracing: Check return value of __create_val_fields() before
  using its result (git-fixes).
- commit 340fd0d
* Mon Oct 19 2020 mbenes@suse.cz
- blacklist.conf: 10819e25799a ("tracing: Handle synthetic event array field type checking correctly")
  CONFIG_SYNTH_EVENTS is not enabled anywhere.
- commit dfcbd72
* Mon Oct 19 2020 mbenes@suse.cz
- blacklist.conf: 9bbb33291f8e ("tracing: Check that the synthetic event and field names are legal")
  CONFIG_SYNTH_EVENTS is not enabled anywhere.
- commit 2bf6e8b
* Mon Oct 19 2020 tiwai@suse.de
- overflow: Include header file with SIZE_MAX declaration
  (git-fixes).
- i3c: master: Fix error return in cdns_i3c_master_probe()
  (git-fixes).
- i3c: master add i3c_master_attach_boardinfo to preserve
  boardinfo (git-fixes).
- mtd: spinand: gigadevice: Add QE Bit (git-fixes).
- mtd: spinand: gigadevice: Only one dummy byte in QUADIO
  (git-fixes).
- mtd: rawnand: vf610: disable clk on error handling path in probe
  (git-fixes).
- mtd: rawnand: stm32_fmc2: fix a buffer overflow (git-fixes).
- mtd: mtdoops: Don't write panic data twice (git-fixes).
- mtd: lpddr: fix excessive stack usage with clang (git-fixes).
- mtd: lpddr: Fix bad logic in print_drs_error (git-fixes).
- rapidio: fix the missed put_device() for rio_mport_add_riodev
  (git-fixes).
- lib/crc32.c: fix trivial typo in preprocessor condition
  (git-fixes).
- Bluetooth: MGMT: Fix not checking if BT_HS is enabled
  (git-fixes).
- VMCI: check return value of get_user_pages_fast() for errors
  (git-fixes).
- USB: serial: option: add Cellient MPL200 card (git-fixes).
- USB: serial: option: Add Telit FT980-KS composition (git-fixes).
- USB: serial: pl2303: add device-id for HP GC device (git-fixes).
- USB: serial: ftdi_sio: add support for FreeCalypso JTAG+UART
  adapters (git-fixes).
- staging: comedi: check validity of wMaxPacketSize of usb
  endpoints found (git-fixes).
- ACPI: Always build evged in (git-fixes).
- commit 88d1ef8
* Mon Oct 19 2020 mbenes@suse.cz
- tracing: Save normal string variables (git-fixes).
- commit 91eb341
* Mon Oct 19 2020 mbenes@suse.cz
- blacklist.conf: 8fbeb52a598c ("tracing: Fix parse_synth_field() error handling")
  CONFIG_SYNTH_EVENTS is not enabled anywhere.
- commit c4d0c48
* Mon Oct 19 2020 bp@suse.de
- blacklist.conf: afce6996943b EDAC/aspeed: Fix handling of platform_get_irq() error
- commit 4d7f300
* Mon Oct 19 2020 bp@suse.de
- EDAC/i5100: Fix error handling order in i5100_init_one()
  (bsc#1152489).
- commit ef65426
* Mon Oct 19 2020 msuchanek@suse.de
- ibmvnic: set up 200GBPS speed (bsc#1129923 git-fixes).
- commit e87977b
* Mon Oct 19 2020 msuchanek@suse.de
- ibmveth: Switch order of ibmveth_helper calls (bsc#1061843
  git-fixes).
- commit e6ac1a9
* Mon Oct 19 2020 wqu@suse.com
- btrfs: tree-checker: fix false alert caused by legacy btrfs
  root item (bsc#1177861).
- commit 5302053
* Mon Oct 19 2020 wqu@suse.com
- btrfs: qgroup: fix qgroup meta rsv leak for subvolume
  operations (bsc#1177856).
- commit 4456f07
* Mon Oct 19 2020 wqu@suse.com
- btrfs: qgroup: fix wrong qgroup metadata reserve for delayed
  inode (bsc#1177855).
- btrfs: add owner and fs_info to alloc_state io_tree
  (bsc#1177854).
- commit e4394c2
* Mon Oct 19 2020 mgorman@suse.de
- series.conf: cleanup
- refresh, update upstream references and move into sorted section:
  patches.suse/sched-fair-Ignore-cache-hotness-for-SMT-migration.patch
  patches.suse/sched-fair-Use-dst-group-while-checking-imbalance-for-NUMA-balancer.patch
  patches.suse/sched-numa-Use-runnable_avg-to-classify-node.patch
- commit 715ffac
* Sat Oct 17 2020 bp@suse.de
- powercap: Restrict energy meter to root access (bsc#1170415
  CVE-2020-8694).
- commit 4deb70f
* Fri Oct 16 2020 jack@suse.cz
- dax: Fix compilation for CONFIG_DAX && !CONFIG_FS_DAX
  (bsc#1177817).
- commit 3294fad
* Fri Oct 16 2020 jack@suse.cz
- dm: Call proper helper to determine dax support (bsc#1177817).
- commit 54f2e3f
* Fri Oct 16 2020 jack@suse.cz
- writeback: Fix sync livelock due to b_dirty_time processing
  (bsc#1177755).
- commit 418c424
* Fri Oct 16 2020 jack@suse.cz
- writeback: Avoid skipping inode writeback (bsc#1177755).
- commit 977317c
* Fri Oct 16 2020 jack@suse.cz
- writeback: Protect inode->i_io_list with inode->i_lock
  (bsc#1177755).
  Refresh patches.suse/writeback-Export-inode_io_list_del.patch
- commit 5034dcb
* Fri Oct 16 2020 jack@suse.cz
- iomap: Make sure iomap_end is called after iomap_begin
  (bsc#1177754).
- commit 1558ead
* Fri Oct 16 2020 jack@suse.cz
- block: ensure bdi->io_pages is always initialized (bsc#1177749).
- commit dbf3e7d
* Fri Oct 16 2020 jack@suse.cz
- block: Fix page_is_mergeable() for compound pages (bsc#1177814).
- commit 1fb5d9d
* Fri Oct 16 2020 jack@suse.cz
- blk-mq: order adding requests to hctx->dispatch and checking
  SCHED_RESTART (bsc#1177750).
- commit 3cc33db
* Fri Oct 16 2020 tiwai@suse.de
- ALSA: fireworks: use semicolons rather than commas to separate
  statements (git-fixes).
- ALSA: hdspm: Fix typo arbitary (git-fixes).
- ALSA: portman2x4: fix repeated word 'if' (git-fixes).
- ALSA: asihpi: fix spellint typo in comments (git-fixes).
- ALSA: vx: vx_pcm: remove redundant assignment (git-fixes).
- ALSA: vx: vx_core: clarify operator precedence (git-fixes).
- ALSA: atmel: ac97: clarify operator precedence (git-fixes).
- ALSA: ac97: (cosmetic) align argument names (git-fixes).
- ALSA: aoa: i2sbus: use DECLARE_COMPLETION_ONSTACK() macro
  (git-fixes).
- commit 1b0d435
* Fri Oct 16 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/Bluetooth-A2MP-Fix-not-initializing-all-members.patch
  patches.suse/Bluetooth-L2CAP-Fix-calling-sk_filter-on-non-socket-.patch
- commit b739656
* Fri Oct 16 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/ovl-call-secutiry-hook-in-ovl_real_ioctl.patch
  patches.suse/ovl-check-permission-to-open-real-file.patch
  patches.suse/ovl-pass-correct-flags-for-opening-real-directory.patch
  patches.suse/ovl-switch-to-mounter-creds-in-readdir.patch
  patches.suse/ovl-verify-permissions-in-ovl_path_open.patch
- commit 8e33a6e
* Fri Oct 16 2020 tiwai@suse.de
- ALSA: hda: use semicolons rather than commas to separate
  statements (git-fixes).
- ALSA: usb-audio: endpoint.c: fix repeated word 'there'
  (git-fixes).
- ALSA: usb-audio: fix spelling mistake "Frequence" -> "Frequency"
  (git-fixes).
- ALSA: usb-audio: Add mixer support for Pioneer DJ DJM-250MK2
  (git-fixes).
- ALSA: ctl: Workaround for lockdep warning wrt
  card->ctl_files_rwlock (git-fixes).
- ALSA: rawmidi: (cosmetic) align function parameters (git-fixes).
- ALSA: usb: scarless_gen2: fix endianness issue (git-fixes).
- ALSA: hda: (cosmetic) align function parameters (git-fixes).
- ALSA: hda: auto_parser: remove shadowed variable declaration
  (git-fixes).
- ALSA: core: init: use DECLARE_COMPLETION_ONSTACK() macro
  (git-fixes).
- ALSA: compress_offload: remove redundant initialization
  (git-fixes).
- ALSA: core: timer: clarify operator precedence (git-fixes).
- ALSA: core: timer: remove redundant assignment (git-fixes).
- ALSA: core: pcm: simplify locking for timers (git-fixes).
- ALSA: hda/realtek - The front Mic on a HP machine doesn't work
  (git-fixes).
- ALSA: hda/realtek: Enable audio jacks of ASUS D700SA with ALC887
  (git-fixes).
- ALSA: hda/realtek - Add mute Led support for HP Elitebook 845 G7
  (git-fixes).
- ALSA: hda - Don't register a cb func if it is registered already
  (git-fixes).
- ALSA: hda/realtek - set mic to auto detect on a HP AIO machine
  (git-fixes).
- commit f02408a
* Fri Oct 16 2020 tiwai@suse.de
- wcn36xx: Fix reported 802.11n rx_highest rate wcn3660/wcn3680
  (git-fixes).
- w1: mxc_w1: Fix timeout resolution problem leading to bus error
  (git-fixes).
- USB: serial: qcserial: fix altsetting probing (git-fixes).
- usb: dwc2: Fix INTR OUT transfers in DDMA mode (git-fixes).
- usb: dwc3: ep0: Fix ZLP for OUT ep0 requests (git-fixes).
- usb: dwc3: core: add phy cleanup for probe error handling
  (git-fixes).
- usb: dwc3: core: don't trigger runtime pm when remove driver
  (git-fixes).
- usb: gadget: u_ether: enable qmult on SuperSpeed Plus as well
  (git-fixes).
- usb: gadget: f_ncm: fix ncm_bitrate for SuperSpeed and above
  (git-fixes).
- xhci: don't create endpoint debugfs entry before ring buffer
  is set (git-fixes).
- commit 3de826d
* Fri Oct 16 2020 tiwai@suse.de
- qtnfmac: fix resource leaks on unsupported iftype error return
  path (git-fixes).
- slimbus: qcom-ngd-ctrl: disable ngd in qmi server down callback
  (git-fixes).
- slimbus: core: do not enter to clock pause mode in core
  (git-fixes).
- slimbus: core: check get_addr before removing laddr ida
  (git-fixes).
- usb: dwc3: pci: Allow Elkhart Lake to utilize DSM method for
  PM functionality (git-fixes).
- usb: dwc2: Fix parameter type in function pointer prototype
  (git-fixes).
- usb: dwc3: gadget: Resume pending requests after CLEAR_STALL
  (git-fixes).
- usb: xhci-mtk: Fix typo (git-fixes).
- staging: rtl8192u: Do not use GFP_KERNEL in atomic context
  (git-fixes).
- commit 40d8c20
* Fri Oct 16 2020 bp@suse.de
- x86/{mce,mm}: Unmap the entire page if the whole page is
  affected and poisoned (bsc#1177765).
- commit d250460
* Fri Oct 16 2020 tiwai@suse.de
- mwifiex: fix double free (git-fixes).
- iwlwifi: mvm: split a print to avoid a WARNING in ROC
  (git-fixes).
- nl80211: fix non-split wiphy information (git-fixes).
- mwifiex: remove function pointer check (git-fixes).
- mwifiex: Remove unnecessary braces from
  HostCmd_SET_SEQ_NO_BSS_INFO (git-fixes).
- mwifiex: Do not use GFP_KERNEL in atomic context (git-fixes).
- ima: Remove semicolon at the end of
  ima_get_binary_runtime_size() (git-fixes).
- pwm: lpss: Add range limit check for the base_unit register
  value (git-fixes).
- pwm: lpss: Fix off by one error in base_unit math in
  pwm_lpss_prepare() (git-fixes).
- misc: mic: scif: Fix error handling path (git-fixes).
- commit 0a90922
* Fri Oct 16 2020 tiwai@suse.de
- ima: Don't ignore errors from crypto_shash_update() (git-fixes).
- iio: adc: gyroadc: fix leak of device node iterator (git-fixes).
- iio: adc: stm32-adc: fix runtime autosuspend delay when slow
  polling (git-fixes).
- iio:adc:ti-adc12138 Fix alignment issue with timestamp
  (git-fixes).
- iio:adc:ti-adc0832 Fix alignment issue with timestamp
  (git-fixes).
- iio:light:si1145: Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio:gyro:itg3200: Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio:accel:bma180: Fix use of true when should be iio_shared_by
  enum (git-fixes).
- iio:magn:hmc5843: Fix passing true where iio_shared_by enum
  required (git-fixes).
- iio:dac:ad5592r: Fix use of true for IIO_SHARED_BY_TYPE
  (git-fixes).
- commit 7b8694c
* Fri Oct 16 2020 tiwai@suse.de
- can: flexcan: remove ack_grp and ack_bit handling from driver
  (git-fixes).
- can: c_can: reg_map_{c,d}_can: mark as __maybe_unused
  (git-fixes).
- can: softing: softing_card_shutdown(): add  braces around
  empty body in an 'if' statement (git-fixes).
- brcmfmac: check ndev pointer (git-fixes).
- HID: hid-input: fix stylus battery reporting (git-fixes).
- HID: wacom: Avoid entering wacom_wac_pen_report for pad /
  battery (git-fixes).
- HID: roccat: add bounds checking in kone_sysfs_write_settings()
  (git-fixes).
- dmaengine: dma-jz4780: Fix race in jz4780_dma_tx_status
  (git-fixes).
- dmaengine: dmatest: Check list for emptiness before access
  its last entry (git-fixes).
- extcon: ptn5150: Fix usage of atomic GPIO with sleeping GPIO
  chips (git-fixes).
- commit f5c71cc
* Fri Oct 16 2020 tiwai@suse.de
- Bluetooth: hci_uart: Cancel init work before unregistering
  (git-fixes).
- ath6kl: wmi: prevent a shift wrapping bug in
  ath6kl_wmi_delete_pstream_cmd() (git-fixes).
- ath10k: Fix the size used in a 'dma_free_coherent()' call in
  an error handling path (git-fixes).
- ath9k: Fix potential out of bounds in
  ath9k_htc_txcompletion_cb() (git-fixes).
- ath9k_htc: Use appropriate rs_datalen type (git-fixes).
- ath6kl: prevent potential array overflow in ath6kl_add_new_sta()
  (git-fixes).
- ath10k: provide survey info as accumulated data (git-fixes).
- ALSA: hda/hdmi: fix incorrect locking in hdmi_pcm_close
  (git-fixes).
- ASoC: fsl: imx-es8328: add missing put_device() call in
  imx_es8328_probe() (git-fixes).
- ASoC: qcom: lpass-cpu: fix concurrency issue (git-fixes).
- ASoC: qcom: lpass-platform: fix memory leak (git-fixes).
- ASoC: sun50i-codec-analog: Fix duplicate use of ADC enable bits
  (git-fixes).
- ASoC: fsl_sai: Instantiate snd_soc_dai_driver (git-fixes).
- ASoC: tlv320aic32x4: Fix bdiv clock rate derivation (git-fixes).
- ALSA: seq: oss: Avoid mutex lock for a long-time ioctl
  (git-fixes).
- ALSA: mixart: Correct comment wrt obsoleted tasklet usage
  (git-fixes).
- ALSA: bebob: potential info leak in hwdep_read() (git-fixes).
- commit 42377f3
* Fri Oct 16 2020 jgross@suse.com
- x86/xen: disable Firmware First mode for correctable memory
  errors (bsc#1176713).
- commit f91015e
* Fri Oct 16 2020 mkubecek@suse.cz
- Update kabi files.
- update to resubmitted October 2020 OOB maintenance update submission (commit 29977655832a)
- commit 01071b5
* Thu Oct 15 2020 rgoldwyn@suse.com
- ovl: check permission to open real file  (bsc#1177470,
  CVE-2020-16120).
- ovl: call secutiry hook in ovl_real_ioctl()  (bsc#1177470,
  CVE-2020-16120).
- ovl: verify permissions in ovl_path_open()  (bsc#1177470,
  CVE-2020-16120).
- ovl: switch to mounter creds in readdir  (bsc#1177470,
  CVE-2020-16120).
- ovl: pass correct flags for opening real directory
  (bsc#1177470, CVE-2020-16120).
- commit 86bcb3f
* Thu Oct 15 2020 tiwai@suse.de
- backlight: sky81452-backlight: Fix refcount imbalance on error
  (git-fixes).
- mfd: sm501: Fix leaks in probe() (git-fixes).
- pinctrl: mcp23s08: Fix mcp23x17 precious range (git-fixes).
- pinctrl: mcp23s08: Fix mcp23x17_regmap initialiser (git-fixes).
- leds: mt6323: move period calculation (git-fixes).
- ipmi_si: Fix wrong return value in try_smi_init() (git-fixes).
- ACPI: button: fix handling lid state changes when input device
  closed (git-fixes).
- ACPI: configfs: Add missing config_item_put() to fix refcount
  leak (git-fixes).
- platform/x86: mlx-platform: Remove PSU EEPROM configuration
  (git-fixes).
- net: wireless: nl80211: fix out-of-bounds access in
  nl80211_del_key() (git-fixes).
- Input: ati_remote2 - add missing newlines when printing module
  parameters (git-fixes).
- commit e531d97
* Thu Oct 15 2020 ddiss@suse.de
- patches.suse/target-rbd-detect-stripe_unit-SCSI-block-size-misali.patch:
  (bsc#1177090).
- patches.suse/target-rbd-support-COMPARE_AND_WRITE.patch:
  (fate#318836, bsc#1177090).
- patches.suse/target-compare-and-write-backend-driver-sense-handli.patch:
  (bsc#1177719).
- commit 3918814
* Thu Oct 15 2020 ailiop@suse.com
- xfs: force the log after remapping a synchronous-writes file
  (git-fixes).
- commit 600980e
* Thu Oct 15 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/scsi-ibmvfc-Avoid-link-down-on-FS9100-canister-reboo.patch
  patches.suse/scsi-ibmvfc-Use-compiler-attribute-defines-instead-o.patch
  patches.suse/scsi-qla2xxx-Add-IOCB-resource-tracking.patch
  patches.suse/scsi-qla2xxx-Add-SLER-and-PI-control-support.patch
  patches.suse/scsi-qla2xxx-Add-rport-fields-in-debugfs.patch
  patches.suse/scsi-qla2xxx-Allow-dev_loss_tmo-setting-for-FC-NVMe-.patch
  patches.suse/scsi-qla2xxx-Correct-the-check-for-sscanf-return-val.patch
  patches.suse/scsi-qla2xxx-Fix-I-O-errors-during-LIP-reset-tests.patch
  patches.suse/scsi-qla2xxx-Fix-I-O-failures-during-remote-port-tog.patch
  patches.suse/scsi-qla2xxx-Fix-MPI-reset-needed-message.patch
  patches.suse/scsi-qla2xxx-Fix-buffer-buffer-credit-extraction-err.patch
  patches.suse/scsi-qla2xxx-Fix-crash-on-session-cleanup-with-unloa.patch
  patches.suse/scsi-qla2xxx-Fix-inconsistent-format-argument-type-i-250bd009.patch
  patches.suse/scsi-qla2xxx-Fix-inconsistent-format-argument-type-i-72e813d9.patch
  patches.suse/scsi-qla2xxx-Fix-inconsistent-format-argument-type-i.patch
  patches.suse/scsi-qla2xxx-Fix-memory-size-truncation.patch
  patches.suse/scsi-qla2xxx-Fix-point-to-point-N2N-device-discovery.patch
  patches.suse/scsi-qla2xxx-Fix-reset-of-MPI-firmware.patch
  patches.suse/scsi-qla2xxx-Fix-the-return-value.patch
  patches.suse/scsi-qla2xxx-Fix-the-size-used-in-a-dma_free_coheren.patch
  patches.suse/scsi-qla2xxx-Fix-wrong-return-value-in-qla_nvme_regi.patch
  patches.suse/scsi-qla2xxx-Fix-wrong-return-value-in-qlt_chk_unres.patch
  patches.suse/scsi-qla2xxx-Honor-status-qualifier-in-FCP_RSP-per-s.patch
  patches.suse/scsi-qla2xxx-Log-calling-function-name-in-qla2x00_ge.patch
  patches.suse/scsi-qla2xxx-Make-tgt_port_database-available-in-ini.patch
  patches.suse/scsi-qla2xxx-Performance-tweak.patch
  patches.suse/scsi-qla2xxx-Reduce-duplicate-code-in-reporting-spee.patch
  patches.suse/scsi-qla2xxx-Remove-pci-dma-compat-wrapper-API.patch
  patches.suse/scsi-qla2xxx-Remove-redundant-variable-initializatio.patch
  patches.suse/scsi-qla2xxx-Remove-superfluous-memset.patch
  patches.suse/scsi-qla2xxx-Remove-unneeded-variable-rval.patch
  patches.suse/scsi-qla2xxx-Setup-debugfs-entries-for-remote-ports.patch
  patches.suse/scsi-qla2xxx-Simplify-return-value-logic-in-qla2x00_.patch
  patches.suse/scsi-qla2xxx-Update-version-to-10.02.00.102-k.patch
  patches.suse/scsi-qla2xxx-Update-version-to-10.02.00.103-k.patch
  patches.suse/scsi-qla2xxx-Warn-if-done-or-free-are-called-on-an-a.patch
  patches.suse/scsi-smartpqi-add-id-support-for-smartraid-3152-8i.patch
  patches.suse/scsi-smartpqi-add-raid-bypass-counter.patch
  patches.suse/scsi-smartpqi-avoid-crashing-kernel-for-controller-issues.patch
  patches.suse/scsi-smartpqi-bump-version-to-1-2-16-010.patch
  patches.suse/scsi-smartpqi-identify-physical-devices-without-issuing-inquiry.patch
  patches.suse/scsi-smartpqi-support-device-deletion-via-sysfs.patch
  patches.suse/scsi-smartpqi-update-logical-volume-size-after-expansion.patch
  No effect on expanded tree.
- commit cd0c079
* Thu Oct 15 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/Bluetooth-A2MP-Fix-not-initializing-all-members.patch
  patches.suse/Bluetooth-L2CAP-Fix-calling-sk_filter-on-non-socket-.patch
- commit a607d96
* Thu Oct 15 2020 jslaby@suse.cz
- x86/unwind/orc: Fix inactive tasks with stack pointer in %%sp
  on GCC 10 compiled kernels (bsc#1176907).
- commit 4f3bd2e
* Thu Oct 15 2020 tiwai@suse.de
- kABI workaround for bluetooth l2cap_ops filter addition
  (CVE-2020-12351 bsc#1177724).
- commit 7c053a8
* Thu Oct 15 2020 tiwai@suse.de
- Bluetooth: L2CAP: Fix calling sk_filter on non-socket based
  channel (CVE-2020-12351 bsc#1177724).
- commit f0ba0e3
* Thu Oct 15 2020 tiwai@suse.de
- Update the patch reference for bluetooth security fix (CVE-2020-24490 bsc#1177726)
- commit 2a88ef6
* Thu Oct 15 2020 tiwai@suse.de
- Move upstreamed intel-vbtn patch into sorted section
- commit cf1a58d
* Thu Oct 15 2020 tiwai@suse.de
- Bluetooth: A2MP: Fix not initializing all members
  (CVE-2020-12352 bsc#1177725).
- commit 099cb6b
* Thu Oct 15 2020 vbabka@suse.cz
- mm, slub: restore initial kmem_cache flags (mm/slub
  bsc#1165692).
- commit 8972663
* Wed Oct 14 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/NFS-Don-t-move-layouts-to-plh_return_segs-list-while.patch
  patches.suse/NFS-Don-t-return-layout-segments-that-are-in-use.patch
  patches.suse/NFS-Fix-flexfiles-read-failover.patch
  patches.suse/NFSv4.2-fix-client-s-attribute-cache-management-for-.patch
  patches.suse/SUNRPC-Revert-241b1f419f0e-SUNRPC-Remove-xdr_buf_tri.patch
  patches.suse/nfs-ensure-correct-writeback-errors-are-returned-on-.patch
  patches.suse/nfs-nfs_file_write-should-check-for-writeback-errors.patch
  patches.suse/nfsd4-fix-NULL-dereference-in-nfsd-clients-display-c.patch
  patches.suse/pNFS-flexfiles-Ensure-we-initialise-the-mirror-bsize.patch
  patches.suse/svcrdma-Fix-page-leak-in-svc_rdma_recv_read_chunk.patch
  patches.suse/xprtrdma-fix-incorrect-header-size-calculations.patch
- commit 90be310
* Wed Oct 14 2020 mkubecek@suse.cz
- series.conf: cleanup
- rename Other drivers / Intel IOMMU subsection to IOMMU
- whitespace cleanup
- commit 263c1bd
* Wed Oct 14 2020 mkubecek@suse.cz
- series.conf: cleanup
- fix Patch-mainline and move to "almost mainline" section:
  patches.suse/qla2xxx-return-ebusy-on-fcport-deletion.patch
- create Storage / NVMe subsection
- move to Storage / NVMe:
  patches.suse/Revert-nvme-allow-64-bit-results-in-passthru-command.patch
  patches.suse/nvme-multipath-retry-commands-for-dying-queues.patch
- drop Storage / bsc#1171688 subsection
  No effect on expanded tree.
- commit 1b55020
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slab/slub: move and improve cache_from_obj() (mm/slub
  bsc#1165692).
  mm, slab/slub: improve error reporting and overhead of
  cache_from_obj() (mm/slub bsc#1165692).
  Squashed to prevent build error after first patch.
- commit ed35ad2
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: extend checks guarded by slub_debug static key
  (mm/slub bsc#1165692).
- commit 95cf5cc
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: introduce kmem_cache_debug_flags() (mm/slub
  bsc#1165692).
- commit 4f68bb2
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: introduce static key for slub_debug() (mm/slub
  bsc#1165692).
- commit 592afaf
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: make reclaim_account attribute read-only (mm/slub
  bsc#1165692).
- commit 749a7fc
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: make remaining slub_debug related attributes read-only
  (mm/slub bsc#1165692).
- commit 0a2f646
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: remove runtime allocation order changes (mm/slub
  bsc#1165692).
- commit d6227f6
* Wed Oct 14 2020 mkoutny@suse.com
- blacklist.conf: a87425a36fb2 mm, memcg: fix build error around the usage of kmem_caches
- commit b5fde68
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: check the right error variable in
  btrfs_del_dir_entries_in_log (bsc#1177687).
- commit d17c6ed
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: do not set the full sync flag on the inode during page
  release (bsc#1177687).
- commit 8954d4a
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: release old extent maps during page release
  (bsc#1177687).
- commit c79f281
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: fix race between page release and a fast fsync
  (bsc#1177687).
- commit 2893955
* Wed Oct 14 2020 ddiss@suse.de
- patches.suse/rbd-add-support-for-COMPARE_AND_WRITE-CMPEXT.patch:
  (fate#318836, bsc#1177090).
- patches.suse/libceph-add-support-for-CMPEXT-compare-extent-reques.patch:
  (fate#318836, bsc#1177090).
- patches.suse/rbd-add-rbd_img_fill_cmp_and_write_from_bvecs.patch:
  (bsc#1177090).
- patches.suse/target-rbd-add-WRITE-SAME-support.patch:
  (bsc#1177090).
- patches.suse/target-rbd-fix-unmap-handling-with-unmap_zeroes_data.patch:
  (bsc#1177271).
- patches.suse/target-rbd-fix-unmap-discard-block-size-conversion.patch:
  (bsc#1177271).
- patches.suse/target-rbd-conditionally-fix-off-by-one-bug-in-get_b.patch:
  (bsc#1177109).
- patches.suse/target-rbd-add-emulate_legacy_capacity-dev-attribute.patch:
  (bsc#1177109).
- commit 613f6b5
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: reduce contention on log trees when logging checksums
  (bsc#1177687).
- commit 449441e
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: make some slub_debug related attributes read-only
  (mm/slub bsc#1165692).
- commit 3730c96
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: remove no longer needed use of log_writers for the log
  root tree (bsc#1177687).
- commit aa9b267
* Wed Oct 14 2020 vbabka@suse.cz
- mm, slub: extend slub_debug syntax for multiple blocks
  (mm/slub bsc#1165692).
- commit db5b44a
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: stop incremening log_batch for the log root tree when
  syncing log (bsc#1177687).
- commit 0fccfec
* Wed Oct 14 2020 vbabka@suse.cz
- mm: call cond_resched() from deferred_init_memmap() (git fixes
  (mm/init), bsc#1177697).
- commit 30c0b50
* Wed Oct 14 2020 vbabka@suse.cz
- mm: initialize deferred pages with interrupts enabled (git fixes
  (mm/init), bsc#1177697).
- commit ea99f65
* Wed Oct 14 2020 vbabka@suse.cz
- mm/pagealloc.c: call touch_nmi_watchdog() on max order
  boundaries in deferred init (git fixes (mm/init), bsc#1177697).
- commit 3c12134
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: only commit delayed items at fsync if we are logging
  a directory (bsc#1177687).
- commit 6999ba9
* Wed Oct 14 2020 fdmanana@suse.com
- btrfs: only commit the delayed inode when doing a full fsync
  (bsc#1177687).
- commit 7ac015a
* Wed Oct 14 2020 yousaf.kaukab@suse.com
- arm64: Enable PCI write-combine resources under sysfs
  (bsc#1175807).
- commit 97c0c04
* Wed Oct 14 2020 mkoutny@suse.com
- mm/memcontrol.c: lost css_put in memcg_expand_shrinker_maps()
  (bsc#1177694).
- commit a848eca
* Wed Oct 14 2020 vbabka@suse.cz
- mm: move_pages: return valid node id in status if the page
  is already on the target node (git fixes (mm/move_pages),
  bsc#1177683).
- commit e8cf54d
* Wed Oct 14 2020 vbabka@suse.cz
- mm: move_pages: report the number of non-attempted pages
  (git fixes (mm/move_pages), bsc#1177683).
- commit e140195
* Wed Oct 14 2020 vbabka@suse.cz
- mm/migrate.c: also overwrite error when it is bigger than zero
  (git fixes (mm/move_pages), bsc#1177683).
- commit 32c9cae
* Wed Oct 14 2020 tiwai@suse.de
- ata: ahci: mvebu: Make SATA PHY optional for Armada 3720
  (git-fixes).
- hwmon: (mlxreg-fan) Fix double "Mellanox" (git-fixes).
- hwmon: (pmbus/max34440) Fix status register reads for
  MAX344{51,60,61} (git-fixes).
- pinctrl: bcm: fix kconfig dependency warning when !GPIOLIB
  (git-fixes).
- spi: omap2-mcspi: Improve performance waiting for CHSTAT
  (git-fixes).
- spi: dw-pci: free previously allocated IRQs if desc->setup()
  fails (git-fixes).
- spi: sprd: Release DMA channel also on probe deferral
  (git-fixes).
- regulator: resolve supply after creating regulator (git-fixes).
- media: usbtv: Fix refcounting mixup (git-fixes).
- media: ti-vpe: Fix a missing check and reference count leak
  (git-fixes).
- media: stm32-dcmi: Fix a reference count leak (git-fixes).
- media: s5p-mfc: Fix a reference count leak (git-fixes).
- media: camss: Fix a reference count leak (git-fixes).
- media: platform: fcp: Fix a reference count leak (git-fixes).
- media: rockchip/rga: Fix a reference count leak (git-fixes).
- media: rcar-vin: Fix a reference count leak (git-fixes).
- media: tc358743: cleanup tc358743_cec_isr (git-fixes).
- media: tc358743: initialize variable (git-fixes).
- media: mx2_emmaprp: Fix memleak in emmaprp_probe (git-fixes).
- media: rcar-csi2: Allocate v4l2_async_subdev dynamically
  (git-fixes).
- media: v4l2-async: Document asd allocation requirements
  (git-fixes).
- media: omap3isp: Fix memleak in isp_probe (git-fixes).
- media: staging/intel-ipu3: css: Correctly reset some memory
  (git-fixes).
- media: uvcvideo: Silence shift-out-of-bounds warning
  (git-fixes).
- media: uvcvideo: Set media controller entity functions
  (git-fixes).
- media: m5mols: Check function pointer in m5mols_sensor_power
  (git-fixes).
- media: ov5640: Correct Bit Div register in clock tree diagram
  (git-fixes).
- media: Revert "media: exynos4-is: Add missed check for
  pinctrl_lookup_state()" (git-fixes).
- media: tuner-simple: fix regression in simple_set_radio_freq
  (git-fixes).
- mmc: sdhci-acpi: AMDI0040: Set SDHCI_QUIRK2_PRESET_VALUE_BROKEN
  (git-fixes).
- mmc: sdhci: Add LTR support for some Intel BYT based controllers
  (git-fixes).
- crypto: bcm - Verify GCM/CCM key length in setkey (git-fixes).
- cypto: mediatek - fix leaks in mtk_desc_ring_alloc (git-fixes).
- crypto: omap-sham - fix digcnt register handling with
  export/import (git-fixes).
- crypto: qat - check cipher length for aead AES-CBC-HMAC-SHA
  (git-fixes).
- crypto: picoxcell - Fix potential race condition bug
  (git-fixes).
- crypto: ixp4xx - Fix the size used in a 'dma_free_coherent()'
  call (git-fixes).
- crypto: mediatek - Fix wrong return value in
  mtk_desc_ring_alloc() (git-fixes).
- crypto: algif_aead - Do not set MAY_BACKLOG on the async path
  (git-fixes).
- crypto: algif_skcipher - EBUSY on aio should be an error
  (git-fixes).
- regulator: axp20x: fix LDO2/4 description (git-fixes).
- spi: stm32: Rate-limit the 'Communication suspended' message
  (git-fixes).
- media: rc: do not access device via sysfs after
  rc_unregister_device() (git-fixes).
- media: rc: uevent sysfs file races with rc_unregister_device()
  (git-fixes).
- commit ac3a9ee
* Wed Oct 14 2020 vbabka@suse.cz
- mm, compaction: make capture control handling safe wrt
  interrupts (git fixes (mm/compaction), bsc#1177681).
- commit c13fd55
* Wed Oct 14 2020 vbabka@suse.cz
- mm, compaction: fully assume capture is not NULL in
  compact_zone_order() (git fixes (mm/compaction), bsc#1177681).
- commit 5fcf485
* Wed Oct 14 2020 ddiss@suse.de
- Update
  patches.suse/target-add-rbd-backend.patch: (fate#318836).
  (simplify block to byte calculations and use consistent error paths)
- commit f576f9b
* Wed Oct 14 2020 mkoutny@suse.com
- blacklist.conf: POSIX timers fixup
- commit bc6b00f
* Wed Oct 14 2020 vbabka@suse.cz
- mm/debug.c: always print flags in dump_page() (git fixes
  (mm/debug)).
- commit 5fed0d2
* Wed Oct 14 2020 msuchanek@suse.de
- blacklist.conf: Add a few of SP3 only fixes.
  f1565c24b596 powerpc: use the generic dma_ops_bypass mode
  d02f6b7dab82 powerpc/uaccess: Evaluate macro arguments once, before user
  access is allowed
  c44dc6323cd4 powerpc/64s/kuap: Restore AMR in fast_interrupt_return
- commit 862373b
* Wed Oct 14 2020 msuchanek@suse.de
- powerpc/dma: Fix dma_map_ops::get_required_mask (bsc#1065729).
- commit 0cddc1e
* Wed Oct 14 2020 tbogendoerfer@suse.de
- RDMA/hfi1: Correct an interlock issue for TID RDMA WRITE request
  (bsc#1175621).
- commit 45b1b9d
* Tue Oct 13 2020 neilb@suse.de
- pNFS/flexfiles: Ensure we initialise the mirror bsizes correctly
  on read (git-fixes).
- commit 80d81a4
* Tue Oct 13 2020 jroedel@suse.de
- x86/mm: unencrypted non-blocking DMA allocations use coherent pools (bsc#1175898, ECO-2743).
- Update config files.
- commit 3ded3cd
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: Fix an uninitialized variable bug in atomic_pool_expand() (bsc#1175898, ECO-2743).
- commit c3028f9
* Tue Oct 13 2020 jroedel@suse.de
- scsi: mptfusion: Don't use GFP_ATOMIC for larger DMA allocations (bsc#1175898, ECO-2743).
- commit 4e5bc96
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: Only allocate from CMA when in same memory zone (bsc#1175898, ECO-2743).
- commit 13beda8
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: fix coherent pool allocations for IOMMU mappings (bsc#1175898, ECO-2743).
- commit 0786759
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: do not allocate pool memory from CMA (bsc#1175898, ECO-2743).
- commit 52c7389
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: make sure atomic pool suits device (bsc#1175898, ECO-2743).
- commit 2d3cf4a
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: introduce dma_guess_pool() (bsc#1175898, ECO-2743).
- commit 077f93b
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: get rid of dma_in_atomic_pool() (bsc#1175898, ECO-2743).
- commit ed85a15
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: provide function to check physical memory area validity (bsc#1175898, ECO-2743).
- commit 69658a0
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: warn when coherent pool is depleted (bsc#1175898, ECO-2743).
- commit b21257b
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: DMA_COHERENT_POOL should select GENERIC_ALLOCATOR (bsc#1175898, ECO-2743).
- commit 0d0760a
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: add missing set_memory_decrypted() for coherent mapping (bsc#1175898, ECO-2743).
- commit 15a3e46
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: check return value when encrypting or decrypting memory (bsc#1175898, ECO-2743).
- commit 7c6f515
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: re-encrypt memory if dma_direct_alloc_pages() fails (bsc#1175898, ECO-2743).
- commit 671af96
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: always align allocation size in dma_direct_alloc_pages() (bsc#1175898, ECO-2743).
- commit 9262343
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: decouple DMA_REMAP from DMA_COHERENT_POOL (bsc#1175898, ECO-2743).
- refresh config files (reorder only)
- commit 6f0618d
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: fix too large DMA pools on medium memory size systems (bsc#1175898, ECO-2743).
- commit ad5deb3
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: scale the default DMA coherent pool size with memory capacity (bsc#1175898, ECO-2743).
- commit 3ad55af
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: add pool sizes to debugfs (bsc#1175898, ECO-2743).
- commit 5711a8a
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: atomic allocations must come from atomic coherent pools (bsc#1175898, ECO-2743).
- commit 4155def
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: dynamically expanding atomic pools (bsc#1175898, ECO-2743).
- commit 2ab8c98
* Tue Oct 13 2020 jroedel@suse.de
- dma-pool: add additional coherent pools to map to gfp mask (bsc#1175898, ECO-2743).
- commit 9e21a34
* Tue Oct 13 2020 jroedel@suse.de
- dma-remap: separate DMA atomic pools from direct remap code (bsc#1175898, ECO-2743).
- Update config files.
- commit 4b9b447
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: make uncached_kernel_address more general (bsc#1175898, ECO-2743).
- commit ca630f5
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: consolidate the error handling in dma_direct_alloc_pages (bsc#1175898, ECO-2743).
- commit 2102fd9
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: merge the generic remapping helpers into dma-direct (bsc#1175898, ECO-2743).
- commit e15d818
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: provide mmap and get_sgtable method overrides (bsc#1175898, ECO-2743).
- Update config files.
- Refresh
  patches.suse/dma-direct-relax-addressability-checks-in-dma_direct_supported.patch.
- commit 4e7185d
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: remove the dma_handle argument to __dma_direct_alloc_pages (bsc#1175898, ECO-2743).
- commit d6d3450
* Tue Oct 13 2020 jroedel@suse.de
- dma-direct: remove __dma_direct_free_pages (bsc#1175898, ECO-2743).
- commit bdd6897
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: always use VM_DMA_COHERENT for generic DMA remap (bsc#1175898, ECO-2743).
- commit a8aa6f1
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: add a dma_can_mmap helper (bsc#1175898, ECO-2743).
- commit 36bbe32
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: make dma_atomic_pool_init self-contained (bsc#1175898, ECO-2743).
- commit fc7b6a3
* Tue Oct 13 2020 jroedel@suse.de
- dma-mapping: remove arch_dma_mmap_pgprot (bsc#1175898, ECO-2743).
- refresh configs (drop ARCH_HAS_DMA_MMAP_PGPROT)
- commit 237c20c
* Tue Oct 13 2020 mgorman@suse.de
- Delete
  patches.suse/sched-fair-update_pick_idlest-Select-group-with-lowest-group_util-when-idle_cpus-are-equal.patch.
  Bisections indicated that this may be problematic in some cases even
  though it benefits in others. This is being temporarily reverted
  until it can be addressed upstream.
- commit 759de68
* Tue Oct 13 2020 jroedel@suse.de
- iommu/vt-d: Correctly calculate agaw in domain_init() (bsc#1176400).
- commit 6cf371a
* Tue Oct 13 2020 ddiss@suse.de
- kabi/severities: ignore kABI for target_core_rbd
  Match behaviour for all other Ceph specific modules.
- commit 1b6ac49
* Tue Oct 13 2020 pvorel@suse.cz
- ima: extend boot_aggregate with kernel measurements
  (bsc#1177617).
- commit c4cca48
* Tue Oct 13 2020 tbogendoerfer@suse.de
- virtio-net: don't disable guest csum when disable LRO
  (git-fixes).
- commit 45b7a4d
* Tue Oct 13 2020 neilb@suse.de
- kabi fix for NFS: Fix flexfiles read failover (git-fixes).
- commit 4923518
* Tue Oct 13 2020 neilb@suse.de
- NFSv4.2: fix client's attribute cache management for
  copy_file_range (git-fixes).
- NFS: Fix flexfiles read failover (git-fixes).
- NFS: Don't return layout segments that are in use (git-fixes).
- NFS: Don't move layouts to plh_return_segs list while in use
  (git-fixes).
- nfs: nfs_file_write() should check for writeback errors
  (git-fixes).
- nfs: ensure correct writeback errors are returned on close()
  (git-fixes).
- svcrdma: Fix page leak in svc_rdma_recv_read_chunk()
  (git-fixes).
- nfsd4: fix NULL dereference in nfsd/clients display code
  (git-fixes).
- xprtrdma: fix incorrect header size calculations (git-fixes).
- SUNRPC: Revert 241b1f419f0e ("SUNRPC: Remove xdr_buf_trim()")
  (git-fixes).
- commit 5c55a8f
* Mon Oct 12 2020 tiwai@suse.de
- i2c: owl: Clear NACK and BUS error bits (git-fixes).
- i2c: meson: fixup rate calculation with filter delay
  (git-fixes).
- i2c: meson: fix clock setting overwrite (git-fixes).
- mmc: core: don't set limits.discard_granularity as 0
  (git-fixes).
- macsec: avoid use-after-free in macsec_handle_frame()
  (git-fixes).
- r8169: fix data corruption issue on RTL8402 (bsc#1174098).
- i2c: cpm: Fix i2c_ram structure (git-fixes).
- commit c1d4f9c
* Mon Oct 12 2020 dwagner@suse.de
- qla2xxx: Return EBUSY on fcport deletion (bsc#1171688).
- commit a63944e
* Mon Oct 12 2020 dwagner@suse.de
- scsi: qla2xxx: Fix inconsistent format argument type in
  qla_dbg.c (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix inconsistent format argument type in qla_os.c
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix inconsistent format argument type in
  tcm_qla2xxx.c (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Update version to 10.02.00.103-k (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix point-to-point (N2N) device discovery issue
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix crash on session cleanup with unload
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix reset of MPI firmware (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix MPI reset needed message (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix buffer-buffer credit extraction error
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Correct the check for sscanf() return value
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Update version to 10.02.00.102-k (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Add SLER and PI control support (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Add IOCB resource tracking (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Add rport fields in debugfs (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Make tgt_port_database available in initiator
  mode (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix I/O errors during LIP reset tests
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Performance tweak (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix memory size truncation (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Reduce duplicate code in reporting speed
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Honor status qualifier in FCP_RSP per spec
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Allow dev_loss_tmo setting for FC-NVMe devices
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Setup debugfs entries for remote ports
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix I/O failures during remote port toggle
  testing (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Remove unneeded variable 'rval' (bsc#1171688
  bsc#1174003).
- commit 4dbce29
* Sun Oct 11 2020 neilb@suse.de
- Update
  patches.suse/nfs-Fix-getxattr-kernel-panic-and-memory-overflow.patch
  (bsc#1176381 CVE-2020-25212).
- Update
  patches.suse/nfs-Fix-security-label-length-not-being-reset.patch
  (bsc#1176381 CVE-2020-25212).
  Fix CVE number
- commit 73b5ecf
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: fix free-space bitmap threshold
  (bsc#1176019).
- commit c27162b
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: remove no longer necessary chunk mutex locking cases
  (bsc#1176019).
- commit db60a0b
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: move the block group freeze/unfreeze helpers into
  block-group.c (bsc#1176019).
- commit 9efb8a2
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: scrub, only lookup for csums if we are dealing with a
  data extent (bsc#1176019).
- commit d291964
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: rename member 'trimming' of block group to a more
  generic name (bsc#1176019).
- commit 23a7d0c
* Fri Oct  9 2020 mbenes@suse.cz
- Disable CONFIG_LIVEPATCH_IPA_CLONES where not needed
  Explicitly disable CONFIG_LIVEPATCH_IPA_CLONES in configs where it is
  not needed to avoid confusion and unwanted values due to fragment config
  files.
- commit 16f2ac3
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: fix a race between scrub and block group
  removal/allocation (bsc#1176019).
- commit 71bd813
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: rename write_one_cache_group()
  (bsc#1176019).
- commit 24a6cec
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: refactor how we insert a block group item
  (bsc#1176019).
- commit 1cecb46
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: refactor how we delete one block group item
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-fix-a-block-group-ref-counter-leak-after-failu.patch.
- Refresh
  patches.suse/btrfs-fix-race-between-block-group-removal-and-block.patch.
- commit 1825f40
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: refactor how we read one block group item
  (bsc#1176019).
- commit 91ae416
* Fri Oct  9 2020 fdmanana@suse.com
- btrfs: block-group: don't set the wrong READA flag for
  btrfs_read_block_groups() (bsc#1176019).
- commit 6be354e
* Fri Oct  9 2020 tiwai@suse.de
- geneve: add transport ports in route lookup for geneve
  (CVE-2020-25645 bsc#1177511).
- commit 7ab9b46
* Thu Oct  8 2020 msuchanek@suse.de
- kernel-binary.spec.in: Exclude .config.old from kernel-devel
  - use tar excludes for .kernel-binary.spec.buildenv
- commit 939a79b
* Thu Oct  8 2020 jroedel@suse.de
- vfio/pci: Decouple PCI_COMMAND_MEMORY bit checks from is_virtfn
  (bsc#1176979).
- commit 3f68ac6
* Thu Oct  8 2020 jroedel@suse.de
- s390/pci: Mark all VFs as not implementing PCI_COMMAND_MEMORY
  (bsc#1176979).
- commit 1afc493
* Thu Oct  8 2020 jroedel@suse.de
- PCI/IOV: Mark VFs as not implementing PCI_COMMAND_MEMORY
  (bsc#1176979).
- commit 36a2c27
* Thu Oct  8 2020 afaerber@suse.com
- blacklist.conf: Realtek DHC Arm SoCs not supported in SLE or Leap
  In v5.3, Realtek Digital Home Center RTD129x and later chipsets are still
  lacking irqchip, clk and any other drivers to actually load a rootfs from.
- commit 2d5007a
* Thu Oct  8 2020 tiwai@suse.de
- vmxnet3: fix cksum offload issues for non-udp tunnels
  (git-fixes).
- Input: i8042 - add nopnp quirk for Acer Aspire 5 A515
  (bsc#954532).
- clocksource/drivers/timer-gx6605s: Fixup counter reload
  (git-fixes).
- spi: fsl-espi: Only process interrupts for expected events
  (git-fixes).
- mac80211: do not allow bigger VHT MPDUs than the hardware
  supports (git-fixes).
- commit 76e08ef
* Thu Oct  8 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/i2c-i801-exclude-device-from-suspend-direct-complete.patch
- commit 9fbf63b
* Wed Oct  7 2020 msuchanek@suse.de
- kernel-binary.spec.in: Package the obj_install_dir as explicit filelist.
- commit 5587762
* Wed Oct  7 2020 jdelvare@suse.de
- i2c: i801: Exclude device from suspend direct complete
  optimization (git-fixes).
- commit cbf8a71
* Wed Oct  7 2020 tiwai@suse.de
- drm/radeon: revert "Prefer lower feedback dividers"
  (bsc#1177384).
- commit 502170c
* Wed Oct  7 2020 mkubecek@suse.cz
- Update kabi files.
- update to resubmitted October 2020 maintenance update (commit a291df1060d0)
- commit 04003b7
* Wed Oct  7 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/nfs-Fix-security-label-length-not-being-reset.patch
- commit ae3a19b
* Wed Oct  7 2020 neilb@suse.de
- nfs: Fix security label length not being reset (bsc#1176381).
- commit c73c639
* Tue Oct  6 2020 tiwai@suse.de
- Refresh intel-vbtn patch from the upstream patch
- commit c3bd737
* Tue Oct  6 2020 tiwai@suse.de
- platform/x86: thinkpad_acpi: re-initialize ACPI buffer size
  when reuse (git-fixes).
- platform/x86: intel_pmc_core: do not create a static struct
  device (git-fixes).
- platform/x86: fix kconfig dependency warning for FUJITSU_LAPTOP
  (git-fixes).
- platform/x86: fix kconfig dependency warning for LG_LAPTOP
  (git-fixes).
- platform/x86: thinkpad_acpi: initialize tp_nvram_state variable
  (git-fixes).
- Platform: OLPC: Fix memleak in olpc_ec_probe (git-fixes).
- net: phy: realtek: fix rtl8211e rx/tx delay config (git-fixes).
- commit b64083a
* Tue Oct  6 2020 martin.wilck@suse.com
- Rename scsi-fnic-do-not-call-scsi_done-for-unhandled-commands.patch
  Fix typo in patch file name.
- commit 82b5d08
* Tue Oct  6 2020 martin.wilck@suse.com
- Refresh patches.suse/fnic-to-not-call-scsi_done-for-unhandled-commands.patch
  (bsc#1168468, bsc#1171675).
- commit f530d7c
* Mon Oct  5 2020 tbogendoerfer@suse.de
- Update config files.
  Enable ACPI_PCI_SLOT and HOTPLUG_PCI_ACPI (bsc#1177194).
- commit bc319f1
* Mon Oct  5 2020 tiwai@suse.de
- platform/x86: intel-vbtn: Switch to an allow-list for
  SW_TABLET_MODE reporting (bsc#1175599).
- commit 677b36d
* Mon Oct  5 2020 mbenes@suse.cz
- ftrace: Move RCU is watching check after recursion check
  (git-fixes).
- commit 3837051
* Mon Oct  5 2020 jroedel@suse.de
- iommu/amd: Fix IOMMU AVIC not properly update the is_run bit
  in IRTE (bsc#1177297).
- commit d4ca096
* Mon Oct  5 2020 jroedel@suse.de
- iommu/amd: Re-factor guest virtual APIC (de-)activation code
  (bsc#1177284).
- Refresh
  patches.suse/iommu-amd-restore-irte-remapen-bit-after-programming-irte.
- commit 9de73d9
* Mon Oct  5 2020 jroedel@suse.de
- iommu/exynos: add missing put_device() call in
  exynos_iommu_of_xlate() (bsc#1177286).
- iommu/amd: Restore IRTE.RemapEn bit for
  amd_iommu_activate_guest_mode (bsc#1177285).
- iommu/amd: Fix potential @entry null deref (bsc#1177283).
- commit 7766a97
* Mon Oct  5 2020 jgross@suse.com
- xen/events: don't use chip_data for legacy IRQs (bsc#1065600).
- commit 1009a6a
* Mon Oct  5 2020 tiwai@suse.de
- phy: ti: am654: Fix a leak in serdes_am654_probe() (git-fixes).
- commit 91925ce
* Mon Oct  5 2020 tiwai@suse.de
- USB: gadget: f_ncm: Fix NDP16 datagram validation (git-fixes).
- commit 62e667f
* Mon Oct  5 2020 tiwai@suse.de
- Input: trackpoint - enable Synaptics trackpoints (git-fixes).
- commit e02fa5e
* Mon Oct  5 2020 tiwai@suse.de
- pinctrl: mvebu: Fix i2c sda definition for 98DX3236 (git-fixes).
- commit 9356b76
* Mon Oct  5 2020 tiwai@suse.de
- iio: adc: qcom-spmi-adc5: fix driver name (git-fixes).
- commit f78905d
* Mon Oct  5 2020 tiwai@suse.de
- gpio: mockup: fix resource leak in error path (git-fixes).
- commit bdd2ea9
* Mon Oct  5 2020 tiwai@suse.de
- gpio: siox: explicitly support only threaded irqs (git-fixes).
- commit 57c8150
* Mon Oct  5 2020 tiwai@suse.de
- gpio: tc35894: fix up tc35894 interrupt configuration
  (git-fixes).
- commit bcd4186
* Mon Oct  5 2020 tiwai@suse.de
- gpio: sprd: Clear interrupt when setting the type as edge
  (git-fixes).
- commit 3f5c502
* Mon Oct  5 2020 tiwai@suse.de
- mmc: sdhci: Workaround broken command queuing on Intel GLK
  based IRBIS models (git-fixes).
- commit ca933ab
* Mon Oct  5 2020 tiwai@suse.de
- clk: socfpga: stratix10: fix the divider for the
  emac_ptp_free_clk (git-fixes).
- commit f3d75fd
* Mon Oct  5 2020 tiwai@suse.de
- clk: samsung: exynos4: mark 'chipid' clock as CLK_IGNORE_UNUSED
  (git-fixes).
- commit e344453
* Mon Oct  5 2020 tiwai@suse.de
- clk: tegra: Always program PLL_E when enabled (git-fixes).
- commit bbc21a4
* Sun Oct  4 2020 lduncan@suse.com
- scsi: iscsi: iscsi_tcp: Avoid holding spinlock while calling
  getpeername() (bsc#1177258).
- commit ea50f56
* Sat Oct  3 2020 mgorman@suse.de
- sched/fair: Ignore cache hotness for SMT migration (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/numa: Use runnable_avg to classify node (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Use dst group while checking imbalance for NUMA
  balancer (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit a9a7020
* Sat Oct  3 2020 tiwai@suse.de
- clocksource/drivers/h8300_timer8: Fix wrong return value in
  h8300_8timer_init() (git-fixes).
- hwmon: (applesmc) check status earlier (git-fixes).
- 9p: Fix memory leak in v9fs_mount (git-fixes).
- yam: fix possible memory leak in yam_init_driver (git-fixes).
- airo: Fix read overflows sending packets (git-fixes).
- clk/ti/adpll: allocate room for terminating null (git-fixes).
- ASoC: kirkwood: fix IRQ error handling (git-fixes).
- commit 7091952
* Fri Oct  2 2020 jdelvare@suse.de
- drm/amdgpu: restore proper ref count in
  amdgpu_display_crtc_set_config (git-fixes).
- commit cb11410
* Fri Oct  2 2020 tiwai@suse.de
- mac802154: tx: fix use-after-free (git-fixes).
- ieee802154/adf7242: check status of adf7242_read_reg
  (git-fixes).
- ieee802154: fix one possible memleak in ca8210_dev_com_init
  (git-fixes).
- i2c: core: Call i2c_acpi_install_space_handler() before
  i2c_acpi_register_devices() (git-fixes).
- i2c: aspeed: Mask IRQ status to relevant bits (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for MPMAN Converter9 2-in-1
  (git-fixes).
- ASoC: wm8994: Ensure the device is resumed in wm89xx_mic_detect
  functions (git-fixes).
- ASoC: wm8994: Skip setting of the WM8994_MICBIAS register for
  WM1811 (git-fixes).
- mac80211: skip mpath lookup also for control port tx
  (git-fixes).
- i2c: tegra: Restore pinmux on system resume (git-fixes).
- mtd: rawnand: omap_elm: Fix runtime PM imbalance on error
  (git-fixes).
- mtd: rawnand: gpmi: Fix runtime PM imbalance on error
  (git-fixes).
- power: supply: max17040: Correct voltage reading (git-fixes).
- drivers: char: tlclk.c: Avoid data race between init and
  interrupt handler (git-fixes).
- staging:r8188eu: avoid skb_clone for amsdu to msdu conversion
  (git-fixes).
- serial: uartps: Wait for tx_empty in console setup (git-fixes).
- usb: dwc3: Increase timeout for CmdAct cleared by device
  controller (git-fixes).
- USB: EHCI: ehci-mv: fix less than zero comparison of an unsigned
  int (git-fixes).
- USB: EHCI: ehci-mv: fix error handling in mv_ehci_probe()
  (git-fixes).
- PCI: tegra: Fix runtime PM imbalance on error (git-fixes).
- PCI: tegra194: Fix runtime PM imbalance on error (git-fixes).
- gpio: rcar: Fix runtime PM imbalance on error (git-fixes).
- ASoC: img-i2s-out: Fix runtime PM imbalance on error
  (git-fixes).
- wlcore: fix runtime pm imbalance in wlcore_regdomain_config
  (git-fixes).
- wlcore: fix runtime pm imbalance in wl1271_tx_work (git-fixes).
- e1000: Do not perform reset in reset_task if we are already down
  (git-fixes).
- Bluetooth: Handle Inquiry Cancel error after Inquiry Complete
  (git-fixes).
- thermal: rcar_thermal: Handle probe error gracefully
  (git-fixes).
- rtc: ds1374: fix possible race condition (git-fixes).
- rtc: sa1100: fix possible race condition (git-fixes).
- bus: hisi_lpc: Fixup IO ports addresses to avoid use-after-free
  in host removal (git-fixes).
- dmaengine: tegra-apb: Prevent race conditions on channel's
  freeing (git-fixes).
- dmaengine: stm32-dma: use vchan_terminate_vdesc() in
  .terminate_all (git-fixes).
- dmaengine: stm32-mdma: use vchan_terminate_vdesc() in
  .terminate_all (git-fixes).
- brcmfmac: Fix double freeing in the fmac usb data path
  (git-fixes).
- ath10k: use kzalloc to read for ath10k_sdio_hif_diag_read
  (git-fixes).
- Bluetooth: L2CAP: handle l2cap config request during open state
  (git-fixes).
- Bluetooth: guard against controllers sending zero'd events
  (git-fixes).
- Bluetooth: prefetch channel before killing sock (git-fixes).
- Bluetooth: Fix refcount use-after-free issue (git-fixes).
- mt76: fix handling full tx queues in mt76_dma_tx_queue_skb_raw
  (git-fixes).
- mt76: clear skb pointers from rx aggregation reorder buffer
  during cleanup (git-fixes).
- serial: 8250: 8250_omap: Terminate DMA before pushing data on
  RX timeout (git-fixes).
- serial: 8250_omap: Fix sleeping function called from invalid
  context during probe (git-fixes).
- serial: 8250_port: Don't service RX FIFO if throttled
  (git-fixes).
- i2c: tegra: Prevent interrupt triggering after transfer timeout
  (git-fixes).
- media: ti-vpe: cal: Restrict DMA to avoid memory corruption
  (git-fixes).
- ar5523: Add USB ID of SMCWUSBT-G2 wireless adapter (git-fixes).
- ACPI: EC: Reference count query handlers under lock (git-fixes).
- dmaengine: zynqmp_dma: fix burst length configuration
  (git-fixes).
- mmc: core: Rework wp-gpio handling (git-fixes).
- mt76: fix LED link time failure (git-fixes).
- PCI: Avoid double hpmemsize MMIO window assignment (git-fixes).
- dmaengine: mediatek: hsdma_probe: fixed a memory leak when
  devm_request_irq fails (git-fixes).
- mfd: mfd-core: Protect against NULL call-back function pointer
  (git-fixes).
- leds: mlxreg: Fix possible buffer overflow (git-fixes).
- dma-fence: Serialise signal enabling
  (dma_fence_enable_sw_signaling) (git-fixes).
- media: smiapp: Fix error handling at NVM reading (git-fixes).
- media: mc-device.c: fix memleak in media_device_register_entity
  (git-fixes).
- mt76: add missing locking around ampdu action (git-fixes).
- mt76: do not use devm API for led classdev (git-fixes).
- ath10k: fix memory leak for tpc_stats_final (git-fixes).
- ath10k: fix array out-of-bounds access (git-fixes).
- mtd: cfi_cmdset_0002: don't free cfi->cfiq in error path of
  cfi_amdstd_setup() (git-fixes).
- commit 6283339
* Thu Oct  1 2020 mgorman@suse.de
- locking/rwsem: Disable reader optimistic spinning (bnc#1176588).
- cpuidle: Poll for a minimum of 30ns and poll for a tick if
  lower c-states are disabled (bnc#1176588).
- commit 978088f
* Thu Oct  1 2020 mgorman@suse.de
- sched/numa: Avoid creating large imbalances at task creation
  time (bnc#1176588).
- commit aa3fc2a
* Thu Oct  1 2020 mgorman@suse.de
- sched/numa: Check numa balancing information only when enabled
  (bnc#1176588).
- commit 576f70b
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: drop logs when we've aborted a transaction (bsc#1176019).
- commit 7345ceb
* Thu Oct  1 2020 tiwai@suse.de
- hdlc_ppp: add range checks in ppp_cp_parse_cr() (CVE-2020-25643
  bsc#1177206).
- commit 8a998ea
* Thu Oct  1 2020 tiwai@suse.de
- block: allow for_each_bvec to support zero len bvec
  (CVE-2020-25641 bsc#1177121).
- commit d4185c3
* Thu Oct  1 2020 fdmanana@suse.com
- Btrfs: fix crash during unmount due to race with delayed inode
  workers (bsc#1176019).
- commit 0dbe270
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: kill the subvol_srcu (bsc#1176019).
- commit 0920c6e
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: make btrfs_cleanup_fs_roots use the radix tree lock
  (bsc#1176019).
- commit c45ade0
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: don't take an extra root ref at allocation time
  (bsc#1176019).
- commit 3454450
* Thu Oct  1 2020 lhenriques@suse.de
- fuse: don't ignore errors from fuse_writepages_fill()
  (bsc#1177193).
- commit 9d94f4c
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: hold a ref on the root on the dead roots list
  (bsc#1176019).
- commit 5e21616
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: make inodes hold a ref on their roots (bsc#1176019).
- commit 4ebbb08
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: move the root freeing stuff into btrfs_put_root
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- Refresh
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch.
- commit 9621b6c
* Thu Oct  1 2020 mkubecek@suse.cz
- Update kabi files.
- update to October 2020 maintenance update submission (commit e037a4e18793)
- commit 05421e4
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: free block groups after free'ing fs trees (bsc#1176019).
- commit 2c64d7b
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: move ino_cache_inode dropping out of btrfs_free_fs_root
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- commit d9887ec
* Thu Oct  1 2020 fdmanana@suse.com
- btrfs: make the extent buffer leak check per fs info
  (bsc#1176019).
- commit 941b4ee
* Wed Sep 30 2020 ohering@suse.de
- rpm/constraints.in: recognize also kernel-source-azure (bsc#1176732)
- commit 7214bbe
* Wed Sep 30 2020 jroedel@suse.de
- kABI: Fix kABI for 12856e7acde4 PCI/IOV: Mark VFs as not
  implementing PCI_COMMAND_MEMORY (bsc#1176979).
- commit e374ebb
* Wed Sep 30 2020 dwagner@suse.de
- Drop patches.suse/scsi-qla2xxx-Handle-incorrect-entry_type-entries.patch
  The patch contains a bug which prevents device discovery. Drop it until
  we have a proper fix from upstream.
- commit d02a6d5
* Tue Sep 29 2020 tiwai@suse.de
- Delete a doubly applied batman-adv patch
- commit edcea1c
* Tue Sep 29 2020 msuchanek@suse.de
- Rename patches to the same name as in SLE15-SP3.
- commit b538695
* Tue Sep 29 2020 mbenes@suse.cz
- tracing: fix double free (git-fixes).
- commit dd7027e
* Tue Sep 29 2020 oneukum@suse.com
- Revert "crypto: chelsio - Inline single pdu only" (git-fixes).
- commit 11462e6
* Tue Sep 29 2020 msuchanek@suse.de
- powerpc: Don't flush caches when adding memory (bsc#1176980
  ltc#187962).
- commit 63612e5
* Tue Sep 29 2020 msuchanek@suse.de
- Fix patch order in sorted section.
- commit ca43e45
* Tue Sep 29 2020 tbogendoerfer@suse.de
- RDMA/bnxt_re: Restrict the max_gids to 256 (bsc#1173017).
- RDMA/bnxt_re: Fix the qp table indexing (bsc#1173017).
- RDMA/bnxt_re: Do not report transparent vlan from QP1
  (bsc#1173017).
- commit 279a57c
* Tue Sep 29 2020 ohering@suse.de
- irqdomain/treewide: Free firmware node after domain removal (git-fixes).
- commit 2fa0cd5
* Tue Sep 29 2020 ohering@suse.de
- irqdomain/treewide: Keep firmware node unconditionally allocated (git-fixes).
- commit 7778bc2
* Tue Sep 29 2020 ohering@suse.de
- Drivers: hv: vmbus: Add timeout to vmbus_wait_for_unload
  (git-fixes).
- Drivers: hv: vmbus: hibernation: do not hang forever in
  vmbus_bus_resume() (git-fixes).
- hv_utils: drain the timesync packets on onchannelcallback
  (bsc#1176877).
- hv_utils: return error if host timesysnc update is stale
  (bsc#1176877).
- Drivers: hv: Specify receive buffer size using Hyper-V page size
  (bsc#1176877).
- commit 5ca04fc
* Mon Sep 28 2020 tiwai@suse.de
- Bluetooth: btrtl: Add support for RTL8761B (bsc#1177021).
- commit 6c51917
* Mon Sep 28 2020 tbogendoerfer@suse.de
- net: sched: initialize with 0 before setting erspan md->u
  (bsc#1154353).
- debugfs: Fix module state check condition (bsc#1173746).
- RDMA/siw: Suppress uninitialized var warning (jsc#SLE-8381).
- commit 97c7a55
* Sat Sep 26 2020 nstange@suse.de
- s390/maccess: add no DAT mode to kernel_write (bsc#1176449).
- commit 8fd068b
* Sat Sep 26 2020 nstange@suse.de
- s390: Change s390_kernel_write() return type to match memcpy()
  (bsc#1176449).
  Prerequisite for bsc#1176449.
- commit 3f17b43
* Fri Sep 25 2020 tiwai@suse.de
- Update patch reference for NFC security fix (CVE-2020-26088 bsc#1176990)
- commit 7eec5ca
* Fri Sep 25 2020 msuchanek@suse.de
- powerpc/kernel: Enables memory hot-remove after reboot on
  pseries guests (bsc#1177030 ltc#187588).
- powerpc/mm: Limit resize_hpt_for_hotplug() call to hash guests
  only (bsc#1177030 ltc#187588).
- commit 9885202
* Fri Sep 25 2020 msuchanek@suse.de
- scsi: ibmvfc: Avoid link down on FS9100 canister reboot
  (bsc#1176962 ltc#188304).
- scsi: ibmvfc: Use compiler attribute defines instead of
  __attribute__() (bsc#1176962 ltc#188304).
- commit 2f6bf7f
* Thu Sep 24 2020 tiwai@suse.de
- Revert "ALSA: usb-audio: Disable Lenovo P620 Rear line-in
  volume control" (git-fixes).
- Revert "ALSA: hda - Fix silent audio output and corrupted
  input on MSI X570-A PRO" (git-fixes).
- ALSA: usb-audio: Add delay quirk for H570e USB headsets
  (git-fixes).
- ALSA: hda/realtek: Enable front panel headset LED on Lenovo
  ThinkStation P520 (git-fixes).
- ALSA: hda/realtek - Couldn't detect Mic if booting with headset
  plugged (git-fixes).
- ALSA: asihpi: fix iounmap in error handler (git-fixes).
- commit 392c032
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: remove a BUG_ON() from merge_reloc_roots() (bsc#1176019).
- commit 070656a
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: hold a ref on the root->reloc_root (bsc#1176019).
- commit cfada4f
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: clear DEAD_RELOC_TREE before dropping the reloc root
  (bsc#1176019).
- commit 3414f3d
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: Remove block_rsv parameter from btrfs_drop_snapshot
  (bsc#1176019).
- commit 0eab798
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: free the reloc_control in a consistent way (bsc#1176019).
- commit 7857718
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: fix setting last_trans for reloc roots (bsc#1176019).
- commit fe4b564
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: do not init a reloc root if we aren't relocating
  (bsc#1176019).
- commit c5afb94
* Thu Sep 24 2020 ggherdovich@suse.cz
- x86, sched: Bail out of frequency invariance if
  turbo_freq/base_freq gives 0 (bsc#1176925).
- commit a66109f
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: reloc: clean dirty subvols if we fail to start a
  transaction (bsc#1176019).
- btrfs: unset reloc control if we fail to recover (bsc#1176019).
- commit 30d2800
* Thu Sep 24 2020 ggherdovich@suse.cz
- x86, sched: Bail out of frequency invariance if turbo frequency
  is unknown (bsc#1176925).
- commit 53cd83a
* Thu Sep 24 2020 ggherdovich@suse.cz
- x86, sched: check for counters overflow in frequency invariant
  accounting (bsc#1176925).
- commit 863fd4c
* Thu Sep 24 2020 fdmanana@suse.com
- btrfs: drop block from cache on error in relocation
  (bsc#1176019).
- commit 40126ae
* Thu Sep 24 2020 tiwai@suse.de
- ALSA: hda/realtek - The Mic on a RedmiBook doesn't work
  (git-fixes).
- ALSA: hda: fixup headset for ASUS GX502 laptop (git-fixes).
- commit e989675
* Thu Sep 24 2020 tiwai@suse.de
- batman-adv: mcast: fix duplicate mcast packets from BLA backbone
  to mesh (git-fixes).
- USB: quirks: Add USB_QUIRK_IGNORE_REMOTE_WAKEUP quirk for BYD
  zhaoxin notebook (git-fixes).
- serial: 8250_pci: Add Realtek 816a and 816b (git-fixes).
- Input: trackpoint - add new trackpoint variant IDs (git-fixes).
- Input: i8042 - add Entroware Proteus EL07R4 to nomux and reset
  lists (git-fixes).
- i2c: i801: Fix resume bug (git-fixes).
- i2c: algo: pca: Reapply i2c bus settings after reset
  (git-fixes).
- spi: Fix memory leak on splited transfers (git-fixes).
- spi: spi-loopback-test: Fix out-of-bounds read (git-fixes).
- regulator: pwm: Fix machine constraints application (git-fixes).
- commit 1a5ffc9
* Thu Sep 24 2020 tiwai@suse.de
- batman-adv: mcast: fix duplicate mcast packets in BLA backbone
  from mesh (git-fixes).
- batman-adv: mcast: fix duplicate mcast packets in BLA backbone
  from LAN (git-fixes).
- batman-adv: Add missing include for in_interrupt() (git-fixes).
- batman-adv: mcast/TT: fix wrongly dropped or rerouted packets
  (git-fixes).
- batman-adv: bla: fix type misuse for backbone_gw hash indexing
  (git-fixes).
- USB: UAS: fix disconnect by unplugging a hub (git-fixes).
- usb: typec: ucsi: Prevent mode overrun (git-fixes).
- i2c: mxs: use MXS_DMA_CTRL_WAIT4END instead of DMA_CTRL_ACK
  (git-fixes).
- commit b4b4983
* Thu Sep 24 2020 tiwai@suse.de
- ASoC: meson: axg-toddr: fix channel order on g12 platforms
  (git-fixes).
- ASoC: qcom: common: Fix refcount imbalance on error (git-fixes).
- ASoC: qcom: Set card->owner to avoid warnings (git-fixes).
- USB: serial: option: support dynamic Quectel USB compositions
  (git-fixes).
- dmaengine: acpi: Put the CSRT table after using it (git-fixes).
- NFC: st95hf: Fix memleak in st95hf_in_send_cmd (git-fixes).
- HID: elan: Fix memleak in elan_input_configured (git-fixes).
- HID: microsoft: Add rumble support for the 8bitdo SN30 Pro+
  controller (git-fixes).
- HID: quirks: Set INCREMENT_USAGE_ON_DUPLICATE for all Saitek
  X52 devices (git-fixes).
- HID: quirks: Always poll three more Lenovo PixArt mice
  (git-fixes).
- commit a978a29
* Thu Sep 24 2020 tiwai@suse.de
- clk: rockchip: Fix initialization of mux_pll_src_4plls_p
  (git-fixes).
- clk: davinci: Use the correct size when allocating memory
  (git-fixes).
- USB: serial: option: add support for SIM7070/SIM7080/SIM7090
  modules (git-fixes).
- USB: serial: ftdi_sio: add IDs for Xsens Mti USB converter
  (git-fixes).
- usb: Fix out of sync data toggle if a configured device is
  reconfigured (git-fixes).
- iio: adc: mcp3422: fix locking on error path (git-fixes).
- iio: adc: mcp3422: fix locking scope (git-fixes).
- iio:adc:max1118 Fix alignment of timestamp and data leak issues
  (git-fixes).
- debugfs: Fix module state check condition (git-fixes).
- iio: dac: ad5592r: fix unbalanced mutex unlocks in
  ad5592r_read_raw() (git-fixes).
- commit c8304fa
* Thu Sep 24 2020 tiwai@suse.de
- usb: core: fix slab-out-of-bounds Read in read_descriptors
  (git-fixes).
- usb: typec: ucsi: acpi: Check the _DEP dependencies (git-fixes).
- iio:adc:ina2xx Fix timestamp alignment issue (git-fixes).
- iio:adc:ti-adc084s021 Fix alignment and data leak issues
  (git-fixes).
- iio:adc:ti-adc081c Fix alignment and data leak issues
  (git-fixes).
- iio:magnetometer:ak8975 Fix alignment and data leak issues
  (git-fixes).
- iio:light:ltr501 Fix timestamp alignment issue (git-fixes).
- iio:light:max44000 Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio:chemical:ccs811: Fix timestamp alignment and prevent data
  leak (git-fixes).
- iio:proximity:mb1232: Fix timestamp alignment and prevent data
  leak (git-fixes).
- iio:accel:mma7455: Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio:accel:bmc150-accel: Fix timestamp alignment and prevent
  data leak (git-fixes).
- iio:accel:mma8452: Fix timestamp alignment and prevent data leak
  (git-fixes).
- iio: accel: kxsd9: Fix alignment of local buffer (git-fixes).
- iio: adc: ti-ads1015: fix conversion when CONFIG_PM is not set
  (git-fixes).
- soundwire: fix double free of dangling pointer (git-fixes).
- spi: stm32: fix pm_runtime_get_sync() error checking
  (git-fixes).
- regulator: core: Fix slab-out-of-bounds in
  regulator_unlock_recursive() (git-fixes).
- regulator: remove superfluous lock in
  regulator_resolve_coupling() (git-fixes).
- regulator: plug of_node leak in regulator_register()'s error
  path (git-fixes).
- regulator: push allocation in set_consumer_device_supply()
  out of lock (git-fixes).
- regulator: push allocations in create_regulator() outside of
  lock (git-fixes).
- regulator: push allocation in regulator_ena_gpio_request()
  out of lock (git-fixes).
- regulator: push allocation in regulator_init_coupling()
  outside of lock (git-fixes).
- mmc: sdio: Use mmc_pre_req() / mmc_post_req() (git-fixes).
- mmc: sdhci-of-esdhc: Don't walk device-tree on every interrupt
  (git-fixes).
- mmc: sdhci-msm: Add retries when all tuning phases are found
  valid (git-fixes).
- mmc: sdhci-acpi: Clear amd_sdhci_host on reset (git-fixes).
- commit 3591d68
* Thu Sep 24 2020 glin@suse.com
- bpf: Fix a rcu warning for bpffs map pretty-print (bsc#1155518).
- bpf: map_seq_next should always increase position index
  (bsc#1155518).
- commit e39f9d2
* Thu Sep 24 2020 lyan@suse.com
- arm64: paravirt: Initialize steal time when cpu is online
  (bsc#1176833).
- Drop
  patches.kabi/kabi-workaround-for-enum-cpuhp_state.patch
  (Variable in enum cpuhp_state is no longer needed)
- commit 5b9b111
* Wed Sep 23 2020 msuchanek@suse.de
- powerpc/numa: Early request for home node associativity
  (bsc#1171068 ltc#183935).
- commit bd89a37
* Wed Sep 23 2020 tiwai@suse.de
- workqueue: require CPU hotplug read exclusion for
  apply_workqueue_attrs (bsc#1176763).
- commit ceaafd0
* Wed Sep 23 2020 msuchanek@suse.de
- powerpc/numa: Offline memoryless cpuless node 0 (bsc#1171068
  ltc#183935).
- powerpc/numa: Prefer node id queried from vphn (bsc#1171068
  ltc#183935).
- powerpc/numa: Set numa_node for all possible cpus (bsc#1171068
  ltc#183935).
- powerpc/numa: Use cpu node map of first sibling thread
  (bsc#1171068 ltc#183935).
- commit 4baf6e2
* Wed Sep 23 2020 msuchanek@suse.de
- rpadlpar_io: Add MODULE_DESCRIPTION entries to kernel modules
  (bsc#1176869 ltc#188243).
- commit e45f4be
* Wed Sep 23 2020 tiwai@suse.de
- fbcon: remove soft scrollback code (CVE-2020-14390 bsc#1176235).
- commit 9b8ada0
* Wed Sep 23 2020 tiwai@suse.de
- cfg80211: regulatory: reject invalid hints (bsc#1176699).
- commit 899f6a9
* Wed Sep 23 2020 dwagner@suse.de
- scsi: qla2xxx: Handle incorrect entry_type entries
  (bsc#1171688).
- scsi: qla2xxx: Log calling function name in
  qla2x00_get_sp_from_handle() (bsc#1171688).
- scsi: qla2xxx: Simplify return value logic in
  qla2x00_get_sp_from_handle() (bsc#1171688).
- scsi: qla2xxx: Warn if done() or free() are called on an
  already freed srb (bsc#1171688).
- scsi: qla2xxx: Fix the return value (bsc#1171688).
- scsi: qla2xxx: Fix wrong return value in qla_nvme_register_hba()
  (bsc#1171688).
- scsi: qla2xxx: Fix wrong return value in
  qlt_chk_unresolv_exchg() (bsc#1171688).
- scsi: qla2xxx: Remove redundant variable initialization
  (bsc#1171688).
- scsi: qla2xxx: Fix the size used in a 'dma_free_coherent()'
  call (bsc#1171688).
- scsi: qla2xxx: Remove pci-dma-compat wrapper API (bsc#1171688).
- scsi: qla2xxx: Remove superfluous memset() (bsc#1171688).
- commit a59756a
* Wed Sep 23 2020 dwagner@suse.de
- wireguard: peerlookup: take lock before checking hash in
  replace operation (git-fixes).
- wireguard: noise: take lock when removing handshake entry from
  table (git-fixes).
- commit 742e9a3
* Wed Sep 23 2020 dwagner@suse.de
- series: Update meta data
- commit 46acdd6
* Wed Sep 23 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/btrfs-require-only-sector-size-alignment-for-parent-.patch
- commit ee89c1f
* Wed Sep 23 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/nfs-Fix-getxattr-kernel-panic-and-memory-overflow.patch
- commit 147bb89
* Wed Sep 23 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ibmvnic-add-missing-parenthesis-in-do_reset.patch
- commit feb9790
* Tue Sep 22 2020 tiwai@suse.de
- libata: implement ATA_HORKAGE_MAX_TRIM_128M and apply to
  Sandisks (jsc#SLE-14459).
- ata: ahci: use ata_link_info() instead of ata_link_printk()
  (jsc#SLE-14459).
- commit e4929bb
* Tue Sep 22 2020 tiwai@suse.de
- Update patch reference for most driver securiy fix (CVE-2020-0432 bsc#1176721)
- commit f4104d9
* Tue Sep 22 2020 tiwai@suse.de
- Update patch reference for pinctrl security fix (CVE-2020-0427, bsc#1176725)
- commit 13119a3
* Tue Sep 22 2020 tiwai@suse.de
- Update patch reference for HID security fix (CVE-2020-0431, bsc#1176722)
- commit 92b53fb
* Tue Sep 22 2020 tiwai@suse.de
- HID: core: fix dmesg flooding if report field larger than 32bit
  (bsc#1176775).
- HID: core: Add printk_once variants to hid_warn() etc
  (bsc#1176775).
- HID: core: reformat and reduce hid_printk macros (bsc#1176775).
- commit 37f3024
* Tue Sep 22 2020 msuchanek@suse.de
- kernel-syms.spec.in: Also use bz compression (boo#1175882).
- commit ecaf78d
* Tue Sep 22 2020 bp@suse.de
- Update
  patches.suse/media-uvcvideo-Avoid-cyclic-entity-chains-due-to-mal.patch
  (bsc#1176423 CVE-2020-0404).
- commit 23cba3a
* Tue Sep 22 2020 jslaby@suse.cz
- platform/x86: dcdbas: Check SMBIOS for protected buffer address
  (jsc#SLE-14407).
- commit 7f21c07
* Tue Sep 22 2020 wqu@suse.com
- btrfs: require only sector size alignment for parent eb  bytenr
  (bsc#1176789).
- commit 868a458
* Tue Sep 22 2020 wqu@suse.com
- btrfs: tree-checker: fix the error message for transid error
  (bsc#1176788).
- commit 96dd2e2
* Tue Sep 22 2020 glin@suse.com
- libbpf: Fix readelf output parsing for Fedora (bsc#1155518).
- commit 667b79c
* Tue Sep 22 2020 glin@suse.com
- libbpf: Fix readelf output parsing on powerpc with recent binutils (bsc#1155518).
- commit 20955ec
* Tue Sep 22 2020 neilb@suse.de
- nfs: Fix getxattr kernel panic and memory overflow (bsc#1176381
  CVE-2020-2521).
- commit 0de797a
* Mon Sep 21 2020 mkubecek@suse.cz
- hsr: use netdev_err() instead of WARN_ONCE() (bsc#1176659).
- commit fe91e40
* Mon Sep 21 2020 mkubecek@suse.cz
- netfilter: ipset: Fix forceadd evaluation path (bsc#1176587).
- commit 64d0b5f
* Mon Sep 21 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/powerpc-book3s64-radix-Fix-boot-failure-with-large-a.patch
  patches.suse/powerpc-papr_scm-Limit-the-readability-of-perf_stats.patch
- commit 1c47455
* Mon Sep 21 2020 msuchanek@suse.de
- libnvdimm/security: fix a typo (bsc#1171742 bsc#1167527).
- commit 7e506d7
* Mon Sep 21 2020 msuchanek@suse.de
- Refresh sorted patches.
- Refresh patches.suse/powerpc-book3s64-radix-Fix-boot-failure-with-large-a.patch.
- Refresh patches.suse/powerpc-papr_scm-Limit-the-readability-of-perf_stats.patch.
- commit 50a09d4
* Mon Sep 21 2020 dwagner@suse.de
- blacklist: Ignore doc update and build warning
  The offending commit for the build warning is in mainlince since 2.6.
- commit ecc1f19
* Mon Sep 21 2020 msuchanek@suse.de
- ibmvnic: add missing parenthesis in do_reset() (bsc#1176700
  ltc#188140).
- commit a96bd66
* Mon Sep 21 2020 glin@suse.com
- rpm/kernel-cert-subpackage: add CA check on key enrollment (bsc#1173115)
  To avoid the unnecessary key enrollment, when enrolling the signing key
  of the kernel package, "--ca-check" is added to mokutil so that mokutil
  will ignore the request if the CA of the signing key already exists in
  MokList or UEFI db.
  Since the macro, %%_suse_kernel_module_subpackage, is only defined in a
  kernel module package (KMP), it's used to determine whether the %%post
  script is running in a kernel package, or a kernel module package.
- commit b15c9bf
* Fri Sep 18 2020 glin@suse.com
- rpm/macros.kernel-source: pass -c proerly in kernel module package (bsc#1176698)
  The "-c" option wasn't passed down to %%_kernel_module_package so the
  ueficert subpackage wasn't generated even if the certificate is
  specified in the spec file.
- commit 34808fb
* Thu Sep 17 2020 tzimmermann@suse.de
- blacklist.conf: Append 'gpu: ipu-v3: image-convert: Wait for all EOFs before completing a tile'
- commit cd2ad4e
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/sun4i: backend: Disable alpha on the lowest plane on the A20 (bsc#1152472)
- commit a28c02e
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/sun4i: backend: Support alpha property on lowest plane (bsc#1152472)
- commit 081a7ef
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/sun4i: Fix dsi dcs long write function (bsc#1152472)
- commit 510ebc1
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/sun4i: add missing put_device() call in (bsc#1152472)
- commit 69345eb
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/virtio: fix missing dma_fence_put() in (bsc#1152489)
  * context changes
- commit 2d93b7f
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/ast: Initialize DRAM type before posting GPU (bsc#1152472)
  * context changes
- commit 933f31f
* Thu Sep 17 2020 tzimmermann@suse.de
- drm/mgag200: Remove declaration of mgag200_mmap() from header file (bsc#1152472)
  * context changes
- commit 435259b
* Wed Sep 16 2020 fdmanana@suse.com
- Btrfs: implement full reflink support for inline extents
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-fix-lost-i_size-update-after-cloning-inline-ex.patch.
- commit 1499e64
* Wed Sep 16 2020 fdmanana@suse.com
- Btrfs: simplify inline extent handling when doing reflinks
  (bsc#1176019).
- commit 378e9bc
* Wed Sep 16 2020 fdmanana@suse.com
- Btrfs: move all reflink implementation code into its own file
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-fix-lost-i_size-update-after-cloning-inline-ex.patch.
- commit 24935c8
* Tue Sep 15 2020 ematsumiya@suse.de
- nvme-pci: override the value of the controller's numa node
  (bsc#1176507).
- commit 1ad78c9
* Tue Sep 15 2020 msuchanek@suse.de
- Remove patch causing regression (bsc#1094244 ltc#168122).
- Delete patches.suse/powerpc-64s-machine-check-interrupt-update-NMI-accou.patch.
- Refresh patches.suse/powerpc-64s-machine-check-do-not-trace-real-mode-han.patch.
- commit f30b04b
* Tue Sep 15 2020 tbogendoerfer@suse.de
- mlx4: disable device on shutdown (git-fixes).
- commit 878fd39
* Tue Sep 15 2020 dwagner@suse.de
- nvme-multipath: retry commands for dying queues (bsc#1171688).
- commit 50f2e12
* Tue Sep 15 2020 aaptel@suse.com
- smb3: warn on confusing error scenario with sec=krb5
  (bsc#1176548).
- commit 87d97c1
* Tue Sep 15 2020 aaptel@suse.com
- cifs: Fix leak when handling lease break for cached root fid
  (bsc#1176242).
- commit 3f36e87
* Tue Sep 15 2020 aaptel@suse.com
- SMB3: Honor 'posix' flag for multiuser mounts (bsc#1176559).
- commit da99223
* Tue Sep 15 2020 aaptel@suse.com
- SMB3: Honor 'handletimeout' flag for multiuser mounts
  (bsc#1176558).
- commit 7fc229a
* Tue Sep 15 2020 aaptel@suse.com
- SMB3: Honor persistent/resilient handle flags for multiuser
  mounts (bsc#1176546).
- Refresh
  patches.suse/SMB3-Honor-lease-disabling-for-multiuser-mounts.patch.
- commit 9b622c7
* Tue Sep 15 2020 aaptel@suse.com
- SMB3: Honor 'seal' flag for multiuser mounts (bsc#1176545).
- commit c2120ee
* Tue Sep 15 2020 aaptel@suse.com
- cifs/smb3: Fix data inconsistent when punch hole (bsc#1176544).
- commit a9ca8fc
* Tue Sep 15 2020 aaptel@suse.com
- cifs/smb3: Fix data inconsistent when zero file range
  (bsc#1176536).
- commit 92bbeda
* Tue Sep 15 2020 msuchanek@suse.de
- driver-core: Introduce DEVICE_ATTR_ADMIN_{RO,RW} (bsc#1176486
  ltc#188130).
- commit daeec95
* Tue Sep 15 2020 msuchanek@suse.de
- powerpc/papr_scm: Limit the readability of 'perf_stats' sysfs
  attribute (bsc#1176486 ltc#188130).
- commit 5a8c141
* Tue Sep 15 2020 jslaby@suse.cz
- net: initialize fastreuse on inet_inherit_port
  (networking-stable-20_08_15).
- net: refactor bind_bucket fastreuse into helper
  (networking-stable-20_08_15).
- net: Fix potential memory leak in proto_register()
  (networking-stable-20_08_15).
- net/nfc/rawsock.c: add CAP_NET_RAW check
  (networking-stable-20_08_15).
- net/tls: Fix kmap usage (networking-stable-20_08_15).
- tcp: correct read of TFO keys on big endian systems
  (networking-stable-20_08_15).
- net: Set fput_needed iff FDPUT_FPUT is set
  (networking-stable-20_08_15).
- commit 172e095
* Tue Sep 15 2020 lhenriques@suse.de
- rbd: require global CAP_SYS_ADMIN for mapping and unmapping
  (CVE-2020-25284 bsc#1176543).
- ceph: don't allow setlease on cephfs (bsc#1176537).
- ceph: handle zero-length feature mask in session messages
  (bsc#1176540).
- ceph: use frag's MDS in either mode (bsc#1176542).
- ceph: set sec_context xattr on symlink creation (bsc#1176541).
- ceph: fix use-after-free for fsc->mdsc (bsc#1176539).
- ceph: fix potential mdsc use-after-free crash (bsc#1176538).
- commit 87663ec
* Mon Sep 14 2020 tbogendoerfer@suse.de
- RDMA/bnxt_re: Remove set but not used variable 'qplib_ctx'
  (bsc#1170774).
- commit d51761b
* Mon Sep 14 2020 bp@suse.de
- blacklist.conf: 2356bb4b8221 tracing/kprobes, x86/ptrace: Fix regs argument order for i386
- commit c54f3f0
* Mon Sep 14 2020 tbogendoerfer@suse.de
- RDMA/bnxt_re: Remove the qp from list only if the qp destroy
  succeeds (bsc#1170774).
- RDMA/bnxt_re: Static NQ depth allocation (bsc#1170774).
- RDMA/mlx4: Read pkey table length instead of hardcoded value
  (git-fixes).
- commit d897d3a
* Mon Sep 14 2020 mbenes@suse.cz
- ftrace: Setup correct FTRACE_FL_REGS flags for module
  (git-fixes).
- commit b5a1bd1
* Mon Sep 14 2020 msuchanek@suse.de
- powerpc/kernel: Cleanup machine check function declarations
  (bsc#1065729).
- commit 05b1221
* Mon Sep 14 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move to sorted section:
  patches.suse/edac-ghes-setup-dimm-label-from-dmi-and-use-it-in-error-reports.patch
  patches.suse/edac-i10nm-update-driver-to-support-different-bus-number-config-register-offsets.patch
  patches.suse/edac-skx-i10nm-make-some-configurations-cpu-model-specific.patch
  patches.suse/firmware_loader-fix-memory-leak-for-paged-buffer.patch
  patches.suse/net-packet-fix-overflow-in-tpacket_rcv.patch
  patches.suse/x86-cpu-add-a-steppings-field-to-struct-x86_cpu_id.patch
  patches.suse/x86-cpu-add-table-argument-to-cpu_matches.patch
  patches.suse/x86-smpboot-remove-the-last-icpu-macro.patch
  patches.suse/x86-speculation-add-special-register-buffer-data-sampling-srbds-mitigation.patch
  patches.suse/x86-speculation-add-srbds-vulnerability-and-mitigation-documentation.patch
- move mainline backports into sorted section:
  patches.suse/revert-zram-convert-remaining-class_attr-to-class_attr_ro
  patches.suse/vgacon-fix-out-of-bounds-write-to-the-scrollback-buf.patch
  No effect on expanded tree.
- commit 0435bb2
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: reset tree root pointer after error in init_tree_roots
  (bsc#1176019).
- commit d323df2
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: rename btrfs_put_fs_root and btrfs_grab_fs_root
  (bsc#1176019).
- Refresh
  patches.suse/0001-btrfs-reloc-fix-reloc-root-leak-and-NULL-pointer-der.patch.
- Refresh
  patches.suse/0002-btrfs-reloc-clear-DEAD_RELOC_TREE-bit-for-orphan-roo.patch.
- Refresh
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch.
- commit 6d38357
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: add a leak check for roots (bsc#1176019).
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- commit 331ee79
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: make the init of static elements in fs_info separate
  (bsc#1176019).
- commit e201abc
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: move fs_info init work into it's own helper function
  (bsc#1176019).
- commit 83952d0
* Fri Sep 11 2020 fdmanana@suse.com
- btrfs: Streamline btrfs_fs_info::backup_root_index semantics
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit b8636e1
* Fri Sep 11 2020 mkubecek@suse.cz
- series.conf: fix sort
- fix order of patches in sorted section
- commit 4d61931
* Fri Sep 11 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/bitfield.h-don-t-compile-time-validate-_val-in-FIELD_FIT.patch
  patches.suse/kernel-cpu_pm-Fix-uninitted-local-in-cpu_pm.patch
  patches.suse/mm-limit-boost_watermark-on-small-zones.patch
  patches.suse/mm-page_alloc-fix-core-hung-in-free_pcppages_bulk.patch
  patches.suse/mm-page_alloc-silence-a-KASAN-false-positive.patch
  patches.suse/mm-remove-VM_BUG_ON-PageSlab-from-page_mapcount.patch
  patches.suse/mm-shuffle-don-t-move-pages-between-zones-and-don-t-read-garbage-memmaps.patch
  patches.suse/mm-sparse-rename-pfn_present-to-pfn_in_present_section.patch
  patches.suse/mm-thp-fix-defrag-setting-if-newline-is-not-used.patch
- commit 8d21545
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Rename find_oldest_super_backup to init_backup_root_slot
  (bsc#1176019).
- commit dd087e3
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Remove unused next_root_backup function (bsc#1176019).
- commit fb3bd27
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Don't use objectid_mutex during mount (bsc#1176019).
- commit c44ea8c
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Factor out tree roots initialization during mount
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-free-more-things-in-btrfs_free_fs_info.patch.
- commit 10657bc
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: use bool argument in free_root_pointers() (bsc#1176019).
- commit 743977b
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Add read_backup_root (bsc#1176019).
- commit 3f9983e
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Remove newest_gen argument from find_oldest_super_backup
  (bsc#1176019).
- commit 58cb4f5
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: Cleanup and simplify find_newest_super_backup
  (bsc#1176019).
- commit 478d905
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: add __cold attribute to more functions (bsc#1176019).
- commit 71f76ab
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: free more things in btrfs_free_fs_info (bsc#1176019).
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit b6ec803
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: push btrfs_grab_fs_root into btrfs_get_fs_root
  (bsc#1176019).
- commit a76defc
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: use btrfs_put_fs_root to free roots always (bsc#1176019).
- Refresh
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch.
- commit 41b464c
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in open_ctree (bsc#1176019).
- commit f1db66d
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: export and rename free_fs_info (bsc#1176019).
- commit 0b624c8
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_check_uuid_tree_entry
  (bsc#1176019).
- commit eca88c1
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_recover_log_trees
  (bsc#1176019).
- commit 351a260
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in create_pending_snapshot
  (bsc#1176019).
- commit 8b70b77
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in get_subvol_name_from_objectid
  (bsc#1176019).
- commit faabe37
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_ioctl_send (bsc#1176019).
- commit 9a7a7b3
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in scrub_print_warning_inode
  (bsc#1176019).
- commit 3f0e119
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref for the root in btrfs_find_orphan_roots
  (bsc#1176019).
- commit 681f58e
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: push grab_fs_root into read_fs_root (bsc#1176019).
- Refresh
  patches.suse/0001-btrfs-reloc-fix-reloc-root-leak-and-NULL-pointer-der.patch.
- Refresh
  patches.suse/0002-btrfs-reloc-clear-DEAD_RELOC_TREE-bit-for-orphan-roo.patch.
- commit 4d5675a
* Thu Sep 10 2020 ptesarik@suse.cz
- blacklist.conf: user-visible change to perf
- commit caa4d65
* Thu Sep 10 2020 ptesarik@suse.cz
- blacklist.conf: cleanup need not be backported
- commit f1a5da2
* Thu Sep 10 2020 ptesarik@suse.cz
- net/smc: put slot when connection is killed (git-fixes).
- commit 8ddc482
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_recover_relocation
  (bsc#1176019).
- commit 4544b15
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in create_reloc_inode
  (bsc#1176019).
- commit 5ad1c23
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in find_data_references
  (bsc#1176019).
- commit b847756
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in record_reloc_root_in_trans
  (bsc#1176019).
- commit ed6b331
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in merge_reloc_roots
  (bsc#1176019).
- Refresh
  patches.suse/0001-btrfs-reloc-fix-reloc-root-leak-and-NULL-pointer-der.patch.
- Refresh
  patches.suse/0002-btrfs-reloc-clear-DEAD_RELOC_TREE-bit-for-orphan-roo.patch.
- commit 6e65a90
* Thu Sep 10 2020 mgorman@suse.de
- mm, page_alloc: fix core hung in free_pcppages_bulk() (git fixes
  (mm/pgalloc)).
- bitfield.h: don't compile-time validate _val in FIELD_FIT
  (git fixes (bitfield)).
- mm/page_alloc: silence a KASAN false positive (git fixes
  (mm/pgalloc)).
- mm/shuffle: don't move pages between zones and don't read
  garbage memmaps (git fixes (mm/pgalloc)).
- kernel/cpu_pm: Fix uninitted local in cpu_pm (git fixes
  (kernel/pm)).
- mm: remove VM_BUG_ON(PageSlab()) from page_mapcount() (git fixes
  (mm/compaction)).
- mm: limit boost_watermark on small zones (git fixes
  (mm/pgalloc)).
- mm/sparse: rename pfn_present() to pfn_in_present_section()
  (git fixes (mm/pgalloc)).
- mm, thp: fix defrag setting if newline is not used (git fixes
  (mm/thp)).
- commit 72b22a6
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in prepare_to_merge (bsc#1176019).
- commit 28b372d
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in build_backref_tree
  (bsc#1176019).
- commit abebe41
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold ref on root in btrfs_ioctl_default_subvol
  (bsc#1176019).
- commit c589a9c
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_ioctl_get_subvol_info
  (bsc#1176019).
- commit 390b892
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_search_path_in_tree_user
  (bsc#1176019).
- commit bbc4f14
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in btrfs_search_path_in_tree
  (bsc#1176019).
- commit cd32183
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in search_ioctl (bsc#1176019).
- commit 8173466
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in create_subvol (bsc#1176019).
- commit 5cde960
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in fixup_tree_root_location
  (bsc#1176019).
- commit 320ca12
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in __btrfs_run_defrag_inode
  (bsc#1176019).
- commit 95a17fd
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a root ref in btrfs_get_dentry (bsc#1176019).
- commit 7aed71d
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on the root in resolve_indirect_ref
  (bsc#1176019).
- commit 628db82
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: hold a ref on fs roots while they're in the radix tree
  (bsc#1176019).
- commit 3062c74
* Thu Sep 10 2020 mgorman@suse.de
- blacklist.conf: Theoritical issues that does not apply to kernel configuration
- commit 2c26708
* Thu Sep 10 2020 mgorman@suse.de
- blacklist.conf: Build fix that is not relevant to kernel configuration
- commit 758bef3
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: handle NULL roots in btrfs_put/btrfs_grab_fs_root
  (bsc#1176019).
- commit 58d4ba4
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: make the fs root init functions static (bsc#1176019).
- commit feb2dca
* Thu Sep 10 2020 fdmanana@suse.com
- btrfs: open code btrfs_read_fs_root_no_name (bsc#1176019).
- commit ab1f957
* Thu Sep 10 2020 msuchanek@suse.de
- powerpc: Add cputime_to_nsecs() (bsc#1065729).
- commit dee0106
* Thu Sep 10 2020 mbenes@suse.cz
- livepatch: Add -fdump-ipa-clones to build (fate#323487).
  Add support for -fdump-ipa-clones GCC option.
  Update config files accordingly.
- commit 59bf95b
* Thu Sep 10 2020 ptesarik@suse.cz
- blacklist.conf: fix needed only if fake NUMA support is removed
- commit 458b58b
* Thu Sep 10 2020 ptesarik@suse.cz
- s390/dasd: fix inability to use DASD with DIAG driver
  (git-fixes).
- s390/mm: fix huge pte soft dirty copying (git-fixes).
- s390/setup: init jump labels before command line parsing
  (git-fixes).
- commit 0b57226
* Thu Sep 10 2020 ptesarik@suse.cz
- blacklist.conf: s390: PAGE_DEFAULT_KEY is always zero
- commit 047e63e
* Wed Sep  9 2020 jroedel@suse.de
- iommu/vt-d: Handle non-page aligned address (bsc#1176367).
- commit 8f4c091
* Wed Sep  9 2020 jroedel@suse.de
- blacklist.conf: Add de2b41be8fcc x86, vmlinux.lds: Page-align end of ..page_aligned sections
- commit 0f6cfca
* Wed Sep  9 2020 jroedel@suse.de
- iommu/vt-d: Handle 36bit addressing for x86-32 (bsc#1176362).
- iommu/amd: Do not use IOMMUv2 functionality when SME is active
  (bsc#1174358).
- iommu/amd: Do not force direct mapping when SME is active
  (bsc#1174358).
- iommu/amd: Use cmpxchg_double() when updating 128-bit IRTE
  (bsc#1176359).
- iommu/amd: Restore IRTE.RemapEn bit after programming IRTE
  (bsc#1176358).
- iommu/vt-d: Serialize IOMMU GCMD register modifications
  (bsc#1176364).
- vfio-pci: Avoid recursive read-lock usage (bsc#1176366).
- iommu/amd: Print extended features in one line to fix divergent
  log levels (bsc#1176357).
- iommu/vt-d: Fix PASID devTLB invalidation (bsc#1176361).
- iommu/vt-d: Remove global page support in devTLB flush
  (bsc#1176363).
- iommu/omap: Check for failure of a call to omap_iommu_dump_ctx
  (bsc#1176360).
- iommu/vt-d: Support flushing more translation cache types
  (bsc#1176365).
- commit d9d3306
* Wed Sep  9 2020 mkubecek@suse.cz
- refresh config files
- commit 09c22d1
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: remove btrfs_read_fs_root, not used anymore
  (bsc#1176019).
- commit 27b7c0e
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: make relocation use btrfs_read_tree_root() (bsc#1176019).
- commit 83c5766
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: export and use btrfs_read_tree_root for tree-log
  (bsc#1176019).
- commit c457d40
* Wed Sep  9 2020 mkubecek@suse.cz
- fix patch metadata
- change from "queued" to "never":
  patches.suse/0001-xen-don-t-reschedule-in-preemption-off-sections.patch
- commit 9a83f52
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: make btrfs_find_orphan_roots use btrfs_get_fs_root
  (bsc#1176019).
- commit 348b1af
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: move fs root init stuff into btrfs_init_fs_root
  (bsc#1176019).
- commit cb580c0
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: push __setup_root into btrfs_alloc_root (bsc#1176019).
- commit 062eab0
* Wed Sep  9 2020 mkubecek@suse.cz
- series.conf: cleanup
- move to sorted section:
  patches.suse/x86-asm-64-Align-start-of-__clear_user-loop-to-16-by.patch
- commit 3cee501
* Wed Sep  9 2020 fdmanana@suse.com
- btrfs: drop create parameter to btrfs_get_extent()
  (bsc#1176019).
- commit 051d33b
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/64: mark emergency stacks valid to unwind (bsc#1156395).
- commit cf61a29
* Wed Sep  9 2020 mbenes@suse.cz
- blacklist.conf: 318af7b80b6a ("Revert "kbuild: use -flive-patching when CONFIG_LIVEPATCH is enabled"")
  Contrary to the upstream we'll support the original patch, since it
  makes things easier for us as of now.
- commit 5f31678
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/traps: Make unrecoverable NMIs die instead of panic
  (bsc#1094244 ltc#168122).
- powerpc/traps: Do not trace system reset (bsc#1094244
  ltc#168122).
- powerpc/64s: machine check do not trace real-mode handler
  (bsc#1094244 ltc#168122).
- powerpc: Implement ftrace_enabled() helpers (bsc#1094244
  ltc#168122).
- powerpc/64s: machine check interrupt update NMI accounting
  (bsc#1094244 ltc#168122).
- powerpc/pseries: Machine check use rtas_call_unlocked() with
  args on stack (bsc#1094244 ltc#168122).
- powerpc/pseries: Limit machine check stack to 4GB (bsc#1094244
  ltc#168122).
- powerpc/pseries/ras: fwnmi sreset should not interlock
  (bsc#1094244 ltc#168122).
- powerpc/pseries/ras: fwnmi avoid modifying r3 in error case
  (bsc#1094244 ltc#168122).
- powerpc/pseries/ras: Fix FWNMI_VALID off by one (bsc#1094244
  ltc#168122).
- powerpc/pseries/ras: Avoid calling rtas_token() in NMI paths
  (bsc#1094244 ltc#168122).
- commit a8046af
* Wed Sep  9 2020 ptesarik@suse.cz
- scsi: zfcp: Fix use-after-free in request timeout handlers
  (git-fixes).
- commit afdea91
* Wed Sep  9 2020 ptesarik@suse.cz
- blacklist.conf: zfcp comment fix
- commit 063b5f1
* Wed Sep  9 2020 colyli@suse.de
- blacklist.conf: add cafe01ef8fcb248583038e1be071383530fe355a
- commit 5a7e3c7
* Wed Sep  9 2020 colyli@suse.de
- dm: don't call report zones for more than the user requested
  (git fixes (block drivers)).
- dm rq: don't call blk_mq_queue_stopped() in dm_stop_queue()
  (git fixes (block drivers)).
- md: raid0/linear: fix dereference before null check on pointer
  mddev (git fixes (block drivers)).
- sbitmap: Consider cleared bits in sbitmap_bitmap_show()
  (git fixes (block drivers)).
- blktrace: fix debugfs use after free (git fixes (block
  drivers)).
- block: revert back to synchronous request_queue removal (git
  fixes (block drivers)).
- block: add docs for gendisk / request_queue refcount helpers
  (git fixes (block drivers)).
- dm integrity: fix integrity recalculation that is improperly
  skipped (git fixes (block drivers)).
- virtio-blk: free vblk-vqs in error path of virtblk_probe()
  (git fixes (block drivers)).
- dm writecache: add cond_resched to loop in
  persistent_memory_claim() (git fixes (block drivers)).
- dm writecache: correct uncommitted_block when discarding
  uncommitted entry (git fixes (block drivers)).
- dm zoned: assign max_io_len correctly (git fixes (block
  drivers)).
- bcache: Convert pr_<level> uses to a more typical style (git
  fixes (block drivers)).
- commit 35db4b2
* Wed Sep  9 2020 colyli@suse.de
- blacklist.conf: add 7bf137298cb73afdb8c5536e474f7ba71ab1c235
- commit cdf662f
* Wed Sep  9 2020 dwagner@suse.de
- scsi: lpfc: Fix setting IRQ affinity with an empty CPU mask
  (git-fixes).
- scsi: qla2xxx: Fix regression on sparc64 (git-fixes).
- commit b922436
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/xmon: Use `dcbf` inplace of `dcbi` instruction for
  64bit Book3S (bsc#1065729).
- commit 9cbba57
* Wed Sep  9 2020 dwagner@suse.de
- scsi: libfc: Fix for double free() (bsc#1174899).
- commit 941605d
* Wed Sep  9 2020 msuchanek@suse.de
- powerpc/book3s64/radix: Add kernel command line option
  to disable radix GTSE (bsc#1055186 ltc#153436 FATE#323286
  jsc#SLE-13512).
- powerpc/mm/radix: Create separate mappings for hot-plugged
  memory (bsc#1055186 ltc#153436 FATE#323286).
- powerpc/mm/radix: Remove split_kernel_mapping() (bsc#1055186
  ltc#153436 FATE#323286).
- powerpc/mm/radix: Free PUD table when freeing pagetable
  (bsc#1055186 ltc#153436 FATE#323286).
- powerpc/mm/radix: Fix PTE/PMD fragment count for early page
  table mappings (bsc#1055186 ltc#153436 FATE#323286).
- powerpc/prom: Enable Radix GTSE in cpu pa-features (bsc#1055186
  ltc#153436 FATE#323286 jsc#SLE-13512).
- powerpc/mm: Enable radix GTSE only if supported (bsc#1055186
  ltc#153436 FATE#323286 jsc#SLE-13512).
- commit d06aeea
* Wed Sep  9 2020 msuchanek@suse.de
- Refresh patches.suse/nvdimm-Avoid-race-between-probe-and-reading-device-a.patch
  Update submit URL to v2
- commit f6fe239
* Tue Sep  8 2020 ptesarik@suse.cz
- crypto: ecc - SP800-56A rev 3 local public key validation
  (bsc#1175718).
- crypto: dh - SP800-56A rev 3 local public key validation
  (bsc#1175718).
- crypto: dh - check validity of Z before export (bsc#1175718).
- lib/mpi: Add mpi_sub_ui() (bsc#1175718).
- crypto: ecdh - check validity of Z before export (bsc#1175718).
- commit 1b908a3
* Tue Sep  8 2020 dwagner@suse.de
- nvme-fc: set max_segments to lldd max value (bsc#1176038).
- commit d7e9e95
* Tue Sep  8 2020 ptesarik@suse.cz
- s390/qeth: don't process empty bridge port events (git-fixes).
- s390/qeth: integrate RX refill worker with NAPI (git-fixes).
- s390/qeth: tolerate pre-filled RX buffer (git-fixes).
- commit 0d5daa2
* Tue Sep  8 2020 mbenes@suse.cz
- rpm/kernel-binary.spec.in: pack .ipa-clones files for live patching
  When -fdump-ipa-clones option is enabled, GCC reports about its cloning
  operation during IPA optimizations. We use the information for live
  patches preparation, because it is crucial to know if and how functions
  are optimized.
  Currently, we create the needed .ipa-clones dump files manually. It is
  unnecessary, because the files may be created automatically during our
  kernel build. Prepare for the step and provide the resulting files in
  - livepatch-devel package.
- commit 98e5a9d
* Tue Sep  8 2020 dwagner@suse.de
- s390: fix GENERIC_LOCKBREAK dependency typo in Kconfig
  (git-fixes).
- x86/hotplug: Silence APIC only after all interrupts are migrated
  (git-fixes).
- test_kmod: avoid potential double free in
  trigger_config_run_type() (git-fixes).
- initramfs: remove clean_rootfs (git-fixes).
- initramfs: remove the populate_initrd_image and clean_rootfs
  stubs (git-fixes).
- scsi: lpfc: Add dependency on CPU_FREQ (git-fixes).
- block: Use non _rcu version of list functions for tag_set_list
  (git-fixes).
- scsi: qla2xxx: Suppress two recently introduced compiler
  warnings (git-fixes).
- commit de8f3c2
* Tue Sep  8 2020 dwagner@suse.de
- blacklist.conf: Add documenation fixes and kabi breaker
- commit dba74e9
* Tue Sep  8 2020 tbogendoerfer@suse.de
- tg3: Fix soft lockup when tg3_reset_task() fails (git-fixes).
- cxgb4: fix thermal zone device registration (git-fixes).
- bnxt: don't enable NAPI until rings are ready (git-fixes).
- taprio: Fix using wrong queues in gate mask (bsc#1154353).
- bnxt_en: fix HWRM error when querying VF temperature
  (git-fixes).
- bnxt_en: Fix possible crash in bnxt_fw_reset_task()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix PCI AER error recovery flow (git-fixes).
- bnxt_en: Check for zero dir entries in NVRAM (git-fixes).
- bnxt_en: Don't query FW when netif_running() is false
  (git-fixes).
- bonding: fix a potential double-unregister (git-fixes).
- i40e: Fix crash during removing i40e driver (git-fixes).
- i40e: Set RX_ONLY mode for unicast promiscuous on VLAN
  (git-fixes).
- commit 4d82728
* Tue Sep  8 2020 jslaby@suse.cz
- selftests/net: relax cpu affinity requirement in msg_zerocopy
  test (networking-stable-20_08_08).
- dpaa2-eth: Fix passing zero to 'PTR_ERR' warning
  (networking-stable-20_08_08).
- net: thunderx: use spin_lock_bh in nicvf_set_rx_mode_task()
  (networking-stable-20_08_08).
- tcp: apply a floor of 1 for RTT samples from TCP timestamps
  (networking-stable-20_08_08).
- net: gre: recompute gre csum for sctp over gre tunnels
  (networking-stable-20_08_08).
- openvswitch: Prevent kernel-infoleak in ovs_ct_put_key()
  (networking-stable-20_08_08).
- net: ethernet: mtk_eth_soc: fix MTU warnings
  (networking-stable-20_08_08).
- rxrpc: Fix race between recvmsg and sendmsg on immediate call
  failure (networking-stable-20_08_08).
- ipv6: fix memory leaks on IPV6_ADDRFORM path
  (networking-stable-20_08_08).
- ipv4: Silence suspicious RCU usage warning
  (networking-stable-20_08_08).
- vxlan: Ensure FDB dump is performed under RCU
  (networking-stable-20_08_08).
- ipv6: Fix nexthop refcnt leak when creating ipv6 route info
  (networking-stable-20_08_08).
- commit a270aeb
* Tue Sep  8 2020 jslaby@suse.cz
- dev: Defer free of skbs in flush_backlog
  (networking-stable-20_07_29).
- qrtr: orphan socket in qrtr_release()
  (networking-stable-20_07_29).
- bonding: check return value of register_netdevice() in
  bond_newlink() (networking-stable-20_07_29).
- sctp: shrink stream outq when fails to do addstream reconf
  (networking-stable-20_07_29).
- sctp: shrink stream outq only when new outcnt < old outcnt
  (networking-stable-20_07_29).
- enetc: Remove the mdio bus on PF probe bailout
  (networking-stable-20_07_29).
- drivers/net/wan/x25_asy: Fix to make it work
  (networking-stable-20_07_29).
- net: dsa: microchip: call phy_remove_link_mode during probe
  (networking-stable-20_07_29).
- kABI: net: dsa: microchip: call phy_remove_link_mode during
  probe (kabi).
- net: udp: Fix wrong clean up for IS_UDPLITE macro
  (networking-stable-20_07_29).
- net-sysfs: add a newline when printing 'tx_timeout' by sysfs
  (networking-stable-20_07_29).
- mlxsw: destroy workqueue when trap_register in mlxsw_emad_init
  (networking-stable-20_07_29).
- rxrpc: Fix sendmsg() returning EPIPE due to recvmsg() returning
  ENODATA (networking-stable-20_07_29).
- bonding: check error value of register_netdevice() immediately
  (networking-stable-20_07_29).
- net: dp83640: fix SIOCSHWTSTAMP to update the struct with
  actual configuration (networking-stable-20_07_29).
- vsock/virtio: annotate 'the_virtio_vsock' RCU pointer
  (networking-stable-20_07_29).
- bnxt_en: Fix completion ring sizing with TPA enabled
  (networking-stable-20_07_29).
- bnxt_en: Fix race when modifying pause settings
  (networking-stable-20_07_29).
- commit 15b35e2
* Tue Sep  8 2020 bp@suse.de
- EDAC: Fix reference count leaks (bsc#1152489).
- commit 3f4ad8e
* Mon Sep  7 2020 bp@suse.de
- x86/mce/inject: Fix a wrong assignment of i_mce.status
  (bsc#1152489).
- commit 64f04e6
* Mon Sep  7 2020 bp@suse.de
- blacklist.conf: 2accfa69050c cpu/speculation: Add prototype for cpu_show_srbds()
- commit 12941df
* Mon Sep  7 2020 dwagner@suse.de
- scsi: libfc: Free skb in fc_disc_gpn_id_resp() for valid cases
  (bsc#1174899).
- scsi: fcoe: Memory leak fix in fcoe_sysfs_fcf_del()
  (bsc#1174899).
- commit f5d1493
* Mon Sep  7 2020 dwagner@suse.de
- series.conf: Update meta-data
  and corresponding patches
- commit 397e951
* Mon Sep  7 2020 bp@suse.de
- Refresh
  patches.suse/x86-asm-64-Align-start-of-__clear_user-loop-to-16-by.patch.
- commit e3c9d3b
* Mon Sep  7 2020 bp@suse.de
- blacklist.conf: cc5277fe66cf x86/resctrl: Fix a NULL vs IS_ERR() static checker warning in rdt_cdp_peer_get()
- commit 67c6df6
* Mon Sep  7 2020 bp@suse.de
- blacklist.conf: 2c18bd525c47 x86/resctrl: Fix memory bandwidth counter width for AMD
  Fix moved to SP3, see bsc#1172757
- commit bacb8af
* Mon Sep  7 2020 jroedel@suse.de
- epoll: call final ep_events_available() check under the lock
  (bsc#1176237).
- epoll: atomically remove wait entry on wake up (bsc#1176236).
- commit 86b758b
* Mon Sep  7 2020 msuchanek@suse.de
- rpm/kernel-source.spec.in: Also use bz compression (boo#1175882).
- commit 375ec84
* Mon Sep  7 2020 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also sign ppc64 kernels (jsc#SLE-15857
  jsc#SLE-13618).
- commit 971fc3d
* Mon Sep  7 2020 bp@suse.de
- EDAC/amd64: Read back the scrub rate PCI register on F15h
  (bsc#1152489).
- commit dae70cc
* Mon Sep  7 2020 bp@suse.de
- EDAC/amd64: Add AMD family 17h model 60h PCI IDs (bsc#1152489).
- commit 059d4f2
* Mon Sep  7 2020 jgross@suse.com
- XEN uses irqdesc::irq_data_common::handler_data to store a
  per interrupt XEN data pointer which contains XEN specific
  information (bsc#1065600).
- commit b863d57
* Mon Sep  7 2020 jgross@suse.com
- xen: don't reschedule in preemption off sections (bsc#1175749).
- commit 2a68c8d
* Mon Sep  7 2020 tiwai@suse.de
- include/asm-generic/vmlinux.lds.h: align ro_after_init
  (git-fixes).
- include/linux/poison.h: remove obsolete comment (git-fixes).
- include/linux/bitops.h: avoid clang shift-count-overflow
  warnings (git-fixes).
- thermal: qcom-spmi-temp-alarm: Don't suppress negative temp
  (git-fixes).
- thermal: ti-soc-thermal: Fix bogus thermal shutdowns for
  omap4430 (git-fixes).
- dmaengine: dw-edma: Fix scatter-gather address calculation
  (git-fixes).
- dmaengine: pl330: Fix burst length if burst size is smaller
  than bus width (git-fixes).
- dmaengine: at_hdmac: check return value of
  of_find_device_by_node() in at_dma_xlate() (git-fixes).
- dmaengine: of-dma: Fix of_dma_router_xlate's of_dma_xlate
  handling (git-fixes).
- drm/radeon: Prefer lower feedback dividers (git-fixes).
- batman-adv: bla: use netif_rx_ni when not in interrupt context
  (git-fixes).
- batman-adv: Fix own OGM check in aggregated OGMs (git-fixes).
- batman-adv: Avoid uninitialized chaddr when handling DHCP
  (git-fixes).
- media: cedrus: Add missing v4l2_ctrl_request_hdl_put()
  (git-fixes).
- HID: core: Sanitize event code and type when mapping input
  (git-fixes).
- HID: core: Correctly handle ReportSize being zero (git-fixes).
- usb: storage: Add unusual_uas entry for Sony PSZ drives
  (git-fixes).
- USB: gadget: u_f: Unbreak offset calculation in VLAs
  (git-fixes).
- USB: gadget: f_ncm: add bounds checks to ncm_unwrap_ntb()
  (git-fixes).
- USB: gadget: u_f: add overflow checks to VLA macros (git-fixes).
- xhci: Do warm-reset when both CAS and XDEV_RESUME are set
  (git-fixes).
- usb: uas: Add quirk for PNY Pro Elite (git-fixes).
- USB: lvtest: return proper error code in probe (git-fixes).
- USB: quirks: Add no-lpm quirk for another Raydium touchscreen
  (git-fixes).
- USB: yurex: Fix bad gfp argument (git-fixes).
- drm/amdgpu: Fix buffer overflow in INFO ioctl (git-fixes).
- drm/amd/pm: correct the thermal alert temperature limit settings
  (git-fixes).
- drm/amdgpu/gfx10: refine mgcg setting (git-fixes).
- drm/amd/pm: correct Vega20 swctf limit setting (git-fixes).
- drm/amd/pm: correct Vega12 swctf limit setting (git-fixes).
- drm/amd/pm: correct Vega10 swctf limit setting (git-fixes).
- fbcon: prevent user font height or width change from causing
  potential out-of-bounds access (git-fixes).
- vt: defer kfree() of vc_screenbuf in vc_do_resize() (git-fixes).
- HID: hiddev: Fix slab-out-of-bounds write in
  hiddev_ioctl_usage() (git-fixes).
- HID: i2c-hid: Always sleep 60ms after I2C_HID_PWR_ON commands
  (git-fixes).
- drm/amd/display: Switch to immediate mode for updating
  infopackets (git-fixes).
- drm/amd/powerplay: correct UVD/VCE PG state on custom pptable
  uploading (git-fixes).
- drm/amd/powerplay: correct Vega20 cached smu feature state
  (git-fixes).
- spi: stm32: always perform registers configuration prior to
  transfer (git-fixes).
- spi: stm32: fix stm32_spi_prepare_mbr in case of odd clk_rate
  (git-fixes).
- spi: stm32: fix fifo threshold level in case of short transfer
  (git-fixes).
- spi: stm32h7: fix race condition at end of transfer (git-fixes).
- spi: stm32: clear only asserted irq flags on interrupt
  (git-fixes).
- mfd: intel-lpss: Add Intel Emmitsburg PCH PCI IDs (git-fixes).
- fbmem: pull fbcon_update_vcs() out of fb_set_var() (git-fixes).
- HID: quirks: add NOGET quirk for Logitech GROUP (git-fixes).
- PCI: Fix pci_create_slot() reference count leak (git-fixes).
- media: davinci: vpif_capture: fix potential double free
  (git-fixes).
- media: pci: ttpci: av7110: fix possible buffer overflow caused
  by bad DMA value in debiirq() (git-fixes).
- ASoC: tegra: Fix reference count leaks (git-fixes).
- ASoC: img-parallel-out: Fix a reference count leak (git-fixes).
- ASoC: img: Fix a reference count leak in img_i2s_in_set_fmt
  (git-fixes).
- rtlwifi: rtl8192cu: Prevent leaking urb (git-fixes).
- drm/nouveau: Fix reference count leak in
  nouveau_connector_detect (git-fixes).
- drm/nouveau: fix reference count leak in nv50_disp_atomic_commit
  (git-fixes).
- drm/nouveau/drm/noveau: fix reference count leak in
  nouveau_fbcon_open (git-fixes).
- omapfb: fix multiple reference count leaks due to
  pm_runtime_get_sync (git-fixes).
- drm/amdgpu/display: fix ref count leak when pm_runtime_get_sync
  fails (git-fixes).
- drm/amdgpu: fix ref count leak in amdgpu_display_crtc_set_config
  (git-fixes).
- drm/amd/display: fix ref count leak in amdgpu_drm_ioctl
  (git-fixes).
- drm/amdgpu: fix ref count leak in amdgpu_driver_open_kms
  (git-fixes).
- drm/radeon: fix multiple reference count leak (git-fixes).
- drm/amdkfd: Fix reference count leaks (git-fixes).
- USB: sisusbvga: Fix a potential UB casued by left shifting a
  negative value (git-fixes).
- media: gpio-ir-tx: improve precision of transmitted signal
  due to scheduling (git-fixes).
- drm/sched:  Fix passing zero to 'PTR_ERR' warning v2
  (git-fixes).
- commit aa50939
* Mon Sep  7 2020 shung-hsi.yu@suse.com
- net: ethernet: mlx4: Fix memory allocation in mlx4_buddy_init()
  (git-fixes).
- commit 4a76c88
* Sun Sep  6 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/ibmvnic-fix-NULL-tx_pools-and-rx_tools-issue-at-do_r.patch
- commit 8ff6392
* Sun Sep  6 2020 tiwai@suse.de
- ALSA: hda/realtek - Improved routing for Thinkpad X1 7th/8th
  Gen (git-fixes).
- ALSA: hda: fix a runtime pm issue in SOF when integrated GPU
  is disabled (git-fixes).
- ALSA: hda: hdmi - add Rocketlake support (git-fixes).
- ALSA: pcm: oss: Remove superfluous WARN_ON() for mulaw sanity
  check (git-fixes).
- ALSA: hda - Fix silent audio output and corrupted input on
  MSI X570-A PRO (git-fixes).
- ALSA: hda/hdmi: always check pin power status in i915 pin fixup
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Book Ion
  NT950XCJ-X716A (git-fixes).
- ALSA: usb-audio: Add basic capture support for Pioneer DJ
  DJM-250MK2 (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for UR22C
  (git-fixes).
- Revert "ALSA: hda: Add support for Loongson 7A1000 controller"
  (git-fixes).
- ALSA: hda/tegra: Program WAKEEN register for Tegra (git-fixes).
- ALSA: hda: Fix 2 channel swapping for Tegra (git-fixes).
- ALSA: ca0106: fix error code handling (git-fixes).
- ALSA: usb-audio: Disable autosuspend for Lenovo ThinkStation
  P620 (git-fixes).
- ALSA: firewire-digi00x: exclude Avid Adrenaline from detection
  (git-fixes).
- ALSA; firewire-tascam: exclude Tascam FE-8 from detection
  (git-fixes).
- ASoC: SOF: Intel: add PCI ID for CometLake-S (git-fixes).
- commit 56f2f52
* Fri Sep  4 2020 mkubecek@suse.cz
- net/packet: fix overflow in tpacket_rcv (CVE-2020-14386
  bsc#1176069).
- commit b3a3711
* Thu Sep  3 2020 ailiop@suse.com
- xfs: fix boundary test in xfs_attr_shortform_verify
  (CVE-2020-14385 bsc#1176137).
- commit e45cbdb
* Thu Sep  3 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/sched-Add-a-tracepoint-to-track-rq-nr_running.patch
  patches.suse/sched-Better-document-ttwu.patch
  patches.suse/sched-Fix-use-of-count-for-nr_running-tracepoint.patch
  patches.suse/sched-cputime-Improve-cputime_adjust.patch
  patches.suse/sched-debug-Add-new-tracepoints-to-track-util_est.patch
  patches.suse/sched-debug-Fix-the-alignment-of-the-show-state-debug-output.patch
  patches.suse/sched-fair-Remove-unused-sd-parameter-from-scale_rt_capacity.patch
  patches.suse/sched-fair-update_pick_idlest-Select-group-with-lowest-group_util-when-idle_cpus-are-equal.patch
  patches.suse/sched-nohz-stop-passing-around-unused-ticks-parameter.patch
  patches.suse/sched-pelt-Remove-redundant-cap_scale-definition.patch
- commit 1ab5af9
* Thu Sep  3 2020 pmladek@suse.com
- blacklist.conf: dma-debug: speed up debug code that is disabled in SUSE kernels
- commit aa33a0d
* Thu Sep  3 2020 pmladek@suse.com
- blacklist.conf: kstrto*: comment fix
- commit 26002cd
* Thu Sep  3 2020 pmladek@suse.com
- blacklist.conf: kthread: comment fix
- commit 7fd20f3
* Thu Sep  3 2020 vliaskovitis@suse.com
- mei: me: disable mei interface on Mehlow server platforms
  (bsc#1175952).
- commit a2053ac
* Thu Sep  3 2020 vliaskovitis@suse.com
- mei: fix CNL itouch device number to match the spec
  (bsc#1175952).
- commit a4a5282
* Thu Sep  3 2020 vliaskovitis@suse.com
- mei: me: disable mei interface on LBG servers (bsc#1175952).
- commit e28fa12
* Thu Sep  3 2020 mgorman@suse.de
- sched/debug: Fix the alignment of the show-state debug output
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched: Fix use of count for nr_running tracepoint (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: update_pick_idlest() Select group with lowest
  group_util when idle_cpus are equal (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched: nohz: stop passing around unused "ticks" parameter
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched: Better document ttwu() (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched: Add a tracepoint to track rq->nr_running (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/debug: Add new tracepoints to track util_est (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Remove unused 'sd' parameter from
  scale_rt_capacity() (bnc#1155798 (CPU scheduler functional
  and performance backports)).
- sched/pelt: Remove redundant cap_scale() definition (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/cputime: Improve cputime_adjust() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit 7ea4247
* Thu Sep  3 2020 wqu@suse.com
- Update
  patches.suse/btrfs-Move-free_pages_out-label-in-inline-extent-han.patch
  (bsc#1174484).
  Fix wrong bsc reference number exposed by Filipe:
  https://bugzilla.suse.com/show_bug.cgi?id=1175263#c1
- commit 8c0ade9
* Wed Sep  2 2020 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 12.8.0.3 (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Fix LUN loss after cable pull (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Fix validation of bsg reply lengths (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Fix retry of PRLI when status indicates its
  unsupported (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix oops when unloading driver while running
  mds diags (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix RSCN timeout due to incorrect gidft counter
  (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000
  jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix no message shown for lpfc_hdw_queue out of
  range value (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix FCoE speed reporting (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Add missing misc_deregister() for lpfc_init()
  (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000
  jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: nvmet: Avoid hang / use-after-free again when
  destroying targetport (bsc#1171558 bsc#1136666 bsc#1174486
  bsc#1175787 bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix typo in comment for ULP (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Add description for lpfc_release_rpi()'s 'ndlpl
  param (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix a bunch of kerneldoc misdemeanors (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Add and rename a whole bunch of function parameter
  descriptions (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Use __printf() format notation (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Fix kerneldoc parameter formatting/misnaming/missing
  issues (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix some function parameter descriptions
  (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000
  jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Ensure variable has the same stipulations as code
  using it (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix-up formatting/docrot where appropriate
  (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000
  jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Provide description for lpfc_mem_alloc()'s
  'align' param (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787
  bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: Fix-up around 120 documentation issues (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Remove unused variable 'pg_addr' (bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Correct some pretty obvious misdocumentation
  (bsc#1171558 bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000
  jsc#SLE-15796 jsc#SLE-15449).
- scsi: lpfc: NVMe remote port devloss_tmo from lldd (bcs#1173060 bsc#1171558
  bsc#1136666 bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
  Replace patches.suse/lpfc-synchronize-nvme-transport-and-lpfc-driver-devloss_tmo.patch
  with upstream version of the fix.
- scsi: lpfc: Quieten some printks (bsc#1171558 bsc#1136666
  bsc#1174486 bsc#1175787 bsc#1171000 jsc#SLE-15796
  jsc#SLE-15449).
- scsi: lpfc: Avoid another null dereference in
  lpfc_sli4_hba_unset() (bsc#1171558 bsc#1136666 bsc#1174486
  bsc#1175787 bsc#1171000 jsc#SLE-15796 jsc#SLE-15449).
- commit b565a9f
* Wed Sep  2 2020 yousaf.kaukab@suse.com
- kabi/severities: ignore kABI for net/ethernet/mscc/
  References: bsc#1176001,bsc#1175999
  Exported symbols from drivers/net/ethernet/mscc/ are
  only used by drivers/net/dsa/ocelot/
- commit 16c1e85
* Wed Sep  2 2020 jack@suse.cz
- ext4: handle read only external journal device (bsc#1176063).
- commit 06e42e2
* Wed Sep  2 2020 dwagner@suse.de
- Update patches.suse/firmware-smccc-drop-smccc_version-enum-and-use-arm_smccc_version_1_x-instead.patch
  By the time the backport happened the file of SMCCC v1.2
  'arm64/kernel/paravirt.c' didn't exist.  It was introduced later on
  with 94bebd30479. Add missing hunk to fix compile breaks on aarch64.
- commit 3d16a74
* Tue Sep  1 2020 msuchanek@suse.de
- powerpc/book3s64/radix: Fix boot failure with large amount of
  guest memory (bsc#1176022 ltc#187208).
- commit 8bb9577
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: rename btrfs_block_group_cache (bsc#1176019).
- Refresh
  patches.suse/btrfs-scrub-Don-t-check-free-space-before-marking-a-.patch.
- commit 1e82a09
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: use btrfs_block_group_cache_done in update_block_group
  (bsc#1176019).
- Update
  patches.suse/btrfs-add-dedicated-members-for-start-and-length-of-.patch
  (bsc#1176019).
- commit 9bd7aef
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: block-group: Reuse the item key from caller of
  read_one_block_group() (bsc#1176019).
- commit a94961e
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: block-group: Refactor btrfs_read_block_groups()
  (bsc#1176019).
- commit 29102c4
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: add dedicated members for start and length of a block
  group (bsc#1176019).
- Refresh
  patches.suse/0001-btrfs-scrub-Require-mandatory-block-group-RO-for-dev.patch.
- Refresh
  patches.suse/0002-btrfs-kill-min_allocable_bytes-in-inc_block_group_ro.patch.
- Refresh
  patches.suse/0002-btrfs-take-overcommit-into-account-in-inc_block_grou.patch.
- Refresh
  patches.suse/Btrfs-fix-block-group-remaining-RO-forever-after-err.patch.
- Refresh
  patches.suse/btrfs-fix-a-block-group-ref-counter-leak-after-failu.patch.
- Refresh
  patches.suse/btrfs-fix-race-between-block-group-removal-and-block.patch.
- commit 1e9fcdd
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: rename extent buffer block group item accessors
  (bsc#1176019).
- commit 8b22e32
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: rename block_group_item on-stack accessors to follow
  naming (bsc#1176019).
- commit 93bdcbc
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: remove embedded block_group_cache::item (bsc#1176019).
- commit 667dac6
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: move block_group_item::flags to block group
  (bsc#1176019).
- commit 6f39840
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: move block_group_item::used to block group (bsc#1176019).
- Refresh
  patches.suse/0002-btrfs-take-overcommit-into-account-in-inc_block_grou.patch.
- commit 225cb14
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: drop unused parameter is_new from btrfs_iget
  (bsc#1176019).
- commit 3fe9dc3
* Tue Sep  1 2020 fdmanana@suse.com
- btrfs: stop clearing EXTENT_DIRTY in inode I/O tree
  (bsc#1176019).
- Refresh
  patches.suse/btrfs-qgroup-fix-data-leak-caused-by-race-between-wr.patch.
- commit 8d60367
* Tue Sep  1 2020 tiwai@suse.de
- sdhci: tegra: Add missing TMCLK for data timeout (git-fixes).
- sdhci: tegra: Remove SDHCI_QUIRK_DATA_TIMEOUT_USES_SDCLK for
  Tegra186 (git-fixes).
- sdhci: tegra: Remove SDHCI_QUIRK_DATA_TIMEOUT_USES_SDCLK for
  Tegra210 (git-fixes).
- mmc: mediatek: add optional module reset property (git-fixes).
- mmc: dt-bindings: Add resets/reset-names for Mediatek MMC
  bindings (git-fixes).
- mmc: sdhci-acpi: Fix HS400 tuning for AMDI0040 (git-fixes).
- commit c4a6eec
* Tue Sep  1 2020 yousaf.kaukab@suse.com
- dpaa_eth: Fix one possible memleak in dpaa_eth_probe
  (bsc#1175996).
- net: dsa: felix: send VLANs on CPU port as egress-tagged
  (bsc#1175998).
- felix: Fix initialization of ioremap resources (bsc#1175997).
- net: dsa: ocelot: the MAC table on Felix is twice as large
  (bsc#1175999).
- net: enetc: fix an issue about leak system resources
  (bsc#1176000).
- net: mscc: ocelot: fix untagged packet drops when enslaving
  to vlan aware bridge (bsc#1176001).
- commit 6defddf
* Tue Sep  1 2020 yousaf.kaukab@suse.com
- blacklist.conf: arm64: add coresight fixes
  Coresight is not enabled in SLE15-SP2
- commit 973814d
* Mon Aug 31 2020 msuchanek@suse.de
- char: virtio: Select VIRTIO from VIRTIO_CONSOLE (bsc#1175667).
- commit 254a9e5
* Mon Aug 31 2020 msuchanek@suse.de
- Set VIRTIO_CONSOLE=y (bsc#1175667).
- commit 73ac49e
* Mon Aug 31 2020 tiwai@suse.de
- i2c: rcar: in slave mode, clear NACK earlier (git-fixes).
- i2c: core: Don't fail PRP0001 enumeration when no ID table exist
  (git-fixes).
- device property: Fix the secondary firmware node handling in
  set_primary_fwnode() (git-fixes).
- drm/amd/powerplay: Fix hardmins not being sent to SMU for RV
  (git-fixes).
- drm/msm/a6xx: fix crashdec section name typo (git-fixes).
- drm/msm/gpu: make ringbuffer readonly (git-fixes).
- drm/msm/adreno: fix updating ring fence (git-fixes).
- commit 861fb8e
* Mon Aug 31 2020 tiwai@suse.de
- PCI: Mark AMD Navi10 GPU rev 0x00 ATS as broken (git-fixes).
- PCI: Add device even if driver attach failed (git-fixes).
- PCI: Avoid Pericom USB controller OHCI/EHCI PME# defect
  (git-fixes).
- commit 0174122
* Mon Aug 31 2020 tiwai@suse.de
- PM: sleep: core: Fix the handling of pending runtime resume
  requests (git-fixes).
- commit 0dfcb13
* Mon Aug 31 2020 tiwai@suse.de
- regulator: fix memory leak on error path of regulator_register()
  (git-fixes).
- commit 924cca3
* Mon Aug 31 2020 tiwai@suse.de
- USB: Ignore UAS for JMicron JMS567 ATA/ATAPI Bridge (git-fixes).
- usb: host: ohci-exynos: Fix error handling in
  exynos_ohci_probe() (git-fixes).
- USB: quirks: Ignore duplicate endpoint on Sound Devices MixPre-D
  (git-fixes).
- xhci: Always restore EP_SOFT_CLEAR_TOGGLE even if ep reset
  failed (git-fixes).
- usb: host: xhci: fix ep context print mismatch in debugfs
  (git-fixes).
- usb: gadget: f_tcm: Fix some resource leaks in some error paths
  (git-fixes).
- USB: cdc-acm: rework notification_buffer resizing (git-fixes).
- virtio_pci_modern: Fix the comment of
  virtio_pci_find_capability() (git-fixes).
- USB: serial: ftdi_sio: fix break and sysrq handling (git-fixes).
- USB: serial: ftdi_sio: clean up receive processing (git-fixes).
- USB: serial: ftdi_sio: make process-packet buffer unsigned
  (git-fixes).
- USB: rename USB quirk to USB_QUIRK_ENDPOINT_IGNORE (git-fixes).
- commit 139c620
* Mon Aug 31 2020 jgross@suse.com
- Fix build error when CONFIG_ACPI is not set/enabled:
  (bsc#1065600).
- commit b05ccc4
* Mon Aug 31 2020 jgross@suse.com
- efi: avoid error message when booting under Xen (bsc#1172419).
- commit e2269b0
* Mon Aug 31 2020 jgross@suse.com
- drm/xen-front: Fix misused IS_ERR_OR_NULL checks (bsc#1065600).
- commit 495693e
* Mon Aug 31 2020 msuchanek@suse.de
- powerpc/perf: Fix crashes with generic_compat_pmu & BHRB
  (bsc#1156395).
- commit 823dc81
* Mon Aug 31 2020 jgross@suse.com
- xen/gntdev: Fix dmabuf import with non-zero sgt offset
  (bsc#1065600).
- commit 4c3d2e5
* Mon Aug 31 2020 jgross@suse.com
- Revert "xen/balloon: Fix crash when ballooning on x86 32 bit
  PAE" (bsc#1065600).
- commit 92eacc3
* Mon Aug 31 2020 jgross@suse.com
- xen/balloon: make the balloon wait interruptible (bsc#1065600).
- commit e8237de
* Mon Aug 31 2020 jgross@suse.com
- xen/balloon: fix accounting in alloc_xenballooned_pages error
  path (bsc#1065600).
- commit eda7ced
* Mon Aug 31 2020 mkubecek@suse.cz
- fix patch metadata
- fix upstream reference:
  patches.suse/0002-dax-do-not-print-error-message-for-non-persistent-me.patch
- commit be9f703
* Sun Aug 30 2020 mkubecek@suse.cz
- Update kabi files.
- update to September 2020 maintenance update submission (commit 8bb516dc7a0a)
- commit 77f2936
* Sun Aug 30 2020 colyli@suse.de
- bcache: allocate meta data pages as compound pages
  (bsc#1172873).
- commit 55a313b
* Sun Aug 30 2020 colyli@suse.de
- block: check queue's limits.discard_granularity in
  __blkdev_issue_discard() (bsc#1152148).
- block: improve discard bio alignment in __blkdev_issue_discard()
  (bsc#1152148).
- commit 7c62217
* Sun Aug 30 2020 colyli@suse.de
- dax: do not print error message for non-persistent memory
  block device (bsc#1171073).
- dax: print error message by pr_info() in
  __generic_fsdax_supported() (bsc#1171073).
- commit d1ad35e
* Fri Aug 28 2020 msuchanek@suse.de
- obsolete_kmp: provide newer version than the obsoleted one
  (boo#1170232).
- commit c5ecb27
* Fri Aug 28 2020 ohering@suse.de
- hv_netvsc: Fix the queue_mapping in netvsc_vf_xmit()
  (git-fixes).
- hv_netvsc: Remove "unlikely" from netvsc_select_queue
  (git-fixes).
- hv_netvsc: do not use VF device if link is down (git-fixes).
- commit 83af1e6
* Fri Aug 28 2020 mkubecek@suse.cz
- update upstream reference
- update "net" repository URL:
  patches.suse/ibmvnic-fix-NULL-tx_pools-and-rx_tools-issue-at-do_r.patch
- commit f299d68
* Fri Aug 28 2020 yousaf.kaukab@suse.com
- soc/tegra: pmc: Enable PMIC wake event on Tegra194
  (bsc#1175834).
- commit e2e5a5c
* Fri Aug 28 2020 msuchanek@suse.de
- ibmvnic fix NULL tx_pools and rx_tools issue at do_reset
  (bsc#1175873 ltc#187922).
- commit eff0cb0
* Fri Aug 28 2020 dwagner@suse.de
- kabi/severities: ignore qla2xxx as all symbols are internal
- commit cbc9e8b
* Thu Aug 27 2020 ddiss@suse.de
- scsi: target/iblock: fix WRITE SAME zeroing (bsc#1169790).
- commit 3f94600
* Thu Aug 27 2020 tonyj@suse.de
- blacklist.conf:  Update for perf userspace git-fixes
- commit 981209c
* Thu Aug 27 2020 dwagner@suse.de
- scsi/fc: kABI fixes for new ELS_RPD definition
  (bsc#1171688 bsc#1174003).
- commit 6839081
* Thu Aug 27 2020 mbrugger@suse.com
- efi: libstub/tpm: enable tpm eventlog function for ARM platforms
  (bsc#1173267).
- commit 1168a55
* Thu Aug 27 2020 dwagner@suse.de
- Revert "scsi: qla2xxx: Disable T10-DIF feature with FC-NVMe
  during probe" (bsc#1171688 bsc#1174003).
- Revert "scsi: qla2xxx: Fix crash on qla2x00_mailbox_command"
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix null pointer access during disconnect from
  subsystem (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Check if FW supports MQ before enabling
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix WARN_ON in qla_nvme_register_hba (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Allow ql2xextended_error_logging special value
  1 to be set anytime (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Reduce noisy debug message (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix login timeout (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Indicate correct supported speeds for Mezz card
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Flush I/O on zone disable (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Flush all sessions on zone disable (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Use MBX_TOV_SECONDS for mailbox command timeout
  values (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Address a set of sparse warnings (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: SAN congestion management implementation
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Change in PUREX to handle FPIN ELS requests
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Introduce a function for computing the debug
  message prefix (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Make qla2x00_restart_isp() easier to read
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix a Coverity complaint in qla2100_fw_dump()
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Make __qla2x00_alloc_iocbs() initialize 32 bits
  of request_t.handle (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Remove a superfluous cast (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Initialize 'n' before using it (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Make qla82xx_flash_wait_write_finish() easier
  to read (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Remove the __packed annotation from struct
  fcp_hdr and fcp_hdr_le (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Check the size of struct fcp_hdr at compile time
  (bsc#1171688 bsc#1174003).
- scsi: Fix trivial spelling (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix a condition in qla2x00_find_all_fabric_devs()
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Keep initiator ports after RSCN (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Remove return value from qla_nvme_ls()
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Remove an unused function (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix endianness annotations in source files
  (bsc#1171688 bsc#1174003).
  Refresh patches.suse/scsi-qla2xxx-Set-NVMe-status-code-for-failed-NVMe-FC.patch
- scsi: qla2xxx: Fix endianness annotations in header files
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Use make_handle() instead of open-coding it
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Cast explicitly to uint16_t / uint32_t
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Change {RD,WRT}_REG_*() function names from
  upper case into lower case (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix the code that reads from mailbox registers
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Use register names instead of register offsets
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Change two hardcoded constants into offsetof()
  / sizeof() expressions (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Increase the size of struct qla_fcp_prio_cfg
  to FCP_PRIO_CFG_SIZE (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Make a gap in struct qla2xxx_offld_chain explicit
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Add more BUILD_BUG_ON() statements (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Sort BUILD_BUG_ON() statements alphabetically
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Simplify the functions for dumping firmware
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix spelling of a variable name (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Make qlafx00_process_aen() return void
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Use true, false for ha->fw_dumped (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Use true, false for need_mpi_reset (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Make qla_set_ini_mode() return void (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix issue with adapter's stopping state
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix failure message in qlt_disable_vha()
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Fix warning after FC target reset (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: make 1-bit bit-fields unsigned int (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Fix MPI failure AEN (8200) handling (bsc#1171688
  bsc#1174003).
- scsi: qla2xxx: Use ARRAY_SIZE() instead of open-coding it
  (bsc#1171688 bsc#1174003).
- scsi: qla2xxx: Split qla2x00_configure_local_loop() (bsc#1171688
  bsc#1174003).
- commit 675dd78
* Thu Aug 27 2020 tiwai@suse.de
- serial: 8250: change lock order in serial8250_do_startup()
  (git-fixes).
- serial: pl011: Fix oops on -EPROBE_DEFER (git-fixes).
- serial: pl011: Don't leak amba_ports entry on driver register
  error (git-fixes).
- kernel/relay.c: fix memleak on destroy relay channel
  (git-fixes).
- drm/amd/display: fix pow() crashing when given base 0
  (git-fixes).
- drm/amd/display: Fix EDID parsing after resume from suspend
  (git-fixes).
- rtc: goldfish: Enable interrupt in set_alarm() when necessary
  (git-fixes).
- Input: psmouse - add a newline when printing 'proto' by sysfs
  (git-fixes).
- media: camss: fix memory leaks on error handling paths in probe
  (git-fixes).
- media: vpss: clean up resources in init (git-fixes).
- media: rockchip: rga: Only set output CSC mode for RGB input
  (git-fixes).
- media: rockchip: rga: Introduce color fmt macros and refactor
  CSC mode logic (git-fixes).
- media: budget-core: Improve exception handling in
  budget_register() (git-fixes).
- commit 0974903
* Thu Aug 27 2020 firo.yang@suse.com
- mm, vmstat: reduce zone->lock holding time by /proc/pagetypeinfo
  (bsc#1175691).
- commit e293f1c
* Wed Aug 26 2020 martin.wilck@suse.com
- Refresh
  patches.suse/nvme-multipath-round-robin-eliminate-fallback-variable.patch.
- commit f3c5d53
* Wed Aug 26 2020 martin.wilck@suse.com
- Refresh
  patches.suse/nvme-multipath-round-robin-fix-single-non-optimized-path-case.patch.
- commit d615e5c
* Wed Aug 26 2020 msuchanek@suse.de
- powerpc/iommu: Allow bypass-only for DMA (bsc#1156395).
- commit 70ae27e
* Wed Aug 26 2020 msuchanek@suse.de
- powerpc/fadump: Fix build error with CONFIG_PRESERVE_FA_DUMP=y
  (bsc#1156395).
- commit a889646
* Wed Aug 26 2020 msuchanek@suse.de
- powerpc/perf: Fix missing is_sier_aviable() during build
  (bsc#1065729).
- pseries: Fix 64 bit logical memory block panic (bsc#1065729).
- KVM: PPC: Book3S PR: Remove uninitialized_var() usage
  (bsc#1065729).
- commit 45994c6
* Wed Aug 26 2020 mbenes@suse.cz
- selftests/livepatch: fix mem leaks in test-klp-shadow-vars
  (bsc#1071995).
- commit 0e9c3d5
* Wed Aug 26 2020 msuchanek@suse.de
- powerpc/pseries/hotplug-cpu: wait indefinitely for vCPU death
  (fate#322438 bsc#1085030 ltC#165630).
- commit d3a8444
* Wed Aug 26 2020 mbenes@suse.cz
- selftests/livepatch: more verification in test-klp-shadow-vars
  (bsc#1071995).
- commit fead416
* Wed Aug 26 2020 mbenes@suse.cz
- selftests/livepatch: rework test-klp-shadow-vars (bsc#1071995).
- commit c5a8b83
* Wed Aug 26 2020 mbenes@suse.cz
- selftests/livepatch: simplify test-klp-callbacks busy target
  tests (bsc#1071995).
- commit ab54a11
* Wed Aug 26 2020 msuchanek@suse.de
- powerpc/64s: Don't init FSCR_DSCR in __init_FSCR()
  (bsc#1065729).
- commit a21209e
* Wed Aug 26 2020 mbenes@suse.cz
- tracing: Use trace_sched_process_free() instead of exit()
  for pid tracing (git-fixes).
- commit 6da73c8
* Wed Aug 26 2020 mbenes@suse.cz
- tracepoint: Mark __tracepoint_string's __used (git-fixes).
- commit 9722e3c
* Wed Aug 26 2020 mbenes@suse.cz
- blacklist.conf: 96b4833b6827 ("tracing/hwlat: Honor the tracing_cpumask")
  CONFIG_HWLAT_TRACER is not set anywhere.
- commit 314fc84
* Wed Aug 26 2020 mbenes@suse.cz
- blacklist.conf: 7ef282e05132 ("tracing: Move pipe reference to trace array instead of current_tracer")
  As mentioned in the changelog, it is a cleanup and not really a critical
  fix.
- commit 9fc5f45
* Wed Aug 26 2020 alnovak@suse.cz
- Mark the SLE15-SP2 kernel properly released.
  There perhaps was a typo, when SUSE_KERNEL_RELEASED missed the trailing
  "D" - this leads to our kernels being marked as "Unreleased kernel".
  SUSE_KERNEL_RELEASED is defined in rpm/kernel-binary.spec.in.
  To fix that, it should be enough to switch from SUSE_KERNEL_RELEASE to
  SUSE_KERNEL_RELEASED.
- commit 2de2687
* Wed Aug 26 2020 jack@suse.cz
- bfq: fix blkio cgroup leakage v4 (bsc#1175775).
- commit 78cc5b1
* Wed Aug 26 2020 jack@suse.cz
- kernfs: do not call fsnotify() with name without a parent
  (bsc#1175770).
- commit 7f9fdb0
* Wed Aug 26 2020 jack@suse.cz
- ext4: fix checking of directory entry validity for inline
  directories (bsc#1175771).
- commit 50ef0f0
* Wed Aug 26 2020 jack@suse.cz
- ext2: fix missing percpu_counter_inc (bsc#1175774).
- commit 5a50871
* Wed Aug 26 2020 jack@suse.cz
- mm: filemap: clear idle flag for writes (bsc#1175769).
- commit 7a6a0d8
* Wed Aug 26 2020 jack@suse.cz
- jbd2: add the missing unlock_buffer() in the error path of
  jbd2_write_superblock() (bsc#1175772).
- commit feb29da
* Wed Aug 26 2020 jack@suse.cz
- dlm: Fix kobject memleak (bsc#1175768).
- commit 88c29e9
* Wed Aug 26 2020 tiwai@suse.de
- mfd: intel-lpss: Add Intel Tiger Lake PCH-H PCI IDs
  (jsc#SLE-13411).
- i2c: i801: Add support for Intel Tiger Lake PCH-H
  (jsc#SLE-13411).
- i2c: i801: Add support for Intel Emmitsburg PCH (jsc#SLE-13411).
- spi: pxa2xx: Add support for Intel Tiger Lake PCH-H
  (jsc#SLE-13411).
- i2c: i801: Add support for Intel Comet Lake PCH-V
  (jsc#SLE-13411).
- commit ec0755f
* Wed Aug 26 2020 jslaby@suse.cz
- ip6_gre: fix null-ptr-deref in ip6gre_init_net() (git-fixes).
- commit 7f7d231
* Tue Aug 25 2020 mkubecek@suse.cz
- update upstream references after rebase
  Once again, scsi maintainer branch got rebased, leaving our Git-commit tags
  invalid and git_sort complaining heavily. Update the tags to rebased
  branch.
- commit 9c95c04
* Tue Aug 25 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/md-cluster-Fix-potential-error-pointer-dereference-i.patch
  patches.suse/md-raid5-Fix-Force-reconstruct-write-io-stuck-in-deg.patch
- commit 5986388
* Tue Aug 25 2020 jack@suse.cz
- ext4: check journal inode extents more carefully (bsc#1173485).
- commit 17c289f
* Tue Aug 25 2020 jack@suse.cz
- ext4: don't allow overlapping system zones (bsc#1173485).
- commit d96644e
* Tue Aug 25 2020 jack@suse.cz
- ext4: handle error of ext4_setup_system_zone() on remount
  (bsc#1173485).
- commit 6d00054
* Tue Aug 25 2020 jack@suse.cz
- ext4: fix potential negative array index in do_split()
  (bsc#1173798 CVE-2020-14314).
- commit 078f390
* Tue Aug 25 2020 jack@suse.cz
- ext4: don't BUG on inconsistent journal feature (bsc#1171634).
- commit f410395
* Tue Aug 25 2020 tiwai@suse.de
- config/x86_64: Make CONFIG_PINCTRL_AMD=y (bsc#1174800)
  The pinctrl driver has to be initialized before hid-i2c and others.
  For assuring it, change it built-in, since we can't put the module
  ordering.  This change follows the SLE15-SP2 kernel behavior.
- commit 96cf8f7
* Tue Aug 25 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Optimize-dequeue_task_fair.patch.
- commit bdf744b
* Tue Aug 25 2020 mgorman@suse.de
- sched/fair: fix NOHZ next idle balance (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit 54284ef
* Tue Aug 25 2020 mgorman@suse.de
- update upstream references and move into sorted section:
  patches.suse/0001-proc-meminfo-avoid-open-coded-reading-of-mv_committed_as.patch.
  patches.suse/0002-mm-util-make-vm_memory_comitted-more-accurate.patch.
  patches.suse/0003-mm-adjust-vm_committed_as_batch-according-to-vm-overcommit-policy.patch.
  patches.suse/fsnotify-Rearrange-fast-path-to-minimise-overhead-when-there-is-no-watcher.patch.
- commit 400e8aa
* Tue Aug 25 2020 jslaby@suse.cz
- mlxsw: pci: Fix use-after-free in case of failed devlink reload
  (networking-stable-20_07_17).
- mlxsw: spectrum_router: Remove inappropriate usage of WARN_ON()
  (networking-stable-20_07_17).
- bnxt_en: fix NULL dereference in case SR-IOV configuration fails
  (networking-stable-20_07_17).
- net/mlx5e: Fix 50G per lane indication
  (networking-stable-20_07_17).
- net/mlx5: Fix eeprom support for SFP module
  (networking-stable-20_07_17).
- tcp: make sure listeners don't initialize congestion-control
  state (networking-stable-20_07_17).
- net_sched: fix a memory leak in atm_tc_init()
  (networking-stable-20_07_17).
- l2tp: remove skb_dst_set() from l2tp_xmit_skb()
  (networking-stable-20_07_17).
- vlan: consolidate VLAN parsing code and limit max parsing depth
  (networking-stable-20_07_17).
- net: Added pointer check for dst->ops->neigh_lookup in
  dst_neigh_lookup_skb (networking-stable-20_07_17).
- ipv4: fill fl4_icmp_{type,code} in ping_v4_sendmsg
  (networking-stable-20_07_17).
- ipv6: Fix use of anycast address with loopback
  (networking-stable-20_07_17).
- net: usb: qmi_wwan: add support for Quectel EG95 LTE modem
  (networking-stable-20_07_17).
- ipv6: fib6_select_path can not use out path for nexthop objects
  (networking-stable-20_07_17).
- sched: consistently handle layer3 header accesses in the
  presence of VLANs (networking-stable-20_07_17).
- net: dsa: microchip: set the correct number of ports
  (networking-stable-20_07_17).
- tcp: fix SO_RCVLOWAT possible hangs under high mem pressure
  (networking-stable-20_07_17).
- tcp: md5: do not send silly options in SYNCOOKIES
  (networking-stable-20_07_17).
- tcp: md5: refine tcp_md5_do_add()/tcp_md5_hash_key() barriers
  (networking-stable-20_07_17).
- genetlink: remove genl_bind (networking-stable-20_07_17).
- kABI: genetlink: remove genl_bind (kabi).
- net: qrtr: Fix an out of bounds read qrtr_endpoint_post()
  (networking-stable-20_07_17).
- tcp: md5: add missing memory barriers
  in tcp_md5_do_add()/tcp_md5_hash_key()
  (networking-stable-20_07_17).
- net: mvneta: fix use of state->speed
  (networking-stable-20_07_17).
- llc: make sure applications use ARPHRD_ETHER
  (networking-stable-20_07_17).
- commit ce8586d
* Tue Aug 25 2020 jslaby@suse.cz
- x86/bugs/multihit: Fix mitigation reporting when VMX is not
  in use (git-fixes).
- commit 52699f0
* Mon Aug 24 2020 tbogendoerfer@suse.de
- net: ena: Make missed_tx stat incremental (git-fixes).
- net: ena: Change WARN_ON expression in ena_del_napi_in_range()
  (bsc#1154492).
- net: ena: Prevent reset after device destruction (git-fixes).
- commit 25750c1
* Mon Aug 24 2020 msuchanek@suse.de
- mm/vunmap: add cond_resched() in vunmap_pmd_range (bsc#1175654
  ltc#184617).
- commit 313860f
* Mon Aug 24 2020 neilb@suse.de
- md-cluster: Fix potential error pointer dereference in
  resize_bitmaps() (git-fixes).
- md/raid5: Fix Force reconstruct-write io stuck in degraded raid5
  (git-fixes).
- commit 5f598a1
* Mon Aug 24 2020 mkubecek@suse.cz
- Update kabi files.
- update to released maintenance update (commit dbe0add4c655)
- commit d427f85
* Mon Aug 24 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/bonding-fix-active-backup-failover-for-current-ARP-s.patch
  patches.suse/powerpc-pseries-Do-not-initiate-shutdown-when-system.patch
- commit 1f2a0f0
* Sun Aug 23 2020 mkubecek@suse.cz
- update patch metadata
- update Git-repo tag:
  patches.suse/bonding-fix-active-backup-failover-for-current-ARP-s.patch
- commit 9d16d24
* Fri Aug 21 2020 tiwai@suse.de
- ALSA: hda: avoid reset of sdo_limit (git-fixes).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Book Ion
  (git-fixes).
- ASoC: intel: Fix memleak in sst_media_open (git-fixes).
- ASoC: wm8994: Avoid attempts to read unreadable registers
  (git-fixes).
- ASoC: msm8916-wcd-analog: fix register Interrupt offset
  (git-fixes).
- ASoC: q6routing: add dummy register read/write function
  (git-fixes).
- ASoC: q6afe-dai: mark all widgets registers as SND_SOC_NOPM
  (git-fixes).
- ALSA: usb-audio: ignore broken processing/extension unit
  (git-fixes).
- ALSA: hda/realtek: Add model alc298-samsung-headphone
  (git-fixes).
- ALSA: usb-audio: Update documentation comment for MS2109 quirk
  (git-fixes).
- ALSA: isa: fix spelling mistakes in the comments (git-fixes).
- ALSA: usb-audio: Add capture support for Saffire 6 (USB 1.1)
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Samsung Galaxy Flex Book
  (git-fixes).
- commit 2cf9c73
* Fri Aug 21 2020 tbogendoerfer@suse.de
- RDMA/mlx5: Fix typo in enum name (git-fixes).
- cpumap: Use non-locked version __ptr_ring_consume_batched
  (git-fixes).
- commit b117316
* Fri Aug 21 2020 tbogendoerfer@suse.de
- igc: Fix PTP initialization (bsc#1160634).
- vmxnet3: use correct tcp hdr length when packet is encapsulated
  (bsc#1175199).
- RDMA/mlx5: Add missing srcu_read_lock in ODP implicit flow
  (jsc#SLE-8446).
- net/mlx5: DR, Change push vlan action sequence (jsc#SLE-8464).
- ice: Graceful error handling in HW table calloc failure
  (jsc#SLE-7926).
- ice: Clear and free XLT entries on reset (jsc#SLE-7926).
- commit da2585a
* Fri Aug 21 2020 jwiesner@suse.com
- bonding: fix active-backup failover for current ARP slave
  (bsc#1174771).
- commit 2837560
* Fri Aug 21 2020 jslaby@suse.cz
- enetc: Fix tx rings bitmap iteration range, irq handling
  (networking-stable-20_06_28).
- sch_cake: don't call diffserv parsing code when it is not needed
  (networking-stable-20_06_28).
- sch_cake: don't try to reallocate or unshare skb unconditionally
  (networking-stable-20_06_28).
- sctp: Don't advertise IPv4 addresses if ipv6only is set on
  the socket (networking-stable-20_06_28).
- tcp_cubic: fix spurious HYSTART_DELAY exit upon drop in min RTT
  (networking-stable-20_06_28).
- net: bridge: enfore alignment for ethernet address
  (networking-stable-20_06_28).
- tcp: don't ignore ECN CWR on pure ACK
  (networking-stable-20_06_28).
- openvswitch: take into account de-fragmentation/gso_size in
  execute_check_pkt_len (networking-stable-20_06_28).
- net: Do not clear the sock TX queue in sk_set_socket()
  (networking-stable-20_06_28).
- net: increment xmit_recursion level in dev_direct_xmit()
  (networking-stable-20_06_28).
- net: Fix the arp error in some cases
  (networking-stable-20_06_28).
- ip_tunnel: fix use-after-free in ip_tunnel_lookup()
  (networking-stable-20_06_28).
- ip6_gre: fix use-after-free in ip6gre_tunnel_lookup()
  (networking-stable-20_06_28).
- net: core: reduce recursion limit value
  (networking-stable-20_06_28).
- net: fix memleak in register_netdevice()
  (networking-stable-20_06_28).
- net: usb: ax88179_178a: fix packet alignment padding
  (networking-stable-20_06_28).
- tcp: grow window for OOO packets only for SACK flows
  (networking-stable-20_06_28).
- mvpp2: ethtool rxtx stats fix (networking-stable-20_06_28).
- rocker: fix incorrect error handling in dma_rings_init
  (networking-stable-20_06_28).
- mld: fix memory leak in ipv6_mc_destroy_dev()
  (networking-stable-20_06_28).
- commit 1f17d28
* Fri Aug 21 2020 lyan@suse.com
- KVM: arm64: Stop clobbering x0 for HVC_SOFT_RESTART
  (bsc#1133021).
- KVM: x86: Fix APIC page invalidation race (bsc#1133021).
- KVM: Reinstall old memslots if arch preparation fails
  (bsc#1133021).
- commit 8362c5b
* Fri Aug 21 2020 firo.yang@suse.com
- ipvs: fix the connection sync failed in some cases (bsc#1174699).
- commit d96eaab
* Thu Aug 20 2020 msuchanek@suse.de
- powerpc/pseries: Do not initiate shutdown when system is
  running on UPS (bsc#1175440 ltc#187574).
- commit 738b1b0
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: fix memory leaks after failure to lookup checksums
  during inode logging (bsc#1175550).
- commit 91d88bc
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: remove useless check for copy_items() return value
  (bsc#1175546).
- commit 564c2ae
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: make full fsyncs always operate on the entire file again
  (bsc#1175546).
- commit 75261f5
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: make ranged full fsyncs more efficient (bsc#1175546).
- commit 4839ec4
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: factor out inode items copy loop from btrfs_log_inode()
  (bsc#1175546).
- commit 269fe12
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: add helper to get the end offset of a file extent item
  (bsc#1175546).
- commit 60d1bb0
* Thu Aug 20 2020 fdmanana@suse.com
- btrfs: fix missing file extent item for hole after ranged fsync
  (bsc#1175546).
- commit dd0a610
* Thu Aug 20 2020 martin.wilck@suse.com
- scsi: smartpqi: Use scnprintf() for avoiding potential buffer
  overflow (bsc#1172418).
- commit 408e9b4
* Thu Aug 20 2020 tiwai@suse.de
- spi: stm32: fixes suspend/resume management (git-fixes).
- HID: input: Fix devices that return multiple bytes in battery
  report (git-fixes).
- Bluetooth: add a mutex lock to avoid UAF in do_enale_set
  (git-fixes).
- iwlegacy: Check the return value of pcie_capability_read_*()
  (git-fixes).
- brcmfmac: set state of hanger slot to FREE when flushing PSQ
  (git-fixes).
- brcmfmac: To fix Bss Info flag definition Bug (git-fixes).
- brcmfmac: keep SDIO watchdog running when console_interval is
  non-zero (git-fixes).
- drm: msm: a6xx: fix gpu failure after system resume (git-fixes).
- drm/msm: ratelimit crtc event overflow error (git-fixes).
- drm/ttm/nouveau: don't call tt destroy callback on alloc failure
  (git-fixes bsc#1175232).
- drm/nouveau: fix reference count leak in
  nouveau_debugfs_strap_peek (git-fixes).
- drm/nouveau: fix multiple instances of reference count leaks
  (git-fixes).
- gpu: host1x: debug: Fix multiple channels emitting messages
  simultaneously (git-fixes).
- drm/amd/powerplay: fix compile error with ARCH=arc (git-fixes).
- drm/etnaviv: fix ref count leak via pm_runtime_get_sync
  (git-fixes).
- drm/nouveau/kms/nv50-: Fix disabling dithering (git-fixes).
- video: fbdev: neofb: fix memory leak in neo_scan_monitor()
  (git-fixes).
- video: fbdev: savage: fix memory leak on error handling path
  in probe (git-fixes).
- drm/amdgpu/display bail early in dm_pp_get_static_clocks
  (git-fixes).
- drm/radeon: Fix reference count leaks caused by
  pm_runtime_get_sync (git-fixes).
- drm/amdgpu: avoid dereferencing a NULL pointer (git-fixes).
- drm/radeon: disable AGP by default (git-fixes).
- drm/tilcdc: fix leak & null ref in panel_connector_get_modes
  (git-fixes).
- drm/debugfs: fix plain echo to connector "force" attribute
  (git-fixes).
- mmc: sdhci-pci-o2micro: Bug fix for O2 host controller Seabird1
  (git-fixes).
- mmc: sdhci-cadence: do not use hardware tuning for SD mode
  (git-fixes).
- usb: mtu3: clear dual mode of u3port when disable device
  (git-fixes).
- usb: bdc: Halt controller on suspend (git-fixes).
- bdc: Fix bug causing crash after multiple disconnects
  (git-fixes).
- usb: gadget: net2280: fix memory leak on probe error handling
  paths (git-fixes).
- dyndbg: fix a BUG_ON in ddebug_describe_flags (git-fixes).
- ACPICA: Do not increment operation_region reference counts
  for field units (git-fixes).
- spi: spidev: Align buffers for DMA (git-fixes).
- soc: qcom: rpmh-rsc: Set suppress_bind_attrs flag (git-fixes).
- platform/x86: asus-nb-wmi: add support for ASUS ROG Zephyrus
  G14 and G15 (git-fixes).
- crypto: aesni - Fix build with LLVM_IAS=1 (git-fixes).
- crypto: aesni - add compatibility with IAS (git-fixes).
- platform/x86: ISST: Add new PCI device ids (git-fixes).
- commit 6acba4d
* Wed Aug 19 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/nvme-multipath-do-not-fall-back-to-__nvme_find_path-.patch
  patches.suse/nvme-multipath-fix-logic-for-non-optimized-paths.patch
- fix Git-commit after rebase and moved into "almost mainline" section:
  patches.suse/nvme-multipath-round-robin-eliminate-fallback-variable.patch
  patches.suse/nvme-multipath-round-robin-fix-single-non-optimized-path-case.patch
- commit 8eb0dea
* Wed Aug 19 2020 fdmanana@suse.com
- btrfs: treat RWF_{,D}SYNC writes as sync for CRCs (bsc#1175493).
- commit f823fb0
* Wed Aug 19 2020 ohering@suse.de
- PCI: hv: Fix a timing issue which causes kdump to fail
  occasionally (bsc#1172871, git-fixes).
- commit e5d6bfd
* Wed Aug 19 2020 nstange@suse.de
- rpm/kernel-binary.spec.in: restrict livepatch metapackage to default flavor
  It has been reported that the kernel-*-livepatch metapackage got
  erroneously enabled for SLE15-SP3's new -preempt flavor, leading to a
  unresolvable dependency to a non-existing kernel-livepatch-x.y.z-preempt
  package.
  As SLE12 and SLE12-SP1 have run out of livepatching support, the need to
  build said metapackage for the -xen flavor is gone and the only remaining
  flavor for which they're still wanted is -default.
  Restrict the build of the kernel-*-livepatch metapackage to the -default
  flavor.
- commit 58949f3
* Wed Aug 19 2020 ohering@suse.de
- Drivers: hv: vmbus: Only notify Hyper-V for die events that
  are oops (bsc#1175128).
- commit 0bc8a06
* Wed Aug 19 2020 jlee@suse.com
- kABI: Fix kABI after EFI_RT_PROPERTIES table backport
  (bsc#1174029, bsc#1174110, bsc#1174111).
- commit b284d8a
* Tue Aug 18 2020 martin.wilck@suse.com
- scsi_dh_alua: set 'transitioning' state on unit attention
  (bsc#1171000, bsc#1165933).
- commit cf7ac61
* Tue Aug 18 2020 martin.wilck@suse.com
- scsi_dh_alua: return BLK_STS_AGAIN for ALUA transitioning state
  (bsc#1165933, bsc#1171000).
- commit f6e8a74
* Tue Aug 18 2020 martin.wilck@suse.com
- block: return status code in blk_mq_end_request() (bsc#1171000,
  bsc#1165933).
- commit 0b97993
* Tue Aug 18 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ALSA-usb-audio-fix-overeager-device-match-for-MacroS.patch
- commit 3e22b20
* Tue Aug 18 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/btrfs-Move-free_pages_out-label-in-inline-extent-han.patch
- commit 113168c
* Tue Aug 18 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline and drop Git-repo:
  patches.suse/xfrm-policy-match-with-both-mark-and-mask-on-user-in.patch
- commit 18fa7c9
* Tue Aug 18 2020 jlee@suse.com
- efi/efivars: Expose RT service availability via efivars
  abstraction (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 7b1e418
* Tue Aug 18 2020 jlee@suse.com
- efi: Mark all EFI runtime services as unsupported on non-EFI
  boot (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 4f0f2d2
* Tue Aug 18 2020 tzimmermann@suse.de
- Revert "drm/amd/display: Expose connector VRR range via debugfs" (bsc#1152489)
  * refreshed for context changes
- commit c657a41
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/ingenic: Fix incorrect assumption about plane->index (bsc#1152489)
  * refreshed for context changes
- commit bc5c9df
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/bridge: dw-hdmi: Don't cleanup i2c adapter and ddc ptr in (bsc#1152472)
  * refreshed for context changes
- commit 44aa1b6
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/vgem: Replace opencoded version of drm_gem_dumb_map_offset() (bsc#1152489)
  * refreshed for context changes
- commit e3e1287
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Move cec_notifier to intel_hdmi_connector_unregister, v2.'
- commit a8c7d52
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: Only swap to a random sibling once upon creation'
- commit d52efd4
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/powerplay: fix a crash when overclocking Vega M'
- commit e5e21f4
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/radeon: fix double free'
- commit 280a51f
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/fbc: Fix fence_y_offset handling'
- commit 479361f
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: Do not schedule normal requests immediately along virtual'
- commit 23a91d5
* Tue Aug 18 2020 tbogendoerfer@suse.de
- net: ena: support new LLQ acceleration mode (bsc#1174852).
- net: ena: move llq configuration from ena_probe to
  ena_device_init() (bsc#1174852).
- net: ena: enable support of rss hash key and function changes
  (bsc#1174852).
- net: ena: add support for traffic mirroring (bsc#1174852).
- net: ena: cosmetic: change ena_com_stats_admin stats to u64
  (bsc#1174852).
- net: ena: cosmetic: satisfy gcc warning (bsc#1174852).
- net: ena: add reserved PCI device ID (bsc#1174852).
- net: ena: avoid unnecessary rearming of interrupt vector when
  busy-polling (bsc#1174852).
- net: ena: Fix using plain integer as NULL pointer in
  ena_init_napi_in_range (bsc#1174852).
- net: ena: reduce driver load time (bsc#1174852).
- net: ena: cosmetic: minor code changes (bsc#1174852).
- net: ena: cosmetic: fix spacing issues (bsc#1174852).
- net: ena: cosmetic: code reorderings (bsc#1174852).
- net: ena: cosmetic: remove unnecessary code (bsc#1174852).
- net: ena: cosmetic: fix line break issues (bsc#1174852).
- net: ena: cosmetic: fix spelling and grammar mistakes in
  comments (bsc#1174852).
- net: ena: cosmetic: set queue sizes to u32 for consistency
  (bsc#1174852).
- net: ena: cosmetic: rename
  ena_update_tx/rx_rings_intr_moderation() (bsc#1174852).
- net: ena: simplify ena_com_update_intr_delay_resolution()
  (bsc#1174852).
- net: ena: fix ena_com_comp_status_to_errno() return value
  (bsc#1174852).
- net: ena: use explicit variable size for clarity (bsc#1174852).
- net: ena: rename ena_com_free_desc to make API more uniform
  (bsc#1174852).
- net: ena: add support for the rx offset feature (bsc#1174852).
- net: ena: cosmetic: extract code to ena_indirection_table_set()
  (bsc#1174852).
- net: ena: cosmetic: remove unnecessary spaces and tabs in
  ena_com.h macros (bsc#1174852).
- net: ena: use SHUTDOWN as reset reason when closing interface
  (bsc#1174852).
- net: ena: drop superfluous prototype (bsc#1174852).
- net: ena: add support for reporting of packet drops
  (bsc#1174852).
- net: ena: add unmask interrupts statistics to ethtool
  (bsc#1174852).
- net: ena: remove code that does nothing (bsc#1174852).
- net: ena: changes to RSS hash key allocation (bsc#1174852).
- net: ena: change default RSS hash function to Toeplitz
  (bsc#1174852).
- net: ena: allow setting the hash function without changing
  the key (bsc#1174852).
- net: ena: fix error returning in ena_com_get_hash_function()
  (bsc#1174852).
- net: ena: avoid unnecessary admin command when RSS function
  set fails (bsc#1174852).
- net/ena: Fix build warning in ena_xdp_set() (bsc#1174852).
- net: ena: Make some functions static (bsc#1174852).
- net: ena: ethtool: clean up minor indentation issue
  (bsc#1174852).
- net: ena: ethtool: remove redundant non-zero check on rc
  (bsc#1174852).
- net: ena: remove set but not used variable 'hash_key'
  (bsc#1174852).
- net: ena: fix continuous keep-alive resets (bsc#1174852).
- net: ena: avoid memory access violation by validating req_id
  properly (bsc#1174852).
- net: ena: fix request of incorrect number of IRQ vectors
  (bsc#1174852).
- commit c12b7e0
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/radeon: fix fb_div check in ni_init_smc_spll_table()'
- commit 85aef32
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/amd/display: disable dcn20 abm feature for bring up"'
- commit 196a32f
* Tue Aug 18 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm: encoder_slave: fix refcouting error for modules'
- commit 29d30a2
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/amdgpu/display: use blanked rather than plane state for sync (bsc#1152489)
  * refreshed for context changes
  * protect code with CONFIG_DRM_AMD_DC_DCN2_0
- commit 481d44a
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/bridge: ti-sn65dsi86: Fix off-by-one error in clock choice (bsc#1152489)
  * refreshed for context changes
- commit fa0e7b9
* Tue Aug 18 2020 tzimmermann@suse.de
- drm/dbi: Fix SPI Type 1 (9-bit) transfer (bsc#1152472)
  * move drm_mipi_dbi.c -> tinydrm/mipi-dbi.c
- commit 7401aea
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: fix lost i_size update after cloning inline extent
  (bsc#1175377).
- commit c827d4a
* Mon Aug 17 2020 fdmanana@suse.com
- Btrfs: avoid unnecessary splits when setting bits on an extent
  io tree (bsc#1175377).
- commit 2f40ee4
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: delete the ordered isize update code (bsc#1175377).
- commit cd0b66c
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: replace all uses of btrfs_ordered_update_i_size
  (bsc#1175377).
- Refresh
  patches.suse/0004-btrfs-change-timing-for-qgroup-reserved-space-for-or.patch.
- commit ea0db18
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: don't set path->leave_spinning for truncate
  (bsc#1175377).
- commit d3721b5
* Mon Aug 17 2020 fdmanana@suse.com
- Btrfs: fix deadlock during fast fsync when logging prealloc
  extents beyond eof (bsc#1175377).
- commit dd561f7
* Mon Aug 17 2020 fdmanana@suse.com
- Btrfs: fix race between shrinking truncate and fiemap
  (bsc#1175377).
- commit 09d1d3a
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: Rename btrfs_join_transaction_nolock (bsc#1175377).
- Refresh
  patches.suse/0004-btrfs-change-timing-for-qgroup-reserved-space-for-or.patch.
- Refresh
  patches.suse/btrfs-improve-global-reserve-stealing-logic.patch.
- Refresh
  patches.suse/btrfs-make-btrfs_ordered_extent-naming-consistent-wi.patch.
- commit fb4625a
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: use the file extent tree infrastructure (bsc#1175377).
- Refresh
  patches.suse/0002-btrfs-inode-move-qgroup-reserved-space-release-to-th.patch.
- commit ac53cba
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: introduce per-inode file extent tree (bsc#1175377).
- Refresh
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch.
- commit add4417
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: use btrfs_ordered_update_i_size in
  clone_finish_inode_update (bsc#1175377).
- commit 266b2b3
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: move extent_io_tree defs to their own header
  (bsc#1175377).
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- Refresh
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch.
- commit 4f0dd59
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: separate out the extent io init function (bsc#1175377).
- commit 82311bf
* Mon Aug 17 2020 fdmanana@suse.com
- btrfs: separate out the extent leak code (bsc#1175377).
- commit 210fc6b
* Mon Aug 17 2020 fdmanana@suse.com
- Btrfs: remove unnecessary delalloc mutex for inodes
  (bsc#1175377).
- commit 0e0ed2f
* Mon Aug 17 2020 martin.wilck@suse.com
- scsi: dh: Add Fujitsu device to devinfo and dh lists
  (bsc#1174026).
- commit 64f1b61
* Mon Aug 17 2020 mkoutny@suse.com
- kABI fix for sock_cgroup_data (bsc#1175213 CVE-2020-14356).
- cgroup: Fix sock_cgroup_data on big-endian (bsc#1175213
  CVE-2020-14356).
- cgroup: fix cgroup_sk_alloc() for sk_clone_lock() (bsc#1175213
  CVE-2020-14356).
- commit a3b6e53
* Mon Aug 17 2020 tiwai@suse.de
- firmware_loader: fix memory leak for paged buffer (bsc#1175367).
- commit 8b7305c
* Mon Aug 17 2020 martin.wilck@suse.com
- nvme: add a Identify Namespace Identification Descriptor list
  quirk (git-fixes).
- commit 7a85489
* Mon Aug 17 2020 msuchanek@suse.de
- scsi: ipr: remove unneeded semicolon (jsc#SLE-13654).
- scsi: ipr: Use scnprintf() for avoiding potential buffer
  overflow (jsc#SLE-13654).
- scsi: ipr: Fix softlockup when rescanning devices in petitboot
  (jsc#SLE-13654).
- commit 48dc40d
* Mon Aug 17 2020 martin.wilck@suse.com
- nvme: fix a crash in nvme_mpath_add_disk (git-fixes, bsc#1159058).
- commit 9afbddd
* Mon Aug 17 2020 martin.wilck@suse.com
- nvme: fix identify error status silent ignore (git-fixes,
  bsc#1159058).
- commit 1c12147
* Mon Aug 17 2020 mhocko@suse.com
- Refresh patches.suse/mm-fix-protection-usage-propagation.patch.
  add upstream references
- commit 8e0bfa9
* Mon Aug 17 2020 ailiop@suse.com
- xfs: preserve rmapbt swapext block reservation from freed blocks
  (git-fixes).
- commit 86a5ed2
* Mon Aug 17 2020 ailiop@suse.com
- xfs: don't eat an EIO/ENOSPC writeback error when scrubbing
  data fork (git-fixes).
- commit 5f2713c
* Mon Aug 17 2020 ailiop@suse.com
- xfs: fix inode allocation block res calculation precedence
  (git-fixes).
- commit 575ee59
* Mon Aug 17 2020 ailiop@suse.com
- xfs: fix reflink quota reservation accounting error (git-fixes).
- commit 887a853
* Mon Aug 17 2020 mbrugger@suse.com
- arm64: dts: clearfog-gt-8k: set gigabit PHY reset deassert delay
  (bsc#1175347).
- commit 4c9be8d
* Mon Aug 17 2020 mbrugger@suse.com
- arm64: dts: exynos: Fix silent hang after boot on Espresso
  (bsc#1175346).
- arm64: dts: imx8qxp-mek: Remove unexisting Ethernet PHY
  (bsc#1175345).
- arm64: dts: uDPU: fix broken ethernet (bsc#1175344).
- commit ebcb713
* Mon Aug 17 2020 mbrugger@suse.com
- blacklist.conf: arm64: add intel DTS
- commit d0107a6
* Mon Aug 17 2020 mbrugger@suse.com
- blacklist.conf: fix ignored arm64 devicetree folders
- commit 1175c5d
* Mon Aug 17 2020 wqu@suse.com
- btrfs: trim: fix underflow in trim length to prevent access
  beyond device boundary (bsc#1175263).
- btrfs: inode: fix NULL pointer dereference if inode doesn't
  need compression (bsc#1174484).
- btrfs: Move free_pages_out label in inline extent handling
  branch in compress_file_range (bsc#1175263).
- commit 0b38364
* Mon Aug 17 2020 dbueso@suse.de
- locktorture: Print ratio of acquisitions, not failures
  (bsc#1149032).
- commit 7698a26
* Sun Aug 16 2020 tiwai@suse.de
- mfd: dln2: Run event handler loop under spinlock (git-fixes).
- mfd: arizona: Ensure 32k clock is put on driver unbind and error
  (git-fixes).
- pwm: bcm-iproc: handle clk_get_rate() return (git-fixes).
- commit a79237e
* Sat Aug 15 2020 tiwai@suse.de
- ALSA: echoaudio: Fix potential Oops in snd_echo_resume()
  (git-fixes).
- ALSA: hda/hdmi: Use force connectivity quirk on another HP
  desktop (git-fixes).
- ALSA: hda/realtek - Fix unused variable warning (git-fixes).
- ALSA: hda - reverse the setting value in the micmute_led_set
  (git-fixes).
- ALSA: echoaduio: Drop superfluous volatile modifier (git-fixes).
- ALSA: usb-audio: Disable Lenovo P620 Rear line-in volume control
  (git-fixes).
- ALSA: usb-audio: add quirk for Pioneer DDJ-RB (git-fixes).
- ALSA: usb-audio: work around streaming quirk for MacroSilicon
  MS2109 (git-fixes).
- ALSA: hda - fix the micmute led status for Lenovo ThinkCentre
  AIO (git-fixes).
- ALSA: hda/realtek: Fix pin default on Intel NUC 8 Rugged
  (git-fixes).
- ALSA: usb-audio: Creative USB X-Fi Pro SB1095 volume knob
  support (git-fixes).
- ALSA: usb-audio: fix spelling mistake "buss" -> "bus"
  (git-fixes).
- commit 9eb0560
* Sat Aug 15 2020 tiwai@suse.de
- Re-sort and refresh the upstreamed USB-audio patch
- commit 56623bd
* Fri Aug 14 2020 tiwai@suse.de
- r8169: read common register for PCI commit (bsc#1175296).
- commit 33be6a7
* Fri Aug 14 2020 tiwai@suse.de
- r8169: move disabling interrupt coalescing to RTL8169/RTL8168
  init (bsc#1175296).
- commit 150a24b
* Fri Aug 14 2020 tiwai@suse.de
- r8169: fix rtl_hw_jumbo_disable for RTL8168evl (bsc#1175296).
- r8169: fix resume on cable plug-in (bsc#1175296).
- r8169: fix jumbo configuration for RTL8168evl (bsc#1175296).
- r8169: fix jumbo packet handling on resume from suspend
  (bsc#1175296).
- commit 205974e
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: bump version to 1.2.16-010 (bsc#1172418).
- commit c7cf3da
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: add RAID bypass counter (bsc#1172418).
- commit 626afe0
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: support device deletion via sysfs (bsc#1172418).
- commit a628df1
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: avoid crashing kernel for controller issues
  (bsc#1172418).
- commit bfa2645
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: update logical volume size after expansion
  (bsc#1172418).
- commit 2f4b5a4
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: add id support for SmartRAID 3152-8i (bsc#1172418).
- commit 2eeedae
* Fri Aug 14 2020 martin.wilck@suse.com
- scsi: smartpqi: Identify physical devices without issuing INQUIRY
  (bsc#1172418).
- commit 34ee136
* Fri Aug 14 2020 shung-hsi.yu@suse.com
- kABI: restore signature of xfrm_policy_bysel_ctx() and
  xfrm_policy_byid() (bsc#1174645).
- xfrm: policy: match with both mark and mask on user interfaces
  (bsc#1174645).
- commit b412835
* Fri Aug 14 2020 martin.wilck@suse.com
- block: Fix the type of 'sts' in bsg_queue_rq() (git-fixes).
- commit 1ab9963
* Fri Aug 14 2020 msuchanek@suse.de
- powerpc/nvdimm: use H_SCM_QUERY hcall on H_OVERLAP error
  (bsc#1175284).
- powerpc/nvdimm: Use HCALL error as the return value
  (bsc#1175284).
- commit 619bc4d
* Fri Aug 14 2020 tiwai@suse.de
- net: phy: fix memory leak in device-create error path
  (git-fixes).
- i2c: iproc: fix race between client unreg and isr (git-fixes).
- i2c: rcar: avoid race when unregistering slave (git-fixes).
- i2c: rcar: slave: only send STOP event when we have been
  addressed (git-fixes).
- net: phy: Check harder for errors in get_phy_id() (git-fixes).
- commit a5bf009
* Thu Aug 13 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/clk-bcm2835-do-not-use-prediv-with-bcm2711-s-plls.patch
- commit f0a312b
* Thu Aug 13 2020 tiwai@suse.de
- clk: at91: sckc: register slow_rc with accuracy option
  (git-fixes).
- clk: at91: sam9x60: fix main rc oscillator frequency
  (git-fixes).
- clk: at91: sam9x60-pll: check fcore against ranges (git-fixes).
- clk: at91: sam9x60-pll: use logical or for range check
  (git-fixes).
- clk: at91: clk-generated: check best_rate against ranges
  (git-fixes).
- clk: at91: clk-generated: continue if __clk_determine_rate()
  returns error (git-fixes).
- clk: clk-atlas6: fix return value check in atlas6_clk_init()
  (git-fixes).
- clk: iproc: round clock rate to the closest (git-fixes).
- clk: rockchip: Revert "fix wrong mmc sample phase shift for
  rk3328" (git-fixes).
- clk: actions: Fix h_clk for Actions S500 SoC (git-fixes).
- clk: qcom: gcc-sdm660: Fix up gcc_mss_mnoc_bimc_axi_clk
  (git-fixes).
- clk: qcom: gcc-sdm660: Add missing modem reset (git-fixes).
- watchdog: initialize device before misc_register (git-fixes).
- watchdog: f71808e_wdt: clear watchdog timeout occurred flag
  (git-fixes).
- watchdog: f71808e_wdt: remove use of wrong watchdog_info option
  (git-fixes).
- watchdog: f71808e_wdt: indicate WDIOF_CARDRESET support in
  watchdog_info.options (git-fixes).
- drm/vmwgfx: Fix two list_for_each loop exit tests (git-fixes).
- drm/vmwgfx: Use correct vmw_legacy_display_unit pointer
  (git-fixes).
- drm: fix drm_dp_mst_port refcount leaks in
  drm_dp_mst_allocate_vcpi (git-fixes).
- kernel.h: remove duplicate include of asm/div64.h (git-fixes).
- platform/chrome: cros_ec_ishtp: Fix a double-unlock issue
  (git-fixes).
- remoteproc: qcom: q6v5: Update running state before requesting
  stop (git-fixes).
- remoteproc: qcom_q6v5_mss: Validate modem blob firmware size
  before load (git-fixes).
- remoteproc: qcom_q6v5_mss: Validate MBA firmware size before
  load (git-fixes).
- Input: sentelic - fix error return when fsp_reg_write fails
  (git-fixes).
- drm/i915/gt: Unlock engine-pm after queuing the kernel context
  switch (git-fixes).
- drm/i915/gt: Close race between engine_park and
  intel_gt_retire_requests (git-fixes).
- drm/i915/gt: Move new timelines to the end of active_list
  (git-fixes).
- commit 760f8de
* Thu Aug 13 2020 mbrugger@suse.com
- irqchip/gic: Atomically update affinity (bsc#1175195).
- commit 5ad8b58
* Thu Aug 13 2020 jlee@suse.com
- integrity: Check properly whether EFI GetVariable() is available
  (bsc#1174029, bsc#1174110, bsc#1174111).
- Refresh
  patches.suse/0003-MODSIGN-load-blacklist-from-MOKx.patch.
- commit 3c8f305
* Thu Aug 13 2020 jlee@suse.com
- x86/ima: Use EFI GetVariable only when available (bsc#1174029,
  bsc#1174110, bsc#1174111).
- commit bc28a75
* Thu Aug 13 2020 jlee@suse.com
- efi: Use EFI ResetSystem only when available (bsc#1174029,
  bsc#1174110, bsc#1174111).
- commit ff49d51
* Thu Aug 13 2020 jlee@suse.com
- scsi: iscsi: Use EFI GetVariable only when available
  (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 4afad03
* Wed Aug 12 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/btrfs-Remove-delalloc_end-argument-from-extent_clear.patch
  patches.suse/btrfs-Remove-leftover-of-in-band-dedupe.patch
  patches.suse/btrfs-fix-a-block-group-ref-counter-leak-after-failu.patch
  patches.suse/btrfs-fix-block-group-leak-when-removing-fails.patch
  patches.suse/btrfs-fix-bytes_may_use-underflow-when-running-balan.patch
  patches.suse/btrfs-fix-corrupt-log-due-to-concurrent-fsync-of-ino.patch
  patches.suse/btrfs-fix-data-block-group-relocation-failure-due-to.patch
  patches.suse/btrfs-fix-double-free-on-ulist-after-backref-resolut.patch
  patches.suse/btrfs-fix-fatal-extent_buffer-readahead-vs-releasepa.patch
  patches.suse/btrfs-fix-page-leaks-after-failure-to-lock-page-for-.patch
  patches.suse/btrfs-fix-race-between-block-group-removal-and-block.patch
  patches.suse/btrfs-fix-space_info-bytes_may_use-underflow-after-n.patch
  patches.suse/btrfs-fix-space_info-bytes_may_use-underflow-during-.patch
  patches.suse/btrfs-fix-wrong-file-range-cleanup-after-an-error-fi.patch
- commit d629da8
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix page leaks after failure to lock page for delalloc
  (bsc#1175149).
- commit 11c5046
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix double free on ulist after backref resolution failure
  (bsc#1175149).
- commit e175c08
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix fatal extent_buffer readahead vs releasepage race
  (bsc#1175149).
- commit 6894e62
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix bytes_may_use underflow when running balance and
  scrub in parallel (bsc#1175149).
- commit 3c1d24d
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix data block group relocation failure due to concurrent
  scrub (bsc#1175149).
- commit e7dccf4
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix race between block group removal and block group
  creation (bsc#1175149).
- commit 22ed64a
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix a block group ref counter leak after failure to
  remove block group (bsc#1175149).
- commit 5c3ef7d
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix block group leak when removing fails (bsc#1175149).
- commit 03037b8
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix space_info bytes_may_use underflow during space
  cache writeout (bsc#1175149).
- commit 9586d9c
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix space_info bytes_may_use underflow after nocow
  buffered write (bsc#1175149).
- commit 457cc33
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix wrong file range cleanup after an error filling
  dealloc range (bsc#1175149).
- commit e7b219b
* Wed Aug 12 2020 mbrugger@suse.com
- arm64: csum: Fix handling of bad packets (bsc#1175192).
- arm64: kgdb: Fix single-step exception handling oops
  (bsc#1175191).
- KVM: arm64: Annotate hyp NMI-related functions as
  __always_inline (bsc#1175190).
- arm64: hw_breakpoint: Don't invoke overflow handler on uaccess
  watchpoints (bsc#1175189).
- arm64: cacheflush: Fix KGDB trap detection (bsc#1175188).
- arm64: kexec_file: print appropriate variable (bsc#1175187).
- arm64: insn: Fix two bugs in encoding 32-bit logical immediates
  (bsc#1175186).
- arm64: Fix PTRACE_SYSEMU semantics (bsc#1175185).
- arm64: fix the flush_icache_range arguments in machine_kexec
  (bsc#1175184).
- arm64: hugetlb: avoid potential NULL dereference (bsc#1175183).
- arm64: vdso: Add -fasynchronous-unwind-tables to cflags
  (bsc#1175182).
- arm64: vdso: don't free unallocated pages (bsc#1175181).
- arm64: armv8_deprecated: Fix undef_hook mask for thumb setend
  (bsc#1175180).
- commit 5e20125
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: Remove leftover of in-band dedupe (bsc#1175149).
- refresh patches.suse/btrfs-move-basic-block_group-definitions-to-their-own-header.patch
- commit f3a05f0
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: Remove delalloc_end argument from
  extent_clear_unlock_delalloc (bsc#1175149).
- commit 24d05e3
* Wed Aug 12 2020 fdmanana@suse.com
- btrfs: fix corrupt log due to concurrent fsync of inodes with
  shared extents (bsc#1175149).
- commit af1520b
* Wed Aug 12 2020 mbrugger@suse.com
- blacklist: ignore Spreadtrum clk fix with wrong SHA
- commit 418cf06
* Wed Aug 12 2020 lhenriques@suse.de
- fuse: Fix parameter for FS_IOC_{GET,SET}FLAGS (bsc#1175176).
- fuse: fix weird page warning (bsc#1175175).
- commit ec519b8
* Wed Aug 12 2020 msuchanek@suse.de
- ibmveth: Fix use of ibmveth in a bridge (bsc#1174387
  ltc#187506).
- commit 60cd53b
* Wed Aug 12 2020 msuchanek@suse.de
- genirq/affinity: Remove const qualifier from node_to_cpumask
  argument (bsc#1174897 ltc#187090).
- genirq/affinity: Spread vectors on node according to nr_cpu
  ratio (bsc#1174897 ltc#187090).
- genirq/affinity: Improve __irq_build_affinity_masks()
  (bsc#1174897 ltc#187090).
- commit 5d5f43f
* Wed Aug 12 2020 glin@suse.com
- bpfilter: reject kernel addresses (bsc#1155518).
- net/bpfilter: split __bpfilter_process_sockopt (bsc#1155518).
- bpfilter: fix up a sparse annotation (bsc#1155518).
- bpfilter: Initialize pos variable (bsc#1155518).
- net/bpfilter: Initialize pos in __bpfilter_process_sockopt
  (bsc#1155518).
- bpfilter: switch to kernel_write (bsc#1155518).
- commit 00f0f2f
* Wed Aug 12 2020 duwe@suse.de
- rpm/modules.fips:
  * add ecdh_generic (boo#1173813)
- commit 5b147f9
* Wed Aug 12 2020 tiwai@suse.de
- media: omap3isp: Add missed v4l2_ctrl_handler_free() for
  preview_init_entities() (git-fixes).
- staging: rtl8712: handle firmware load failure (git-fixes).
- Bluetooth: Prevent out-of-bounds read in
  hci_inquiry_result_with_rssi_evt() (git-fixes).
- Bluetooth: Prevent out-of-bounds read in
  hci_inquiry_result_evt() (git-fixes).
- Bluetooth: Fix slab-out-of-bounds read in
  hci_extended_inquiry_result_evt() (git-fixes).
- usb: xhci: Fix ASMedia ASM1142 DMA addressing (git-fixes).
- usb: xhci: define IDs for various ASMedia host controllers
  (git-fixes).
- USB: serial: qcserial: add EM7305 QDL product ID (git-fixes).
- mtd: properly check all write ioctls for permissions
  (git-fixes).
- cfg80211: check vendor command doit pointer before use
  (git-fixes).
- atm: fix atm_dev refcnt leaks in atmtcp_remove_persistent
  (git-fixes).
- net: lan78xx: replace bogus endpoint lookup (git-fixes).
- usb: hso: check for return value in hso_serial_common_create()
  (git-fixes).
- i2c: slave: add sanity check when unregistering (git-fixes).
- i2c: slave: improve sanity check when registering (git-fixes).
- firmware: Fix a reference count leak (git-fixes).
- drm/nouveau/fbcon: zero-initialise the mode_cmd2 structure
  (git-fixes).
- drm/nouveau/fbcon: fix module unload when fbcon init has failed
  for some reason (git-fixes).
- AX.25: Prevent integer overflows in connect and sendmsg
  (git-fixes).
- AX.25: Prevent out-of-bounds read in ax25_sendmsg() (git-fixes).
- AX.25: Fix out-of-bounds read in ax25_connect() (git-fixes).
- commit 01f7466
* Wed Aug 12 2020 jlee@suse.com
- infiniband: hfi1: Use EFI GetVariable only when available
  (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 5f092e5
* Wed Aug 12 2020 jslaby@suse.cz
- vgacon: Fix for missing check in scrollback handling
  (bsc#1174205 CVE-2020-14331).
  Update upstream status.
- commit e6ac692
* Tue Aug 11 2020 ykaukab@suse.de
- soc/tegra: pmc: Enable PMIC wake event on Tegra210
  (bsc#1175116).
- commit af9a16c
* Tue Aug 11 2020 msuchanek@suse.de
- powerpc/pseries/hotplug-cpu: Remove double free in error path
  (bsc#1065729).
- powerpc/boot: Fix CONFIG_PPC_MPC52XX references (bsc#1065729).
- powerpc: Allow 4224 bytes of stack expansion for the signal
  frame (bsc#1065729).
- powerpc/book3s64/pkeys: Use PVR check instead of cpu feature
  (bsc#1065729).
- powerpc/vdso: Fix vdso cpu truncation (bsc#1065729).
- powerpc/rtas: don't online CPUs for partition suspend
  (bsc#1065729).
- powerpc/pseries: remove cede offline state for CPUs
  (bsc#1065729).
- ibmvnic: Fix IRQ mapping disposal in error path (bsc#1175112
  ltc#187459).
- powerpc/64s: Fix early_init_mmu section mismatch (bsc#1065729).
- commit 59a966b
* Tue Aug 11 2020 jlee@suse.com
- efi: Register EFI rtc platform device only when available
  (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 7ac188a
* Tue Aug 11 2020 jlee@suse.com
- efi: Use more granular check for availability for variable
  services (bsc#1174029, bsc#1174110, bsc#1174111).
- commit 90067a7
* Tue Aug 11 2020 jslaby@suse.cz
- blacklist.conf: add sparse warning fixes
- commit 301555e
* Tue Aug 11 2020 jslaby@suse.cz
- PCI: rcar: Fix runtime PM imbalance on error (git-fixes).
- PCI: cadence: Fix updating Vendor ID and Subsystem Vendor ID
  register (git-fixes).
- commit 272b523
* Tue Aug 11 2020 jslaby@suse.cz
- arm64: dts: qcom: msm8998-clamshell: Fix label on l15 regulator
  (git-fixes).
- commit 8896400
* Tue Aug 11 2020 jlee@suse.com
- efi: Add support for EFI_RT_PROPERTIES table (bsc#1174029,
  bsc#1174110, bsc#1174111).
- commit 4e5fc8c
* Tue Aug 11 2020 jlee@suse.com
- efi: Store mask of supported runtime services in struct efi
  (bsc#1174029, bsc#1174110, bsc#1174111).
- Refresh
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch.
- commit 738249f
* Mon Aug 10 2020 tiwai@suse.de
- blacklist.conf: Add inapplicable drm/i915 commit for git-fixes
- commit 89499be
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Drop no-semaphore boosting (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Reorder-await_execution-before-await_reques.patch.
- commit abd8209
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Prevent using semaphores to chain up to external
  fences (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Reorder-await_execution-before-await_reques.patch.
- commit 8cf5766
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Peel dma-fence-chains for await (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Reorder-await_execution-before-await_reques.patch.
- commit 1951d28
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Pull waiting on an external dma-fence into its routine
  (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Reorder-await_execution-before-await_reques.patch.
- commit b2bfc63
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Ignore submit-fences on the same timeline
  (bsc#1174737).
- commit fae2bcb
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Rely on direct submission to the queue (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Remove-wait-priority-boosting.patch.
- commit a8208d8
* Mon Aug 10 2020 tiwai@suse.de
- drm/i915: Remove wait priority boosting (bsc#1174737).
- commit 0fea26e
* Mon Aug 10 2020 tiwai@suse.de
- pinctrl: ingenic: Enhance support for IRQ_TYPE_EDGE_BOTH
  (git-fixes).
- pinctrl: single: fix function name in documentation (git-fixes).
- pinctrl-single: fix pcs_parse_pinconf() return value
  (git-fixes).
- mtd: rawnand: qcom: avoid write to unavailable register
  (git-fixes).
- mtd: rawnand: fsl_upm: Remove unused mtd var (git-fixes).
- power: supply: check if calc_soc succeeded in
  pm860x_init_battery (git-fixes).
- PCI: tegra: Revert tegra124 raw_violation_fixup (git-fixes).
- PCI: qcom: Add support for tx term offset for rev 2.1.0
  (git-fixes).
- PCI: qcom: Define some PARF params needed for ipq8064 SoC
  (git-fixes).
- PCI: qcom: Add missing reset for ipq806x (git-fixes).
- PCI: qcom: Add missing ipq806x clocks in PCIe driver
  (git-fixes).
- PCI: switchtec: Add missing __iomem tag to fix sparse warnings
  (git-fixes).
- PCI: switchtec: Add missing __iomem and __user tags to fix
  sparse warnings (git-fixes).
- PCI: Release IVRS table in AMD ACS quirk (git-fixes).
- PCI: Fix pci_cfg_wait queue locking problem (git-fixes).
- PCI/ASPM: Add missing newline in sysfs 'policy' (git-fixes).
- clk: bcm63xx-gate: fix last clock availability (git-fixes).
- go7007: add sanity checking for endpoints (git-fixes).
- media: exynos4-is: Add missed check for pinctrl_lookup_state()
  (git-fixes).
- media: nuvoton-cir: remove setting tx carrier functions
  (git-fixes).
- media: vsp1: dl: Fix NULL pointer dereference on unbind
  (git-fixes).
- media: firewire: Using uninitialized values in node_probe()
  (git-fixes).
- media: media-request: Fix crash if memory allocation fails
  (git-fixes).
- media: marvell-ccic: Add missed v4l2_async_notifier_cleanup()
  (git-fixes).
- media: cxusb-analog: fix V4L2 dependency (git-fixes).
- iio: improve IIO_CONCENTRATION channel type description
  (git-fixes).
- staging: vchiq_arm: Add a matching unregister call (git-fixes).
- integrity: remove redundant initialization of variable ret
  (git-fixes).
- omapfb: dss: Fix max fclk divider for omap36xx (git-fixes).
- media: sur40: Remove uninitialized_var() usage (git-fixes).
- clk: spear: Remove uninitialized_var() usage (git-fixes).
- clk: st: Remove uninitialized_var() usage (git-fixes).
- ide: Remove uninitialized_var() usage (git-fixes).
- rtlwifi: rtl8192cu: Remove uninitialized_var() usage
  (git-fixes).
- drbd: Remove uninitialized_var() usage (git-fixes).
- random32: move the pseudo-random 32-bit definitions to prandom.h
  (git-fixes).
- PCI: hotplug: ACPI: Fix context refcounting in
  acpiphp_grab_context() (git-fixes).
- random32: remove net_rand_state from the latent entropy gcc
  plugin (git-fixes).
- commit 5480d4c
* Mon Aug 10 2020 msuchanek@suse.de
- powerpc/papr_scm: Add support for fetching nvdimm 'fuel-gauge'
  metric (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- powerpc/papr_scm: Fetch nvdimm performance stats from PHYP
  (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- powerpc/papr_scm: Implement support for PAPR_PDSM_HEALTH
  (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- ndctl/papr_scm,uapi: Add support for PAPR nvdimm specific
  methods (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- powerpc/papr_scm: Improve error logging and handling
  papr_scm_ndctl() (bsc#1175052 jsc#SLE-13823 bsc#1174969
  jsc#SLE-12769).
- powerpc/papr_scm: Fetch nvdimm health information from PHYP
  (bsc#1175052 jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- seq_buf: Export seq_buf_printf (bsc#1175052 jsc#SLE-13823
  bsc#1174969 jsc#SLE-12769).
- powerpc: Document details on H_SCM_HEALTH hcall (bsc#1175052
  jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- powerpc/papr_scm: Mark papr_scm_ndctl() as static (bsc#1175052
  jsc#SLE-13823 bsc#1174969 jsc#SLE-12769).
- commit 83564d9
* Mon Aug 10 2020 tiwai@suse.de
- ALSA: usb-audio: fix overeager device match for MacroSilicon
  MS2109 (bsc#1174625).
- commit 2c2144c
* Mon Aug 10 2020 ghe@suse.com
- ocfs2: fix remounting needed after setfacl command
  (bsc#1173954).
- commit 5e09cdc
* Sun Aug  9 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/powerpc-fadump-fix-race-between-pstore-write-and-fad.patch
  patches.suse/powerpc-pseries-PCIE-PHB-reset.patch
  patches.suse/powerpc-xmon-Reset-RCU-and-soft-lockup-watchdogs.patch
- commit fe82dc0
* Sun Aug  9 2020 mkubecek@suse.cz
- fix patch metadata
- fix confusing References tags:
  patches.suse/arm64-dts-allwinner-a64-Remove-unused-SPDIF-sound-ca.patch
  patches.suse/arm64-dts-imx8mm-evk-correct-ldo1-ldo2-voltage-range.patch
  patches.suse/arm64-dts-librem5-devkit-add-a-vbus-supply-to-usb0.patch
  patches.suse/arm64-dts-ls1028a-delete-extraneous-interrupt-cells-.patch
  patches.suse/arm64-dts-rockchip-Rename-dwc3-device-nodes-on-rk339.patch
  patches.suse/arm64-dts-rockchip-Replace-RK805-PMIC-node-name-with.patch
  patches.suse/arm64-dts-rockchip-fix-rk3399-puma-gmac-reset-gpio.patch
  patches.suse/arm64-dts-rockchip-fix-rk3399-puma-vcc5v0-host-gpio.patch
  patches.suse/arm64-dts-uniphier-Set-SCSSI-clock-and-reset-IDs-for.patch
  patches.suse/arm64-tegra-Enable-I2C-controller-for-EEPROM.patch
  patches.suse/arm64-tegra-Fix-Tegra194-PCIe-compatible-string.patch
  patches.suse/arm64-tegra-Fix-ethernet-phy-mode-for-Jetson-Xavier.patch
  patches.suse/arm64-tegra-Fix-flag-for-64-bit-resources-in-ranges-.patch
- commit 176f025
* Fri Aug  7 2020 lyan@suse.com
- KVM: arm64: Select TASK_DELAY_ACCT+TASKSTATS rather than
  SCHEDSTATS (bsc#1172197 jsc#SLE-13593).
- arm64: Retrieve stolen time as paravirtualized guest
  (bsc#1172197 jsc#SLE-13593).
- KVM: arm64: Provide VCPU attributes for stolen time (bsc#1172197
  jsc#SLE-13593).
- KVM: Allow kvm_device_ops to be const (bsc#1172197
  jsc#SLE-13593).
- KVM: arm64: Support stolen time reporting via shared structure
  (bsc#1172197 jsc#SLE-13593).
- KVM: Implement kvm_put_guest() (bsc#1172197 jsc#SLE-13593).
- KVM: arm64: Implement PV_TIME_FEATURES call (bsc#1172197
  jsc#SLE-13593).
  Refresh:
  patches.suse/arm-arm64-provide-a-wrapper-for-smccc-1-1-calls.patch
  patches.suse/firmware-smccc-add-the-definition-for-smcccv1-2-version-error-codes.patch
- KVM: arm/arm64: Factor out hypercall handling from PSCI code
  (bsc#1172197 jsc#SLE-13593).
- KVM: arm64: Document PV-time interface (bsc#1172197
  jsc#SLE-13593).
- commit f17479f
* Fri Aug  7 2020 mbrugger@suse.com
- arm64: dts: rockchip: fix rk3399-puma gmac reset gpio (none
  bsc#1175021).
- arm64: dts: rockchip: fix rk3399-puma vcc5v0-host gpio (none
  bsc#1175020).
- arm64: dts: imx8mm-evk: correct ldo1/ldo2 voltage range
  (none bsc#1175019).
- arm64: tegra: Fix flag for 64-bit resources in 'ranges' property
  (none bsc#1175018).
- arm64: tegra: Fix ethernet phy-mode for Jetson Xavier (none
  bsc#1175017).
- arm64: dts: allwinner: a64: Remove unused SPDIF sound card
  (none bsc#1175016).
- arm64: dts: rockchip: Rename dwc3 device nodes on rk3399 to
  make dtc happy (none bsc#1175015).
- arm64: dts: rockchip: Replace RK805 PMIC node name with "pmic"
  on rk3328 boards (none bsc#1175014).
- arm64: dts: librem5-devkit: add a vbus supply to usb0 (none
  bsc#1175013).
- arm64: dts: ls1028a: delete extraneous #interrupt-cells for
  ENETC RCIE (none bsc#1175012).
- arm64: dts: uniphier: Set SCSSI clock and reset IDs for each
  channel (none bsc#1175011).
- arm64: tegra: Enable I2C controller for EEPROM (none
  bsc#1175010).
- arm64: tegra: Fix Tegra194 PCIe compatible string (none
  bsc#1175009).
- commit a5198b8
* Fri Aug  7 2020 mbrugger@suse.com
- blacklist.conf: ignore rk3368 dts fixes
- commit ee22702
* Fri Aug  7 2020 mbrugger@suse.com
- blacklist.conf: add unsupported Arm devicetree folder
- commit b7cfb90
* Fri Aug  7 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/brcmfmac-set-timeout-value-when-configuring-power-save.patch
- commit 3eb2862
* Fri Aug  7 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/brcmfmac-Transform-compatible-string-for-FW-loading.patch
  patches.suse/scsi-lpfc-Add-an-internal-trace-log-buffer.patch
  patches.suse/scsi-lpfc-Add-blk_io_poll-support-for-latency-improv.patch
  patches.suse/scsi-lpfc-Add-support-to-display-if-adapter-dumps-ar.patch
  patches.suse/scsi-lpfc-Allow-applications-to-issue-Common-Set-Fea.patch
  patches.suse/scsi-lpfc-Fix-NVMe-rport-deregister-and-registration.patch
  patches.suse/scsi-lpfc-Fix-inconsistent-indenting.patch
  patches.suse/scsi-lpfc-Fix-interrupt-assignments-when-multiple-ve.patch
  patches.suse/scsi-lpfc-Fix-kdump-hang-on-PPC.patch
  patches.suse/scsi-lpfc-Fix-language-in-0373-message-to-reflect-no.patch
  patches.suse/scsi-lpfc-Fix-less-than-zero-comparison-of-unsigned-.patch
  patches.suse/scsi-lpfc-Fix-missing-MDS-functionality.patch
  patches.suse/scsi-lpfc-Fix-oops-due-to-overrun-when-reading-SLI3-.patch
  patches.suse/scsi-lpfc-Fix-shost-refcount-mismatch-when-deleting-.patch
  patches.suse/scsi-lpfc-Fix-stack-trace-seen-while-setting-rrq-act.patch
  patches.suse/scsi-lpfc-Fix-unused-assignment-in-lpfc_sli4_bsg_lin.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.2.patch
- commit adcc571
* Fri Aug  7 2020 tiwai@suse.de
- thermal: ti-soc-thermal: Fix reversed condition in
  ti_thermal_expose_sensor() (git-fixes).
- Staging: rtl8188eu: rtw_mlme: Fix uninitialized variable
  authmode (git-fixes).
- staging: rtl8192u: fix a dubious looking mask before a shift
  (git-fixes).
- spi: lantiq-ssc: Fix warning by using WQ_MEM_RECLAIM
  (git-fixes).
- spi: davinci: Remove uninitialized_var() usage (git-fixes).
- commit e403b7a
* Fri Aug  7 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/btrfs-make-btrfs_ordered_extent-naming-consistent-wi.patch
- commit 3f5df49
* Fri Aug  7 2020 tiwai@suse.de
- ALSA: echoaudio: Race conditions around "opencount" (git-fixes).
- commit 9c2eff2
* Fri Aug  7 2020 tiwai@suse.de
- ALSA: pci: delete repeated words in comments (git-fixes).
- ALSA: isa: delete repeated words in comments (git-fixes).
- ALSA: seq: oss: Serialize ioctls (git-fixes).
- ALSA: hda/hdmi: Add quirk to force connectivity (git-fixes).
- ALSA: usb-audio: add startech usb audio dock name (git-fixes).
- ALSA: usb-audio: Add support for Lenovo ThinkStation P620
  (git-fixes).
- ASoC: hdac_hda: fix deadlock after PCM open error (git-fixes).
- ALSA: hda: fix snd_hda_codec_cleanup() documentation
  (git-fixes).
- ASoC: Intel: bxt_rt298: add missing .owner field (git-fixes).
- ASoC: SOF: nocodec: add missing .owner field (git-fixes).
- ASoC: fsl_sai: Fix value of FSL_SAI_CR1_RFW_MASK (git-fixes).
- ASoC: meson: axg-tdmin: fix g12a skew (git-fixes).
- ASoC: meson: axg-tdm-interface: fix link fmt setup (git-fixes).
- ASoC: meson: fixes the missed kfree() for
  axg_card_add_tdm_loopback (git-fixes).
- Revert "ALSA: hda: call runtime_allow() for all hda controllers"
  (git-fixes).
- ALSA: hda/ca0132 - Fix AE-5 microphone selection commands
  (git-fixes).
- ALSA: hda/ca0132 - Add new quirk ID for Recon3D (git-fixes).
- ALSA: hda/ca0132 - Fix ZxR Headphone gain control get value
  (git-fixes).
- ALSA: usb-audio: endpoint : remove needless check before
  usb_free_coherent() (git-fixes).
- ALSA: asihpi: delete duplicated word (git-fixes).
- ALSA: line6: Use kmemdup in podhd_set_monitor_level()
  (git-fixes).
- ALSA: hda: Add support for Loongson 7A1000 controller
  (git-fixes).
- ALSA: hda/tegra: Disable sync-write operation (git-fixes).
- ALSA: echoaudio: re-enable IRQs on failure path (git-fixes).
- ALSA: line6: add hw monitor volume control for POD HD500
  (git-fixes).
- ALSA: xen: Remove superfluous fall through comments (git-fixes).
- ALSA: atmel: Remove invalid "fall through" comments (git-fixes).
- ALSA: echoaudio: Address bugs in the interrupt handling
  (git-fixes).
- ALSA: echoaudio: Prevent some noise on unloading the module
  (git-fixes).
- ALSA: echoaudio: Prevent races in calls to set_audio_format()
  (git-fixes).
- ALSA: echoaudio: Remove redundant check (git-fixes).
- ALSA: usb/line6: remove 'defined but not used' warning
  (git-fixes).
- ALSA: pci/au88x0: remove "defined but not used" warnings
  (git-fixes).
- ALSA: vx_core: remove warning for empty loop body (git-fixes).
- ALSA: pcmcia/pdaudiocf: fix kernel-doc (git-fixes).
- ALSA: pci/via82xx: remove 'set but not used' warnings
  (git-fixes).
- ALSA: pci/fm801: fix kernel-doc (git-fixes).
- ALSA: pci/es1938: remove 'set but not used' warning (git-fixes).
- ALSA: xen: remove 'set but not used' warning (git-fixes).
- ALSA: pci/oxygen/xonar_wm87x6: remove always true condition
  (git-fixes).
- ALSA: pci/rme9652/hdspm: remove always true condition
  (git-fixes).
- ALSA: pci/korg1212: remove 'set but not used' warnings
  (git-fixes).
- ALSA: pci/emu10k1: remove 'set but not used' warning
  (git-fixes).
- ALSA: firewire: fix kernel-doc (git-fixes).
- ALSA: pci/ctxfi: fix kernel-doc warnings (git-fixes).
- ALSA: pci/ctxfi/ctatc: fix kernel-doc (git-fixes).
- ALSA: pci/aw2-saa7146: remove 'set but not used' warning
  (git-fixes).
- ALSA: pci/echoaudio: remove 'set but not used' warning
  (git-fixes).
- ALSA: pci/asihpi: remove 'set but not used' warning (git-fixes).
- ALSA: pci/asihpi: fix kernel-doc (git-fixes).
- ALSA: pci/asihpi: remove 'set but not used' warnings
  (git-fixes).
- ALSA: isa/gus: remove 'set but not used' warning (git-fixes).
- ALSA: isa/gus: remove -Wmissing-prototypes warnings (git-fixes).
- ALSA: core: pcm_iec958: fix kernel-doc (git-fixes).
- ALSA: usb-audio: Fix some typos (git-fixes).
- ALSA: hda: Enable sync-write operation as default for all
  controllers (git-fixes).
- ALSA: hda/realtek: Add alc269/alc662 pin-tables for Loongson-3
  laptops (git-fixes).
- commit 49b9124
* Fri Aug  7 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/rhashtable-Document-the-right-function-parameters.patch
  patches.suse/rhashtable-Fix-unprotected-RCU-dereference-in-__rht_.patch
- commit 1af1b05
* Thu Aug  6 2020 tiwai@suse.de
- Re-sort another cherry-picked i915 patch in the upstream
  Refresh patches.suse/drm-i915-Actually-emit-the-await_start.patch
- commit 46112ad
* Thu Aug  6 2020 tiwai@suse.de
- Resort the i915 cherry-picked patch
  Refresh
  patches.suse/drm-i915-Protect-i915_request_await_start-from-early.patch
  patches.suse/drm-i915-Return-early-for-await_start-on-same-timeli.patch
- commit 20cca9b
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Return early for await_start on same timeline
  (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Protect-i915_request_await_start-from-early.patch.
- commit 06dbabf
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Improve the start alignment of bonded pairs
  (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Reorder-await_execution-before-await_reques.patch.
- commit 44313fe
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Mark up unlocked update of i915_request.hwsp_seqno
  (bsc#1174737).
- commit 50bee7f
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Mark racy read of intel_engine_cs.saturated
  (bsc#1174737).
- commit e5038ad
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Do not poison i915_request.link on removal
  (bsc#1174737).
- commit 808ecc5
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Actually emit the await_start (bsc#1174737).
- commit f0424b5
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Protect i915_request_await_start from early waits
  (bsc#1174737).
- commit 03accf1
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Flush execution tasklets before checking request
  status (bsc#1174737).
- drm/i915: Flush tasklet submission before sleeping on
  i915_request_wait (bsc#1174737).
- commit 140a397
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915/gt: Flush submission tasklet before waiting/retiring
  (bsc#1174737).
- commit b17d2a1
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Keep track of request among the scheduling lists
  (bsc#1174737).
- commit 4388a9e
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Eliminate the trylock for awaiting an earlier request
  (bsc#1174737).
- Refresh
  patches.suse/0002-drm-i915-gt-Do-not-schedule-normal-requests-immediat.patch.
- commit 590b628
* Thu Aug  6 2020 jgross@suse.com
- xen/pvcalls-back: test for errors when calling backend_connect()
  (bsc#1065600).
- commit cbfa27b
* Thu Aug  6 2020 tiwai@suse.de
- drm/i915: Use EAGAIN for trylock failures (bsc#1174737).
- commit d8a7f90
* Thu Aug  6 2020 martin.wilck@suse.com
- kabi/severities: ignore KABI for NVMe, except nvme-fc (bsc#1174777)
  Exported symbols under drivers/nvme/host/ are only used by the
  nvme subsystem itself, except for the nvme-fc symbols.
- commit 16ddcd8
* Thu Aug  6 2020 martin.wilck@suse.com
- nvme-multipath: round-robin: eliminate "fallback" variable
  (bsc#1172108).
- commit 4cdac03
* Thu Aug  6 2020 martin.wilck@suse.com
- nvme: multipath: round-robin: fix single non-optimized path case
  (bsc#1172108).
- commit 3d56aa0
* Thu Aug  6 2020 tbogendoerfer@suse.de
- ionic: unlock queue mutex in error path (bsc#1167773).
- devlink: ignore -EOPNOTSUPP errors on dumpit (bsc#1154353).
- net/mlx5e: Fix kernel crash when setting vf VLANID on a VF dev
  (jsc#SLE-8464).
- net/mlx5: E-switch, Destroy TSAR when fail to enable the mode
  (jsc#SLE-8464).
- RDMA/mlx5: Fix prefetch memory leak if get_prefetchable_mr fails
  (jsc#SLE-8446).
- commit 23bdd26
* Thu Aug  6 2020 glin@suse.com
- libbpf: Wrap source argument of BPF_CORE_READ macro in
  parentheses (bsc#1155518).
- bpf: Fix map leak in HASH_OF_MAPS map (bsc#1155518).
- net, sk_msg: Don't use RCU_INIT_POINTER on sk_user_data
  (bsc#1155518).
- commit a6677ae
* Thu Aug  6 2020 tiwai@suse.de
- wireless: Use linux/stddef.h instead of stddef.h (git-fixes).
- commit ec3012b
* Thu Aug  6 2020 tiwai@suse.de
- wl1251: fix always return 0 error (git-fixes).
- video: pxafb: Fix the function used to balance a
  'dma_alloc_coherent()' call (git-fixes).
- video: fbdev: sm712fb: fix an issue about iounmap for a wrong
  address (git-fixes).
- USB: serial: iuu_phoenix: fix led-activity helpers (git-fixes).
- USB: serial: cp210x: re-enable auto-RTS on open (git-fixes).
- USB: serial: cp210x: enable usb generic throttle/unthrottle
  (git-fixes).
- USB: iowarrior: fix up report size handling for some devices
  (git-fixes).
- usb: gadget: f_uac2: fix AC Interface Header Descriptor
  wTotalLength (git-fixes).
- usb: core: fix quirks_param_set() writing to a const pointer
  (git-fixes).
- usb: dwc2: gadget: Make use of GINTMSK2 (git-fixes).
- usbip: tools: fix module name in man page (git-fixes).
- usb: hso: Fix debug compile warning on sparc32 (git-fixes).
- wireless: Use offsetof instead of custom macro (git-fixes).
- commit 0511c57
* Thu Aug  6 2020 tiwai@suse.de
- rtw88: fix short GI capability based on current bandwidth
  (git-fixes).
- rtw88: fix LDPC field for RA info (git-fixes).
- mac80211: fix misplaced while instead of if (git-fixes).
- liquidio: Fix wrong return value in cn23xx_get_pf_num()
  (git-fixes).
- mwifiex: Fix firmware filename for sd8997 chipset (git-fixes).
- mwifiex: Fix firmware filename for sd8977 chipset (git-fixes).
- mwifiex: Prevent memory corruption handling keys (git-fixes).
- leds: gpio: Fix semantic error (git-fixes).
- leds: core: Flush scheduled work for system suspend (git-fixes).
- leds: wm831x-status: fix use-after-free on unbind (git-fixes).
- leds: lm36274: fix use-after-free on unbind (git-fixes).
- leds: lm3533: fix use-after-free on unbind (git-fixes).
- leds: da903x: fix use-after-free on unbind (git-fixes).
- phy: armada-38x: fix NETA lockup when repeatedly switching
  speeds (git-fixes).
- phy: renesas: rcar-gen3-usb2: move irq registration to init
  (git-fixes).
- phy: exynos5-usbdrd: Calibrating makes sense only for USB2.0
  PHY (git-fixes).
- net: lan78xx: fix transfer-buffer memory leak (git-fixes).
- net: lan78xx: add missing endpoint sanity check (git-fixes).
- drivers/net/wan: lapb: Corrected the usage of skb_cow
  (git-fixes).
- nfc: s3fwrn5: add missing release on skb in s3fwrn5_recv_frame
  (git-fixes).
- commit ffa42ff
* Thu Aug  6 2020 tiwai@suse.de
- drm/etnaviv: Fix error path on failure to enable bus clk
  (git-fixes).
- drm/imx: imx-ldb: Disable both channels for split mode in
  enc->disable() (git-fixes).
- drm/imx: tve: fix regulator_disable error path (git-fixes).
- drm/imx: fix use after free (git-fixes).
- drm/bridge: sil_sii8620: initialize return of sii8620_readb
  (git-fixes).
- drm: panel: simple: Fix bpc for LG LB070WV8 panel (git-fixes).
- drm/stm: repair runtime power management (git-fixes).
- drm/mipi: use dcs write for mipi_dsi_dcs_set_tear_scanline
  (git-fixes).
- drm/radeon: fix array out-of-bounds read and write issues
  (git-fixes).
- drm/panel: otm8009a: Drop unnessary
  backlight_device_unregister() (git-fixes).
- drm/arm: fix unintentional integer overflow on left shift
  (git-fixes).
- drm/bridge: ti-sn65dsi86: Don't use kernel-doc comment for
  local array (git-fixes).
- drm/bridge: ti-sn65dsi86: Clear old error bits before AUX
  transfers (git-fixes).
- drm/gem: Fix a leak in drm_gem_objects_lookup() (git-fixes).
- leds: 88pm860x: fix use-after-free on unbind (git-fixes).
- leds: lm355x: avoid enum conversion warning (git-fixes).
- gpio: max77620: Fix missing release of interrupt (git-fixes).
- kobject: Avoid premature parent object freeing in
  kobject_cleanup() (git-fixes).
- commit 004490b
* Thu Aug  6 2020 tiwai@suse.de
- appletalk: Fix atalk_proc_init() return path (git-fixes).
- Bluetooth: hci_serdev: Only unregister device if it was
  registered (git-fixes).
- Bluetooth: hci_h5: Set HCI_UART_RESET_ON_INIT to correct flags
  (git-fixes).
- Bluetooth: Fix update of connection state in `hci_encrypt_cfm`
  (git-fixes).
- Bluetooth: btmtksdio: fix up firmware download sequence
  (git-fixes).
- Bluetooth: btusb: fix up firmware download sequence (git-fixes).
- btmrvl: Fix firmware filename for sd8997 chipset (git-fixes).
- btmrvl: Fix firmware filename for sd8977 chipset (git-fixes).
- ath10k: Acquire tx_lock in tx error paths (git-fixes).
- agp/intel: Fix a memory leak on module initialisation failure
  (git-fixes).
- console: newport_con: fix an issue about leak related system
  resources (git-fixes).
- driver core: Avoid binding drivers to dead devices (git-fixes).
- devres: keep both device name and resource name in pretty name
  (git-fixes).
- b43: Remove uninitialized_var() usage (git-fixes).
- Bluetooth: fix kernel oops in store_pending_adv_report
  (git-fixes).
- drm: hold gem reference until object is no longer accessed
  (git-fixes).
- dlm: remove BUG() before panic() (git-fixes).
- ath10k: enable transmit data ack RSSI for QCA9884 (git-fixes).
- commit 964f75f
* Wed Aug  5 2020 nsaenzjulienne@suse.de
- firmware: smccc: Add ARCH_SOC_ID support (bsc#1174906).
- Update arm64 config
- firmware: smccc: Add function to fetch SMCCC version
  (bsc#1174906).
- firmware: smccc: Refactor SMCCC specific bits into separate file
  (bsc#1174906).
- firmware: smccc: Drop smccc_version enum and use
  ARM_SMCCC_VERSION_1_x instead (bsc#1174906).
- firmware: smccc: Add the definition for SMCCCv1.2 version/error
  codes (bsc#1174906).
- firmware: smccc: Update link to latest SMCCC specification
  (bsc#1174906).
- firmware: smccc: Add HAVE_ARM_SMCCC_DISCOVERY to identify SMCCC v1.1 and above (bsc#1174906).
- Update arm64 config
- arm/arm64: Make use of the SMCCC 1.1 wrapper (bsc#1174906).
- arm/arm64: Provide a wrapper for SMCCC 1.1 calls (bsc#1174906).
- firmware: arm_sdei: use common SMCCC_CONDUIT_* (bsc#1174906).
- firmware/psci: use common SMCCC_CONDUIT_* (bsc#1174906).
- arm: spectre-v2: use arm_smccc_1_1_get_conduit() (bsc#1174906).
- arm64: errata: use arm_smccc_1_1_get_conduit() (bsc#1174906).
- arm/arm64: smccc/psci: add arm_smccc_1_1_get_conduit()
  (bsc#1174906).
- commit 91485ab
* Wed Aug  5 2020 mbrugger@suse.com
- blacklist.conf: ignore documentation fixes
- commit da3606d
* Wed Aug  5 2020 wqu@suse.com
- btrfs: qgroup: remove ASYNC_COMMIT mechanism in favor of
  reserve retry-after-EDQUOT (bsc#1120163).
- commit a0c01d8
* Wed Aug  5 2020 wqu@suse.com
- btrfs: qgroup: try to flush qgroup space when we get  -EDQUOT
  (bsc#1120163).
- commit 110b26f
* Wed Aug  5 2020 wqu@suse.com
- btrfs: qgroup: allow to unreserve range without releasing
  other ranges (bsc#1120163).
- commit 292ee83
* Wed Aug  5 2020 wqu@suse.com
- btrfs: qgroup: fix data leak caused by race between writeback
  and truncate (bsc#1172247).
- commit e7691a1
* Wed Aug  5 2020 wqu@suse.com
- btrfs: change timing for qgroup reserved space for  ordered
  extents to fix reserved space leak (bsc#1172247).
- commit 5f13741
* Wed Aug  5 2020 wqu@suse.com
- btrfs: file: reserve qgroup space after the hole punch  range
  is locked (bsc#1172247).
- commit c1e305c
* Wed Aug  5 2020 wqu@suse.com
- btrfs: inode: move qgroup reserved space release to the  callers
  of insert_reserved_file_extent() (bsc#1172247).
- commit c77d18c
* Wed Aug  5 2020 wqu@suse.com
- btrfs: inode: refactor the parameters of
  insert_reserved_file_extent() (bsc#1172247).
- commit 999728e
* Wed Aug  5 2020 wqu@suse.com
- btrfs: make btrfs_ordered_extent naming consistent with
  btrfs_file_extent_item (bsc#1172247).
- commit 3a23bcd
* Wed Aug  5 2020 glin@suse.com
- bpf: net: Avoid incorrect bpf_sk_reuseport_detach call
  (bsc#1155518).
- bpf: net: Avoid copying sk_user_data of reuseport_array during
  sk_clone (bsc#1155518).
- net, sk_msg: Clear sk_user_data pointer on clone if tagged
  (bsc#1155518).
- commit 9a81f17
* Wed Aug  5 2020 dbueso@suse.de
- rhashtable: Restore RCU marking on rhash_lock_head
  (bsc#1174880).
- rhashtable: Fix unprotected RCU dereference in __rht_ptr
  (bsc#1174880).
- rhashtable: drop duplicated word in <linux/rhashtable.h>
  (bsc#1174880).
- rhashtable: Drop raw RCU deref in nested_table_free
  (bsc#1174880).
- rhashtable: Document the right function parameters
  (bsc#1174880).
- commit c0ec5b4
* Tue Aug  4 2020 lyan@suse.com
- KVM: arm64: Make vcpu_cp1x() work on Big Endian hosts
  (bsc#1133021).
- KVM: arm64: Stop writing aarch32's CSSELR into ACTLR
  (bsc#1133021).
- KVM: arm64: Fix 32bit PC wrap-around (bsc#1133021).
- KVM: arm: vgic: Fix limit condition when writing to
  GICD_IACTIVER (bsc#1133021).
- KVM: arm64: Use the correct timer structure to access the
  physical counter (bsc#1133021).
- KVM: arm/arm64: Correct AArch32 SPSR on exception entry
  (bsc#1133021).
- KVM: arm/arm64: Correct CPSR on exception entry (bsc#1133021).
- KVM: arm64: Correct PSTATE on exception entry (bsc#1133021).
- KVM: Play nice with read-only memslots when querying host page
  size (bsc#1133021).
- commit 854e6da
* Tue Aug  4 2020 tiwai@suse.de
- drm/i915: Reorder await_execution before await_request
  (bsc#1174737).
- commit 75817a8
* Tue Aug  4 2020 tiwai@suse.de
- drm/i915: Copy across scheduler behaviour flags across submit
  fences (bsc#1174737).
- commit 718e478
* Tue Aug  4 2020 tiwai@suse.de
- drm/i915: Lock signaler timeline while navigating (bsc#1174737).
- commit d0600f4
* Tue Aug  4 2020 tiwai@suse.de
- drm/i915: Mark i915_request.timeline as a volatile, rcu pointer
  (bsc#1174737).
- Refresh
  patches.suse/drm-i915-Hold-reference-to-intel_frontbuffer-as-we-t.patch.
- Refresh
  patches.suse/drm-i915-Protect-context-while-grabbing-its-name-for.patch.
- Refresh
  patches.suse/drm-i915-Reduce-nested-prepare_remote_context-to-a-t.patch.
- commit fce086e
* Tue Aug  4 2020 lyan@suse.com
- KVM: s390: Remove false WARN_ON_ONCE for the PQAP instruction
  (bsc#1133021).
- commit f7e204d
* Tue Aug  4 2020 nsaenzjulienne@suse.de
- clk: bcm2835: Do not use prediv with bcm2711's PLLs
  (bsc#1174865).
- brcmfmac: Set timeout value when configuring power save
  (bsc#1173468).
- commit 4d732a9
* Tue Aug  4 2020 tbogendoerfer@suse.de
- IB/rdmavt: Fix RQ counting issues causing use of an invalid RWQE
  (bsc#1174770).
- commit 4c02379
* Tue Aug  4 2020 tiwai@suse.de
- spi: rockchip: Fix error in SPI slave pio read (git-fixes).
- spi: sun4i: update max transfer size reported (git-fixes).
- spi: lantiq: fix: Rx overflow error in full duplex mode
  (git-fixes).
- spi: spi-geni-qcom: Actually use our FIFO (git-fixes).
- regulator: gpio: Honor regulator-boot-on property (git-fixes).
- clk: scmi: Fix min and max rate when registering clocks with
  discrete rates (git-fixes).
- firmware: arm_scmi: Keep the discrete clock rates sorted
  (git-fixes).
- firmware: arm_scmi: Fix SCMI genpd domain probing (git-fixes).
- platform/x86: intel-vbtn: Fix return value check in
  check_acpi_dev() (git-fixes).
- platform/x86: intel-hid: Fix return value check in
  check_acpi_dev() (git-fixes).
- crypto: qat - fix double free in qat_uclo_create_batch_init_list
  (git-fixes).
- crypto: ccp - Fix use of merged scatterlists (git-fixes).
- crypto: ccree - fix resource leak on error path (git-fixes).
- crypto: hisilicon - don't sleep of CRYPTO_TFM_REQ_MAY_SLEEP
  was not specified (git-fixes).
- crypto: cpt - don't sleep of CRYPTO_TFM_REQ_MAY_SLEEP was not
  specified (git-fixes).
- crypto: caam - Fix argument type in handle_imx6_err005766
  (git-fixes).
- crc-t10dif: Fix potential crypto notify dead-lock (git-fixes).
- tpm: Require that all digests are present in TCG_PCR_EVENT2
  structures (git-fixes).
- commit 64bac7f
* Mon Aug  3 2020 lyan@suse.com
- kABI workaround for struct kvm_device (git-fixes).
  Just change an variable to "const" type in kvm_device.
- commit 1c95856
* Mon Aug  3 2020 lyan@suse.com
- kABI workaround for enum cpuhp_state (git-fixes).
- commit 889dc24
* Mon Aug  3 2020 lyan@suse.com
- kABI workaround for struct kvm_vcpu_arch (git-fixes).
  Add a struct variable to the end of kvm_vcpu_arch and kvm_vcpu_arch
  is embedded into kvm_vcpu at the end. It is usually used by pointer
  and allocated dynamically, so this change should be fine even for
  external kvm module.
- commit c324264
* Mon Aug  3 2020 jack@suse.cz
- patches.suse/revert-zram-convert-remaining-class_attr-to-class_attr_ro:
  Update tags
- commit 3b99445
* Mon Aug  3 2020 jack@suse.cz
- gfs2: fix gfs2_find_jhead that returns uninitialized jhead
  with seq 0 (bsc#1174825).
- commit 796da2e
* Mon Aug  3 2020 jack@suse.cz
- gfs2: Another gfs2_find_jhead fix (bsc#1174824).
- commit eb92077
* Mon Aug  3 2020 lhenriques@suse.de
- blacklist.conf: mtd kernel-doc fixes
- commit 12371a2
* Mon Aug  3 2020 jslaby@suse.cz
- Fix for missing check in vgacon scrollback handling (bsc#1174205
  CVE-2020-14331).
  Update to the latest findings/submission.
- commit 2b80031
* Mon Aug  3 2020 shung-hsi.yu@suse.com
- ubsan: check panic_on_warn (bsc#1174805).
- commit 4b3b09b
* Sun Aug  2 2020 tiwai@suse.de
- af_key: pfkey_dump needs parameter validation (git-fixes).
- mac80211: mesh: Free pending skb when destroying a mpath
  (git-fixes).
- mac80211: mesh: Free ie data when leaving mesh (git-fixes).
- i2c: also convert placeholder function to return errno
  (git-fixes).
- drm/amd/display: Clear dm_state for fast updates (git-fixes).
- drm/amdgpu: Prevent kernel-infoleak in amdgpu_info_ioctl()
  (git-fixes).
- regmap: debugfs: check count when read regmap file (git-fixes).
- PM: wakeup: Show statistics for deleted wakeup sources again
  (git-fixes).
- commit f22517a
* Sun Aug  2 2020 tiwai@suse.de
- ALSA: hda/realtek - Fixed HP right speaker no sound (git-fixes).
- ALSA: hda: fix NULL pointer dereference during suspend
  (git-fixes).
- ALSA: hda/hdmi: Fix keep_power assignment for non-component
  devices (git-fixes).
- ALSA: hda: Workaround for spurious wakeups on some Intel
  platforms (git-fixes).
- ALSA: hda/realtek: Fix add a "ultra_low_power" function for
  intel reference board (alc256) (git-fixes).
- ALSA: hda/realtek: typo_fix: enable headset mic of ASUS ROG
  Zephyrus G14(GA401) series with ALC289 (git-fixes).
- ALSA: hda/realtek: enable headset mic of ASUS ROG Zephyrus
  G15(GA502) series with ALC289 (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for SSL2
  (git-fixes).
- commit 7cc8f61
* Fri Jul 31 2020 mkoutny@suse.com
- mm: Fix protection usage propagation (bsc#1174002).
- commit 446569c
* Fri Jul 31 2020 tiwai@suse.de
- Revert "drm/amdgpu: Fix NULL dereference in dpm sysfs handlers"
  (git-fixes).
- ARM: percpu.h: fix build error (git-fixes).
- random: fix circular include dependency on arm64 after addition
  of percpu.h (git-fixes).
- commit a78809a
* Fri Jul 31 2020 mbrugger@suse.com
- uio_pdrv_genirq: Remove warning when irq is not specified
  (bsc#1174762).
- commit 31bf7b7
* Fri Jul 31 2020 tiwai@suse.de
- random32: update the net random state on interrupt and activity
  (CVE-2020-16166 bsc#1174757).
- commit 81d991d
* Fri Jul 31 2020 tiwai@suse.de
- PCI/ASPM: Disable ASPM on ASMedia ASM1083/1085 PCIe-to-PCI
  bridge (git-fixes).
- commit f661820
* Thu Jul 30 2020 tiwai@suse.de
- 9p/trans_fd: Fix concurrency del of req_list in
  p9_fd_cancelled/p9_read_work (git-fixes).
- staging: wlan-ng: properly check endpoint types (git-fixes).
- serial: exar: Fix GPIO configuration for Sealevel cards based
  on XR17V35X (git-fixes).
- fbdev: Detect integer underflow at "struct
  fbcon_ops"->clear_margins (git-fixes).
- serial: 8250_mtk: Fix high-speed baud rates clamping
  (git-fixes).
- serial: 8250: fix null-ptr-deref in serial8250_start_tx()
  (git-fixes).
- serial: tegra: fix CREAD handling for PIO (git-fixes).
- vt: Reject zero-sized screen buffer size (git-fixes).
- usb: xhci: Fix ASM2142/ASM3142 DMA addressing (git-fixes).
- drm/amdgpu: Fix NULL dereference in dpm sysfs handlers
  (git-fixes).
- usb: gadget: udc: gr_udc: fix memleak on error handling path
  in gr_ep_init() (git-fixes).
- usb: dwc3: pci: add support for the Intel Jasper Lake
  (git-fixes).
- usb: dwc3: pci: add support for the Intel Tiger Lake PCH -H
  variant (git-fixes).
- hwmon: (scmi) Fix potential buffer overflow in
  scmi_hwmon_probe() (git-fixes).
- hwmon: (nct6775) Accept PECI Calibration as temperature source
  for NCT6798D (git-fixes).
- hwmon: (adm1275) Make sure we are reading enough data for
  different chips (git-fixes).
- hwmon: (aspeed-pwm-tacho) Avoid possible buffer overflow
  (git-fixes).
- spi: mediatek: use correct SPI_CFG2_REG MACRO (git-fixes).
- regmap: dev_get_regmap_match(): fix string comparison
  (git-fixes).
- HID: apple: Disable Fn-key key-re-mapping on clone keyboards
  (git-fixes).
- HID: steam: fixes race in handling device list (git-fixes).
- HID: alps: support devices with report id 2 (git-fixes).
- HID: i2c-hid: add Mediacom FlexBook edge13 to descriptor
  override (git-fixes).
- drm/amdgpu: fix preemption unit test (git-fixes).
- drm/amdgpu/gfx10: fix race condition for kiq (git-fixes).
- serial: mxs-auart: add missed iounmap() in probe failure and
  remove (git-fixes).
- dmaengine: ioat setting ioat timeout as module parameter
  (git-fixes).
- dmaengine: fsl-edma: fix wrong tcd endianness for big-endian
  cpu (git-fixes).
- dmaengine: tegra210-adma: Fix runtime PM imbalance on error
  (git-fixes).
- Input: elan_i2c - only increment wakeup count on touch
  (git-fixes).
- Input: synaptics - enable InterTouch for ThinkPad X1E 1st gen
  (git-fixes).
- mac80211: allow rx of mesh eapol frames with default rx key
  (git-fixes).
- pinctrl: amd: fix npins for uart0 in kerncz_groups (git-fixes).
- gpio: arizona: put pm_runtime in case of failure (git-fixes).
- gpio: arizona: handle pm_runtime_get_sync failure case
  (git-fixes).
- drivers/firmware/psci: Fix memory leakage in
  alloc_init_cpu_groups() (git-fixes).
- drm/nouveau/i2c/g94-: increase NV_PMGR_DP_AUXCTL_TRANSACTREQ
  timeout (git-fixes).
- serial: amba-pl011: Make sure we initialize the port.lock
  spinlock (git-fixes).
- serial: 8250_pci: Move Pericom IDs to pci_ids.h (git-fixes).
- commit 5b7d8a8
* Thu Jul 30 2020 hare@suse.de
- nvme: kABI fixes for nvme_ctrl (bsc#1159058).
- commit dc7531f
* Thu Jul 30 2020 ghe@suse.com
- ocfs2: fix panic on nfs server over ocfs2 (bsc#1172963).
- ocfs2: load global_inode_alloc (bsc#1172963).
- ocfs2: avoid inode removal while nfsd is accessing it
  (bsc#1172963).
- commit 1a01c78
* Thu Jul 30 2020 aherrmann@suse.com
- docs: fix memory.low description in cgroup-v2.rst (git-fixes).
  (SLE documentation might refer to cgroup-v2.rst.)
- commit 1c58dff
* Thu Jul 30 2020 aherrmann@suse.com
- net: Fix a documentation bug wrt. ip_unprivileged_port_start (git-fixes).
  (SLES tuning guide refers to ip-sysctl.txt.)
- commit b51f83b
* Thu Jul 30 2020 aherrmann@suse.com
- blacklist.conf: Add dc8d37ed304ee ("cpu/SMT: Fix x86 link error without CONFIG_SYSFS")
- commit 24e5ac8
* Thu Jul 30 2020 aherrmann@suse.com
- blacklist.conf: Add 98919f4c9a342 ("Documentation: debugfs: Document debugfs helper for unsigned long values")
- commit 5a3f2df
* Thu Jul 30 2020 aherrmann@suse.com
- io-mapping: indicate mapping failure (git-fixes).
- commit b3a6154
* Wed Jul 29 2020 dwagner@suse.de
- powerpc/pseries: PCIE PHB reset (bsc#1174689).
- powerpc/eeh: Fix pseries_eeh_configure_bridge() (bsc#1174689).
- commit ba8e81b
* Wed Jul 29 2020 hare@suse.de
- nvme: consolodate io settings (bsc#1159058).
- nvme: revalidate namespace stream parameters (bsc#1159058).
- nvme: consolidate chunk_sectors settings (bsc#1159058).
- nvme: revalidate after verifying identifiers (bsc#1159058).
- nvme-multipath: set bdi capabilities once (bsc#1159058).
- nvme: check namespace head shared property (bsc#1159058).
- nvme: always search for namespace head (bsc#1159058).
- nvme: release namespace head reference on error (bsc#1159058).
- nvme: unlink head after removing last namespace (bsc#1159058).
- nvme: remove the magic 1024 constant in nvme_scan_ns_list
  (bsc#1159058).
- nvme: avoid an Identify Controller command for each namespace
  (bsc#1159058).
- nvme: factor out a nvme_ns_remove_by_nsid helper (bsc#1159058).
- nvme: clean up nvme_scan_work (bsc#1159058).
- nvme: refine the Qemu Identify CNS quirk (bsc#1159058).
- nvme: remove unused parameter (bsc#1159058).
- commit fe17413
* Wed Jul 29 2020 rgoldwyn@suse.com
- Delete patches.suse/apparmor-Fix-memory-leak-of-profile-proxy.patch (bsc#1174627)
- commit dbe0add
* Wed Jul 29 2020 hare@suse.de
- nvme-multipath: do not fall back to __nvme_find_path() for non-optimized paths (bsc#1172108).
- nvme-multipath: fix logic for non-optimized paths (bsc#1172108).
- commit a2fe085
* Wed Jul 29 2020 dwagner@suse.de
- xfrm: fix a warning in xfrm_policy_insert_list (bsc#1174645).
- commit e77828e
* Wed Jul 29 2020 tbogendoerfer@suse.de
- IB/mlx5: Fix DEVX support for MLX5_CMD_OP_INIT2INIT_QP command
  (git-fixes).
- i40iw: fix null pointer dereference on a null wqe pointer
  (git-fixes).
- commit 76175e9
* Wed Jul 29 2020 mbenes@suse.cz
- x86/stacktrace: Fix reliable check for empty user task stacks
  (bsc#1058115).
- commit 4883ff2
* Wed Jul 29 2020 tbogendoerfer@suse.de
- qed: suppress false-positives interrupt error messages on HW
  init (git-fixes).
- qed: suppress "don't support RoCE & iWARP" flooding on HW init
  (git-fixes).
- netdevsim: fix unbalaced locking in nsim_create() (git-fixes).
- net: hns3: fix return value error when query MAC link status
  fail (git-fixes).
- net: hns3: fix error handling for desc filling (git-fixes).
- net: hns3: fix for not calculating TX BD send size correctly
  (git-fixes).
- ionic: use mutex to protect queue operations (bsc#1167773).
- ionic: keep rss hash after fw update (bsc#1167773).
- ionic: update filter id after replay (bsc#1167773).
- ionic: fix up filter locks and debug msgs (bsc#1167773).
- ionic: use offset for ethtool regs data (bsc#1167773).
- mlxsw: core: Fix wrong SFP EEPROM reading for upper pages 1-3
  (bsc#1154488).
- rtnetlink: Fix memory(net_device) leak when ->newlink fails
  (bsc#1154353).
- bnxt_en: Init ethtool link settings after reading updated PHY
  configuration (jsc#SLE-8371 bsc#1153274).
- RDMA/mlx5: Prevent prefetch from racing with implicit
  destruction (jsc#SLE-8446).
- RDMA/core: Fix race in rdma_alloc_commit_uobject() (git-fixes).
- RDMA/mlx5: Use xa_lock_irq when access to SRQ table (git-fixes).
- IB/mlx5: Fix 50G per lane indication (git-fixes).
- RDMA/siw: Fix reporting vendor_part_id (git-fixes).
- IB/sa: Resolv use-after-free in ib_nl_make_request()
  (git-fixes).
- IB/mad: Fix use after free when destroying MAD agent
  (git-fixes).
- RDMA/counter: Query a counter before release (git-fixes).
- RDMA/mad: Fix possible memory leak in ib_mad_post_receive_mads()
  (git-fixes).
- RDMA/cma: Protect bind_list and listen_list while finding
  matching cm id (git-fixes).
- RDMA/qedr: Fix KASAN: use-after-free in ucma_event_handler+0x532
  (git-fixes).
- RDMA/efa: Set maximum pkeys device attribute (git-fixes).
- RDMA/rvt: Fix potential memory leak caused by rvt_alloc_rq
  (git-fixes).
- RDMA/siw: Fix pointer-to-int-cast warning in siw_rx_pbl()
  (git-fixes).
- IB/cma: Fix ports memory leak in cma_configfs (git-fixes).
- RDMA/mlx5: Add init2init as a modify command (git-fixes).
- RDMA/hns: Fix cmdq parameter of querying pf timer resource
  (git-fixes).
- RDMA/hns: Bugfix for querying qkey (git-fixes).
- RDMA/uverbs: Fix create WQ to use the given user handle
  (git-fixes).
- RDMA/mlx5: Verify that QP is created with RQ or SQ (git-fixes).
- RDMA/mlx5: Fix udata response upon SRQ creation (git-fixes).
- RDMA/rxe: Set default vendor ID (git-fixes).
- IB/ipoib: Fix double free of skb in case of multicast traffic
  in CM mode (git-fixes).
- RDMA/core: Fix double destruction of uobject (git-fixes).
- RDMA/pvrdma: Fix missing pci disable in pvrdma_pci_probe()
  (git-fixes).
- IB/qib: Call kobject_put() when kobject_init_and_add() fails
  (git-fixes).
- RDMA/iw_cxgb4: Fix incorrect function parameters (git-fixes).
- RDMA/core: Fix double put of resource (git-fixes).
- IB/core: Fix potential NULL pointer dereference in pkey cache
  (git-fixes).
- IB/mlx4: Test return value of calls to ib_get_cached_pkey
  (git-fixes).
- RDMA/rxe: Always return ERR_PTR from rxe_create_mmap_info()
  (git-fixes).
- i40iw: Fix error handling in i40iw_manage_arp_cache()
  (git-fixes).
- RDMA/core: Fix race between destroy and release FD object
  (git-fixes).
- IB/rdmavt: Always return ERR_PTR from rvt_create_mmap_info()
  (git-fixes).
- RDMA/core: Prevent mixed use of FDs between shared ufiles
  (git-fixes).
- RDMA/mlx5: Set GRH fields in query QP on RoCE (git-fixes).
- RDMA/siw: Fix potential siw_mem refcnt leak in siw_fastreg_mr()
  (git-fixes).
- RDMA/mlx4: Initialize ib_spec on the stack (git-fixes).
- RDMA/cm: Fix an error check in cm_alloc_id_priv() (git-fixes).
- IB/hfi1: Fix memory leaks in sysfs registration and
  unregistration (git-fixes).
- RDMA/rxe: Set sys_image_guid to be aligned with HW IB devices
  (git-fixes).
- RDMA/cm: Update num_paths in cma_resolve_iboe_route error flow
  (git-fixes).
- IB/rdmavt: Delete unused routine (git-fixes).
- i40iw: Report correct firmware version (git-fixes).
- RDMA/cm: Add missing locking around id.state in
  cm_dup_req_handler (git-fixes).
- RDMA/cm: Read id.state under lock when doing pr_debug()
  (git-fixes).
- RDMA/cm: Remove a race freeing timewait_info (git-fixes).
- RDMA/cm: Fix checking for allowed duplicate listens (git-fixes).
- RDMA/cm: Fix ordering of xa_alloc_cyclic() in ib_create_cm_id()
  (git-fixes).
- IB/mlx5: Replace tunnel mpls capability bits for tunnel_offloads
  (git-fixes).
- RDMA/siw: Fix passive connection establishment (git-fixes).
- IB/mlx5: Fix missing congestion control debugfs on rep rdma
  device (git-fixes).
- RDMA/ucma: Put a lock around every call to the rdma_cm layer
  (git-fixes).
- RDMA/siw: Fix setting active_{speed, width} attributes
  (git-fixes).
- RDMA/rxe: Fix configuration of atomic queue pair attributes
  (git-fixes).
- RDMA/siw: Fix setting active_mtu attribute (git-fixes).
- i40iw: Do an RCU lookup in i40iw_add_ipv4_addr (git-fixes).
- RDMA/mlx5: Fix access to wrong pointer while performing flush
  due to error (git-fixes).
- IB/hfi1: Ensure pq is not left on waitlist (git-fixes).
- RDMA/mad: Do not crash if the rdma device does not have a umad
  interface (git-fixes).
- RDMA/core: Fix missing error check on dev_set_name()
  (git-fixes).
- RDMA/mlx5: Fix the number of hwcounters of a dynamic counter
  (git-fixes).
- RDMA/iwcm: Fix iwcm work deallocation (git-fixes).
- RDMA/siw: Fix failure handling during device creation
  (git-fixes).
- RDMA/nldev: Fix crash when set a QP to a new counter but QPN
  is missing (git-fixes).
- RDMA/core: Fix protection fault in ib_mr_pool_destroy
  (git-fixes).
- IB/hfi1, qib: Ensure RCU is locked when accessing list
  (git-fixes).
- RMDA/cm: Fix missing ib_cm_destroy_id() in ib_cm_insert_listen()
  (git-fixes).
- Revert "RDMA/cma: Simplify rdma_resolve_addr() error flow"
  (git-fixes).
- commit 3509d43
* Wed Jul 29 2020 mbenes@suse.cz
- x86/unwind/orc: Fix ORC for newly forked tasks (bsc#1058115).
- commit c9872a0
* Tue Jul 28 2020 tzimmermann@suse.de
- drm/amd/powerplay: fix a crash when overclocking Vega M (bsc#1152472)
- commit e5783e4
* Tue Jul 28 2020 tzimmermann@suse.de
- drm/i915: Move cec_notifier to intel_hdmi_connector_unregister, v2. (bsc#1152489)
  * context changes
- commit 832eb1e
* Tue Jul 28 2020 tzimmermann@suse.de
- drm/i915/gt: Only swap to a random sibling once upon creation (bsc#1152489)
  * context changes
- commit b0d94d8
* Tue Jul 28 2020 tzimmermann@suse.de
- drm/i915/fbc: Fix fence_y_offset handling (bsc#1152489)
  * context changes
- commit c4ded04
* Tue Jul 28 2020 tiwai@suse.de
- rtnetlink: Fix memory(net_device) leak when ->newlink fails
  (git-fixes).
- commit 11a9564
* Tue Jul 28 2020 tiwai@suse.de
- NTB: ntb_test: Fix bug when counting remote files (git-fixes).
- NTB: perf: Fix race condition when run with ntb_test
  (git-fixes).
- NTB: perf: Fix support for hardware that doesn't have port
  numbers (git-fixes).
- NTB: perf: Don't require one more memory window than number
  of peers (git-fixes).
- NTB: ntb_pingpong: Choose doorbells based on port number
  (git-fixes).
- NTB: Fix the default port and peer numbers for legacy drivers
  (git-fixes).
- NTB: Revert the change to use the NTB device dev for DMA
  allocations (git-fixes).
- NTB: ntb_tool: reading the link file should not end in a NULL
  byte (git-fixes).
- ntb_tool: pass correct struct device to dma_alloc_coherent
  (git-fixes).
- ntb_perf: pass correct struct device to dma_alloc_coherent
  (git-fixes).
- ntb: hw: remove the code that sets the DMA mask (git-fixes).
- NTB: Fix static check warning in perf_clear_test (git-fixes).
- habanalabs: increase timeout during reset (git-fixes).
- commit 6d2dc2c
* Tue Jul 28 2020 tiwai@suse.de
- geneve: fix an uninitialized value in geneve_changelink()
  (git-fixes).
- ieee802154: fix one possible memleak in adf7242_probe
  (git-fixes).
- nfc: nci: add missed destroy_workqueue in nci_register_device
  (git-fixes).
- hippi: Fix a size used in a 'pci_free_consistent()' in an
  error handling path (git-fixes).
- i2c: i2c-qcom-geni: Fix DMA transfer race (git-fixes).
- i2c: rcar: always clear ICSAR to avoid side effects (git-fixes).
- Revert "i2c: cadence: Fix the hold bit setting" (git-fixes).
- drm/amd/powerplay: fix a crash when overclocking Vega M
  (git-fixes).
- drm: sun4i: hdmi: Fix inverted HPD result (git-fixes).
- phy: sun4i-usb: fix dereference of pointer phy0 before it is
  null checked (git-fixes).
- commit ce8f443
* Tue Jul 28 2020 tiwai@suse.de
- fpga: dfl: fix bug in port reset handshake (git-fixes).
- staging: comedi: addi_apci_1564: check INSN_CONFIG_DIGITAL_TRIG
  shift (git-fixes).
- staging: comedi: addi_apci_1500: check INSN_CONFIG_DIGITAL_TRIG
  shift (git-fixes).
- staging: comedi: addi_apci_1032: check INSN_CONFIG_DIGITAL_TRIG
  shift (git-fixes).
- staging: comedi: ni_6527: fix INSN_CONFIG_DIGITAL_TRIG support
  (git-fixes).
- usb: tegra: Fix allocation for the FPCI context (git-fixes).
- usb: xhci-mtk: fix the failure of bandwidth allocation
  (git-fixes).
- commit c8a893b
* Tue Jul 28 2020 tiwai@suse.de
- ath9k: Fix regression with Atheros 9271 (git-fixes).
- ath9k: Fix general protection fault in ath9k_hif_usb_rx_cb
  (git-fixes).
- commit 86f66b0
* Tue Jul 28 2020 tiwai@suse.de
- blacklist.conf: remove ath9k commit and add phy/realtek commit
- commit d6994a7
* Tue Jul 28 2020 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: Enable overlayfs
  Overlayfs is needed for podman or docker builds when no more specific
  driver can be used (like lvm or btrfs). As the default build fs is ext4
  currently, we need overlayfs kernel modules to be available.
- commit 29474aa
* Tue Jul 28 2020 jslaby@suse.cz
- vgacon: fix out of bounds write to the scrollback buffer
  (bsc#1174205 CVE-2020-14331).
- commit ffe1c3f
* Mon Jul 27 2020 tiwai@suse.de
- tpm_crb: fix fTPM on AMD Zen+ CPUs (bsc#1174362).
- commit 244d11a
* Mon Jul 27 2020 dwagner@suse.de
- scsi: libfc: Skip additional kref updating work event
  (bsc#1173849).
- scsi: libfc: Handling of extra kref (bsc#1173849).
- scsi: libfc: rport state move to PLOGI if all PRLI retry
  exhausted (bsc#1173849).
- scsi: libfc: If PRLI rejected, move rport to PLOGI state
  (bsc#1173849).
- scsi: libfc: free response frame from GPN_ID (bsc#1173849).
- commit e4b0418
* Mon Jul 27 2020 jslaby@suse.cz
- /dev/mem: Add missing memory barriers for devmem_inode
  (git-fixes).
- commit faada70
* Mon Jul 27 2020 mkubecek@suse.cz
- fix paches metadata
- fix Patch-mainline:
  patches.suse/NFS-Fix-interrupted-slots-by-sending-a-solo-SEQUENCE.patch
  patches.suse/sunrpc-Fix-gss_unwrap_resp_integ-again.patch
- commit 8700f50
* Mon Jul 27 2020 jslaby@suse.cz
- /dev/mem: Revoke mappings when a driver claims the region
  (git-fixes).
- commit 12e79d4
* Mon Jul 27 2020 vbabka@suse.cz
- mm/mmap.c: close race between munmap() and
  expand_upwards()/downwards() (bsc#1174527).
- commit 8d322cd
* Mon Jul 27 2020 acho@suse.com
- Bluetooth: Disconnect if E0 is used for Level 4 (bsc#1171988
  CVE-2020-10135).
- Bluetooth: Consolidate encryption handling in hci_encrypt_cfm
  (bsc#1171988 CVE-2020-10135).
- commit 247f41e
* Mon Jul 27 2020 jslaby@suse.cz
- udp: Improve load balancing for SO_REUSEPORT (git-fixes).
- udp: Copy has_conns in reuseport_grow() (git-fixes).
- net/smc: fix restoring of fallback changes (git-fixes).
- ax88172a: fix ax88172a_unbind() failures (git-fixes).
- ovl: inode reference leak in ovl_is_inuse true case (git-fixes).
- commit 8886a83
* Mon Jul 27 2020 tbogendoerfer@suse.de
- IB/hfi1: Fix module use count flaw due to leftover module put
  calls (bsc#1174407).
- IB/hfi1: Fix another case where pq is left on waitlist
  (bsc#1174411).
- commit 4615f3f
* Mon Jul 27 2020 tiwai@suse.de
- PCI/EDR: Log only ACPI_NOTIFY_DISCONNECT_RECOVER events
  (bsc#1174513).
- commit 4124752
* Mon Jul 27 2020 neilb@suse.de
- kabi fix for SUNRPC-dont-update-timeout-value-on-connection-reset.patch
  (bsc1174263).
- commit b2c60a4
* Mon Jul 27 2020 neilb@suse.de
- SUNRPC dont update timeout value on connection reset
  (bsc#1174263).
- NFS: Fix interrupted slots by sending a solo SEQUENCE operation
  (bsc#1174264).
- commit a34253a
* Mon Jul 27 2020 neilb@suse.de
- sunrpc: Fix gss_unwrap_resp_integ() again (bsc#1174116).
- commit 74de0ef
* Mon Jul 27 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section:
  patches.suse/sched-Fix-race-against-ptrace_freeze_trace.patch
- commit d3c68dc
* Sun Jul 26 2020 tiwai@suse.de
- arm64: dts: ls1046ardb: set RGMII interfaces to RGMII_ID mode
  (bsc#1174398).
- arm64: dts: ls1043a-rdb: correct RGMII delay mode to rgmii-id
  (bsc#1174398).
- net: fsl/fman: treat all RGMII modes in memac_adjust_link()
  (bsc#1174398).
- commit 9181d93
* Sun Jul 26 2020 tiwai@suse.de
- net: phy: realtek: add support for configuring the RX delay
  on RTL8211F (bsc#1174398).
- commit f56681f
* Sat Jul 25 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/sched-fair-handle-case-of-task_h_load-returning-0.patch
- commit 48a221d
* Fri Jul 24 2020 mgorman@suse.de
- sched/fair: handle case of task_h_load() returning 0
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit ea548c6
* Fri Jul 24 2020 mgorman@suse.de
- Refresh patches.suse/sched-Fix-loadavg-accounting-race.patch.
- commit 1d3f65b
* Fri Jul 24 2020 tbogendoerfer@suse.de
- IB/hfi1: Do not destroy link_wq when the device is shut down
  (bsc#1174409).
- IB/hfi1: Do not destroy hfi1_wq when the device is shut down
  (bsc#1174409).
- commit 469cd59
* Fri Jul 24 2020 tiwai@suse.de
- Update patch reference tag for cdev security fix (CVE-2020-0305, bsc#1174462)
- commit 589a02e
* Thu Jul 23 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/btrfs-add-assertions-for-tree-inode-io_tree-to-exten.patch
  patches.suse/btrfs-drop-argument-tree-from-btrfs_lock_and_flush_o.patch
  patches.suse/btrfs-use-correct-count-in-btrfs_file_write_iter.patch
- commit 06e9b7f
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: fix RWF_NOWAIT writes blocking on extent locks and
  waiting for IO (bsc#1174438).
- commit 6283198
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: drop argument tree from
  btrfs_lock_and_flush_ordered_range (bsc#1174438).
- commit fddc7a9
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: add assertions for tree == inode->io_tree to extent IO
  helpers (bsc#1174438).
- commit b6577c1
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: fix RWF_NOWAIT write not failling when we need to cow
  (bsc#1174438).
- commit 5cd33df
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: fix failure of RWF_NOWAIT write into prealloc extent
  beyond eof (bsc#1174438).
- commit e8b9f70
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: fix hang on snapshot creation after RWF_NOWAIT write
  (bsc#1174438).
- commit b6d39e5
* Thu Jul 23 2020 fdmanana@suse.com
- btrfs: use correct count in btrfs_file_write_iter()
  (bsc#1174438).
- commit b0f2e4b
* Thu Jul 23 2020 ykaukab@suse.de
- dpaa_eth: Make dpaa_a050385_wa static (bsc#1174396).
- dpaa_eth: FMan erratum A050385 workaround (bsc#1174396).
- commit 28d087a
* Thu Jul 23 2020 ykaukab@suse.de
- fsl/fman: detect FMan erratum A050385 (bsc#1174396)
  Update arm64 config file
- commit f586da0
* Thu Jul 23 2020 ohering@suse.de
- PCI: hv: Add support for protocol 1.3 and support
  PCI_BUS_RELATIONS2 (bsc#1172201).
- commit 901fe3f
* Thu Jul 23 2020 oneukum@suse.com
- media: cec: silence shift wrapping warning in
  __cec_s_log_addrs() (git-fixes).
- commit 78dd0ad
* Thu Jul 23 2020 oneukum@suse.com
- blacklist.conf: for future infrastructure, and will need kABI workarounds in each user, only if we really need it
- commit 5125020
* Thu Jul 23 2020 oneukum@suse.com
- blacklist.conf: cleanup removing unused exported symbols, unavoidable kABI breakage
- commit 5042b86
* Thu Jul 23 2020 tiwai@suse.de
- ALSA: hda/realtek: Fixed ALC298 sound bug by adding quirk for
  Samsung Notebook Pen S (git-fixes).
- ASoC: rt5682: Report the button event in the headset type only
  (git-fixes).
- ASoC: Intel: bytcht_es8316: Add missed put_device() (git-fixes).
- ASoC: rt286: fix unexpected interrupt happens (git-fixes).
- ASoC: wm8974: remove unsupported clock mode (git-fixes).
- ASoC: wm8974: fix Boost Mixer Aux Switch (git-fixes).
- ASoC: topology: fix tlvs in error handling for widget_dmixer
  (git-fixes).
- ASoC: topology: fix kernel oops on route addition error
  (git-fixes).
- ASoc: codecs: max98373: remove Idle_bias_on to let codec suspend
  (git-fixes).
- ASoC: codecs: max98373: Removed superfluous volume control
  from chip default (git-fixes).
- ASoC: rockchip: add format and rate constraints on rk3399
  (git-fixes).
- ASoC: rt5670: Fix dac- and adc- vol-tlv values being off by
  a factor of 10 (git-fixes).
- ASoC: rt5670: Add new gpio1_is_ext_spk_en quirk and enable it
  on the Lenovo Miix 2 10 (git-fixes).
- ASoC: rt5670: Correct RT5670_LDO_SEL_MASK (git-fixes).
- ALSA: info: Drop WARN_ON() from buffer NULL sanity check
  (git-fixes).
- USB: serial: option: add Quectel EG95 LTE modem (git-fixes).
- USB: serial: ch341: add new Product ID for CH340 (git-fixes).
- USB: serial: option: add GosunCn GM500 series (git-fixes).
- USB: serial: cypress_m8: enable Simply Automated UPB PIM
  (git-fixes).
- HID: quirks: Ignore Simply Automated UPB PIM (git-fixes).
- HID: magicmouse: do not set up autorepeat (git-fixes).
- HID: quirks: Always poll Obins Anne Pro 2 keyboard (git-fixes).
- drm/amdgpu/sdma5: fix wptr overwritten in ->get_wptr()
  (git-fixes).
- intel_th: pci: Add Emmitsburg PCH support (git-fixes).
- intel_th: pci: Add Tiger Lake PCH-H support (git-fixes).
- intel_th: pci: Add Jasper Lake CPU support (git-fixes).
- mei: bus: don't clean driver pointer (git-fixes).
- thermal: int3403_thermal: Downgrade error message (git-fixes).
- Input: elan_i2c - add more hardware ID for Lenovo laptops
  (git-fixes).
- Input: i8042 - add Lenovo XiaoXin Air 12 to i8042 nomux list
  (git-fixes).
- i2c: eg20t: Load module automatically if ID matches (git-fixes).
- drm/exynos: fix ref count leak in mic_pre_enable (git-fixes).
- drm/exynos: Properly propagate return value in
  drm_iommu_attach_device() (git-fixes).
- drm/msm/dpu: allow initialization of encoder locks during
  encoder init (git-fixes).
- drm/msm: fix potential memleak in error branch (git-fixes).
- tpm_tis: extra chip->ops check on error path in
  tpm_tis_core_init (git-fixes).
- thermal/drivers: imx: Fix missing of_node_put() at probe time
  (git-fixes).
- ALSA: usb-audio: Add registration quirk for Kingston HyperX
  Cloud Flight S (git-fixes).
- spi: spidev: fix a potential use-after-free in spidev_release()
  (git-fixes).
- spi: spidev: fix a race between spidev_release and spidev_remove
  (git-fixes).
- Input: mms114 - add extra compatible for mms345l (git-fixes).
- ACPI: video: Use native backlight on Acer TravelMate 5735Z
  (git-fixes).
- Input: goodix - fix touch coordinates on Cube I15-TC
  (git-fixes).
- ACPI: video: Use native backlight on Acer Aspire 5783z
  (git-fixes).
- drm/sun4i: tcon: Separate quirks for tcon0 and tcon1 on A20
  (git-fixes).
- HID: quirks: Remove ITE 8595 entry from hid_have_special_driver
  (git-fixes).
- mmc: sdhci: do not enable card detect interrupt for gpio cd type
  (git-fixes).
- commit d00f168
* Thu Jul 23 2020 lduncan@suse.com
- blk-mq: consider non-idle request as "inflight" in
  blk_mq_rq_inflight() (bsc#1165933).
- dm: do not use waitqueue for request-based DM (bsc#1165933).
- commit 07e428e
* Wed Jul 22 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/brcmfmac-Transform-compatible-string-for-FW-loading.patch
- commit 75a973a
* Wed Jul 22 2020 tbogendoerfer@suse.de
- net/mlx5e: Fix CPU mapping after function reload to avoid aRFS
  RX crash (jsc#SLE-8464).
- net/mlx5e: Fix VXLAN configuration restore after function reload
  (jsc#SLE-8464).
- ionic: centralize queue reset code (bsc#1167773).
- net: hns3: check reset pending after FLR prepare (bsc#1154353).
- net: ipv4: Fix wrong type conversion from hint to rt in
  ip_route_use_hint() (bsc#1154353).
- ionic: update the queue count on open (bsc#1167773).
- commit 7491bf6
* Tue Jul 21 2020 tiwai@suse.de
- pci: Revive pci_dev __aer_firmware_first* fields for kABI
  (bsc#1174356).
- commit 4d2fe32
* Tue Jul 21 2020 tiwai@suse.de
- PCI/AER: Remove HEST/FIRMWARE_FIRST parsing for AER ownership
  (bsc#1174356).
- PCI/AER: Use only _OSC to determine AER ownership (bsc#1174356).
- commit 6e69c19
* Tue Jul 21 2020 ykaukab@suse.de
- Refresh
  patches.suse/clk-qoriq-add-cpufreq-platform-device.patch.
- commit 5dec1a6
* Tue Jul 21 2020 ykaukab@suse.de
- Refresh
  patches.suse/cpufreq-qoriq-convert-to-a-platform-driver.patch.
- commit cf18c2c
* Tue Jul 21 2020 ykaukab@suse.de
- Refresh
  patches.suse/gpio-tegra186-export-MODULE_DEVICE_TABLE.patch.
- commit 3a8c8f1
* Tue Jul 21 2020 ykaukab@suse.de
- Refresh
  patches.suse/soc-tegra-pmc-Enable-PMIC-wake-event-on-Tegra186.patch.
- commit d3492b2
* Tue Jul 21 2020 ykaukab@suse.de
- Refresh
  patches.suse/cpufreq-tegra186-add-CPUFREQ_NEED_INITIAL_FREQ_CHECK.patch.
- commit 8dcc9fc
* Tue Jul 21 2020 mgorman@suse.de
- sched: Fix race against ptrace_freeze_trace() (bsc#1174345).
- commit 2138587
* Tue Jul 21 2020 jslaby@suse.cz
- net/mlx5e: Fix repeated XSK usage on one channel
  (networking-stable-20_06_16).
- net/mlx5: Fix fatal error handling during device load
  (networking-stable-20_06_16).
- net/mlx5: drain health workqueue in case of driver load error
  (networking-stable-20_06_16).
- selftests/net: in rxtimestamp getopt_long needs terminating
  null entry (networking-stable-20_06_16).
- dccp: Fix possible memleak in dccp_init and dccp_fini
  (networking-stable-20_06_16).
- mlxsw: core: Use different get_trend() callbacks for different
  thermal zones (networking-stable-20_06_10).
- net_failover: fixed rollback in net_failover_open()
  (networking-stable-20_06_10).
- vxlan: Avoid infinite loop when suppressing NS messages with
  invalid options (networking-stable-20_06_10).
- bridge: Avoid infinite loop when suppressing NS messages with
  invalid options (networking-stable-20_06_10).
- l2tp: add sk_family checks to l2tp_validate_socket
  (networking-stable-20_06_07).
- l2tp: do not use inet_hash()/inet_unhash()
  (networking-stable-20_06_07).
- kABI: reintroduce inet_hashtables.h include to l2tp_ip (kabi).
- devinet: fix memleak in inetdev_init()
  (networking-stable-20_06_07).
- net: be more gentle about silly gso requests coming from user
  (networking-stable-20_06_07).
- vsock: fix timeout in vsock_accept()
  (networking-stable-20_06_07).
- nfp: flower: fix used time of merge flow statistics
  (networking-stable-20_06_07).
- net: usb: qmi_wwan: add Telit LE910C1-EUX composition
  (networking-stable-20_06_07).
- net: check untrusted gso_size at kernel entry
  (networking-stable-20_06_07).
- net: stmmac: enable timestamp snapshot for required PTP packets
  in dwmac v5.10a (networking-stable-20_06_07).
- commit 9e80866
* Tue Jul 21 2020 tiwai@suse.de
- USB: serial: iuu_phoenix: fix memory corruption (git-fixes).
- usb: gadget: function: fix missing spinlock in f_uac1_legacy
  (git-fixes).
- usb: gadget: udc: atmel: fix uninitialized read in debug printk
  (git-fixes).
- usb: gadget: udc: atmel: remove outdated comment in
  usba_ep_disable() (git-fixes).
- usb: dwc2: Fix shutdown callback in platform (git-fixes).
- USB: c67x00: fix use after free in c67x00_giveback_urb
  (git-fixes).
- usb: chipidea: core: add wakeup support for extcon (git-fixes).
- hwmon: (emc2103) fix unable to change fan pwm1_enable attribute
  (git-fixes).
- intel_th: Fix a NULL dereference when hub driver is not loaded
  (git-fixes).
- virt: vbox: Fix guest capabilities mask check (git-fixes).
- virt: vbox: Fix VBGL_IOCTL_VMMDEV_REQUEST_BIG and _LOG req
  numbers to match upstream (git-fixes).
- iio: adc: ad7780: Fix a resource handling path in
  'ad7780_probe()' (git-fixes).
- iio:pressure:ms5611 Fix buffer element alignment (git-fixes).
- iio:humidity:hts221 Fix alignment and data leak issues
  (git-fixes).
- iio:humidity:hdc100x Fix alignment and data leak issues
  (git-fixes).
- iio:magnetometer:ak8974: Fix alignment and data leak issues
  (git-fixes).
- iio: pressure: zpa2326: handle pm_runtime_get_sync failure
  (git-fixes).
- iio: core: add missing IIO_MOD_H2/ETHANOL string identifiers
  (git-fixes).
- iio: magnetometer: ak8974: Fix runtime PM imbalance on error
  (git-fixes).
- iio: mma8452: Add missed iio_device_unregister() call in
  mma8452_probe() (git-fixes).
- iio:health:afe4404 Fix timestamp alignment and prevent data leak
  (git-fixes).
- dmaengine: dmatest: stop completed threads when running without
  set channel (git-fixes).
- dmaengine: fsl-edma-common: correct DSIZE_32BYTE (git-fixes).
- dmaengine: dw: Initialize channel before each transfer
  (git-fixes).
- dmaengine: mcf-edma: Fix NULL pointer exception in
  mcf_edma_tx_handler (git-fixes).
- dmaengine: fsl-edma: Fix NULL pointer exception in
  fsl_edma_tx_handler (git-fixes).
- dmaengine: sh: usb-dmac: set tx_result parameters (git-fixes).
- dmaengine: imx-sdma: Fix: Remove 'always true' comparison
  (git-fixes).
- keys: asymmetric: fix error return code in software_key_query()
  (git-fixes).
- mmc: meson-gx: limit segments to 1 when dram-access-quirk is
  needed (git-fixes).
- usbnet: smsc95xx: Fix use-after-free after removal (git-fixes).
- hwrng: ks-sa - Fix runtime PM imbalance on error (git-fixes).
- drm/amd/display: Use kfree() to free rgb_user in
  calculate_user_regamma_ramp() (git-fixes).
- usb: gadget: Fix issue with config_ep_by_speed function
  (git-fixes).
- ACPICA: Dispatcher: add status checks (git-fixes).
- ACPI/IORT: Fix PMCG node single ID mapping handling (git-fixes).
- commit b0f8c80
* Mon Jul 20 2020 dbueso@suse.de
- percpu: Separate decrypted varaibles anytime encryption can
  be enabled (bsc#1174332).
- selinux: fall back to ref-walk if audit is required
  (bsc#1174333).
- selinux: revert "stop passing MAY_NOT_BLOCK to the AVC upon
  follow_link" (bsc#1174333).
- lib: Reduce user_access_begin() boundaries in
  strncpy_from_user() and strnlen_user() (bsc#1174331).
- commit 444a65c
* Mon Jul 20 2020 msuchanek@suse.de
- powerpc/book3s64/pkeys: Fix pkey_access_permitted() for execute
  disable pkey (bsc#1065729).
- commit c00b49a
* Sat Jul 18 2020 mkubecek@suse.cz
- fix bdev inode reference count disbalance regression (bsc#1174244)
  Update patches.suse/bdev-add-open_finish.patch to adapt to changes
  introduced by patches.suse/block-Fix-use-after-free-in-blkdev_get.patch
  (backport of mainline commit 2d3a8e2dedde).
- commit 7efbe7b
* Sat Jul 18 2020 tiwai@suse.de
- bus: ti-sysc: Do not disable on suspend for no-idle (git-fixes).
- spi: spi-sun6i: sun6i_spi_transfer_one(): fix setting of clock
  rate (git-fixes).
- regmap: debugfs: Don't sleep while atomic for fast_io regmaps
  (git-fixes).
- HID: logitech-hidpp: avoid repeated "multiplier = " log messages
  (git-fixes).
- drm/i915/gt: Ignore irq enabling on the virtual engines
  (git-fixes).
- virtio: virtio_console: add missing MODULE_DEVICE_TABLE()
  for rproc serial (git-fixes).
- soundwire: intel: fix memory leak with devm_kasprintf
  (git-fixes).
- staging: comedi: verify array index is correct before using it
  (git-fixes).
- Revert "thermal: mediatek: fix register index error"
  (git-fixes).
- gpio: pca953x: Fix GPIO resource leak on Intel Galileo Gen 2
  (git-fixes).
- gpio: pca953x: disable regmap locking for automatic address
  incrementing (git-fixes).
- gpio: pca953x: Override IRQ for one of the expanders on Galileo
  Gen 2 (git-fixes).
- drm/amdgpu: don't do soft recovery if gpu_recovery=0
  (git-fixes).
- drm/radeon: fix double free (git-fixes).
- drm/mediatek: Check plane visibility in atomic_update
  (git-fixes).
- drm/amdgpu: use %%u rather than %%d for sclk/mclk (git-fixes).
- drm/amdgpu/atomfirmware: fix vram_info fetching for renoir
  (git-fixes).
- usb: dwc3: pci: Fix reference count leak in dwc3_pci_resume_work
  (git-fixes).
- drm: panel-orientation-quirks: Use generic orientation-data
  for Acer S1003 (git-fixes).
- drm: panel-orientation-quirks: Add quirk for Asus T101HA panel
  (git-fixes).
- drm: mcde: Fix display initialization problem (git-fixes).
- gpu: host1x: Detach driver on unregister (git-fixes).
- drm/tegra: hub: Do not enable orphaned window group (git-fixes).
- regmap: Fix memory leak from regmap_register_patch (git-fixes).
- regmap: fix alignment issue (git-fixes).
- commit c917659
* Sat Jul 18 2020 tiwai@suse.de
- ALSA: hda/realtek - fixup for yet another Intel reference board
  (git-fixes).
- ALSA: hda/realtek - Enable Speaker for ASUS UX563 (git-fixes).
- ALSA: hda/realtek - Enable Speaker for ASUS UX533 and UX534
  (git-fixes).
- ALSA: hda/realtek: Enable headset mic of Acer TravelMate
  B311R-31 with ALC256 (git-fixes).
- ALSA: hda/realtek: enable headset mic of ASUS ROG Zephyrus
  G14(G401) series with ALC289 (git-fixes).
- ALSA: hda/realtek - change to suitable link model for ASUS
  platform (git-fixes).
- ALSA: usb-audio: Fix race against the error recovery URB
  submission (git-fixes).
- ALSA: line6: Sync the pending work cancel at disconnection
  (git-fixes).
- ALSA: line6: Perform sanity check for each URB creation
  (git-fixes).
- commit 9ce2855
* Fri Jul 17 2020 ptesarik@suse.cz
- scsi: zfcp: Fix panic on ERP timeout for previously dismissed
  ERP action (git-fixes).
- s390/qeth: fix error handling for isolation mode cmds
  (git-fixes).
- s390: fix syscall_get_error for compat processes (git-fixes).
- s390/qdio: put thinint indicator after early error (git-fixes).
- s390/qdio: tear down thinint indicator after early error
  (git-fixes).
- s390/qdio: consistently restore the IRQ handler (git-fixes).
- s390/kaslr: add support for R_390_JMP_SLOT relocation type
  (git-fixes).
- s390/pci: Fix s390_mmio_read/write with MIO (git-fixes).
- s390/ism: fix error return code in ism_probe() (git-fixes).
- commit 06ae989
* Fri Jul 17 2020 tiwai@suse.de
- blacklist.conf: Add superfluous stable commit IDs
- commit 89408b6
* Fri Jul 17 2020 mkubecek@suse.cz
- netfilter: ip6tables: Add a .pre_exit hook in all ip6table_foo.c
  (bsc#1171857).
- netfilter: ip6tables: Split ip6t_unregister_table() into
  pre_exit and exit helpers (bsc#1171857).
- netfilter: iptables: Add a .pre_exit hook in all iptable_foo.c
  (bsc#1171857).
- netfilter: iptables: Split ipt_unregister_table() into pre_exit
  and exit helpers (bsc#1171857).
- commit cb31b4c
* Fri Jul 17 2020 glin@suse.com
- bpf: Do not allow btf_ctx_access with __int128 types
  (bsc#1155518).
- commit 60b474b
* Thu Jul 16 2020 msuchanek@suse.de
- powerpc/fadump: fix race between pstore write and fadump crash
  trigger (bsc#1168959 ltc#185010).
- commit 2b958e4
* Thu Jul 16 2020 msuchanek@suse.de
- powerpc/xmon: Reset RCU and soft lockup watchdogs (bsc#1065729).
- commit 6d8c5ea
* Thu Jul 16 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section
  patches.suse/revert-zram-convert-remaining-class_attr-to-class_attr_ro
- commit 2caa587
* Thu Jul 16 2020 tiwai@suse.de
- platform/x86: ISST: Increase timeout (bsc#1174185).
- commit 1a0cfdb
* Thu Jul 16 2020 tiwai@suse.de
- Update patch reference tag for ACPI configfs security fix (CVE-2020-15780, bsc#1173573).
- commit 4d52b6d
* Wed Jul 15 2020 tiwai@suse.de
- mfd: intel-lpss: Add Intel Jasper Lake PCI IDs (jsc#SLE-12602).
- commit f068576
* Wed Jul 15 2020 jslaby@suse.cz
- bridge: mcast: Fix MLD2 Report IPv6 payload length check
  (git-fixes).
- tcp: md5: allow changing MD5 keys in all socket states
  (git-fixes).
- nbd: Fix memory leak in nbd_add_socket (git-fixes).
- SMB3: Honor lease disabling for multiuser mounts (git-fixes).
- net: macb: call pm_runtime_put_sync on failure path (git-fixes).
- net: dsa: bcm_sf2: Fix node reference count (git-fixes).
- scsi: ufs-bsg: Fix runtime PM imbalance on error (git-fixes).
- tty: hvc_console, fix crashes on parallel open/close
  (git-fixes).
- workqueue: Remove unnecessary kfree() call in rcu_free_wq()
  (git-fixes).
- powerpc/kasan: Fix issues by lowering KASAN_SHADOW_END
  (git-fixes).
- KVM: nVMX: always update CR3 in VMCS (git-fixes).
- net/tls: free record only on encryption error (git-fixes).
- net/tls: fix encryption error checking (git-fixes).
- commit ed61f4d
* Wed Jul 15 2020 mbrugger@suse.com
- brcmfmac: Transform compatible string for FW loading
  (bsc#1169771).
- commit 6bdc85b
* Tue Jul 14 2020 rgoldwyn@suse.com
- exfat: move setting VOL_DIRTY over exfat_remove_entries()
  (git-fixes).
- exfat: add missing brelse() calls on error paths  (git-fixes).
- fuse: copy_file_range should truncate cache  (git-fixes).
- fuse: fix copy_file_range cache issues  (git-fixes).
- exfat: fix incorrect update of stream entry in
  __exfat_truncate()  (git-fixes).
- exfat: fix memory leak in exfat_parse_param()  (git-fixes).
- apparmor: Fix memory leak of profile proxy  (git-fixes).
- apparmor: fix introspection of of task mode for unconfined tasks
  (git-fixes).
- apparmor: ensure that dfa state tables have entries
  (git-fixes).
- apparmor: remove useless aafs_create_symlink  (git-fixes).
- apparmor: Fix use-after-free in aa_audit_rule_init  (git-fixes).
- commit 094ca51
* Tue Jul 14 2020 jroedel@suse.de
- blacklist.conf: Add 9486727f5981 iommu/vt-d: Make Intel SVM code 64-bit only
- commit 6287dc6
* Tue Jul 14 2020 jroedel@suse.de
- vfio/pci: Fix SR-IOV VF handling with MMIO blocking
  (bsc#1174129).
- iommu/vt-d: Update scalable mode paging structure coherency
  (bsc#1174128).
- iommu/vt-d: Enable PCI ACS for platform opt in hint
  (bsc#1174127).
- iommu/arm-smmu-v3: Don't reserve implementation defined register
  space (bsc#1174126).
- commit 4b65886
* Tue Jul 14 2020 lduncan@suse.com
- Revert "zram: convert remaining CLASS_ATTR() to CLASS_ATTR_RO()"
  (bsc#1173074 CVE-2020-10781).
- commit d59a129
* Tue Jul 14 2020 oneukum@suse.com
- padata: kABI fixup for struct padata_instance splitting nodes
  (git-fixes).
- commit 03321ff
* Tue Jul 14 2020 oneukum@suse.com
- padata: add separate cpuhp node for CPUHP_PADATA_DEAD
  (git-fixes).
- commit 3966f99
* Mon Jul 13 2020 mkubecek@suse.cz
- Update kabi files.
- update to first maintenance update submission (commit eabfb0896fac)
- commit 9da6523
* Mon Jul 13 2020 tiwai@suse.de
- watchdog: iTCO: Add support for Cannon Lake PCH iTCO
  (jsc#SLE-13202).
- commit e9c44ca
* Mon Jul 13 2020 tiwai@suse.de
- ALSA: hda: Intel: add missing PCI IDs for ICL-H, TGL-H and EKL
  (jsc#SLE-13261).
- commit 137c3b6
* Mon Jul 13 2020 ykaukab@suse.de
- serial: 8250_tegra: Create Tegra specific 8250 driver (bsc#1173941).
- Update config files.
- commit 3b0dd22
* Mon Jul 13 2020 ykaukab@suse.de
- net: stmmac: don't attach interface until resume finishes
  (bsc#1174072).
- net: stmmac: dwc-qos: avoid clk and reset for acpi device
  (bsc#1174072).
- net: stmmac: dwc-qos: use generic device api (bsc#1174072).
- net: stmmac: platform: fix probe for ACPI devices (bsc#1174072).
- commit 05074b1
* Mon Jul 13 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/net-smc-tolerate-future-smcd-versions
- commit 83f40de
* Mon Jul 13 2020 mkubecek@suse.cz
- Fix
  patches.suse/media-mtk-vpu-avoid-unaligned-access-to-DTCM-buffer.patch
  (fix build without the kabi fix)
- Refresh
  patches.kabi/kABI-fixup-mtk-vpu-avoid-unaligned-access-to-DTCM-buffer.patch
  This commit has no effect on expanded tree but it fixes build without
  patches.kabi/* (so that it will be needed for SLE15-SP3).
- commit 62b468e
* Mon Jul 13 2020 ptesarik@suse.cz
- net/smc: tolerate future SMCD versions (bsc#1172543 LTC#186069).
- commit fd05166
* Mon Jul 13 2020 ohering@suse.de
- hv_netvsc: Fix netvsc_start_xmit's return type (git-fixes).
- commit 5b7bc98
* Mon Jul 13 2020 msuchanek@suse.de
- dm writecache: reject asynchronous pmem devices (bsc#1156395).
- commit 26f82f2
* Fri Jul 10 2020 mkoutny@suse.com
- fork: prevent accidental access to clone3 features
  (bsc#1174018).
- commit 8b81b50
* Fri Jul 10 2020 mkoutny@suse.com
- signal: Avoid corrupting si_pid and si_uid in do_notify_parent
  (bsc#1171529).
- commit eb37c8d
* Fri Jul 10 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/ALSA-usb-audio-Fix-packet-size-calculation.patch
- commit f5de6d1
* Fri Jul 10 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/NFSv4-fix-CLOSE-not-waiting-for-direct-IO-compeletio.patch
  patches.suse/SUNRPC-Properly-set-the-subbuf-parameter-of-xdr_buf_.patch
  patches.suse/libceph-don-t-omit-recovery_deletes-in-target_copy.patch
  patches.suse/nfsd-apply-umask-on-fs-without-ACL-support.patch
  patches.suse/nfsd-fix-nfsdfs-inode-reference-count-leak.patch
  patches.suse/nfsd4-fix-nfsdfs-reference-count-loop.patch
  patches.suse/pNFS-flexfiles-Fix-list-corruption-if-the-mirror-cou.patch
  patches.suse/sunrpc-fixed-rollback-in-rpc_gssd_dummy_populate.patch
  patches.suse/xprtrdma-Fix-handling-of-RDMA_ERROR-replies.patch
- commit ad850c9
* Fri Jul 10 2020 dwagner@suse.de
- net: core: device_rename: Use rwsem instead of a seqcount
  (bsc#1162702).
- commit 7a01d9d
* Fri Jul 10 2020 ohering@suse.de
- kabi: hv: prevent struct device_node to become defined
  (bsc#1172871).
- PCI: hv: Retry PCI bus D0 entry on invalid device state
  (bsc#1172871).
- PCI: hv: Fix the PCI HyperV probe failure path to release
  resource properly (bsc#1172871).
- PCI: hv: Introduce hv_msi_entry (bsc#1172871).
- PCI: hv: Move retarget related structures into tlfs header
  (bsc#1172871).
- PCI: hv: Move hypercall related definitions into tlfs header
  (bsc#1172871).
- PCI: hv: Decouple the func definition in hv_dr_state from VSP
  message (bsc#1172871).
- PCI: hv: Change pci_protocol_version to per-hbus (bsc#1172871).
- PCI: hv: Reorganize the code in preparation of hibernation
  (bsc#1172871).
- commit 35a7d93
* Fri Jul 10 2020 ohering@suse.de
- Drivers: hv: Change flag to write log level in panic msg to
  false (bsc#1170617).
- commit bcd509e
* Thu Jul  9 2020 tiwai@suse.de
- Fix boot crash with MD (bsc#1173860)
  Refresh patches.suse/mdraid-fix-read-write-bytes-accounting.patch
- commit 119f164
* Thu Jul  9 2020 dwagner@suse.de
- scsi: lpfc: Fix less-than-zero comparison of unsigned value
  (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix interrupt assignments when multiple vectors
  are supported on same CPU (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix inconsistent indenting (bsc#1172687
  bsc#1171530).
- scsi: lpfc: Update lpfc version to 12.8.0.2 (bsc#1172687
  bsc#1171530).
- scsi: lpfc: Add an internal trace log buffer (bsc#1172687
  bsc#1171530).
- scsi: lpfc: Add blk_io_poll support for latency improvment
  (bsc#1172687 bsc#1171530).
- scsi: lpfc: Add support to display if adapter dumps are
  available (bsc#1172687 bsc#1171530).
- scsi: lpfc: Allow applications to issue Common Set Features
  mailbox command (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix language in 0373 message to reflect non-error
  message (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix kdump hang on PPC (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix shost refcount mismatch when deleting vport
  (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix stack trace seen while setting rrq active
  (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix oops due to overrun when reading SLI3 data
  (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix NVMe rport deregister and registration during
  ADISC (bsc#1172687 bsc#1171530).
- scsi: lpfc: Fix missing MDS functionality (bsc#1172687
  bsc#1171530).
- scsi: lpfc: Fix unused assignment in
  lpfc_sli4_bsg_link_diag_test (bsc#1172687 bsc#1171530).
- commit fa0f156
* Thu Jul  9 2020 dwagner@suse.de
- Refresh metadata of patches.suse/ALSA-usb-audio-Fix-packet-size-calculation.patch
- commit 964e72b
* Thu Jul  9 2020 mgorman@suse.de
- series.conf: cleanup (sort)
- patches.suse/sched-core-Check-cpus_mask-not-cpus_ptr-in-__set_cpus_allowed_ptr-to-fix-mask-corruption.patch
- commit 451a6ea
* Thu Jul  9 2020 mgorman@suse.de
- sched: Fix loadavg accounting race (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- commit 38a840e
* Thu Jul  9 2020 tzimmermann@suse.de
- drm: sun4i: hdmi: Remove extra HPD polling (bsc#1152489)
- commit 9f8314c
* Thu Jul  9 2020 tzimmermann@suse.de
- drm/i915/gvt: Fix two CFL MMIO handling caused by regression. (bsc#1152489)
- commit 5522961
* Thu Jul  9 2020 tzimmermann@suse.de
- drm/msm/dpu: fix error return code in dpu_encoder_init (bsc#1152489)
- commit c65f050
* Thu Jul  9 2020 tiwai@suse.de
- ALSA: usb-audio: Add implicit feedback quirk for RTX6001
  (git-fixes).
- ALSA: usb-audio: add quirk for MacroSilicon MS2109 (git-fixes).
- ALSA: hda/realtek: Enable headset mic of Acer Veriton N4660G
  with ALC269VC (git-fixes).
- ALSA: hda/realtek: Enable headset mic of Acer C20-820 with
  ALC269VC (git-fixes).
- ALSA: hda/realtek - Enable audio jacks of Acer vCopperbox with
  ALC269VC (git-fixes).
- ALSA: hda/realtek - Fix Lenovo Thinkpad X1 Carbon 7th quirk
  subdevice id (git-fixes).
- ALSA: hda/hdmi: improve debug traces for stream lookups
  (git-fixes).
- ALSA: hda/hdmi: fix failures at PCM open on Intel ICL and later
  (git-fixes).
- ALSA: opl3: fix infoleak in opl3 (git-fixes).
- ALSA: usb-audio: Replace s/frame/packet/ where appropriate
  (git-fixes).
- ALSA: hda - let hs_mic be picked ahead of hp_mic (git-fixes).
- commit 6ae71bb
* Thu Jul  9 2020 tiwai@suse.de
- Refresh and move an upstreamed sound fix patch
- commit 7719bb1
* Wed Jul  8 2020 tiwai@suse.de
- regualtor: pfuze100: correct sw1a/sw2 on pfuze3000 (git-fixes).
- remoteproc: qcom_q6v5_mss: map/unmap mpss segments before/after
  use (git-fixes).
- slimbus: ngd: get drvdata from correct device (git-fixes).
- watchdog: da9062: No need to ping manually before setting
  timeout (git-fixes).
- commit 086dd89
* Wed Jul  8 2020 tiwai@suse.de
- drm/amd/display: Only revalidate bandwidth on medium and fast
  updates (git-fixes).
- drm/amdgpu: drop redundant cg/pg ungate on runpm enter
  (git-fixes).
- drm/amdgpu: move kfd suspend after ip_suspend_phase1
  (git-fixes).
- commit 8b89f9a
* Wed Jul  8 2020 tiwai@suse.de
- drm/amdgpu: fix the hw hang during perform system reboot and
  reset (git-fixes).
- commit edc269e
* Wed Jul  8 2020 tiwai@suse.de
- pwm: img: Call pm_runtime_put() in pm_runtime_get_sync()
  failed case (git-fixes).
- PCI: Don't disable decoding when mmio_always_on is set
  (git-fixes).
- PCI: Add Loongson vendor ID (git-fixes).
- PCI: vmd: Add device id for VMD device 8086:9A0B (git-fixes).
- commit c92f65d
* Wed Jul  8 2020 tiwai@suse.de
- media: dvbdev: Fix tuner->demod media controller link
  (git-fixes).
- media: imx: imx7-mipi-csis: Cleanup and fix subdev pad format
  handling (git-fixes).
- media: staging: imgu: do not hold spinlock during freeing mmu
  page table (git-fixes).
- media: ov5640: fix use of destroyed mutex (git-fixes).
- media: staging/intel-ipu3: Implement lock for stream on/off
  operations (git-fixes).
- commit 615fb19
* Wed Jul  8 2020 tiwai@suse.de
- Revert "i2c: tegra: Fix suspending in active runtime PM state"
  (git-fixes).
- gpio: pca953x: fix handling of automatic address incrementing
  (git-fixes).
- ipmi: use vzalloc instead of kmalloc for user creation
  (git-fixes).
- HID: Add quirks for Trust Panora Graphic Tablet (git-fixes).
- iwlwifi: mvm: fix aux station leak (git-fixes).
- commit 667aa89
* Wed Jul  8 2020 tiwai@suse.de
- drm: sun4i: hdmi: Remove extra HPD polling (git-fixes).
- drm/i915/gvt: Fix two CFL MMIO handling caused by regression
  (git-fixes).
- drm/msm/dpu: fix error return code in dpu_encoder_init
  (git-fixes).
- bus: ti-sysc: Ignore clockactivity unless specified as a quirk
  (git-fixes).
- drm/amd: fix potential memleak in err branch (git-fixes).
- drm/amdgpu: add fw release for sdma v5_0 (git-fixes).
- drm/msm/mdp5: Fix mdp5_init error path for failed mdp5_kms
  allocation (git-fixes).
- drm/amd/display: Revalidate bandwidth before commiting DC
  updates (git-fixes).
- drm/nouveau/disp/gm200-: fix NV_PDISP_SOR_HDMI2_CTRL(n)
  selection (git-fixes).
- batman-adv: Revert "disable ethtool link speed detection when
  auto negotiation off" (git-fixes).
- ath10k: fix kernel null pointer dereference (git-fixes).
- ath10k: Fix the race condition in firmware dump work queue
  (git-fixes).
- drm/amd/powerpay: Disable gfxoff when setting manual mode on
  picasso and raven (git-fixes).
- drm/amdgpu: Init data to avoid oops while reading pp_num_states
  (git-fixes).
- cpufreq: Fix up cpufreq_boost_set_sw() (git-fixes).
- cpuidle: Fix three reference count leaks (git-fixes).
- cpufreq: intel_pstate: Only mention the BIOS disabling turbo
  mode once (git-fixes).
- drm/amdgpu: fix gfx hang during suspend with video playback (v2)
  (git-fixes).
- cpufreq: powernv: Fix frame-size-overflow in
  powernv_cpufreq_work_fn (git-fixes).
- commit 8cd5c7d
* Wed Jul  8 2020 tbogendoerfer@suse.de
- bnxt_en: fix firmware message length endianness (bsc#1173894).
- bnxt_en: Fix return code to "flash_device" (bsc#1173894).
- commit 69ae6c0
* Wed Jul  8 2020 tiwai@suse.de
- Revert commit e918e570415c ("tpm_tis: Remove the HID IFX0102")
  (git-fixes).
- commit 8dc0431
* Wed Jul  8 2020 tbogendoerfer@suse.de
- ixgbe: don't check firmware errors (bsc#1170284).
- commit 37dfeb2
* Wed Jul  8 2020 tiwai@suse.de
- usb: usbtest: fix missing kfree(dev->buf) in usbtest_disconnect
  (CVE-2020-15393 bsc#1173514).
- commit 0265130
* Wed Jul  8 2020 tiwai@suse.de
- Update patch reference tag for ACPI lockdown fix (bsc#1173573)
- commit 9a83bf0
* Wed Jul  8 2020 tiwai@suse.de
- media: dvbsky: add support for eyeTV Geniatech T2 lite
  (bsc#1173776).
- media: dvbsky: add support for Mygica T230C v2 (bsc#1173776).
- media: si2168: add support for Mygica T230C v2 (bsc#1173776).
- commit d3b7a06
* Wed Jul  8 2020 oneukum@suse.com
- media: vicodec: Fix error codes in probe function (git-fixes).
- commit b82f6d2
* Wed Jul  8 2020 neilb@suse.de
- nfsd: fix nfsdfs inode reference count leak (git-fixes).
- nfsd4: fix nfsdfs reference count loop (git-fixes).
- nfsd: apply umask on fs without ACL support (git-fixes).
- SUNRPC: Properly set the @subbuf parameter of
  xdr_buf_subsegment() (git-fixes).
- NFSv4 fix CLOSE not waiting for direct IO compeletion
  (git-fixes).
- pNFS/flexfiles: Fix list corruption if the mirror count changes
  (git-fixes).
- sunrpc: fixed rollback in rpc_gssd_dummy_populate() (git-fixes).
- xprtrdma: Fix handling of RDMA_ERROR replies (git-fixes).
- libceph: don't omit recovery_deletes in target_copy()
  (git-fixes).
- commit 04a6d04
* Tue Jul  7 2020 jack@suse.cz
- jbd2: Preserve kABI when adding j_abort_mutex (bsc#1173833).
- commit 60b0b9e
* Tue Jul  7 2020 jack@suse.cz
- blacklist.conf: Blacklist 3c597282887f
- commit 4979dd4
* Tue Jul  7 2020 tiwai@suse.de
- Drop ath9k backport patch that leads to a broken WiFi (bko#208251)
  Deleted and blacklisted:
  patches.suse/ath9k-Fix-general-protection-fault-in-ath9k_hif_usb_.patch
- commit 3c2d65b
* Tue Jul  7 2020 oneukum@suse.com
- input: i8042 - Remove special PowerPC handling (git-fixes).
- commit 6f410a4
* Tue Jul  7 2020 tiwai@suse.de
- usb: renesas_usbhs: getting residue from callback_result
  (git-fixes).
- xhci: Poll for U0 after disabling USB2 LPM (git-fixes).
- xhci: Return if xHCI doesn't support LPM (git-fixes).
- usb: host: xhci-mtk: avoid runtime suspend when removing hcd
  (git-fixes).
- xhci: Fix enumeration issue when setting max packet size for
  FS devices (git-fixes).
- xhci: Fix incorrect EP_STATE_MASK (git-fixes).
- USB: ohci-sm501: Add missed iounmap() in remove (git-fixes).
- USB: ehci: reopen solution for Synopsys HC bug (git-fixes).
- usb: add USB_QUIRK_DELAY_INIT for Logitech C922 (git-fixes).
- usb: host: ehci-exynos: Fix error check in exynos_ehci_probe()
  (git-fixes).
- usb/ehci-platform: Set PM runtime as active on resume
  (git-fixes).
- usb/xhci-plat: Set PM runtime as active on resume (git-fixes).
- usb/ohci-platform: Fix a warning when hibernating (git-fixes).
- usblp: poison URBs upon disconnect (git-fixes).
- usb: host: ehci-platform: add a quirk to avoid stuck
  (git-fixes).
- commit 89437cf
* Tue Jul  7 2020 tiwai@suse.de
- ALSA: usb-audio: Fix packet size calculation (bsc#1173847).
- commit 72eb911
* Tue Jul  7 2020 tiwai@suse.de
- ASoC: Intel: bytcr_rt5640: Add quirk for Toshiba Encore WT8-A
  tablet (git-fixes).
- Refresh
  patches.suse/ASoC-Intel-bytcr_rt5640-Add-quirk-for-Toshiba-Encore.patch.
- commit 9af3c7c
* Tue Jul  7 2020 tiwai@suse.de
- spi: dw: Return any value retrieved from the dma_transfer
  callback (git-fixes).
- Refresh
  patches.suse/spi-dw-Add-SPI-Rx-done-wait-method-to-DMA-based-tran.patch.
- Refresh
  patches.suse/spi-dw-Add-SPI-Tx-done-wait-method-to-DMA-based-tran.patch.
- commit 62c15de
* Tue Jul  7 2020 jack@suse.cz
- blacklist.conf: Blacklist 32302085a8d9
- commit 856ff38
* Tue Jul  7 2020 tiwai@suse.de
- i2c: mlxcpld: check correct size of maximum RECV_LEN packet
  (git-fixes).
- i2c: algo-pca: Add 0x78 as SCL stuck low status for PCA9665
  (git-fixes).
- hwmon: (pmbus) fix a typo in Kconfig SENSORS_IR35221 option
  (git-fixes).
- hwmon: (acpi_power_meter) Fix potential memory leak in
  acpi_power_meter_add() (git-fixes).
- hwmon: (max6697) Make sure the OVERT mask is set correctly
  (git-fixes).
- tpm_tis: Remove the HID IFX0102 (git-fixes).
- tpm: Fix TIS locality timeout problems (git-fixes).
- thermal/drivers/rcar_gen3: Fix undefined temperature if negative
  (git-fixes).
- thermal/drivers/mediatek: Fix bank number settings on mt8183
  (git-fixes).
- i2c: core: check returned size of emulated smbus block read
  (git-fixes).
- i2c: fsi: Fix the port number field in status register
  (git-fixes).
- Staging: rtl8723bs: prevent buffer overflow in
  update_sta_support_rate() (git-fixes).
- cdc-acm: Add DISABLE_ECHO quirk for Microchip/SMSC chip
  (git-fixes).
- clk: sifive: allocate sufficient memory for struct __prci_data
  (git-fixes).
- ACPI: sysfs: Fix pm_profile_attr type (git-fixes).
- ACPI: configfs: Disallow loading ACPI tables when locked down
  (git-fixes).
- geneve: allow changing DF behavior after creation (git-fixes).
- ALSA: usb-audio: Fix OOB access of mixer element list
  (git-fixes).
- ALSA: usb-audio: add quirk for Samsung USBC Headset (AKG)
  (git-fixes).
- ASoC: rockchip: Fix a reference count leak (git-fixes).
- ASoC: fsl_ssi: Fix bclk calculation for mono channel
  (git-fixes).
- ASoc: q6afe: add support to get port direction (git-fixes).
- ASoC: q6asm: handle EOS correctly (git-fixes).
- ALSA: hda/realtek: Add mute LED and micmute LED support for
  HP systems (git-fixes).
- ALSA: usb-audio: Fix potential use-after-free of streams
  (git-fixes).
- ALSA: hda/realtek - Add quirk for MSI GE63 laptop (git-fixes).
- ALSA: usb-audio: add quirk for Denon DCD-1500RE (git-fixes).
- ALSA: usb-audio: Add implicit feedback quirk for SSL2+
  (git-fixes).
- ALSA: hda: Add NVIDIA codec IDs 9a & 9d through a0 to patch
  table (git-fixes).
- spi: sprd: switch the sequence of setting WDG_LOAD_LOW and _HIGH
  (git-fixes).
- pinctrl: tegra: Use noirq suspend/resume callbacks (git-fixes).
- ata/libata: Fix usage of page address by page_address in
  ata_scsi_mode_select_xlat function (git-fixes).
- sata_rcar: handle pm_runtime_get_sync failure cases (git-fixes).
- i2c: pxa: clear all master action bits in i2c_pxa_stop_message()
  (git-fixes).
- i2c: pxa: fix i2c_pxa_scream_blue_murder() debug output
  (git-fixes).
- i2c: piix4: Detect secondary SMBus controller on AMD AM4
  chipsets (git-fixes).
- hwmon: (k10temp) Add AMD family 17h model 60h PCI match
  (git-fixes).
- x86/amd_nb: Add AMD family 17h model 60h PCI IDs (git-fixes).
- thermal/drivers/ti-soc-thermal: Avoid dereferencing ERR_PTR
  (git-fixes).
- amdgpu: a NULL ->mm does not mean a thread is a kthread
  (git-fixes).
- ASoC: SOF: nocodec: conditionally set dpcm_capture/dpcm_playback
  flags (git-fixes).
- ASoC: core: only convert non DPCM link to DPCM link (git-fixes).
- crypto: omap-sham - add proper load balancing support for
  multicore (git-fixes).
- clk: qcom: msm8916: Fix the address location of pll->config_reg
  (git-fixes).
- clk: ti: composite: fix memory leak (git-fixes).
- clk: zynqmp: fix memory leak in zynqmp_register_clocks
  (git-fixes).
- clk: samsung: exynos5433: Add IGNORE_UNUSED flag to sclk_i2s1
  (git-fixes).
- geneve: change from tx_error to tx_dropped on missing metadata
  (git-fixes).
- pinctrl: rockchip: fix memleak in rockchip_dt_node_to_map
  (git-fixes).
- drivers: base: Fix NULL pointer exception in
  __platform_driver_probe() if a driver developer is foolish
  (git-fixes).
- iio: bmp280: fix compensation of humidity (git-fixes).
- PCI: pci-bridge-emul: Fix PCIe bit conflicts (git-fixes).
- PCI: dwc: Fix inner MSI IRQ domain registration (git-fixes).
- PCI: aardvark: Don't blindly enable ASPM L0s and don't write
  to read-only register (git-fixes).
- PCI: Add ACS quirk for Intel Root Complex Integrated Endpoints
  (git-fixes).
- PCI: Avoid FLR for AMD Starship USB 3.0 (git-fixes).
- PCI: Avoid FLR for AMD Matisse HD Audio & USB 3.0 (git-fixes).
- PCI/ASPM: Allow ASPM on links to PCIe-to-PCI/PCI-X Bridges
  (git-fixes).
- ASoC: qcom: q6asm-dai: kCFI fix (git-fixes).
- ASoC: fsl_asrc_dma: Fix dma_chan leak when config DMA channel
  failed (git-fixes).
- ASoC: SOF: Do nothing when DSP PM callbacks are not set
  (git-fixes).
- ASoC: ti: omap-mcbsp: Fix an error handling path in
  'asoc_mcbsp_probe()' (git-fixes).
- ASoC: tegra: tegra_wm8903: Support nvidia, headset property
  (git-fixes).
- ASoC: max98373: reorder max98373_reset() in resume (git-fixes).
- ASoC: davinci-mcasp: Fix dma_chan refcnt leak when getting
  dma type (git-fixes).
- ALSA: isa/wavefront: prevent out of bounds write in ioctl
  (git-fixes).
- backlight: lp855x: Ensure regulators are disabled on probe
  failure (git-fixes).
- mfd: wm8994: Fix driver operation if loaded as modules
  (git-fixes).
- media: si2157: Better check for running tuner in init
  (git-fixes).
- Bluetooth: Add SCO fallback for invalid LMP parameters error
  (git-fixes).
- b43_legacy: Fix connection problem with WPA3 (git-fixes).
- b43: Fix connection problem with WPA3 (git-fixes).
- e1000e: Relax condition to trigger reset for ME workaround
  (git-fixes).
- Bluetooth: btbcm: Add 2 missing models to subver tables
  (git-fixes).
- carl9170: remove P2P_GO support (git-fixes).
- Crypto/chcr: fix for ccm(aes) failed test (git-fixes).
- e1000: Distribute switch variables for initialization
  (git-fixes).
- clocksource: dw_apb_timer: Make CPU-affiliation being optional
  (git-fixes).
- drm: bridge: adv7511: Extend list of audio sample rates
  (git-fixes).
- platform/x86: asus_wmi: Reserve more space for struct bias_args
  (git-fixes).
- platform/x86: intel-hid: Add a quirk to support HP Spectre X2
  (2015) (git-fixes).
- platform/x86: hp-wmi: Convert simple_strtoul() to kstrtou32()
  (git-fixes).
- mmc: via-sdmmc: Respect the cmd->busy_timeout from the mmc core
  (git-fixes).
- mmc: sdhci-msm: Set SDHCI_QUIRK_MULTIBLOCK_READ_ACMD12 quirk
  (git-fixes).
- spi: dw: Fix Rx-only DMA transfers (git-fixes).
- spi: dw: Enable interrupts in accordance with DMA xfer mode
  (git-fixes).
- spi: pxa2xx: Apply CS clk quirk to BXT (git-fixes).
- commit 303666a
* Tue Jul  7 2020 jack@suse.cz
- jbd2: avoid leaking transaction credits when unreserving handle
  (bsc#1173845).
- commit 1c291c0
* Tue Jul  7 2020 jack@suse.cz
- mm: fix NUMA node file count error in replace_page_cache()
  (bsc#1173844).
- commit e3f2d50
* Tue Jul  7 2020 jack@suse.cz
- ext4: avoid utf8_strncasecmp() with unstable name (bsc#1173843).
- commit 92563f1
* Tue Jul  7 2020 jack@suse.cz
- ext4: stop overwrite the errcode in ext4_setup_super
  (bsc#1173841).
- commit aaa2254
* Tue Jul  7 2020 jack@suse.cz
- ext4: fix partial cluster initialization when splitting extent
  (bsc#1173839).
- commit 563be96
* Tue Jul  7 2020 jack@suse.cz
- ext4: fix race between ext4_sync_parent() and rename()
  (bsc#1173838).
- commit 722d064
* Tue Jul  7 2020 jack@suse.cz
- ext4: fix error pointer dereference (bsc#1173837).
- commit 70157c5
* Tue Jul  7 2020 jack@suse.cz
- ext4: fix EXT_MAX_EXTENT/INDEX to check for zeroed eh_max
  (bsc#1173836).
- commit a460d9c
* Tue Jul  7 2020 jack@suse.cz
- block: Fix use-after-free in blkdev_get() (bsc#1173834).
- commit 2225310
* Tue Jul  7 2020 jack@suse.cz
- ext4, jbd2: ensure panic by fix a race between jbd2 abort and
  ext4 error handlers (bsc#1173833).
- commit 13dac57
* Tue Jul  7 2020 jack@suse.cz
- io_uring: use kvfree() in io_sqe_buffer_register()
  (bsc#1173832).
- commit 307ffb6
* Tue Jul  7 2020 jack@suse.cz
- fat: don't allow to mount if the FAT length == 0 (bsc#1173831).
- commit b0aa8d0
* Tue Jul  7 2020 jack@suse.cz
- proc: Use new_inode not new_inode_pseudo (bsc#1173830).
- commit 3016fa7
* Tue Jul  7 2020 jack@suse.cz
- aio: fix async fsync creds (bsc#1173828).
- commit 61a9adb
* Tue Jul  7 2020 jack@suse.cz
- ubifs: fix wrong use of crypto_shash_descsize() (bsc#1173827).
- commit bbe5f1d
* Tue Jul  7 2020 jack@suse.cz
- ubifs: remove broken lazytime support (bsc#1173826).
- commit e41be50
* Tue Jul  7 2020 jack@suse.cz
- fix multiplication overflow in copy_fdtable() (bsc#1173825).
- commit 8426c92
* Tue Jul  7 2020 jack@suse.cz
- namei: only return -ECHILD from follow_dotdot_rcu()
  (bsc#1173824).
- commit ff263dd
* Tue Jul  7 2020 jack@suse.cz
- gfs2: fix glock reference problem in gfs2_trans_remove_revoke
  (bsc#1173823).
- commit cfd9533
* Tue Jul  7 2020 jack@suse.cz
- gfs2: Multi-block allocations in gfs2_page_mkwrite
  (bsc#1173822).
- commit 403212e
* Tue Jul  7 2020 jack@suse.cz
- loop: replace kill_bdev with invalidate_bdev (bsc#1173820).
- commit 7ce51fe
* Tue Jul  7 2020 jack@suse.cz
- block: nr_sects_write(): Disable preemption on seqcount write
  (bsc#1173818).
- commit fe385e8
* Tue Jul  7 2020 jack@suse.cz
- block/bio-integrity: don't free 'buf' if
  bio_integrity_add_page() failed (bsc#1173817).
- commit 181e153
* Mon Jul  6 2020 tbogendoerfer@suse.de
- debugfs: Check module state before warning in
  {full/open}_proxy_open() (bsc#1173746).
- commit 8445625
* Mon Jul  6 2020 oneukum@suse.com
- kABI fixup mtk-vpu: avoid unaligned access to DTCM buffer
  (git-fixes).
- media: mtk-vpu: avoid unaligned access to DTCM buffer
  (git-fixes).
- commit 347e1e1
* Mon Jul  6 2020 colyli@suse.de
- bcache: fix potential deadlock problem in btree_gc_coalesce
  (bsc#1171732, CVE-2020-12771).
- commit 34f5bd2
* Fri Jul  3 2020 pmladek@suse.com
- bpf: Restrict bpf_trace_printk()'s %%s usage and add %%pks,
  %%pus specifier (bsc#1172344).
- commit df79955
* Thu Jul  2 2020 tbogendoerfer@suse.de
- IB/rdmavt: Free kernel completion queue when done (bsc#1173625).
- commit d6f112e
* Thu Jul  2 2020 mkubecek@suse.cz
- Fix
  patches.suse/0001-video-vt8500lcdfb-fix-fallthrough-warning.patch.
  Fix openSUSE-15.2 build breakage by using a fall through comment instead of
  the "fallthrough" macro which is not defined in SLE15-SP2 and openSUSE-15.2.
- commit 668daf6
* Thu Jul  2 2020 tbogendoerfer@suse.de
- ionic: add pcie_print_link_status (bsc#1167773).
- wil6210: use after free in wil_netif_rx_any() (bsc#1154353).
- commit 23910ad
* Thu Jul  2 2020 tbogendoerfer@suse.de
- wil6210: account for napi_gro_receive never returning GRO_DROP
  (bsc#1154353).
- socionext: account for napi_gro_receive never returning GRO_DROP
  (bsc#1154353).
- ionic: tame the watchdog timer on reconfig (bsc#1167773).
- tg3: driver sleeps indefinitely when EEH errors exceed
  eeh_max_freezes (bsc#1173284).
- ionic: export features for vlans to use (bsc#1167773).
- ionic: no link check while resetting queues (bsc#1167773).
- devmap: Use bpf_map_area_alloc() for allocating hash buckets
  (bsc#1154353).
- RDMA/core: Check that type_attrs is not NULL prior access
  (jsc#SLE-8449).
- mvpp2: remove module bugfix (bsc#1154353).
- bnxt_en: Return from timer if interface is not in open state
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix AER reset logic on 57500 chips (bsc#1171150).
- bnxt_en: Re-enable SRIOV during resume (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Simplify bnxt_resume() (jsc#SLE-8371 bsc#1153274).
- bpf: Fix an error code in check_btf_func() (bsc#1154353).
- net/mlx5: Disable reload while removing the device
  (jsc#SLE-8464).
- net/mlx5: DR, Fix freeing in dr_create_rc_qp() (jsc#SLE-8464).
- ionic: remove support for mgmt device (bsc#1167773).
- ionic: wait on queue start until after IFF_UP (bsc#1167773).
- wil6210: add wil_netif_rx() helper function (bsc#1154353).
- commit fe9e2ce
* Thu Jul  2 2020 dwagner@suse.de
- scsi: qla2xxx: Set NVMe status code for failed NVMe FCP request
  (bsc#1158983).
- commit 3de702e
* Thu Jul  2 2020 glin@suse.com
- bpf: Document optval > PAGE_SIZE behavior for sockopt hooks
  (bsc#1155518).
- selftests/bpf: Make sure optvals > PAGE_SIZE are bypassed
  (bsc#1155518).
- bpf: Don't return EINVAL from {get,set}sockopt when optlen >
  PAGE_SIZE (bsc#1155518).
- bpf, xdp, samples: Fix null pointer dereference in *_user code
  (bsc#1155518).
- commit 525d7c1
* Thu Jul  2 2020 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: do not run klp-symbols for configs with no modules
  Starting with 5.8-rc1, s390x/zfcpdump builds fail because rpm/klp-symbols
  script does not find .tmp_versions directory. This is missing because
  s390x/zfcpdump is built without modules (CONFIG_MODULES disabled).
  As livepatching cannot work without modules, the cleanest solution is
  setting %%klp_symbols to 0 if CONFIG_MODULES is disabled. (We cannot simply
  add another condition to the place where %%klp_symbols is set as it can be
  already set to 1 from prjconf.)
- commit a048c4b
* Wed Jul  1 2020 msuchanek@suse.de
- rpm/config.sh: Update OBS build project.
- commit c470a01
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/radeon: fix fb_div check in ni_init_smc_spll_table() (bsc#1152472)
- commit f188884
* Wed Jul  1 2020 tzimmermann@suse.de
- drm: rcar-du: Fix build error (bsc#1152472)
- commit 6214328
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/amdgpu: Replace invalid device ID with a valid device ID (bsc#1152472)
- commit 8b94e6d
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/i915/icl+: Fix hotplug interrupt disabling after storm detection (bsc#1152489)
- commit c7ec144
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/connector: notify userspace on hotplug after register complete (bsc#1152489)
  * context changes
- commit ab4aef3
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/msm: Check for powered down HW in the devfreq callbacks (bsc#1152489)
- commit 8647289
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/i915/gt: Do not schedule normal requests immediately along (bsc#1152489)
- commit 9c3d561
* Wed Jul  1 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: Stage the transfer of the virtual breadcrumb'
- commit d2de202
* Wed Jul  1 2020 tzimmermann@suse.de
- drm: amd/display: fix Kconfig help text (bsc#1152489)
  * context changes
- commit 6439719
* Wed Jul  1 2020 tzimmermann@suse.de
- drm/qxl: Use correct notify port address when creating cursor ring (bsc#1152472)
- commit 600c22c
* Wed Jul  1 2020 tzimmermann@suse.de
- video: vt8500lcdfb: fix fallthrough warning (bsc#1152489)
- commit 476a73c
* Wed Jul  1 2020 mhocko@suse.com
- mm/memory_hotplug: refrain from adding memory into an impossible
  node (bsc#1173552).
- commit 65546dc
* Tue Jun 30 2020 oneukum@suse.com
- crypto: algif_skcipher - Cap recv SG list at ctx->used
  (git-fixes).
- commit 63acd01
* Tue Jun 30 2020 oneukum@suse.com
- crypto - Avoid free() namespace collision (git-fixes).
- commit 08a9f27
* Tue Jun 30 2020 jslaby@suse.cz
- dpaa_eth: fix usage as DSA master, try 3
  (networking-stable-20_05_27).
- net/tls: fix race condition causing kernel panic
  (networking-stable-20_05_27).
- net/mlx5: Fix error flow in case of function_setup failure
  (networking-stable-20_05_27).
- net/mlx5e: Update netdev txq on completions during closure
  (networking-stable-20_05_27).
- net/mlx5: Fix memory leak in mlx5_events_init
  (networking-stable-20_05_27).
- net/mlx5e: Fix inner tirs handling (networking-stable-20_05_27).
- net/mlx5e: kTLS, Destroy key object after destroying the TIS
  (networking-stable-20_05_27).
- net/mlx5: Add command entry handling completion
  (networking-stable-20_05_27).
- kABI: protect struct mlx5_cmd_work_ent (kabi).
- net: ethernet: ti: cpsw: fix ASSERT_RTNL() warning during
  suspend (networking-stable-20_05_27).
- sctp: Start shutdown on association restart if in SHUTDOWN-SENT
  state and socket is closed (networking-stable-20_05_27).
- tipc: block BH before using dst_cache
  (networking-stable-20_05_27).
- net: mvpp2: fix RX hashing for non-10G ports
  (networking-stable-20_05_27).
- net: don't return invalid table id error when we fall back to
  PF_UNSPEC (networking-stable-20_05_27).
- kABI: protect struct fib_dump_filter (kabi).
- net: ipip: fix wrong address family in init error path
  (networking-stable-20_05_27).
- net: qrtr: Fix passing invalid reference to qrtr_local_enqueue()
  (networking-stable-20_05_27).
- net: nlmsg_cancel() if put fails for nhmsg
  (networking-stable-20_05_27).
- sctp: Don't add the shutdown timer if its already been added
  (networking-stable-20_05_27).
- __netif_receive_skb_core: pass skb by reference
  (networking-stable-20_05_27).
- net: inet_csk: Fix so_reuseport bind-address cache in tb->fast*
  (networking-stable-20_05_27).
- net sched: fix reporting the first-time use timestamp
  (networking-stable-20_05_27).
- nexthop: Fix attribute checking for groups
  (networking-stable-20_05_27).
- net: dsa: mt7530: fix roaming from DSA user ports
  (networking-stable-20_05_27).
- commit 8e6293e
* Tue Jun 30 2020 jslaby@suse.cz
- dpaa2-eth: properly handle buffer size restrictions
  (networking-stable-20_05_16).
- tcp: fix error recovery in tcp_zerocopy_receive()
  (networking-stable-20_05_16).
- pppoe: only process PADT targeted at local interfaces
  (networking-stable-20_05_16).
- net: stmmac: fix num_por initialization
  (networking-stable-20_05_16).
- net: phy: fix aneg restart in phy_ethtool_set_eee
  (networking-stable-20_05_16).
- tcp: fix SO_RCVLOWAT hangs with fat skbs
  (networking-stable-20_05_16).
- hinic: fix a bug of ndo_stop (networking-stable-20_05_16).
- net: dsa: loop: Add module soft dependency
  (networking-stable-20_05_16).
- netprio_cgroup: Fix unlimited memory leak of v2 cgroups
  (networking-stable-20_05_16).
- dpaa2-eth: prevent array underflow in update_cls_rule()
  (networking-stable-20_05_16).
- nfp: abm: fix error return code in nfp_abm_vnic_alloc()
  (networking-stable-20_05_16).
- net: tcp: fix rx timestamp behavior for tcp_recvmsg
  (networking-stable-20_05_16).
- net: fix a potential recursive NETDEV_FEAT_CHANGE
  (networking-stable-20_05_16).
- Revert "ipv6: add mtu lock check in __ip6_rt_update_pmtu"
  (networking-stable-20_05_16).
- virtio_net: fix lockdep warning on 32 bit
  (networking-stable-20_05_16).
- hinic: fix wrong para of wait_for_completion_timeout
  (networking-stable-20_05_16).
- commit 8a9049d
* Tue Jun 30 2020 jslaby@suse.cz
- net: dsa: Do not leave DSA master with NULL netdev_ops
  (networking-stable-20_05_12).
- net: stricter validation of untrusted gso packets
  (networking-stable-20_05_12).
- net: mvpp2: cls: Prevent buffer overflow in
  mvpp2_ethtool_cls_rule_del() (networking-stable-20_05_12).
- net: mvpp2: prevent buffer overflow in mvpp22_rss_ctx()
  (networking-stable-20_05_12).
- neigh: send protocol value in neighbor create notification
  (networking-stable-20_05_12).
- nfp: abm: fix a memory leak bug (networking-stable-20_05_12).
- net/mlx4_core: Fix use of ENOSPC around mlx4_counter_alloc()
  (networking-stable-20_05_12).
- tipc: fix partial topology connection closure
  (networking-stable-20_05_12).
- net: macb: fix an issue about leak related system resources
  (networking-stable-20_05_12).
- net: usb: qmi_wwan: add support for DW5816e
  (networking-stable-20_05_12).
- net_sched: sch_skbprio: add message validation to
  skbprio_change() (networking-stable-20_05_12).
- devlink: fix return value after hitting end in region read
  (networking-stable-20_05_12).
- mlxsw: spectrum_acl_tcam: Position vchunk in a vregion list
  properly (networking-stable-20_05_12).
- tunnel: Propagate ECT(1) when decapsulating as recommended by
  RFC6040 (networking-stable-20_05_12).
- net: macsec: preserve ingress frame ordering
  (networking-stable-20_05_12).
- net/mlx5: Fix command entry leak in Internal Error State
  (networking-stable-20_05_12).
- net/mlx5: Fix forced completion access non initialized command
  entry (networking-stable-20_05_12).
- net: tc35815: Fix phydev supported/advertising mask
  (networking-stable-20_05_12).
- sch_sfq: validate silly quantum values
  (networking-stable-20_05_12).
- sch_choke: avoid potential panic in choke_reset()
  (networking-stable-20_05_12).
- fq_codel: fix TCA_FQ_CODEL_DROP_BATCH_SIZE sanity checks
  (networking-stable-20_05_12).
- net/tls: Fix sk_psock refcnt leak when in tls_data_ready()
  (networking-stable-20_05_12).
- net/tls: Fix sk_psock refcnt leak in bpf_exec_tx_verdict()
  (networking-stable-20_05_12).
- commit 01407a0
* Mon Jun 29 2020 oneukum@suse.com
- usb: gadget: udc: Potential Oops in error handling code
  (git-fixes).
- commit e68d3a3
* Mon Jun 29 2020 mgorman@suse.de
- Delete
  patches.suse/fs-Do-not-check-if-there-is-a-fsnotify-watcher-on-pseudo-inodes.patch.
  This patch (mainline commit e9c15badbb7b) breaks chromium browser:
  http://lkml.kernel.org/r/7b4aa1e985007c6d582fffe5e8435f8153e28e0f.camel@redhat.com
- commit e23a2e5
* Mon Jun 29 2020 oneukum@suse.com
- usb: typec: tcpci_rt1711h: avoid screaming irq causing boot
  hangs (git-fixes).
- commit 9bf110f
* Mon Jun 29 2020 oneukum@suse.com
- USB: serial: ch341: add basis for quirk detection (git-fixes).
- commit 5fcb9a5
* Mon Jun 29 2020 fvogt@suse.de
- efi/tpm: Verify event log header before parsing (bsc#1173461).
- commit 855e4d4
* Mon Jun 29 2020 mbenes@suse.cz
- blacklist.conf: aadf9dcef9d4 ("rxrpc: Fix trace string")
  Cosmetic change only.
- commit 3492fbc
* Mon Jun 29 2020 mbrugger@suse.com
- brcmfmac: expose RPi firmware config files through modinfo
  (bsc#1169094).
- commit ceefe76
* Mon Jun 29 2020 mbenes@suse.cz
- tracing: Fix event trigger to accept redundant spaces
  (git-fixes).
- commit b441336
* Mon Jun 29 2020 mbenes@suse.cz
- ring-buffer: Zero out time extend if it is nested and not
  absolute (git-fixes).
- commit 4f656dc
* Mon Jun 29 2020 mgorman@suse.de
- sched/core: Fix PI boosting between RT and DEADLINE tasks
  (git fixes (sched)).
- commit 55e2b0c
* Mon Jun 29 2020 mgorman@suse.de
- sched/deadline: Initialize ->dl_boosted (git fixes (sched)).
- commit d7f40dc
* Mon Jun 29 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-cfs-change-initial-value-of-runnable_avg.patch.
- Refresh
  patches.suse/sched-core-Check-cpus_mask-not-cpus_ptr-in-__set_cpus_allowed_ptr-to-fix-mask-corruption.patch.
- Refresh patches.suse/sched-core-Fix-ttwu-race.patch.
- Refresh patches.suse/sched-core-s-WF_ON_RQ-WQ_ON_CPU.patch.
- commit 302ff9b
* Mon Jun 29 2020 ptesarik@suse.cz
- s390/pci: Log new handle in clp_disable_fh() (git-fixes).
- commit 0747f74
* Mon Jun 29 2020 dwagner@suse.de
- sched/core: Fix PI boosting between RT and DEADLINE tasks
  (bsc#1172823).
- sched/deadline: Initialize ->dl_boosted (bsc#1172823).
- commit b64bd29
* Mon Jun 29 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/ibmvnic-continue-to-init-in-CRQ-reset-returns-H_CLOS.patch
- commit 8848a5a
* Mon Jun 29 2020 bp@suse.de
- EDAC/skx: Use the mcmtr register to retrieve
  close_pg/bank_xor_enable (bsc#1152489).
- commit ba796e7
* Sun Jun 28 2020 dbueso@suse.de
- rcu: Use WRITE_ONCE() for assignments to ->pprev for hlist_nulls
  (bsc#1173438).
- commit f9be02d
* Sun Jun 28 2020 dbueso@suse.de
- selftests/timens: handle a case when alarm clocks are not
  supported (bsc#1164648,jsc#SLE-11493).
- eventpoll: fix missing wakeup for ovflist in ep_poll_callback
  (bsc#1159867).
- random: fix data races at timer_rand_state (bsc#1173438).
- timer: Use hlist_unhashed_lockless() in timer_pending()
  (bsc#1173438).
- jbd2: fix data races at struct journal_head (bsc#1173438).
- list: Add hlist_unhashed_lockless() (bsc#1173438).
- rcu: Fix data-race due to atomic_t copy-by-value (bsc#1171828).
- tick/sched: Annotate lockless access to last_jiffies_update
  (bsc#1173438).
- commit ea6eb59
* Fri Jun 26 2020 msuchanek@suse.de
- Refresh metadata of patches.suse/ibmvnic-continue-to-init-in-CRQ-reset-returns-H_CLOS.patch.
- commit 9767e8e
* Fri Jun 26 2020 msuchanek@suse.de
- ibmveth: Fix max MTU limit (bsc#1173428 ltc#186397).
- commit 79145c1
* Fri Jun 26 2020 bp@suse.de
- EDAC/ghes: Setup DIMM label from DMI and use it in error reports
  (bsc#1168779).
- commit a469a1d
* Fri Jun 26 2020 dwagner@suse.de
- wireguard: receive: account for napi_gro_receive never returning
  GRO_DROP (git-fixes).
- wireguard: device: avoid circular netns references (git-fixes).
- wireguard: noise: do not assign initiation time in if condition
  (git-fixes).
- wireguard: send/receive: use explicit unlikely branch instead
  of implicit coalescing (git-fixes).
  Update context:
  patches.suse/wireguard-noise-separate-receive-counter-from-send-c.patch
- wireguard: selftests: initalize ipv6 members to NULL to squelch
  clang warning (git-fixes).
- commit 4d2639d
* Wed Jun 24 2020 mgorman@suse.de
- sched/cfs: change initial value of runnable_avg (bsc#1158765).
- commit daa01a4
* Wed Jun 24 2020 tiwai@suse.de
- spi: dw-pci: Fix Chip Select amount on Intel Elkhart Lake PSE
  SPI (jsc#SLE-12735).
- spi: dw-pci: Add runtime power management support
  (jsc#SLE-12735).
- SPI: designware: pci: Switch over to MSI interrupts
  (jsc#SLE-12735).
- spi: dw-pci: Add MODULE_DEVICE_TABLE (jsc#SLE-12735).
- spi: dw-pci: Add support for Intel Elkhart Lake PSE SPI
  (jsc#SLE-12735).
- commit fb43301
* Wed Jun 24 2020 tiwai@suse.de
- thermal: intel: intel_pch_thermal: Add Comet Lake (CML)
  platform support (jsc#SLE-12668).
- commit fd37b6c
* Wed Jun 24 2020 tiwai@suse.de
- ntb: intel: fix static declaration (jsc#SLE-12710).
- ntb: intel: add hw workaround for NTB BAR alignment
  (jsc#SLE-12710).
- commit 2f0e6e8
* Wed Jun 24 2020 mhocko@suse.com
- mm: adjust vm_committed_as_batch according to vm overcommit
  policy (bnc#1173271).
- mm/util.c: make vm_memory_committed() more accurate
  (bnc#1173271).
- proc/meminfo: avoid open coded reading of vm_committed_as
  (bnc#1173271).
- commit aef113d
* Wed Jun 24 2020 mkubecek@suse.cz
- series.conf: refresh
  No effect on expanded tree.
- commit c2d8ecc
* Wed Jun 24 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/net-revert-net-get-rid-of-an-signed-integer-overflow-in-ip_idents_reserve.patch
- commit b3deae9
* Wed Jun 24 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/nvme-fc-avoid-gcc-10-zero-length-bounds-warning.patch
  patches.suse/scsi-sd_zbc-Fix-sd_zbc_complete.patch
- fix bugzilla reference (bsc1173206 -> bsc#1173206):
  patches.suse/iocost-don-t-let-vrate-run-wild-while-there-s-no-sat.patch
- commit 7891a6f
* Wed Jun 24 2020 mgorman@suse.de
- sched/core: s/WF_ON_RQ/WQ_ON_CPU/ (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- commit dfd878b
* Wed Jun 24 2020 mgorman@suse.de
- sched/core: Fix ttwu() race (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- commit 2e88482
* Wed Jun 24 2020 mgorman@suse.de
- sched/core: Check cpus_mask, not cpus_ptr in
  __set_cpus_allowed_ptr(), to fix mask corruption (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit 1ad19c5
* Wed Jun 24 2020 mgorman@suse.de
- net: revert "net: get rid of an signed integer overflow in
  ip_idents_reserve()" (bnc#1158748 (network regression)).
- commit 1b123ac
* Tue Jun 23 2020 msuchanek@suse.de
- ibmvnic: continue to init in CRQ reset returns H_CLOSED
  (bsc#1173280 ltc#185369).
- commit 39f977e
* Tue Jun 23 2020 jroedel@suse.de
- vfio-pci: Invalidate mmaps and block MMIO access on disabled
  memory (CVE-2020-12888 bsc#1171868).
- vfio-pci: Fault mmaps to enable vma tracking (CVE-2020-12888
  bsc#1171868).
- vfio/type1: Support faulting PFNMAP vmas (CVE-2020-12888
  bsc#1171868).
- commit d737eb2
* Tue Jun 23 2020 tiwai@suse.de
- Fix a regression of AF_ALG crypto interface hang with aes_s390 (bsc#1167651)
  The upstream fix backported via git-fixes seems causing a trouble with
  s390 aes crypto module.  The problem is generic and should be addressed
  in the upstream, but now we drop the patch as a quick resolution.
  The commit ID is added in blacklist, too.
  Deleted:
  patches.suse/0001-crypto-algif_skcipher-Use-chunksize-instead-of-block.patch
- commit 59211f8
* Tue Jun 23 2020 tiwai@suse.de
- i2c: designware-pci: Fix BUG_ON during device removal
  (jsc#SLE-12734).
- commit 7d1f12c
* Tue Jun 23 2020 tiwai@suse.de
- i2c: designware-pci: Add support for Elkhart Lake PSE I2C
  (jsc#SLE-12734).
- i2c: designware-pci: Switch over to MSI interrupts
  (jsc#SLE-12734).
- commit 7f79de2
* Tue Jun 23 2020 tiwai@suse.de
- ntb: intel: Add Icelake (gen4) support for Intel NTB
  (jsc#SLE-12710).
- commit 37883e6
* Mon Jun 22 2020 tiwai@suse.de
- Revert "pinctrl: freescale: imx: Use 'devm_of_iomap()' to avoid
  a resource leak in case of error in 'imx_pinctrl_probe()'"
  (git-fixes).
- crypto: algboss - don't wait during notifier callback
  (git-fixes).
- drm: encoder_slave: fix refcouting error for modules
  (git-fixes).
- drm/i915: work around false-positive maybe-uninitialized warning
  (git-fixes).
- commit 18a77fa
* Mon Jun 22 2020 dwagner@suse.de
- lpfc: Synchronize NVME transport and lpfc driver devloss_tmo
  (bcs#1173060).
- commit 124f086
* Mon Jun 22 2020 tiwai@suse.de
- r8169: Revive default chip version for r8168 (bsc#1173085).
- commit c0956cb
* Mon Jun 22 2020 hare@suse.de
- scsi: megaraid_sas: Replace undefined MFI_BIG_ENDIAN macro
  with __BIG_ENDIAN_BITFIELD macro (bsc#1173206).
- nvme-fc: avoid gcc-10 zero-length-bounds warning (bsc#1173206).
- iocost: don't let vrate run wild while there's no saturation
  signal (bsc1173206).
- blk-iocost: Fix error on iocost_ioc_vrate_adj (bsc#1173206).
- blk-iocost: fix incorrect vtime comparison in iocg_is_idle()
  (bsc#1173206).
- iocost: over-budget forced IOs should schedule async delay
  (bsc#1173206).
- scsi: smartpqi: Update attribute name to `driver_version`
  (bsc#1173206).
- iocost: check active_list of all the ancestors in
  iocg_activate() (bsc#1173206).
- scsi: sd_zbc: Fix sd_zbc_complete() (bsc#1173206).
- commit 7abe8d4
* Mon Jun 22 2020 hare@suse.de
- blacklist.conf: Add commit for git-fixes (bsc#1173206)
- commit 4a864a5
* Mon Jun 22 2020 ykaukab@suse.de
- irqchip/al-fic: Add support for irq retrigger (jsc#SLE-10505).
- commit 8ec37c7
* Mon Jun 22 2020 mgorman@suse.de
- sched/fair: Optimize dequeue_task_fair() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit 3b10cba
* Fri Jun 19 2020 tiwai@suse.de
- Update patch reference for intel_th patch (jsc#SLE-12705)
- commit 2f7215f
* Thu Jun 18 2020 ptesarik@suse.cz
- s390/bpf: Maintain 8-byte stack alignment (bsc#1169194,
  LTC#185911).
- commit 58beb12
* Thu Jun 18 2020 tiwai@suse.de
- Update patch reference for s390 security fix (CVE-2020-10773 bsc#1172999)
- commit 7370304
* Thu Jun 18 2020 tiwai@suse.de
- firmware: imx-scu: Support one TX and one RX (git-fixes).
- Refresh
  patches.suse/firmware-imx-scu-Fix-corruption-of-header.patch.
- commit 0e40d23
* Thu Jun 18 2020 tiwai@suse.de
- ACPI: GED: use correct trigger type field in _Exx / _Lxx
  handling (git-fixes).
- commit 510ece6
* Thu Jun 18 2020 tiwai@suse.de
- lib/lzo: fix ambiguous encoding bug in lzo-rle (git-fixes).
- x86/reboot/quirks: Add MacBook6,1 reboot quirk (git-fixes).
- x86/PCI: Mark Intel C620 MROMs as having non-compliant BARs
  (git-fixes).
- ASoC: max9867: fix volume controls (git-fixes).
- ath9k: Fix general protection fault in ath9k_hif_usb_rx_cb
  (git-fixes).
- ath9x: Fix stack-out-of-bounds Write in ath9k_hif_usb_rx_cb
  (git-fixes).
- ath9k: Fix use-after-free Write in ath9k_htc_rx_msg (git-fixes).
- ath9k: Fix use-after-free Read in ath9k_wmi_ctrl_rx (git-fixes).
- ath9k: Fix use-after-free Read in htc_connect_service
  (git-fixes).
- drm/vkms: Hold gem object while still in-use (git-fixes).
- ACPI: GED: add support for _Exx / _Lxx handler methods
  (git-fixes).
- mmc: tmio: Further fixup runtime PM management at remove
  (git-fixes).
- mmc: sdio: Fix several potential memory leaks in
  mmc_sdio_init_card() (git-fixes).
- efi/efivars: Add missing kobject_put() in sysfs entry creation
  error path (git-fixes).
- spi: bcm-qspi: Handle clock probe deferral (git-fixes).
- Input: synaptics - add a second working PNP_ID for Lenovo T470s
  (git-fixes).
- Input: mms114 - fix handling of mms345l (git-fixes).
- firmware: imx: warn on unexpected RX (git-fixes).
- commit c722a2d
* Thu Jun 18 2020 tiwai@suse.de
- pinctrl: tigerlake: Tiger Lake uses _HID enumeration
  (jsc#SLE-12737).
- commit 6831e2b
* Thu Jun 18 2020 tiwai@suse.de
- pinctrl: intel: Add Intel Tiger Lake pin controller support
  (jsc#SLE-12737).
- Update config files: Add CONFIG_PINCTRL_TIGERLAKE=m
- supported.conf: Add pinctrl-tigerlake as supported
- commit 2966fcc
* Thu Jun 18 2020 tiwai@suse.de
- mfd: intel-lpss: Add Intel Tiger Lake PCI IDs (jsc#SLE-12737).
- mtd: spi-nor: intel-spi: Add support for Intel Tiger Lake SPI
  serial flash (jsc#SLE-12737).
- commit c6209c3
* Thu Jun 18 2020 tiwai@suse.de
- Update the patch reference for ish-hid fix (jsc#SLE-12683)
- commit 4a77970
* Thu Jun 18 2020 tiwai@suse.de
- Update patch reference for can driver security fix (CVE-2020-14416 bsc#1162002)
- commit f86a41b
* Wed Jun 17 2020 dwagner@suse.de
- rcutorture: Make kvm-find-errors.sh abort on bad directory
  (bsc#1173068).
- rcutorture: Summarize summary of build and run results
  (bsc#1173068).
- rcutorture: Add 100-CPU configuration (bsc#1173068).
- torture: Make results-directory date format completion-friendly
  (bsc#1173068).
- locktorture: Allow CPU-hotplug to be disabled via --bootargs
  (bsc#1173068).
- torture: Hoist calls to lscpu to higher-level kvm.sh script
  (bsc#1173068).
- torture: Allow "CFLIST" to specify default list of scenarios
  (bsc#1173068).
- rcutorture: Add worst-case call_rcu() forward-progress results
  (bsc#1173068).
- torture: Handle systems lacking the mpstat command
  (bsc#1173068).
- torture: Handle jitter for CPUs that cannot be offlined
  (bsc#1173068).
- rcutorture: Dispense with Dracut for initrd creation
  (bsc#1173068).
- torture: Use gawk instead of awk for systime() function
  (bsc#1173068).
- rcutorture: Remove CONFIG_HOTPLUG_CPU=n from scenarios
  (bsc#1173068).
- rcutorture: Test TREE03 with the threadirqs kernel boot
  parameter (bsc#1173068).
- torture: Expand last_ts variable in kvm-test-1-run.sh
  (bsc#1173068).
- commit 937076b
* Wed Jun 17 2020 msuchanek@suse.de
- ibmvnic: Harden device login requests (bsc#1170011 ltc#183538).
- commit f073312
* Wed Jun 17 2020 duwe@suse.de
- rpm/modules.fips:
  * add aes-ce-ccm and des3_ede-x86_64 (boo#173030)
  * add aes_ti and aes_neon_bs (boo#1172956)
- commit 9492a4d
* Wed Jun 17 2020 mbenes@suse.cz
- objtool: Allow no-op CFI ops in alternatives (bsc#1169514).
- commit b40dd12
* Wed Jun 17 2020 tiwai@suse.de
- firmware: imx: scu: Fix corruption of header (git-fixes).
- commit bd25a67
* Wed Jun 17 2020 tiwai@suse.de
- e1000e: Do not wake up the system via WOL if device wakeup is
  disabled (git-fixes).
- commit 8a4bb5a
* Wed Jun 17 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/NFS-Fix-fscache-super_cookie-index_key-from-changing.patch
  patches.suse/NFSv4-Fix-fscache-cookie-aux_data-to-ensure-change_a.patch
  patches.suse/NFSv4.1-fix-rpc_call_done-assignment-for-BIND_CONN_T.patch
  patches.suse/SUNRPC-Signalled-ASYNC-tasks-need-to-exit.patch
  patches.suse/nfs-fscache-use-timespec64-in-inode-auxdata.patch
  patches.suse/nfs-set-invalid-blocks-after-NFSv4-writes.patch
  patches.suse/nfsd4-make-drc_slab-global-not-per-net.patch
  patches.suse/svcrdma-Fix-leak-of-svc_rdma_recv_ctxt-objects.patch
- commit 91ef650
* Wed Jun 17 2020 mbenes@suse.cz
- objtool: Fix ORC vs alternatives (bsc#1169514).
- commit 0222f6e
* Wed Jun 17 2020 mbenes@suse.cz
- objtool: Uniquely identify alternative instruction groups
  (bsc#1169514).
- commit 862a5a6
* Wed Jun 17 2020 mbenes@suse.cz
- objtool: Remove check preventing branches within alternative
  (bsc#1169514).
- commit c794e66
* Tue Jun 16 2020 mbenes@suse.cz
- objtool: Fix !CFI insn_state propagation (bsc#1169514).
- commit 52c95b4
* Tue Jun 16 2020 mbenes@suse.cz
- objtool: Rename struct cfi_state (bsc#1169514).
- commit faa0120
* Tue Jun 16 2020 lhenriques@suse.com
- ceph: skip checking caps when session reconnecting and releasing
  reqs (bsc#1172990).
- ceph: make sure mdsc->mutex is nested in s->s_mutex to fix
  dead lock (bsc#1172989).
- ceph: don't return -ESTALE if there's still an open file
  (bsc#1171915).
- ceph: allow rename operation under different quota realms
  (bsc#1172988).
- ceph: normalize 'delta' parameter usage in check_quota_exceeded
  (bsc#1172987).
- ceph: ceph_kick_flushing_caps needs the s_mutex (bsc#1172986).
- ceph: request expedited service on session's last cap flush
  (bsc#1172985 bsc#1167104).
- ceph: convert mdsc->cap_dirty to a per-session list (bsc#1172984
  bsc#1167104).
- ceph: reset i_requested_max_size if file write is not wanted
  (bsc#1172983).
- ceph: throw a warning if we destroy session with mutex still
  locked (bsc#1172940).
- ceph: fix potential race in ceph_check_caps (bsc#1172940).
- ceph: document what protects i_dirty_item and i_flushing_item
  (bsc#1172940).
- ceph: don't take i_ceph_lock in handle_cap_import (bsc#1172940).
- ceph: don't release i_ceph_lock in handle_cap_trunc
  (bsc#1172940).
- ceph: add comments for handle_cap_flush_ack logic (bsc#1172940).
- ceph: split up __finish_cap_flush (bsc#1172940).
- ceph: reorganize __send_cap for less spinlock abuse
  (bsc#1172940).
- ceph: flush release queue when handling caps for unknown inode
  (bsc#1172939).
- libceph: ignore pool overlay and cache logic on redirects
  (bsc#1172938).
- commit 14735c0
* Tue Jun 16 2020 tiwai@suse.de
- media: cedrus: Program output format during each run
  (git-fixes).
- clk: renesas: cpg-mssr: Fix STBCR suspend/resume handling
  (git-fixes).
- serial: 8250: Fix max baud limit in generic 8250 port
  (git-fixes).
- drivers: phy: sr-usb: do not use internal fsm for USB2 phy init
  (git-fixes).
- HID: multitouch: enable multi-input as a quirk for some devices
  (git-fixes).
- tun: correct header offsets in napi frags mode (git-fixes).
- r8152: support additional Microsoft Surface Ethernet Adapter
  variant (git-fixes).
- staging: kpc2000: fix error return code in kp2000_pcie_probe()
  (git-fixes).
- irqchip/ti-sci-inta: Fix processing of masked irqs (git-fixes).
- irqchip/versatile-fpga: Apply clear-mask earlier (git-fixes).
- irqchip/versatile-fpga: Handle chained IRQs properly
  (git-fixes).
- ktest: Add timeout for ssh sync testing (git-fixes).
- commit ac894fa
* Tue Jun 16 2020 mgorman@suse.de
- fs: Do not check if there is a fsnotify watcher on pseudo inodes
  (bsc#1158765).
- commit 7b8d90d
* Tue Jun 16 2020 denis.kirjanov@suse.com
- bpf, sockhash: Synchronize_rcu before free'ing map (git-fixes).
- bpf, sockmap: Check update requirements after locking
  (git-fixes).
- rxrpc: Fix call RCU cleanup using non-bh-safe locks (git-fixes).
- netfilter: nft_tunnel: add the missing ERSPAN_VERSION nla_policy
  (git-fixes).
- netfilter: nft_tproxy: Fix port selector on Big Endian
  (git-fixes).
- netfilter: nf_tables_offload: return EOPNOTSUPP if rule
  specifies no actions (git-fixes).
- netfilter: nf_queue: enqueue skbs with NULL dst (git-fixes).
- af_unix: add compat_ioctl support (git-fixes).
- ipvs: Improve robustness to the ipvs sysctl (git-fixes).
- commit 988684c
* Tue Jun 16 2020 glin@suse.com
- bpf: Undo internal BPF_PROBE_MEM in BPF insns dump (bsc#1155518).
- commit 3b9919e
* Tue Jun 16 2020 neilb@suse.de
- blacklist.conf: mark commit with incorrect Fixes line
- commit 0804266
* Tue Jun 16 2020 neilb@suse.de
- nfs: set invalid blocks after NFSv4 writes (git-fixes).
- NFSv4.1 fix rpc_call_done assignment for BIND_CONN_TO_SESSION
  (git-fixes).
- nfsd4: make drc_slab global, not per-net (git-fixes).
- NFSv4: Fix fscache cookie aux_data to ensure change_attr is
  included (git-fixes).
- NFS: Fix fscache super_cookie index_key from changing after
  umount (git-fixes).
- SUNRPC: Signalled ASYNC tasks need to exit (git-fixes).
- svcrdma: Fix leak of svc_rdma_recv_ctxt objects (git-fixes).
- nfs: fscache: use timespec64 in inode auxdata (git-fixes).
- commit a77a576
* Tue Jun 16 2020 neilb@suse.de
- blacklist.conf: add uninteresting commit
- commit 3cb617b
* Mon Jun 15 2020 mkubecek@suse.cz
- genetlink: clean up family attributes allocations (git-fixes).
- commit f616c3b
* Mon Jun 15 2020 jeyu@suse.de
- panic: do not print uninitialized taint_flags (bsc#1172814).
- commit 045c8db
* Mon Jun 15 2020 msuchanek@suse.de
- ibmvnic: Flush existing work items before device removal
  (bsc#1065729).
- commit 3f9ece1
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/fadump: Account for memory_limit while reserving memory
  (jsc#SLE-9099 git-fixes).
- commit 3bdf3b7
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/fadump: consider reserved ranges while reserving memory
  (jsc#SLE-9099 git-fixes).
- powerpc/fadump: use static allocation for reserved memory ranges
  (jsc#SLE-9099 git-fixes).
- commit 5e676b4
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/powernv: Fix a warning message (bsc#1156395).
- commit c1f8cea
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/64s: Save FSCR to init_task.thread.fscr after feature
  init (bsc#1065729).
- powerpc/64s: Don't let DT CPU features set FSCR_DSCR
  (bsc#1065729).
- commit 054bf6b
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/64s/exception: Fix machine check no-loss idle wakeup
  (bsc#1156395).
- commit 81b4c8f
* Mon Jun 15 2020 msuchanek@suse.de
- asm-gemeric/tlb: remove stray function declarations
  (bsc#1156395).
- commit 72eefc6
* Mon Jun 15 2020 msuchanek@suse.de
- include/asm-generic/topology.h: guard cpumask_of_node() macro
  argument (bsc#1148868).
- commit 8cdd828
* Mon Jun 15 2020 msuchanek@suse.de
- powerpc/xive: Clear the page tables for the ESB IO mapping
  (fate#322438 bsc#1085030).
- commit e1d4bd5
* Mon Jun 15 2020 dwagner@suse.de
- nvme-fc: don't call nvme_cleanup_cmd() for AENs (bsc#1171688).
- commit abf08ba
* Mon Jun 15 2020 bp@suse.de
- x86/cpu/amd: Make erratum #1054 a legacy erratum (bsc#1152489).
- commit f243f91
* Mon Jun 15 2020 bp@suse.de
- blacklist.conf: 5214028dd89e x86/boot: Correct relocation destination on old linkers
- commit 741883d
* Mon Jun 15 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-ibmvscsi-Don-t-send-host-info-in-adapter-info-M.patch
  patches.suse/sunrpc-clean-up-properly-in-gss_mech_unregister.patch
  patches.suse/sunrpc-svcauth_gss_register_pseudoflavor-must-reject.patch
- commit 1bb600f
* Mon Jun 15 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/sched-fair-Fix-enqueue_task_fair-warning-some-more.patch
- commit f581127
* Mon Jun 15 2020 neilb@suse.de
- work around mvfs bug (bsc#1162063).
- commit 5a1f922
* Mon Jun 15 2020 mkubecek@suse.cz
- rpm: drop execute permissions on source files
  Sometimes a source file with execute permission appears in upstream
  repository and makes it into our kernel-source packages. This is caught by
  OBS build checks and may even result in build failures.
  Sanitize the source tree by removing execute permissions from all C source
  and header files.
- commit 771e293
* Fri Jun 12 2020 bp@suse.de
- x86/speculation: PR_SPEC_FORCE_DISABLE enforcement for indirect
  branches (bsc#1172783 CVE-2020-10768).
- commit 1ce088f
* Fri Jun 12 2020 tiwai@suse.de
- drm/i915: Limit audio CDCLK>=2*BCLK constraint back to GLK only
  (git-fixes).
- drm/i915: extend audio CDCLK>=2*BCLK constraint to more
  platforms (git-fixes).
- commit 9b79e3a
* Fri Jun 12 2020 mgorman@suse.de
- sched/cpuacct: Fix charge cpuacct.usage_sys (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/pelt: Sync util/runnable_sum with PELT window when
  propagating (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/fair: Optimize enqueue_task_fair() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched: Make newidle_balance() static again (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/fair: find_idlest_group(): Remove unused sd_flag parameter
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Simplify the code of should_we_balance()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Fix enqueue_task_fair() warning some more
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 6d2135e
* Fri Jun 12 2020 bp@suse.de
- x86/speculation: Prevent rogue cross-process SSBD shutdown
  (bsc#1172781 CVE-2020-10766).
- commit 9163040
* Fri Jun 12 2020 tbogendoerfer@suse.de
- RDMA/nl: Do not permit empty devices names during
  RDMA_NLDEV_CMD_NEWLINK/SET (bsc#1172841).
- commit 543b194
* Fri Jun 12 2020 tiwai@suse.de
- crypto: cavium/nitrox - Fix 'nitrox_get_first_device()' when
  ndevlist is fully iterated (git-fixes).
- e1000e: Disable TSO for buffer overrun workaround (git-fixes).
- commit 1f86986
* Fri Jun 12 2020 tbogendoerfer@suse.de
- vmxnet3: allow rx flow hash ops only when rss is enabled
  (bsc#1172484).
- net: vmxnet3: fix possible buffer overflow caused by bad DMA
  value in vmxnet3_get_rss() (bsc#1172484).
- vmxnet3: use correct hdr reference when packet is encapsulated
  (bsc#1172484).
- vmxnet3: update to version 4 (bsc#1172484).
- vmxnet3: add geneve and vxlan tunnel offload support
  (bsc#1172484).
- vmxnet3: add support to get/set rx flow hash (bsc#1172484).
- vmxnet3: prepare for version 4 changes (bsc#1172484).
- commit f2fe4cd
* Fri Jun 12 2020 tbogendoerfer@suse.de
- net: ena: xdp: update napi budget for DROP and ABORTED
  (bsc#1154492).
- net: ena: xdp: XDP_TX: fix memory leak (bsc#1154492).
- genetlink: fix memory leaks in genl_family_rcv_msg_dumpit()
  (bsc#1154353).
- RDMA/core: Move and rename trace_cm_id_create() (jsc#SLE-8449).
- RDMA/srpt: Fix disabling device management (jsc#SLE-8449).
- RDMA/bnxt_re: Remove dead code from rcfw (bsc#1170774).
- RDMA/uverbs: Make the event_queue fds return POLLERR when
  disassociated (jsc#SLE-8449).
- ipv6: fix IPV6_ADDRFORM operation logic (bsc#1171662).
- ice: Fix inability to set channels when down (jsc#SLE-7926).
- bnxt_en: Improve TQM ring context memory sizing formulas
  (jsc#SLE-8371 bsc#1153274).
- ice: Fix error return code in ice_add_prof() (jsc#SLE-7926).
- net/mlx5e: replace EINVAL in mlx5e_flower_parse_meta()
  (jsc#SLE-8464).
- net/mlx5e: Fix stats update for matchall classifier
  (jsc#SLE-8464).
- net/mlx5: Fix crash upon suspend/resume (bsc#1172365).
- net: dsa: declare lockless TX feature for slave ports
  (bsc#1154353).
- RDMA/mlx5: Fix NULL pointer dereference in destroy_prefetch_work
  (jsc#SLE-8446).
- net/mlx5: Fix cleaning unmanaged flow tables (jsc#SLE-8464).
- net: phy: propagate an error back to the callers of
  phy_sfp_probe (bsc#1154353).
- commit 2741342
* Fri Jun 12 2020 tiwai@suse.de
- mailbox: zynqmp-ipi: Fix NULL vs IS_ERR() check in
  zynqmp_ipi_mbox_probe() (git-fixes).
- drm/sun4i: hdmi ddc clk: Fix size of m divider (git-fixes).
- ACPI: PM: Avoid using power resources if there are none for D0
  (git-fixes).
- Input: edt-ft5x06 - fix get_default register write access
  (git-fixes).
- mtd: rawnand: brcmnand: fix CS0 layout (git-fixes).
- mtd: rawnand: xway: Fix the probe error path (git-fixes).
- mtd: rawnand: tmio: Fix the probe error path (git-fixes).
- mtd: rawnand: sunxi: Fix the probe error path (git-fixes).
- mtd: rawnand: socrates: Fix the probe error path (git-fixes).
- mtd: rawnand: sharpsl: Fix the probe error path (git-fixes).
- mtd: rawnand: plat_nand: Fix the probe error path (git-fixes).
- mtd: rawnand: pasemi: Fix the probe error path (git-fixes).
- mtd: rawnand: oxnas: Release all devices in the _remove() path
  (git-fixes).
- mtd: rawnand: oxnas: Keep track of registered devices
  (git-fixes).
- mtd: rawnand: orion: Fix the probe error path (git-fixes).
- mtd: rawnand: mtk: Fix the probe error path (git-fixes).
- mtd: rawnand: ingenic: Fix the probe error path (git-fixes).
- mtd: rawnand: diskonchip: Fix the probe error path (git-fixes).
- mtd: rawnand: Fix nand_gpio_waitrdy() (git-fixes).
- mtd: rawnand: brcmnand: correctly verify erased pages
  (git-fixes).
- mtd: rawnand: brcmnand: fix hamming oob layout (git-fixes).
- mtd: rawnand: onfi: Fix redundancy detection check (git-fixes).
- mtd: rawnand: timings: Fix default tR_max and tCCS_min timings
  (git-fixes).
- mtd: rawnand: marvell: Fix probe error path (git-fixes).
- mtd: rawnand: marvell: Use nand_cleanup() when the device is
  not yet registered (git-fixes).
- mtd: rawnand: marvell: Fix the condition on a return code
  (git-fixes).
- clk: mediatek: assign the initial value to clk_init_data of
  mtk_mux (git-fixes).
- clk: qcom: Add missing msm8998 ufs_unipro_core_clk_src
  (git-fixes).
- clk: clk-flexgen: fix clock-critical handling (git-fixes).
- clk: bcm2835: Remove casting to bcm2835_clk_register
  (git-fixes).
- clk: bcm2835: Fix return type of bcm2835_register_gate
  (git-fixes).
- clk: sprd: return correct type of value for
  _sprd_pll_recalc_rate (git-fixes).
- clk: sunxi: Fix incorrect usage of round_down() (git-fixes).
- clk: samsung: Mark top ISP and CAM clocks on Exynos542x as
  critical (git-fixes).
- clk: meson: meson8b: Don't rely on u-boot to init all GP_PLL
  registers (git-fixes).
- clk: meson: meson8b: Fix the vclk_div{1, 2, 4, 6, 12}_en gate
  bits (git-fixes).
- clk: meson: meson8b: Fix the polarity of the RESET_N lines
  (git-fixes).
- power: supply: smb347-charger: IRQSTAT_D is volatile
  (git-fixes).
- power: supply: lp8788: Fix an error handling path in
  'lp8788_charger_probe()' (git-fixes).
- power: supply: core: fix memory leak in HWMON error path
  (git-fixes).
- power: supply: core: fix HWMON temperature labels (git-fixes).
- power: reset: qcom-pon: reg write mask depends on pon generation
  (git-fixes).
- power: supply: bq24257_charger: Replace depends on REGMAP_I2C
  with select (git-fixes).
- staging: rtl8712: Fix IEEE80211_ADDBA_PARAM_BUF_SIZE_MASK
  (git-fixes).
- USB: serial: option: add Telit LE910C1-EUX compositions
  (git-fixes).
- USB: serial: qcserial: add DW5816e QDL support (git-fixes).
- mmc: fix compilation of user API (git-fixes).
- spi: dt-bindings: spi-controller: Fix #address-cells for slave
  mode (git-fixes).
- spi: dw: use "smp_mb()" to avoid sending spi data error
  (git-fixes).
- commit f18fb8c
* Fri Jun 12 2020 tiwai@suse.de
- ASoC: rt5645: Add platform-data for Asus T101HA (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for Toshiba Encore WT10-A
  tablet (git-fixes).
- ASoC: meson: add missing free_irq() in error path (git-fixes).
- ALSA: hda/realtek - add a pintbl quirk for several Lenovo
  machines (git-fixes).
- ALSA: emu10k1: delete an unnecessary condition (git-fixes).
- commit 509b163
* Fri Jun 12 2020 tiwai@suse.de
- ALSA: pcm: disallow linking stream to itself (git-fixes).
- ALSA: usb-audio: Manage auto-pm of all bundled interfaces
  (git-fixes).
- ALSA: pcm: fix snd_pcm_link() lockdep splat (git-fixes).
- ALSA: usb-audio: Use the new macro for HP Dock rename quirks
  (git-fixes).
- ALSA: usb-audio: Add vendor, product and profile name for HP
  Thunderbolt Dock (git-fixes).
- ALSA: usb-audio: Fix inconsistent card PM state after resume
  (git-fixes).
- ALSA: usb-audio: Add Pioneer DJ DJM-900NXS2 support (git-fixes).
- pcm_native: result of put_user() needs to be checked
  (git-fixes).
- commit ef14fbe
* Thu Jun 11 2020 bp@suse.de
- x86/speculation: Avoid force-disabling IBPB based on STIBP
  and enhanced IBRS (bsc#1172782 CVE-2020-10767).
- commit 6c80e35
* Thu Jun 11 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-Offload-wakee-task-activation-if-it-the-wakee-is-descheduling.patch.
- Refresh
  patches.suse/sched-Optimize-ttwu-spinning-on-p-on_cpu.patch.
- Refresh
  patches.suse/sched-cpuacct-Use-__this_cpu_add-instead-of-this_cpu_ptr.patch.
- Refresh
  patches.suse/sched-fair-Fix-negative-imbalance-in-imbalance-calculation.patch.
- Refresh
  patches.suse/sched-fair-Use-__this_cpu_read-in-wake_wide.patch.
- commit 34c599d
* Thu Jun 11 2020 mbenes@suse.cz
- livepatch: Make klp_apply_object_relocs static (bsc#1071995).
- commit 293cfbf
* Thu Jun 11 2020 mbenes@suse.cz
- livepatch: Prevent module-specific KLP rela sections from
  referencing vmlinux symbols (bsc#1071995).
- Refresh
  patches.suse/livepatch-create-and-include-UAPI-headers.patch.
- commit 9ab151a
* Thu Jun 11 2020 mbenes@suse.cz
- livepatch: Remove .klp.arch (bsc#1071995).
- commit 0d36b79
* Thu Jun 11 2020 jack@suse.cz
- bfq: Fix check detecting whether waker queue should be selected
  (bsc#1168838).
- commit 570a2f2
* Thu Jun 11 2020 mbenes@suse.cz
- livepatch: Apply vmlinux-specific KLP relocations early
  (bsc#1071995).
- Refresh
  patches.suse/livepatch-create-and-include-UAPI-headers.patch.
- commit 28cfe0c
* Thu Jun 11 2020 mgorman@suse.de
- Refresh
  patches.suse/cpufreq-intel_pstate-Allow-unspecified-FADT-profile-to-probe-PPC.patch.
- Refresh
  patches.suse/pcc-cpufreq-Re-introduce-deadband-effect-to-reduce-number-of-frequency-changes.patch.
- Refresh patches.suse/readahead-request-tunables.patch.
- commit e092759
* Wed Jun 10 2020 msuchanek@suse.de
- scsi: ibmvscsi: Don't send host info in adapter info MAD after
  LPM (bsc#1172759 ltc#184814).
- commit 2cb7730
* Wed Jun 10 2020 mbenes@suse.cz
- livepatch: Disallow vmlinux.ko (bsc#1071995).
- commit a7813fd
* Wed Jun 10 2020 tiwai@suse.de
- ASoC: intel: cht_bsw_max98090_ti: Add all Chromebooks that
  need pmc_plt_clk_0 quirk (bsc#1171246).
- commit 912573f
* Wed Jun 10 2020 colyli@suse.de
- blacklist.conf: add Add 78f57ef9d50a75326da73d352d7c27828495229a
- commit 828a354
* Wed Jun 10 2020 ykaukab@suse.de
- config: arm64: enable CONFIG_IOMMU_DEFAULT_PASSTHROUGH
  References: bsc#1172739
- commit 3b77faf
* Wed Jun 10 2020 mgorman@suse.de
- fsnotify: Rearrange fast path to minimise overhead when there
  is no watcher (bsc#1158765).
- sched/fair: fix nohz next idle balance (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit 1b0cbfe
* Wed Jun 10 2020 tiwai@suse.de
- vt: keyboard: avoid signed integer overflow in k_ascii
  (CVE-2020-13974 bsc#1172775).
- commit 9b0650e
* Wed Jun 10 2020 tiwai@suse.de
- remoteproc: Fix and restore the parenting hierarchy for vdev
  (git-fixes).
- remoteproc: Fall back to using parent memory pool if no
  dedicated available (git-fixes).
- remoteproc: Add missing '\n' in log messages (git-fixes).
- remoteproc: Fix IDR initialisation in rproc_alloc() (git-fixes).
- drm/i915: Whitelist context-local timestamp in the gen9
  cmdparser (git-fixes).
- drm/i915/gem: Avoid iterating an empty list (git-fixes).
- Revert "drm/amd/display: disable dcn20 abm feature for bring up"
  (git-fixes).
- commit 8d68d47
* Wed Jun 10 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/fanotify-fix-ignore-mask-logic-for-events-on-child-a.patch
- commit bceb814
* Wed Jun 10 2020 mkoutny@suse.com
- Revert "fs/seq_file.c: seq_read(): add info message about buggy .next functions" (bsc#1172751)
  The message floods dmesg and its benefit is marginal in default kernel.
  Delete patches.suse/fs-seq_file.c-seq_read-add-info-message-about-buggy-.patch.
- commit 00aa3d5
* Wed Jun 10 2020 pvorel@suse.cz
- fanotify: fix ignore mask logic for events on child and on dir
  (bsc#1172719).
- commit ce60cdb
* Tue Jun  9 2020 jroedel@suse.de
- blacklist.conf: Add c4e0f3b24004 iommu/msm: Make msm_iommu_lock static
- commit fd75b72
* Tue Jun  9 2020 jroedel@suse.de
- KVM: x86/mmu: Set mmio_value to '0' if reserved #PF can't be
  generated (bsc#1171904).
- KVM: x86: only do L1TF workaround on affected processors
  (bsc#1171904).
- commit d33828d
* Tue Jun  9 2020 dwagner@suse.de
- blacklist: 55e8c8eb2c7b ("posix-cpu-timers: Store a reference to a pid not a task")
  This fixes a historical/theoretical bug which is not worth
  back porting. It depends on tglx's massive posix-cpu-timers
  refactoring. The risk to introduce subtle bugs do not outweigh the
  gain of fixing the bug.
- commit fc0a1e1
* Tue Jun  9 2020 dwagner@suse.de
- netfilter: not mark a spinlock as __read_mostly (git-fixes).
- netfilter: connlabels: prefer static lock initialiser
  (git-fixes).
- commit 2cf2f11
* Tue Jun  9 2020 oneukum@suse.com
- CDC-ACM: heed quirk also in error handling (git-fixes).
- commit a90fe00
* Mon Jun  8 2020 tzimmermann@suse.de
- drm/dp_mst: Increase ACT retry timeout to 3s (bsc#1152472)
  * context changes
- commit 07b82ee
* Mon Jun  8 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: force fbdev into vram'
- commit 0516e8a
* Mon Jun  8 2020 ailiop@suse.com
- xfs: fix duplicate verification from xfs_qm_dqflush()
  (git-fixes).
- commit 51ce4f9
* Mon Jun  8 2020 ailiop@suse.com
- xfs: clean up the error handling in xfs_swap_extents
  (git-fixes).
- commit 7e54c91
* Mon Jun  8 2020 nsaenzjulienne@suse.de
- PCI: brcmstb: Fix window register offset from 4 to 8
  (git-fixes).
- PCI: brcmstb: Assert fundamental reset on initialization
  (git-fixes).
- commit 70db1f0
* Mon Jun  8 2020 nsaenzjulienne@suse.de
- blacklist.conf: Blacklist 3ac395a5b3f3
- commit f86499e
* Mon Jun  8 2020 tiwai@suse.de
- ima: Remove __init annotation from ima_pcrread() (git-fixes).
- commit 438f005
* Mon Jun  8 2020 tiwai@suse.de
- ima: Directly free *entry in ima_alloc_init_template() if
  digests is NULL (bsc#1172223).
- commit 3741933
* Mon Jun  8 2020 tiwai@suse.de
- ima: Call ima_calc_boot_aggregate() in ima_eventdigest_init()
  (bsc#1172223).
- commit 25930ca
* Mon Jun  8 2020 tiwai@suse.de
- Move upstreamed IMA patches into sorted section
- commit 7e9708e
* Mon Jun  8 2020 tiwai@suse.de
- ima: Directly assign the ima_default_policy pointer to ima_rules (bsc#1172223)
  Delete obsoleted downstream fix, too:
  patches.suse/ima-Fix-Oops-at-boot-with-ima_template_fmt-d-boot-op.patch
- commit f1f48b1
* Mon Jun  8 2020 tiwai@suse.de
- evm: Fix a small race in init_desc() (git-fixes).
- commit 391f180
* Mon Jun  8 2020 tiwai@suse.de
- pinctrl: sprd: Fix the incorrect pull-up definition (git-fixes).
- pinctrl: freescale: imx: Use 'devm_of_iomap()' to avoid
  a resource leak in case of error in 'imx_pinctrl_probe()'
  (git-fixes).
- pinctrl: freescale: imx: Fix an error handling path in
  'imx_pinctrl_probe()' (git-fixes).
- pinctrl: imxl: Fix an error handling path in
  'imx1_pinctrl_core_probe()' (git-fixes).
- pinctrl: samsung: Save/restore eint_mask over suspend for
  EINT_TYPE GPIOs (git-fixes).
- pinctrl: samsung: Correct setting of eint wakeup mask on s5pv210
  (git-fixes).
- pinctrl: ocelot: Fix GPIO interrupt decoding on Jaguar2
  (git-fixes).
- pinctrl: rza1: Fix wrong array assignment of rza1l_swio_entries
  (git-fixes).
- pinctrl: stmfx: stmfx_pinconf_set doesn't require to get
  direction anymore (git-fixes).
- rtc: rv3028: Add missed check for devm_regmap_init_i2c()
  (git-fixes).
- rtc: mc13xxx: fix a double-unlock issue (git-fixes).
- extcon: adc-jack: Fix an error handling path in
  'adc_jack_probe()' (git-fixes).
- w1: omap-hdq: cleanup to add missing newline for some dev_dbg
  (git-fixes).
- fpga: dfl: afu: Corrected error handling levels (git-fixes).
- habanalabs: Align protection bits configuration of all TPCs
  (git-fixes).
- misc: fastrpc: fix potential fastrpc_invoke_ctx leak
  (git-fixes).
- slimbus: core: Fix mismatch in of_node_get/put (git-fixes).
- firmware: xilinx: Fix an error handling path in
  'zynqmp_firmware_probe()' (git-fixes).
- iio:chemical:pms7003: Fix timestamp alignment and prevent data
  leak (git-fixes).
- iio:chemical:sps30: Fix timestamp alignment (git-fixes).
- iio: vcnl4000: Fix i2c swapped word reading (git-fixes).
- staging: sm750fb: add missing case while setting FB_VISUAL
  (git-fixes).
- iio: pressure: bmp280: Tolerate IRQ before registering
  (git-fixes).
- iio: buffer: Don't allow buffers without any channels enabled
  to be activated (git-fixes).
- tty: n_gsm: Fix bogus i++ in gsm_data_kick (git-fixes).
- tty: n_gsm: Fix waking up upper tty layer when room available
  (git-fixes).
- tty: n_gsm: Fix SOF skipping (git-fixes).
- USB: serial: usb_wwan: do not resubmit rx urb on fatal errors
  (git-fixes).
- CDC-ACM: heed quirk also in error handling (git-fixes).
- usb: musb: Fix runtime PM imbalance on error (git-fixes).
- usb: musb: start session in resume for host port (git-fixes).
- usb: gadget: fix potential double-free in m66592_probe
  (git-fixes).
- usb: gadget: lpc32xx_udc: don't dereference ep pointer before
  null check (git-fixes).
- USB: gadget: udc: s3c2410_udc: Remove pointless NULL check in
  s3c2410_udc_nuke (git-fixes).
- usb: dwc2: gadget: move gadget resume after the core is in L0
  state (git-fixes).
- usb: dwc3: gadget: Properly handle failed kick_transfer
  (git-fixes).
- usb: dwc3: gadget: Properly handle ClearFeature(halt)
  (git-fixes).
- USB: host: ehci-mxc: Add error handling in ehci_mxc_drv_probe()
  (git-fixes).
- USB: ohci-sm501: fix error return code in
  ohci_hcd_sm501_drv_probe() (git-fixes).
- PCI: vmd: Filter resource type bits from shadow register
  (git-fixes).
- PCI: v3-semi: Fix a memory leak in v3_pci_probe() error handling
  paths (git-fixes).
- PCI: rcar: Fix incorrect programming of OB windows (git-fixes).
- PCI: amlogic: meson: Don't use FAST_LINK_MODE to set up link
  (git-fixes).
- PCI: brcmstb: Fix window register offset from 4 to 8
  (git-fixes).
- PCI: brcmstb: Assert fundamental reset on initialization
  (git-fixes).
- PCI: Allow pci_resize_resource() for devices on root bus
  (git-fixes).
- PCI/PM: Adjust pcie_wait_for_link_delay() for caller delay
  (git-fixes).
- PCI/PM: Call .bridge_d3() hook only if non-NULL (git-fixes).
- PCI/PTM: Inherit Switch Downstream Port PTM settings from
  Upstream Port (git-fixes).
- PCI: Program MPS for RCiEP devices (git-fixes).
- PCI: Fix pci_register_host_bridge() device_register() error
  handling (git-fixes).
- evm: Fix possible memory leak in evm_calc_hmac_or_hash()
  (git-fixes).
- gpio: dwapb: Call acpi_gpiochip_free_interrupts() on GPIO chip
  de-registration (git-fixes).
- gpiolib: Document that GPIO line names are not globally unique
  (git-fixes).
- gpio: dwapb: Append MODULE_ALIAS for platform driver
  (git-fixes).
- vfio/mdev: Fix reference count leak in add_mdev_supported_type
  (git-fixes).
- vfio/pci: fix memory leaks in alloc_perm_bits() (git-fixes).
- HID: i2c-hid: add Schneider SCL142ALM to descriptor override
  (git-fixes).
- mt76: mt76x02u: Add support for newer versions of the XBox
  One wifi adapter (git-fixes).
- p54usb: add AirVasT USB stick device-id (git-fixes).
- drm/edid: Add Oculus Rift S to non-desktop list (git-fixes).
- i2c: altera: Fix race between xfer_msg and isr thread
  (git-fixes).
- evm: Fix RCU list related warnings (git-fixes).
- evm: Check also if *tfm is an error pointer in init_desc()
  (git-fixes).
- drm/i915: fix port checks for MST support on gen >= 11
  (git-fixes).
- ASoC: intel - fix the card names (git-fixes).
- commit 993a2a7
* Mon Jun  8 2020 colyli@suse.de
- raid5: remove gfp flags from scribble_alloc() (bsc#1166985).
- commit d35a2bb
* Mon Jun  8 2020 tiwai@suse.de
- Add cherry-picked ID to the already applied pinctrl patch
- commit b7b9bd6
* Mon Jun  8 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-lpfc-Change-default-queue-allocation-for-reduce.patch
  patches.suse/scsi-lpfc-Fix-MDS-Diagnostic-Enablement-definition.patch
  patches.suse/scsi-lpfc-Fix-lpfc_nodelist-leak-when-processing-uns.patch
  patches.suse/scsi-lpfc-Fix-negation-of-else-clause-in-lpfc_prep_n.patch
  patches.suse/scsi-lpfc-Fix-noderef-and-address-space-warnings.patch
  patches.suse/scsi-lpfc-Maintain-atomic-consistency-of-queue_claim.patch
  patches.suse/scsi-lpfc-Remove-re-binding-of-nvme-rport-during-reg.patch
  patches.suse/scsi-lpfc-Remove-redundant-initialization-to-variabl.patch
  patches.suse/scsi-lpfc-Remove-unnecessary-lockdep_assert_held-cal.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.1.patch
  patches.suse/scsi-lpfc-remove-duplicate-unloading-checks.patch
  patches.suse/scsi-zfcp-Fence-adapter-status-propagation-for-commo.patch
  patches.suse/scsi-zfcp-Fence-early-sysfs-interfaces-for-accesses-.patch
  patches.suse/scsi-zfcp-Fence-fc_host-updates-during-link-down-han.patch
  patches.suse/scsi-zfcp-Move-allocation-of-the-shost-object-to-aft.patch
  patches.suse/scsi-zfcp-Move-fc_host-updates-during-xport-data-han.patch
  patches.suse/scsi-zfcp-Move-p-t-p-port-allocation-to-after-xport-.patch
  patches.suse/scsi-zfcp-Move-shost-modification-after-QDIO-re-open.patch
  patches.suse/scsi-zfcp-Move-shost-updates-during-xconfig-data-han.patch
- commit 9ccb987
* Sun Jun  7 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline and drop Git-repo:
  patches.suse/bpf-Fix-map-permissions-check.patch
  patches.suse/libbpf-Fix-perf_buffer__free-API-for-sparse-allocs.patch
  patches.suse/selftests-bpf-CONFIG_IPV6_SEG6_BPF-required-for-test.patch
  patches.suse/selftests-bpf-CONFIG_LIRC-required-for-test_lirc_mod.patch
  patches.suse/selftests-bpf-Fix-invalid-memory-reads-in-core_relo-.patch
  patches.suse/selftests-bpf-Fix-memory-leak-in-extract_build_id.patch
  patches.suse/selftests-bpf-flow_dissector-Close-TAP-device-FD-aft.patch
- commit fb39453
* Sun Jun  7 2020 colyli@suse.de
- xfrm: fix error in comment (git fixes (block drivers)).
- virtio-blk: handle block_device_operations callbacks after hot unplug (git fixes (block drivers)).
- dm verity fec: fix hash block number in verity_fec_decode (git fixes (block drivers)).
- dm writecache: fix data corruption when reloading the target (git fixes (block drivers)).
- commit b4c0830
* Sat Jun  6 2020 ailiop@suse.com
- xfs: force writes to delalloc regions to unwritten
  (bsc#1158242).
- commit 0735a16
* Sat Jun  6 2020 ailiop@suse.com
- xfs: measure all contiguous previous extents for prealloc size
  (bsc#1158242).
- commit 0724b42
* Sat Jun  6 2020 ailiop@suse.com
- xfs: don't fail unwritten extent conversion on writeback due
  to edquot (bsc#1158242).
- commit 8be9c37
* Fri Jun  5 2020 jeffm@suse.com
- mdraid: fix read/write bytes accounting (bsc#1172537).
- commit 52b03e4
* Fri Jun  5 2020 dwagner@suse.de
- lpfc: Fix return value in __lpfc_nvme_ls_abort (bsc#1171530).
- lpfc: fix axchg pointer reference after free and double frees
  (bsc#1171530).
- lpfc: Fix pointer checks and comments in LS receive refactoring
  (bsc#1171530).
- commit d3a7d02
* Fri Jun  5 2020 dwagner@suse.de
- series: update meta data
  The nmve/nvme-5.8 branch has been merged into mainline, that means no more
  rebases of these patches. Hence move them back to the sorted section.
- commit 4a0d7a9
* Fri Jun  5 2020 tiwai@suse.de
- firmware: imx: scu: Fix possible memory leak in imx_scu_probe()
  (git-fixes).
- firmware: qcom_scm: fix bogous abuse of dma-direct internals
  (git-fixes).
- i2c: fix missing pm_runtime_put_sync in i2c_device_probe
  (git-fixes).
- i2c: acpi: put device when verifying client fails (git-fixes).
- commit d4c4283
* Fri Jun  5 2020 bp@suse.de
- blacklist.conf: 88743470668e x86/dma: Fix max PFN arithmetic overflow on 32 bit systems
- commit efee432
* Fri Jun  5 2020 dwagner@suse.de
- lpfc_debugfs: get rid of pointless access_ok() (bsc#1171530).
- scsi: lpfc: Copyright updates for 12.6.0.4 patches
  (bsc#1171530).
- scsi: lpfc: Make lpfc_defer_acc_rsp static (bsc#1171530).
- scsi: lpfc: Fix incomplete NVME discovery when target
  (bsc#1171530).
- scsi: lpfc: fix spelling mistakes of asynchronous (bsc#1171530).
- scsi: lpfc: fix build failure with DEBUGFS disabled
  (bsc#1171530).
- scsi: lpfc: Fix memory leak on lpfc_bsg_write_ebuf_set func
  (bsc#1171530).
- commit 07d03b5
* Fri Jun  5 2020 hare@suse.de
- nvme: provide num dword helper (bsc#1159058).
- nvme: fix possible hang when ns scanning fails during error (bsc#1159058).
- nvme: prevent double free in nvme_alloc_ns() error handling (bsc#1159058).
- nvme-tcp: fix possible crash in write_zeroes processing
  (bsc#1159058).
- nvme: cleanup namespace identifier reporting in (bsc#1159058).
- nvme: rename __nvme_find_ns_head to nvme_find_ns_head
  (bsc#1159058).
- nvme: refactor nvme_identify_ns_descs error handling
  (bsc#1159058).
- nvme-tcp: Add warning on state change failure at (bsc#1159058).
- nvme-rdma: Add warning on state change failure at (bsc#1159058).
- nvme: Fix controller creation races with teardown flow
  (bsc#1159058).
- nvme: Make nvme_uninit_ctrl symmetric to nvme_init_ctrl
  (bsc#1159058).
- nvme: Fix ctrl use-after-free during sysfs deletion
  (bsc#1159058).
- nvme-pci: Re-order nvme_pci_free_ctrl (bsc#1159058).
- nvme: Remove unused return code from nvme_delete_ctrl_sync
  (bsc#1159058).
- nvme: release ida resources (bsc#1159058).
- nvme: expose hostid via sysfs for fabrics controllers
  (bsc#1159058).
- nvme: expose hostnqn via sysfs for fabrics controllers
  (bsc#1159058).
- commit 377781c
* Fri Jun  5 2020 tiwai@suse.de
- soc: qcom: rpmh: Dirt can only make you dirtier, not cleaner
  (git-fixes).
- commit 9e8f57f
* Fri Jun  5 2020 tiwai@suse.de
- drivers: soc: ti: knav_qmss_queue: Make knav_gp_range_ops static
  (git-fixes).
- soc/tegra: pmc: Select GENERIC_PINCONF (git-fixes).
- soc: qcom: rpmh-rsc: Allow using free WAKE TCS for active
  request (git-fixes).
- soc: qcom: rpmh-rsc: Clear active mode configuration for wake
  TCS (git-fixes).
- soc: qcom: rpmh: Invalidate SLEEP and WAKE TCSes before flushing
  new data (git-fixes).
- soc: qcom: rpmh: Update dirty flag only when data changes
  (git-fixes).
- HID: intel-ish-hid: avoid bogus uninitialized-variable warning
  (git-fixes).
- HID: sony: Fix for broken buttons on DS3 USB dongles
  (git-fixes).
- ASoC: fix incomplete error-handling in img_i2s_in_probe
  (git-fixes).
- ASoC: ux500: mop500: Fix some refcounted resources issues
  (git-fixes).
- ASoC: SOF: core: fix error return code in sof_probe_continue()
  (git-fixes).
- watchdog: imx_sc_wdt: Fix reboot on crash (git-fixes).
- mfd: stmfx: Fix stmfx_irq_init error path (git-fixes).
- mfd: stmfx: Reset chip on resume as supply was disabled
  (git-fixes).
- commit cdc4c92
* Fri Jun  5 2020 tiwai@suse.de
- Refresh and move the upstreamed relay security fix to sorted section
- commit b8d4113
* Fri Jun  5 2020 tiwai@suse.de
- kABI workaround for struct hdac_bus changes (git-fixes).
- commit d370486
* Fri Jun  5 2020 jkosina@suse.cz
- Refresh
  patches.suse/block-floppy-fix-contended-case-in-floppy_queue_rq.patch: update
  upstream reference.
- commit ec891fb
* Fri Jun  5 2020 tiwai@suse.de
- ALSA: es1688: Add the missed snd_card_free() (git-fixes).
- ALSA: hda: add sienna_cichlid audio asic id for sienna_cichlid
  up (git-fixes).
- ALSA: hda: Add ElkhartLake HDMI codec vid (git-fixes).
- ALSA: usb-audio: Fixing usage of plain int instead of NULL
  (git-fixes).
- ALSA: usb-audio: Clean up quirk entries with macros (git-fixes).
- ALSA: hda: Fix potential race in unsol event handler
  (git-fixes).
- ALSA: usb-audio: Add duplex sound support for USB devices
  using implicit feedback (git-fixes).
- ALSA: usb-audio: fixing upper volume limit for RME Babyface
  Pro routing crosspoints (git-fixes).
- ALSA: fireface: fix configuration error for nominal sampling
  transfer frequency (git-fixes).
- ALSA: firewire-lib: fix invalid assignment to union data for
  directional parameter (git-fixes).
- ALSA: hda/tegra: workaround playback failure on Tegra194
  (git-fixes).
- ALSA: hda: add member to store ratio for stripe control
  (git-fixes).
- ALSA: hda/tegra: correct number of SDO lines for Tegra194
  (git-fixes).
- ALSA: hda/realtek - Fix unused variable warning w/o
  CONFIG_LEDS_TRIGGER_AUDIO (git-fixes).
- ALSA: hda/realtek - Add LED class support for micmute LED
  (git-fixes).
- ALSA: hda/realtek - Enable micmute LED on and HP system
  (git-fixes).
- ALSA: hda/realtek - Introduce polarity for micmute LED GPIO
  (git-fixes).
- ALSA: usb-audio: Fix racy list management in output queue
  (git-fixes).
- ALSA: usb-audio: Remove async workaround for Scarlett 2nd gen
  (git-fixes).
- ALSA: usb-audio: Improve frames size computation (git-fixes).
- ALSA: usb-audio: Fix a limit check in
  proc_dump_substream_formats() (git-fixes).
- ALSA: usb-audio: Print more information in stream proc files
  (git-fixes).
- ALSA: usb-audio: RME Babyface Pro mixer patch (git-fixes).
- commit 4609c7f
* Fri Jun  5 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/nfs-add-minor-version-to-nfs_server_key-for-fscache.patch
- commit 5fe8ee1
* Fri Jun  5 2020 mkubecek@suse.cz
- Update upstream reference:
  patches.suse/mm-fix-mremap-not-considering-huge-pmd-devmap.patch
- commit a7fb6a0
* Fri Jun  5 2020 glin@suse.com
- selftests/bpf: CONFIG_LIRC required for test_lirc_mode2.sh
  (bsc#1155518).
- selftests/bpf: CONFIG_IPV6_SEG6_BPF required for
  test_seg6_loop.o (bsc#1155518).
- selftests/bpf: Fix invalid memory reads in core_relo selftest
  (bsc#1155518).
- commit 433235c
* Fri Jun  5 2020 glin@suse.com
- selftests/bpf, flow_dissector: Close TAP device FD after the
  test (bsc#1155518).
- bpf: Fix map permissions check (bsc#1155518).
- libbpf: Fix perf_buffer__free() API for sparse allocs
  (bsc#1155518).
- selftests/bpf: Fix memory leak in extract_build_id()
  (bsc#1155518).
- commit 1e6959e
* Fri Jun  5 2020 glin@suse.com
- Refresh patches.suse/selftests-bpf-Validate-frozen-map-contents-stays-fro.patch.
- commit a23c87d
* Thu Jun  4 2020 ailiop@suse.com
- xfs: preserve default grace interval during quotacheck
  (bsc#1172170).
- commit 6ac0d79
* Thu Jun  4 2020 ailiop@suse.com
- xfs: don't commit sunit/swidth updates to disk if that would
  cause repair failures (bsc#1172169).
- commit 428ff5a
* Thu Jun  4 2020 ailiop@suse.com
- xfs: split the sunit parameter update into two parts
  (bsc#1172169).
- commit ae3fe8d
* Thu Jun  4 2020 ailiop@suse.com
- xfs: refactor agfl length computation function (bsc#1172169).
- commit 59f4128
* Thu Jun  4 2020 jack@suse.cz
- bfq: Use only idle IO periods for think time calculations
  (bsc#1171513).
- bfq: Use 'ttime' local variable (bsc#1171513).
- commit e237c2f
* Thu Jun  4 2020 bp@suse.de
- x86: Fix early boot crash on gcc-10, third try (bsc#1152489).
- commit 4156a32
* Thu Jun  4 2020 tiwai@suse.de
- media: go7007: fix a miss of snd_card_free (CVE-2019-20810
  bsc#1172458).
- commit af15264
* Thu Jun  4 2020 bp@suse.de
- EDAC/amd64: Add PCI device IDs for family 17h, model 70h
  (bsc#1165975).
- Refresh
  patches.suse/edac-amd64-add-family-ops-for-family-19h-models-00h-0fh.patch.
- commit 7847579
* Thu Jun  4 2020 jack@suse.cz
- bfq: Avoid false bfq queue merging (bsc#1171513).
- commit 5742c15
* Thu Jun  4 2020 dwagner@suse.de
- nvme-fc: print proper nvme-fc devloss_tmo value (bsc#1172391).
- commit 3186404
* Thu Jun  4 2020 tiwai@suse.de
- media: staging: ipu3-imgu: Move alignment attribute to field
  (git-fixes).
- media: Revert "staging: imgu: Address a compiler warning on
  alignment" (git-fixes).
- media: staging: ipu3: Fix stale list entries on parameter
  queue failure (git-fixes).
- media: platform: fcp: Set appropriate DMA parameters
  (git-fixes).
- media: dvb: return -EREMOTEIO on i2c transfer failure
  (git-fixes).
- Bluetooth: btmtkuart: Improve exception handling in
  btmtuart_probe() (git-fixes).
- ath10k: Remove ath10k_qmi_register_service_notifier()
  declaration (git-fixes).
- wcn36xx: Fix error handling path in 'wcn36xx_probe()'
  (git-fixes).
- ath10k: Skip handling del_server during driver exit (git-fixes).
- mwifiex: Fix memory corruption in dump_station (git-fixes).
- rtlwifi: Fix a double free in _rtl_usb_tx_urb_setup()
  (git-fixes).
- iwlwifi: avoid debug max amsdu config overwriting itself
  (git-fixes).
- ath9k_htc: Silence undersized packet warnings (git-fixes).
- ath10k: remove the max_sched_scan_reqs value (git-fixes).
- libertas_tf: avoid a null dereference in pointer priv
  (git-fixes).
- mwifiex: avoid -Wstringop-overflow warning (git-fixes).
- rtw88: fix an issue about leak system resources (git-fixes).
- b43legacy: Fix case where channel status is corrupted
  (git-fixes).
- brcmfmac: fix wrong location to get firmware feature
  (git-fixes).
- Bluetooth: hci_bcm: fix freeing not-requested IRQ (git-fixes).
- clocksource: dw_apb_timer_of: Fix missing clockevent timers
  (git-fixes).
- spi: spi-fsl-dspi: Fix 16-bit word order in 32-bit XSPI mode
  (git-fixes).
- commit 4b38228
* Thu Jun  4 2020 neilb@suse.de
- nfs: add minor version to nfs_server_key for fscache
  (bsc#1172467).
- commit b589a40
* Wed Jun  3 2020 tiwai@suse.de
- Update patch reference of a net security fix (CVE-2019-20812 bsc#1172453)
- commit c181788
* Wed Jun  3 2020 mbenes@suse.cz
- objtool: Ignore empty alternatives (bsc#1169514).
- commit 117af93
* Wed Jun  3 2020 mbenes@suse.cz
- objtool: Clean instruction state before each function validation
  (bsc#1169514).
- commit 7737495
* Wed Jun  3 2020 mhocko@suse.com
- mm: Fix mremap not considering huge pmd devmap (bsc#1172317,
  CVE-2020-10757).
- commit 43819f6
* Wed Jun  3 2020 msuchanek@suse.de
- Delete patches.suse/seltests-powerpc-Add-a-selftest-for-memcpy_mcsafe.patch (bsc#1171699).
  This patch adds a symlink which cannot be handled by quilt.
- commit 6407cc2
* Wed Jun  3 2020 tiwai@suse.de
- relay: handle alloc_percpu returning NULL in relay_open
  (CVE-2019-19462 bsc#1158265).
- commit 47f5251
* Wed Jun  3 2020 dwagner@suse.de
- Drop a couple of block layer git-fixes (bsc#1170891 bsc#1173139)
  Upstream changed the partition usage counter check back and forth and
  ended up reverting all changes. Let's drop our the partial backport.
  (cherry picked from commit 70ad1b2fa5955d91e1a09a8027daf210e28fee30)
- Drop a couple of block layer git-fixes
  Upstream changed the partition usage counter check back and forth and
  ended up reverting all changes. Let's drop our the partial backport.
- commit e674b5a
* Wed Jun  3 2020 dwagner@suse.de
- series: Update meta data
  lfpc commits have been merged into the jejb tree.
- commit 557015d
* Wed Jun  3 2020 tiwai@suse.de
- platform/x86: intel-vbtn: Only blacklist SW_TABLET_MODE on
  the 9 / "Laptop" chasis-type (git-fixes).
- commit 19f981c
* Wed Jun  3 2020 tiwai@suse.de
- drm/mcde: dsi: Fix return value check in mcde_dsi_bind()
  (git-fixes).
- video: fbdev: w100fb: Fix a potential double free (git-fixes).
- drm/dp_mst: Reformat drm_dp_check_act_status() a bit
  (git-fixes).
- agp/intel: Reinforce the barrier after GTT updates (git-fixes).
- ACPI: CPPC: Fix reference count leak in
  acpi_cppc_processor_probe() (git-fixes).
- ACPI: sysfs: Fix reference count leak in
  acpi_sysfs_add_hotplug_profile() (git-fixes).
- PM: runtime: clk: Fix clk_pm_runtime_get() error path
  (git-fixes).
- platform/x86: dell-laptop: don't register micmute LED if there
  is no token (git-fixes).
- platform/x86: intel-vbtn: Also handle tablet-mode switch on
  "Detachable" and "Portable" chassis-types (git-fixes).
- platform/x86: intel-vbtn: Do not advertise switches to userspace
  if they are not there (git-fixes).
- platform/x86: intel-vbtn: Split keymap into buttons and switches
  parts (git-fixes).
- platform/x86: intel-vbtn: Use acpi_evaluate_integer()
  (git-fixes).
- mmc: sdhci-msm: Clear tuning done flag while hs400 tuning
  (git-fixes).
- mmc: sdhci-esdhc-imx: fix the mask for tuning start point
  (git-fixes).
- mmc: mmci_sdmmc: fix DMA API warning overlapping mappings
  (git-fixes).
- mmc: uniphier-sd: call devm_request_irq() after
  tmio_mmc_host_probe() (git-fixes).
- mmc: meson-mx-sdio: trigger a soft reset after a timeout or
  CRC error (git-fixes).
- mmc: sdio: Fix potential NULL pointer error in
  mmc_sdio_init_card() (git-fixes).
- mmc: core: Use DEFINE_DEBUGFS_ATTRIBUTE instead of
  DEFINE_SIMPLE_ATTRIBUTE (git-fixes).
- Input: synaptics-rmi4 - fix error return code in
  rmi_driver_probe() (git-fixes).
- Input: i8042 - add ThinkPad S230u to i8042 reset list
  (git-fixes).
- Input: xpad - add custom init packet for Xbox One S controllers
  (git-fixes).
- Input: evdev - call input_flush_device() on release(), not
  flush() (git-fixes).
- Input: usbtouchscreen - add support for BonXeon TP (git-fixes).
- clk: ti: am33xx: fix RTC clock parent (git-fixes).
- usb: gadget: legacy: fix redundant initialization warnings
  (git-fixes).
- usb: dwc3: pci: Enable extcon driver for Intel Merrifield
  (git-fixes).
- drm/amd/powerplay: perform PG ungate prior to CG ungate
  (git-fixes).
- gpio: tegra: mask GPIO IRQs during IRQ shutdown (git-fixes).
- commit 28d8ae3
* Wed Jun  3 2020 ykaukab@suse.de
- fdt: Update CRC check for rng-seed (jsc#SLE-12424).
- commit 4204d16
* Wed Jun  3 2020 wqu@suse.com
- btrfs: reloc: clear DEAD_RELOC_TREE bit for orphan roots  to
  prevent runaway balance (bsc#1171417 bsc#1160947 bsc#1172366).
- commit af6e7de
* Wed Jun  3 2020 wqu@suse.com
- btrfs: reloc: fix reloc root leak and NULL pointer  dereference
  (bsc#1171417 bsc#1160947 bsc#1172366).
- commit 96f60c2
* Wed Jun  3 2020 neilb@suse.de
- nfsd: always check return value of find_any_file (bsc#1172208).
- commit 2c210bd
* Tue Jun  2 2020 tiwai@suse.de
- fs/binfmt_elf.c: allocate initialized memory in
  fill_thread_core_info() (CVE-2020-10732 bsc#1171220).
- commit b52f45b
* Tue Jun  2 2020 tiwai@suse.de
- iwlwifi: pcie: handle QuZ configs with killer NICs as well
  (bsc#1172374).
- commit 21f33d7
* Tue Jun  2 2020 tiwai@suse.de
- crypto: stm32/crc32 - fix multi-instance (git-fixes).
- crypto: stm32/crc32 - fix run-time self test issue (git-fixes).
- crypto: stm32/crc32 - fix ext4 chksum BUG_ON() (git-fixes).
- crypto: drbg - fix error return code in drbg_alloc_state()
  (git-fixes).
- crypto: ccp -- don't "select" CONFIG_DMADEVICES (git-fixes).
- crypto: algapi - Avoid spurious modprobe on LOADED (git-fixes).
- spi: dw: Add SPI Rx-done wait method to DMA-based transfer
  (git-fixes).
- spi: dw: Add SPI Tx-done wait method to DMA-based transfer
  (git-fixes).
- spi: dw: Fix native CS being unset (git-fixes).
- spi: dw: Zero DMA Tx and Rx configurations on stack (git-fixes).
- spi: spi-mem: Fix Dual/Quad modes on Octal-capable devices
  (git-fixes).
- spi: pxa2xx: Fix runtime PM ref imbalance on probe error
  (git-fixes).
- spi: pxa2xx: Fix controller unregister order (git-fixes).
- spi: dw: Fix controller unregister order (git-fixes).
- spi: bcm2835aux: Fix controller unregister order (git-fixes).
- spi: bcm2835: Fix controller unregister order (git-fixes).
- spi: Fix controller unregister order (git-fixes).
- spi: bcm-qspi: when tx/rx buffer is NULL set to 0 (git-fixes).
- spi: Respect DataBitLength field of SpiSerialBusV2() ACPI
  resource (git-fixes).
- NFC: st21nfca: add missed kfree_skb() in an error path
  (git-fixes).
- crypto: chelsio/chtls: properly set tp->lsndtime (git-fixes).
- ieee80211: Fix incorrect mask for default PE duration
  (git-fixes).
- mac80211: mesh: fix discovery timer re-arming issue / crash
  (git-fixes).
- gpio: bcm-kona: Fix return value of bcm_kona_gpio_probe()
  (git-fixes).
- gpio: pxa: Fix return value of pxa_gpio_probe() (git-fixes).
- gpio: exar: Fix bad handling for ida_simple_get error path
  (git-fixes).
- commit c5d8ee8
* Tue Jun  2 2020 nsaenzjulienne@suse.de
- spi: spi-fsl-dspi: Replace interruptible wait queue with a
  simple completion (git-fixes).
- commit eb6dfdf
* Tue Jun  2 2020 ykaukab@suse.de
- kabi: ppc64le: prevent struct dma_map_ops to become defined (jsc#SLE-12424).
- commit ca74359
* Tue Jun  2 2020 jroedel@suse.de
- iommu: Fix reference count leak in iommu_group_alloc
  (bsc#1172394).
- iommu/amd: Fix legacy interrupt remapping for x2APIC-enabled
  system (bsc#1172393).
- commit 7cd78b9
* Tue Jun  2 2020 jslaby@suse.cz
- net: bcmgenet: correct per TX/RX ring statistics
  (networking-stable-20_04_27).
- net/x25: Fix x25_neigh refcnt leak when receiving frame
  (networking-stable-20_04_27).
- cxgb4: fix adapter crash due to wrong MC size
  (networking-stable-20_04_27).
- vxlan: use the correct nlattr array in NL_SET_ERR_MSG_ATTR
  (networking-stable-20_04_27).
- mlxsw: Fix some IS_ERR() vs NULL bugs
  (networking-stable-20_04_27).
- ipv4: Update fib_select_default to handle nexthop objects
  (networking-stable-20_04_27).
- vrf: Fix IPv6 with qdisc and xfrm (networking-stable-20_04_27).
- sched: etf: do not assume all sockets are full blown
  (networking-stable-20_04_27).
- net: dsa: b53: b53_arl_rw_op() needs to select IVL or SVL
  (networking-stable-20_04_27).
- net: dsa: b53: Rework ARL bin logic
  (networking-stable-20_04_27).
- net: dsa: b53: Fix ARL register definitions
  (networking-stable-20_04_27).
- net: dsa: b53: Lookup VID in ARL searches when VLAN is enabled
  (networking-stable-20_04_27).
- vrf: Check skb for XFRM_TRANSFORMED flag
  (networking-stable-20_04_27).
- xfrm: Always set XFRM_TRANSFORMED in xfrm{4,6}_output_finish
  (networking-stable-20_04_27).
- team: fix hang in team_mode_get() (networking-stable-20_04_27).
- cxgb4: fix large delays in PTP synchronization
  (networking-stable-20_04_27).
- net: openvswitch: ovs_ct_exit to be done under ovs_lock
  (networking-stable-20_04_27).
- tcp: cache line align MAX_TCP_HEADER
  (networking-stable-20_04_27).
- net/mlx4_en: avoid indirect call in TX completion
  (networking-stable-20_04_27).
- net: netrom: Fix potential nr_neigh refcnt leak in nr_add_node
  (networking-stable-20_04_27).
- commit 5938694
* Tue Jun  2 2020 nsaenzjulienne@suse.de
- spi: fsl: use platform_get_irq() instead of of_irq_to_resource()
  (git-fixes).
- commit bd042e3
* Tue Jun  2 2020 jslaby@suse.cz
- amd-xgbe: Use __napi_schedule() in BH context
  (networking-stable-20_04_17).
- net: dsa: mt7530: fix tagged frames pass-through in VLAN-unaware
  mode (networking-stable-20_04_17).
- net: tun: record RX queue in skb before do_xdp_generic()
  (networking-stable-20_04_17).
- net: ipv4: devinet: Fix crash when add/del multicast IP with
  autojoin (networking-stable-20_04_17).
- net: qrtr: send msgs from local of same id as broadcast
  (networking-stable-20_04_17).
- net/mlx5e: Fix pfnum in devlink port attribute
  (networking-stable-20_04_17).
- net/mlx5e: Add missing release firmware call
  (networking-stable-20_04_17).
- net/mlx5: Fix frequent ioread PCI access during recovery
  (networking-stable-20_04_17).
- l2tp: Allow management of tunnels and session in user namespace
  (networking-stable-20_04_17).
- hsr: check protocol version in hsr_newlink()
  (networking-stable-20_04_17).
- net: revert default NAPI poll timeout to 2 jiffies
  (networking-stable-20_04_17).
- net: ipv6: do not consider routes via gateways for anycast
  address check (networking-stable-20_04_17).
- commit 1727243
* Tue Jun  2 2020 tiwai@suse.de
- supported.conf: Mark two hwtracing helper modules as externally supported (bsc#1170879)
- commit 504def2
* Tue Jun  2 2020 tbogendoerfer@suse.de
- net: mvpp2: Enable autoneg bypass for 1000BaseX/2500BaseX ports
  (bsc#1162209).
- commit 7789c1f
* Tue Jun  2 2020 neilb@suse.de
- kabi fix for sunrpc-clean-up-properly-in-gss_mech_unregister
  (bsc#1171219, CVE-2020-12656).
- sunrpc: clean up properly in gss_mech_unregister() (bsc#1171219,
  CVE-2020-12656).
- sunrpc: svcauth_gss_register_pseudoflavor must reject duplicate
  registrations (bsc#1171219, CVE-2020-12656).
- commit 6de429c
* Mon Jun  1 2020 mkubecek@suse.cz
- selinux: properly handle multiple messages in
  selinux_netlink_send() (CVE-2020-10751 bsc#1171189).
- commit 7f84ce6
* Mon Jun  1 2020 nsaenzjulienne@suse.de
- spi: spi-fsl-dspi: Don't access reserved fields in SPI_MCR
  (git-fixes).
- pwm: sun4i: Move pwm_calculate() out of spin_lock() (git-fixes).
- spi: fsl: don't map irq during probe (git-fixes).
- spi: spi-fsl-dspi: Change usage pattern of SPI_MCR_* and
  SPI_CTAR_* macros (git-fixes).
- commit b10c30b
* Mon Jun  1 2020 nsaenzjulienne@suse.de
- blacklist.conf: Blacklist 671ffde1752f
- commit 5cf09f7
* Mon Jun  1 2020 mkubecek@suse.cz
- netlabel: cope with NULL catmap (CVE-2020-10711 bsc#1171191).
- commit 5e0d442
* Mon Jun  1 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/btrfs-fix-log-context-list-corruption-after-rename-w.patch
- commit e2decaa
* Mon Jun  1 2020 nsaenzjulienne@suse.de
- blacklist.conf: Blacklist 37b410018064
- commit e4b5a91
* Mon Jun  1 2020 nsaenzjulienne@suse.de
- blacklist.conf: Blacklist 34719de919af
- commit b0e5046
* Mon Jun  1 2020 fdmanana@suse.com
- btrfs: fix partial loss of prealloc extent past i_size after
  fsync (bsc#1172343).
- commit 54a1118
* Mon Jun  1 2020 fdmanana@suse.com
- btrfs: fix log context list corruption after rename whiteout
  error (bsc#1172342).
- commit 4fb9cbe
* Mon Jun  1 2020 msuchanek@suse.de
- drivers/net/ibmvnic: Update VNIC protocol version reporting
  (bsc#1065729).
- commit 141c495
* Mon Jun  1 2020 pmladek@suse.com
- powerpc/bpf: Enable bpf_probe_read{, str}() on powerpc again
  (bsc#1172344).
- Update config files.
- commit 4d25196
* Mon Jun  1 2020 pmladek@suse.com
- bpf: Restrict bpf_probe_read{, str}() only to archs where they
  work (bsc#1172344).
- Update config files.
- commit e0c0f64
* Sat May 30 2020 tiwai@suse.de
- soc: mediatek: cmdq: return send msg error code (git-fixes).
- mmc: block: Fix use-after-free issue for rpmb (git-fixes).
- gpu/drm: Ingenic: Fix opaque pointer casted to wrong type
  (git-fixes).
- drm/amd/display: drop cursor position check in atomic test
  (git-fixes).
- commit a495b53
* Sat May 30 2020 tiwai@suse.de
- Move an upstreamed sound patch into sorted section
- commit 423c7d0
* Sat May 30 2020 tiwai@suse.de
- ALSA: hda/realtek - Add new codec supported for ALC287
  (git-fixes).
- ALSA: usb-audio: Quirks for Gigabyte TRX40 Aorus Master onboard
  audio (git-fixes).
- ALSA: usb-audio: mixer: volume quirk for ESS Technology Asus
  USB DAC (git-fixes).
- ALSA: hwdep: fix a left shifting 1 by 31 UB bug (git-fixes).
- commit eb6c2db
* Fri May 29 2020 bp@suse.de
- x86/mm/cpa: Flush direct map alias during cpa (bsc#1152489).
- commit 9b8006c
* Fri May 29 2020 bp@suse.de
- blacklist.conf: Add arch/x86/um to the blacklist
- commit afdd481
* Fri May 29 2020 tiwai@suse.de
- ima: Fix Oops at boot with ima_template_fmt=d boot option
  (bsc#1172223).
- commit f5ff35f
* Fri May 29 2020 tiwai@suse.de
- Input: synaptics-rmi4 - really fix attn_data use-after-free
  (git-fixes).
- Input: dlink-dir685-touchkeys - fix a typo in driver name
  (git-fixes).
- commit 80c7b8b
* Thu May 28 2020 tiwai@suse.de
- misc: rtsx: Add short delay after exit from ASPM (git-fixes).
- mei: release me_cl object reference (git-fixes).
- iio: adc: stm32-dfsdm: fix device used to request dma
  (git-fixes).
- iio: adc: stm32-adc: fix device used to request dma (git-fixes).
- drm/etnaviv: fix perfmon domain interation (git-fixes).
- component: Silence bind error on -EPROBE_DEFER (git-fixes).
- USB: core: Fix misleading driver bug report (git-fixes).
- drm/amd/display: Prevent dpcd reads with passive dongles
  (git-fixes).
- platform/x86: asus-nb-wmi: Do not load on Asus T100TA and T200TA
  (git-fixes).
- HID: quirks: Add HID_QUIRK_NO_INIT_REPORTS quirk for Dell K12A
  keyboard-dock (git-fixes).
- HID: i2c-hid: reset Synaptics SYNA2393 on resume (git-fixes).
- HID: alps: ALPS_1657 is too specific; use U1_UNICORN_LEGACY
  instead (git-fixes).
- HID: alps: Add AUI1657 device ID (git-fixes).
- HID: multitouch: add eGalaxTouch P80H84 support (git-fixes).
- i2c: dev: Fix the race between the release of i2c_dev and cdev
  (git-fixes).
- iio: adc: stm32-adc: Use dma_request_chan() instead
  dma_request_slave_channel() (git-fixes).
- iio: adc: stm32-dfsdm: Use dma_request_chan() instead
  dma_request_slave_channel() (git-fixes).
- commit 44aca06
* Wed May 27 2020 bp@suse.de
- x86/speculation: Add SRBDS vulnerability and mitigation
  documentation (bsc#1154824 CVE-2020-0543).
- commit 6bcc04c
* Wed May 27 2020 ykaukab@suse.de
- Refresh
  patches.suse/cpufreq-tegra186-add-CPUFREQ_NEED_INITIAL_FREQ_CHECK.patch.
- commit 819998f
* Wed May 27 2020 bp@suse.de
- x86/speculation: Add Special Register Buffer Data Sampling
  (SRBDS) mitigation (bsc#1154824 CVE-2020-0543).
- commit a4ac28e
* Wed May 27 2020 ykaukab@suse.de
- PCI: mobiveil: ls_pcie_g4: fix SError when accessing config space (bsc#1161495).
- PCI: mobiveil: ls_pcie_g4: add Workaround for A-011451 (bsc#1161495).
- PCI: mobiveil: ls_pcie_g4: add Workaround for A-011577 (bsc#1161495).
- PCI: mobiveil: Fix unmet dependency warning for PCIE_MOBIVEIL_PLAT (bsc#1161495).
- PCI: mobiveil: Fix sparse different address space warnings (bsc#1161495).
- PCI: mobiveil: Add PCIe Gen4 RC driver for Layerscape SoCs (bsc#1161495).
- PCI: mobiveil: Add Header Type field check (bsc#1161495).
- PCI: mobiveil: Add 8-bit and 16-bit CSR register accessors (bsc#1161495).
- PCI: mobiveil: Allow mobiveil_host_init() to be used to re-init host (bsc#1161495).
- PCI: mobiveil: Add callback function for link up check (bsc#1161495).
- PCI: mobiveil: Add callback function for interrupt initialization (bsc#1161495).
- PCI: mobiveil: Modularize the Mobiveil PCIe Host Bridge IP driver (bsc#1161495).
- PCI: mobiveil: Collect the interrupt related operations into a function (bsc#1161495).
- PCI: mobiveil: Move the host initialization into a function (bsc#1161495).
- PCI: mobiveil: Introduce a new structure mobiveil_root_port (bsc#1161495).
- commit 84a8a95
* Wed May 27 2020 ykaukab@suse.de
- pcie: mobiveil: remove patchset v9
  Prepare to backport upstream version.
- commit 00b589d
* Wed May 27 2020 bp@suse.de
- x86/cpu: Add 'table' argument to cpu_matches() (bsc#1154824
  CVE-2020-0543).
- commit a0bbf3d
* Wed May 27 2020 dwagner@suse.de
- scsi: lpfc: Fix lpfc_nodelist leak when processing unsolicited
  event (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: remove duplicate unloading checks (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
  Remove hunk in patches.suse/lpfc-Refactor-Send-LS-Response-support.patch
  which is in patches.suse/scsi-lpfc-remove-duplicate-unloading-checks.patch
- scsi: lpfc: Remove redundant initialization to variable rc
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.8.0.1 (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix MDS Diagnostic Enablement definition
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix noderef and address space warnings (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Remove unnecessary lockdep_assert_held calls
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Change default queue allocation for reduced memory
  consumption (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix negation of else clause in
  lpfc_prep_node_fc4type (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- scsi: lpfc: Remove re-binding of nvme rport during registration
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Maintain atomic consistency of queue_claimed flag
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- commit 575ae7a
* Wed May 27 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/s390-kexec_file-fix-initrd-location-for-kdump-kernel.patch
- update upstream reference and move into sorted section:
  patches.suse/x86-microcode-amd-increase-microcode-patch_max_size.patch
- move into sorted section:
  patches.suse/signal-avoid-double-atomic-counter-increments-for-user-accounting.patch
  No effect on expanded tree.
- commit 571cf9a
* Wed May 27 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/cifs-add-SMB2_open-arg-to-return-POSIX-data.patch
  patches.suse/cifs-add-smb2-POSIX-info-level.patch
  patches.suse/cifs-call-wake_up-server-response_q-inside-of-cifs_r.patch
  patches.suse/cifs-do-d_move-in-rename.patch
  patches.suse/cifs-do-not-ignore-the-SYNC-flags-in-getattr.patch
  patches.suse/cifs-handle-prefix-paths-in-reconnect.patch
  patches.suse/cifs-make-use-of-cap_unix-ses-in-cifs_reconnect_tcon.patch
  patches.suse/cifs-plumb-smb2-POSIX-dir-enumeration.patch
  patches.suse/cifs-potential-unintitliazed-error-code-in-cifs_geta.patch
  patches.suse/cifs-rename-posix-create-rsp.patch
  patches.suse/cifs-use-mod_delayed_work-for-server-reconnect-if-al.patch
  patches.suse/smb3-fix-performance-regression-with-setting-mtime.patch
- update to mainline version, rename and move into sorted section:
  patches.suse/cifs-print-warning-once-if-mounting-with-vers-1.0.patch -> patches.suse/cifs-print-warning-mounting-with-vers-1-0.patch
  No relevant effect on expanded tree:
  diff -urN old/fs/cifs/connect.c new/fs/cifs/connect.c
  - -- old/fs/cifs/connect.c	2020-05-27 11:46:54.090968292 +0200
  +++ new/fs/cifs/connect.c	2020-05-27 11:46:54.990971522 +0200
  @@ -1466,8 +1466,8 @@
  cifs_dbg(VFS, "vers=1.0 (cifs) not permitted when mounting with smb3\n");
  return 1;
  }
  - printk_once(KERN_WARNING "Use of the less secure dialect "
  - "vers=1.0 is not recommended unless required for "
  +		cifs_dbg(VFS, "Use of the less secure dialect vers=1.0 "
  +			   "is not recommended unless required for "
  "access to very old servers\n");
  vol->ops = &smb1_operations;
  vol->vals = &smb1_values;
  diff -urN old/fs/cifs/smb2ops.c new/fs/cifs/smb2ops.c
  - -- old/fs/cifs/smb2ops.c	2020-05-27 11:46:54.074968234 +0200
  +++ new/fs/cifs/smb2ops.c	2020-05-27 11:46:54.974971463 +0200
  @@ -3020,7 +3020,7 @@
  oparms.fid = &fid;
  oparms.reconnect = false;
  - rc = SMB2_open(xid, &oparms, utf16_path, &oplock, NULL,NULL, NULL,
  +	rc = SMB2_open(xid, &oparms, utf16_path, &oplock, NULL, NULL, NULL,
  NULL);
  kfree(utf16_path);
  if (!rc) {
  - -
- commit f7dacbf
* Tue May 26 2020 jkosina@suse.cz
- Refresh
  patches.suse/block-floppy-fix-contended-case-in-floppy_queue_rq.patch:
  update upstream references (submitted -> applied).
- commit fce9354
* Tue May 26 2020 jkosina@suse.cz
- block/floppy: fix contended case in floppy_queue_rq()
  (bsc#1171426).
- commit 18ed9ad
* Tue May 26 2020 tiwai@suse.de
- tty: serial: add missing spin_lock_init for SiFive serial
  console (git-fixes).
- vfio/type1: Fix VA->PA translation for PFNMAP VMAs in
  vaddr_get_pfn() (git-fixes).
- vfio: avoid possible overflow in vfio_iommu_type1_pin_pages
  (git-fixes).
- vfio: Ignore -ENODEV when getting MSI cookie (git-fixes).
- commit 250c72c
* Tue May 26 2020 tiwai@suse.de
- Add a GIT commit ID of already cherry-picked x86/platform patch
- commit 6c1b791
* Tue May 26 2020 tiwai@suse.de
- ax25: fix setsockopt(SO_BINDTODEVICE) (git-fixes).
- dmaengine: tegra210-adma: Fix an error handling path in
  'tegra_adma_probe()' (git-fixes).
- dmaengine: dmatest: Restore default for channel (git-fixes).
- dmaengine: owl: Use correct lock in owl_dma_get_pchan()
  (git-fixes).
- mtd: Fix mtd not registered due to nvmem name collision
  (git-fixes).
- mtd: spinand: Propagate ECC information to the MTD structure
  (git-fixes).
- ARM: oxnas: make ox820_boot_secondary static (git-fixes).
- commit eaf4ceb
* Tue May 26 2020 tiwai@suse.de
- ACPICA: Fixes for acpiExec namespace init file (git-fixes).
- commit 36c0ce1
* Tue May 26 2020 msuchanek@suse.de
- powerpc/64s/kuap: Restore AMR in system reset exception
  (bsc#1156395).
- powerpc/kuap: PPC_KUAP_DEBUG should depend on PPC_KUAP
  (bsc#1156395).
- commit bba3032
* Tue May 26 2020 msuchanek@suse.de
- powerpc/setup_64: Set cache-line-size based on cache-block-size
  (bsc#1065729).
- commit 2697326
* Tue May 26 2020 msuchanek@suse.de
- blacklist.conf: Add 9d82973e032e gcc-10 warnings: fix low-hanging fruit
- commit d3df11a
* Tue May 26 2020 msuchanek@suse.de
- scripts/decodecode: fix trapping instruction formatting
  (bsc#1065729).
- commit b83c354
* Tue May 26 2020 msuchanek@suse.de
- tpm: ibmvtpm: retry on H_CLOSED in tpm_ibmvtpm_send()
  (bsc#1065729).
- commit a0d3d55
* Tue May 26 2020 msuchanek@suse.de
- rpm/kernel-source.spec.in: Add obsolete_rebuilds (boo#1172073).
- commit 6524463
* Tue May 26 2020 pmladek@suse.com
- printk: queue wake_up_klogd irq_work only if per-CPU areas
  are ready (bsc#1172095).
- commit 96ce1d2
* Tue May 26 2020 pmladek@suse.com
- vsprintf: don't obfuscate NULL and error pointers (bsc#1172086).
- commit f35dca1
* Tue May 26 2020 tiwai@suse.de
- ALSA: hda/realtek - Add a model for Thinkpad T570 without DAC
  workaround (bsc#1172017).
- commit c7e1c2b
* Tue May 26 2020 jroedel@suse.de
- kabi/severities: Ingnore get_dev_data()
  The function is internal to the AMD IOMMU driver and must
  not be called by any third party.
- commit b897173
* Mon May 25 2020 jroedel@suse.de
- iommu/amd: Fix over-read of ACPI UID from IVRS table
  (bsc#1172064).
- iommu/virtio: Reverse arguments to list_add (bsc#1172068).
- iommu/amd: Do not flush Device Table in iommu_map_page()
  (bsc#1172062).
- iommu/amd: Update Device Table in increase_address_space()
  (bsc#1172066).
- iommu/amd: Call domain_flush_complete() in update_domain()
  (bsc#1172061).
- iommu/amd: Do not loop forever when trying to increase address
  space (bsc#1172063).
- iommu/amd: Fix race in increase_address_space()/fetch_pte()
  (bsc#1172065).
- iommu/qcom: Fix local_base status check (bsc#1172067).
- KVM: Check validity of resolved slot when searching memslots
  (bsc#1172069).
- commit dd49af6
* Mon May 25 2020 mkoutny@suse.com
- mm: memcontrol: fix memory.low proportional distribution
  (bsc#1168230).
- commit 94666fc
* Mon May 25 2020 dwagner@suse.de
- scsi: qla2xxx: Do not log message when reading port speed via
  sysfs (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: Delete all sessions before unregister local nvme
  port (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: Fix hang when issuing nvme disconnect-all in NPIV
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- commit b6f8c1c
* Mon May 25 2020 dwagner@suse.de
- wireguard: noise: separate receive counter from send counter
  (bsc#1169021 jsc#SLE-12250).
- wireguard: queueing: preserve flow hash across packet scrubbing
  (bsc#1169021 jsc#SLE-12250).
- wireguard: noise: read preshared key while taking lock
  (bsc#1169021 jsc#SLE-12250).
- wireguard: selftests: use newer iproute2 for gcc-10 (bsc#1169021
  jsc#SLE-12250).
- commit 299cebb
* Mon May 25 2020 dwagner@suse.de
- rcu: Avoid data-race in rcu_gp_fqs_check_wake() (bsc#1171828).
- rcu: Use *_ONCE() to protect lockless ->expmask accesses
  (bsc#1171828).
- rcu: Make rcu_read_unlock_special() checks match
  raise_softirq_irqoff() (bsc#1172046).
  Refresh rcu-Use-READ_ONCE-for-expmask-in-rcu_read_unlock_spe.patch
- rcu: Simplify rcu_read_unlock_special() deferred wakeups
  (bsc#1172046).
- commit 14cfc7d
* Mon May 25 2020 mbenes@suse.cz
- x86/unwind/orc: Fix unwind_get_return_address_ptr() for inactive
  tasks (bsc#1058115).
  (cherry picked from commit 5d062fa0c4b96d9f6695e0393114da63299cd52e)
- x86/unwind/orc: Fix unwind_get_return_address_ptr() for inactive
  tasks (bsc#1058115).
- commit d9c0a48
* Mon May 25 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/s390-kexec_file-fix-initrd-location-for-kdump-kernel.patch
- commit 6765b4b
* Mon May 25 2020 tiwai@suse.de
- iio: sca3000: Remove an erroneous 'get_device()' (git-fixes).
- iio: adc: ti-ads8344: Fix channel selection (git-fixes).
- staging: iio: ad2s1210: Fix SPI reading (git-fixes).
- iio: dac: vf610: Fix an error handling path in
  'vf610_dac_probe()' (git-fixes).
- commit f20f881
* Mon May 25 2020 glin@suse.com
- bpf: Prevent mmap()'ing read-only maps as writable
  (bsc#1155518).
- commit db279bd
* Sun May 24 2020 mgorman@suse.de
- sched: Offload wakee task activation if it the wakee is
  descheduling (bnc#1158748, bnc#1159781).
- sched: Optimize ttwu() spinning on p->on_cpu (bnc#1158748,
  bnc#1159781).
- commit 6a690f9
* Fri May 22 2020 tiwai@suse.de
- ALSA: hda/realtek - Add more fixup entries for Clevo machines
  (git-fixes).
- ALSA: iec1712: Initialize STDSP24 properly when using the
  model=staudio option (git-fixes).
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus
  Xtreme (git-fixes).
- ALSA: pcm: fix incorrect hw_base increase (git-fixes).
- commit 1a75995
* Fri May 22 2020 tiwai@suse.de
- Update patch reference for SPI security fix (CVE-2020-12769 bsc#1171983)
- commit bdb2e59
* Fri May 22 2020 tiwai@suse.de
- Update patch reference for USB gadeget security fix (CVE-2020-13143 bsc#1171982)
- commit 2b875ef
* Fri May 22 2020 bp@suse.de
- x86/resctrl: Preserve CDP enable over CPU hotplug (bsc#1152489).
- commit f6b2bde
* Fri May 22 2020 bp@suse.de
- x86/resctrl: Fix invalid attempt at removing the default
  resource group (bsc#1152489).
- commit 960b1f0
* Fri May 22 2020 bp@suse.de
- EDAC/synopsys: Do not dump uninitialized pinf->col
  (bsc#1152489).
- commit 349fab2
* Fri May 22 2020 bp@suse.de
- blacklist.conf: 870b4333a62e x86/ioremap: Fix CONFIG_EFI=n build
- commit c645d02
* Fri May 22 2020 pvorel@suse.cz
- nfs: fix NULL deference in nfs4_get_valid_delegation.
- commit ee8a543
* Fri May 22 2020 tonyj@suse.de
- blacklist.conf:
- commit 1787033
* Wed May 20 2020 mkubecek@suse.cz
- Update kabi files.
- update to "RC3" submission (commit de1e6fb20e9d)
- commit 8f25cbe
* Wed May 20 2020 tiwai@suse.de
- USB: gadget: fix illegal array access in binding with UDC
  (git-fixes).
- USB: usbfs: fix mmap dma mismatch (git-fixes).
- dwc3: Remove check for HWO flag in
  dwc3_gadget_ep_reclaim_trb_sg() (git-fixes).
- drm/amd/display: add basic atomic check for cursor plane
  (git-fixes).
- Make the "Reducing compressed framebufer size" message be
  DRM_INFO_ONCE() (git-fixes).
- usb: usbfs: correct kernel->user page attribute mismatch
  (git-fixes).
- dmaengine: mmp_tdma: Reset channel error on release (git-fixes).
- dmaengine: mmp_tdma: Do not ignore slave config validation
  errors (git-fixes).
- dmaengine: pch_dma.c: Avoid data race between probe and irq
  handler (git-fixes).
- drm/amdgpu: invalidate L2 before SDMA IBs (v2) (git-fixes).
- drm/amd/powerplay: avoid using pm_en before it is initialized
  revised (git-fixes).
- drm/qxl: lost qxl_bo_kunmap_atomic_page in
  qxl_image_init_helper() (git-fixes).
- pnp: Use list_for_each_entry() instead of open coding
  (git-fixes).
- drm/amdgpu: simplify padding calculations (v2) (git-fixes).
- commit eb4042e
* Wed May 20 2020 tiwai@suse.de
- blacklist.conf: Add an entry for non-supported arch/hexagon
- commit 4f664be
* Wed May 20 2020 tiwai@suse.de
- workqueue: Remove the warning in wq_worker_sleeping()
  (git-fixes).
- workqueue: don't use wq_select_unbound_cpu() for bound works
  (git-fixes).
- commit 4686860
* Wed May 20 2020 tiwai@suse.de
- vt: vt_ioctl: fix VT_DISALLOCATE freeing in-use virtual console
  (git-fixes).
- vt: vt_ioctl: remove unnecessary console allocation checks
  (git-fixes).
- commit 3c82977
* Wed May 20 2020 tiwai@suse.de
- usb: core: hub: limit HUB_QUIRK_DISABLE_AUTOSUSPEND to USB5534B
  (git-fixes).
- usb: gadget: udc: atmel: Make some symbols static (git-fixes).
- usb: host: xhci-plat: keep runtime active when removing host
  (git-fixes).
- usb: gadget: legacy: fix error return code in gncm_bind()
  (git-fixes).
- usb: gadget: legacy: fix error return code in cdc_bind()
  (git-fixes).
- usb: gadget: net2272: Fix a memory leak in an error handling
  path in 'net2272_plat_probe()' (git-fixes).
- usb: gadget: audio: Fix a missing error return value in
  audio_bind() (git-fixes).
- commit 8d23cb6
* Wed May 20 2020 tiwai@suse.de
- i2c: mux: demux-pinctrl: Fix an error handling path in
  'i2c_demux_pinctrl_probe()' (git-fixes).
- gpio: pca953x: Fix pca953x_gpio_set_config (git-fixes).
- iwlwifi: mvm: limit maximum queue appropriately (git-fixes).
- mfd: intel-lpss: Use devm_ioremap_uc for MMIO (git-fixes).
- lib: devres: add a helper function for ioremap_uc (git-fixes).
- commit db78707
* Wed May 20 2020 tiwai@suse.de
- drm/i915/gvt: Fix kernel oops for 3-level ppgtt guest
  (git-fixes).
- drm/i915/gvt: Init DPLL/DDI vreg for virtual display instead
  of inheritance (git-fixes).
- drm/i915: Propagate error from completed fences (git-fixes).
- drm/i915: Don't enable WaIncreaseLatencyIPCEnabled when IPC
  is disabled (git-fixes).
- coredump: fix crash when umh is disabled (git-fixes).
- dmaengine: dmatest: Fix process hang when reading 'wait'
  parameter (git-fixes).
- drm/i915: HDCP: fix Ri prime check done during link check
  (git-fixes).
- coredump: fix null pointer dereference on coredump (git-fixes).
- dma-debug: fix displaying of dma allocation type (git-fixes).
- dma-direct: fix data truncation in
  dma_direct_get_required_mask() (git-fixes).
- dma-coherent: fix integer overflow in the reserved-memory dma
  allocation (git-fixes).
- drm/etnaviv: rework perfmon query infrastructure (git-fixes).
- commit 79467c5
* Wed May 20 2020 tonyj@suse.de
- perf/core: fix parent pid/tid in task exit events (git-fixes).
- perf/core: Fix endless multiplex timer (git-fixes).
- commit 9e85c92
* Wed May 20 2020 mkubecek@suse.cz
- netfilter: ctnetlink: netns exit must wait for callbacks
  (bsc#1169795).
- commit 1367464
* Wed May 20 2020 ggherdovich@suse.cz
- Update upstream reference and move to sorted section:
  patches.suse/x86-sched-Don-t-enable-static-key-when-starting-seco.patch.
- commit 286ea13
* Wed May 20 2020 ggherdovich@suse.cz
- Update upstream reference and move to sorted section:
  patches.suse/x86-sched-Account-for-CPUs-with-less-than-4-cores-in.patch.
- commit 806c75b
* Wed May 20 2020 ggherdovich@suse.cz
- Update upstream reference and move to sorted section:
  patches.suse/x86-sched-Bail-out-of-frequency-invariance-if-.patch.
- commit debf0d3
* Wed May 20 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/NFSv3-fix-rpc-receive-buffer-size-for-MOUNT-call.patch
- commit c8d32f9
* Wed May 20 2020 tzimmermann@suse.de
- drm/i915/gvt: Fix kernel oops for 3-level ppgtt guest (bsc#1152489)
- commit 9d0ce16
* Wed May 20 2020 tzimmermann@suse.de
- drm/i915/gvt: Init DPLL/DDI vreg for virtual display instead of (bsc#1152489)
- commit addefe4
* Wed May 20 2020 tzimmermann@suse.de
- drm/amdgpu: force fbdev into vram (bsc#1152472)
  * context changes
- commit 84af19b
* Wed May 20 2020 tzimmermann@suse.de
- drm/i915: Don't enable WaIncreaseLatencyIPCEnabled when IPC is (bsc#1152489)
- commit 2c2843b
* Wed May 20 2020 tzimmermann@suse.de
- sun6i: dsi: fix gcc-4.8 (bsc#1152489)
- commit 7678d54
* Wed May 20 2020 tzimmermann@suse.de
- drm/i915: HDCP: fix Ri prime check done during link check (bsc#1152489)
  * context changes
- commit a3e33d0
* Wed May 20 2020 tzimmermann@suse.de
- drm/i915: Extend WaDisableDARBFClkGating to icl,ehl,tgl (bsc#1152489)
- commit 99f05b3
* Wed May 20 2020 neilb@suse.de
- NFSv3: fix rpc receive buffer size for MOUNT call (bsc#1171849).
- commit 4832c5f
* Tue May 19 2020 lduncan@suse.com
- scsi: mptfusion: Fix double fetch bug in ioctl (bsc#1171218
  CVE-2020-12652).
- commit d61daf3
* Tue May 19 2020 tiwai@suse.de
- Update patch reference for ipv6 security fix (CVE-2020-1749 bsc#1165629)
- commit b65b793
* Tue May 19 2020 jroedel@suse.de
- KVM: SVM: Fix potential memory leak in svm_cpu_init() (bsc#1171736).
- commit 010dbdc
* Tue May 19 2020 dmueller@suse.com
- scripts/dtc: Remove redundant YYLOC global declaration
  (bsc#1160388).
- commit 40e5eca
* Tue May 19 2020 jack@suse.cz
- bdi: Fix up kabi for dev_name addition (bsc#1171844).
- commit 4d83bb4
* Tue May 19 2020 mbenes@suse.cz
- x86/unwind/orc: Fix error handling in __unwind_start()
  (bsc#1058115).
- commit ad0fbff
* Tue May 19 2020 tiwai@suse.de
- platform/x86: ISST: Fix wrong unregister type (bsc#1171810).
- platform/x86: ISST: Allow additional core-power mailbox commands
  (bsc#1171810).
- platform/x86: ISST: Use dev_get_drvdata (bsc#1171810).
- commit 6bfd9ca
* Tue May 19 2020 tiwai@suse.de
- Move two upstreamed IMA patches into sorted section
- commit caf8825
* Tue May 19 2020 glin@suse.com
- bpf: Fix error return code in map_lookup_and_delete_elem()
  (bsc#1155518).
- bpf: Fix sk_psock refcnt leak when receiving message
  (bsc#1155518).
- commit d621e20
* Mon May 18 2020 tonyj@suse.de
- perf/x86/intel/uncore: Add Ice Lake server uncore support
  (jsc#SLE-8898).
- perf/x86/intel/uncore: Factor out __snr_uncore_mmio_init_box
  (jsc#SLE-8898).
- perf/x86/intel/uncore: Add box_offsets for free-running counters
  (jsc#SLE-8898).
- commit 093dafa
* Mon May 18 2020 oneukum@suse.com
- vt: fix unicode console freeing with a common interface
  (git-fixes).
- commit 4d7b8d6
* Mon May 18 2020 msuchanek@suse.de
- s390/kexec_file: fix initrd location for kdump kernel
  (bsc#1166340 ltc#184171).
- commit d2b5550
* Mon May 18 2020 jack@suse.cz
- block: Fix writeback throttling W=1 compiler warnings
  (bsc#1171844).
- blacklist.conf: Remove the commit
- commit 2a895f4
* Mon May 18 2020 jack@suse.cz
- bdi: add a ->dev_name field to struct backing_dev_info
  (bsc#1171844).
- commit 1e675b2
* Mon May 18 2020 jack@suse.cz
- bdi: move bdi_dev_name out of line (bsc#1171844).
- commit 8c98f9b
* Mon May 18 2020 jack@suse.cz
- bdi: use bdi_dev_name() to get device name (bsc#1171844).
- commit 2f2a729
* Mon May 18 2020 jack@suse.cz
- propagate_one(): mnt_set_mountpoint() needs mount_lock
  (bsc#1171843).
- commit d12939e
* Mon May 18 2020 oneukum@suse.com
- vt: don't hardcode the mem allocation upper bound (git-fixes).
- commit cef46bf
* Mon May 18 2020 oneukum@suse.com
- vt: don't use kmalloc() for the unicode screen buffer
  (git-fixes).
- commit 4fd1f99
* Mon May 18 2020 dwagner@suse.de
- rcu: Add *_ONCE() for grace-period progress indicators
  (bsc#1171828).
- rcu: Add READ_ONCE() to rcu_segcblist ->tails (bsc#1171828).
- rcu: Add WRITE_ONCE() to rcu_node ->qsmaskinitnext
  (bsc#1171828).
- rcu: Add WRITE_ONCE() to rcu_state ->gp_req_activity
  (bsc#1171828).
- rcu: Add WRITE_ONCE to rcu_node ->exp_seq_rq store
  (bsc#1171828).
- rcu: Add WRITE_ONCE() to rcu_node ->qsmask update (bsc#1171828).
- rcu: Provide debug symbols and line numbers in KCSAN runs
  (bsc#1171828).
- rcu: Fix exp_funnel_lock()/rcu_exp_wait_wake() datarace
  (bsc#1171828).
- rcu: Use READ_ONCE() for ->expmask in rcu_read_unlock_special()
  (bsc#1171828).
- srcu: Apply *_ONCE() to ->srcu_last_gp_end (bsc#1171828).
- commit a409a59
* Mon May 18 2020 jack@suse.cz
- blacklist.conf: Blacklist c4b4c2a78a9f
- commit 7d1f234
* Mon May 18 2020 jack@suse.cz
- ext4: use non-movable memory for superblock readahead
  (bsc#1171842).
- commit cc13e88
* Mon May 18 2020 jack@suse.cz
- ocfs2: no need try to truncate file beyond i_size (bsc#1171841).
- commit 4ea0462
* Mon May 18 2020 oneukum@suse.com
- USB: uas: add quirk for LaCie 2Big Quadra (git-fixes).
- commit 827d447
* Mon May 18 2020 jack@suse.cz
- io_uring: remove bogus RLIMIT_NOFILE check in file registration
  (bsc#1171840).
- commit 2d64873
* Mon May 18 2020 jack@suse.cz
- io_uring: honor original task RLIMIT_FSIZE (bsc#1171839).
- commit c77337d
* Mon May 18 2020 oneukum@suse.com
- USB: serial: qcserial: Add DW5816e support (git-fixes).
- commit aa6d686
* Mon May 18 2020 rgoldwyn@suse.com
- mm/swapfile.c: move inode_lock out of claim_swapfile (git-fixes, bsc#1171730).
- commit e2fed77
* Mon May 18 2020 oneukum@suse.com
- usb: xhci: Fix NULL pointer dereference when enqueuing trbs
  from urb sg list (git-fixes).
- commit 25bbbc6
* Mon May 18 2020 jack@suse.cz
- blacklist.conf: Blacklist ce623f89872d
- commit 1a198c3
* Mon May 18 2020 jack@suse.cz
- blacklist.conf: Blacklist 02f03c4206c1
- commit 2d8e6ba
* Mon May 18 2020 jack@suse.cz
- ext4: fix a data race at inode->i_blocks (bsc#1171835).
- commit 3a01d10
* Mon May 18 2020 jack@suse.cz
- block, bfq: invoke flush_idle_tree after reparent_active_queues
  in pd_offline (bsc#1171834).
- commit 2f6d8ec
* Mon May 18 2020 jack@suse.cz
- block, bfq: make reparent_leaf_entity actually work only on
  leaf entities (bsc#1171833).
- commit d07ba45
* Mon May 18 2020 jack@suse.cz
- block, bfq: turn put_queue into release_process_ref in
  __bfq_bic_change_cgroup (bsc#1171832).
- commit 8dc34a5
* Mon May 18 2020 msuchanek@suse.de
- libnvdimm/dax: Pick the right alignment default when creating dax
  devices (bsc#1171759).
- powerpc/book3s64: Export has_transparent_hugepage() related
  functions (bsc#1171759).
- Refresh patches.suse/powerpc-hash64-devmap-Use-H_PAGE_THP_HUGE-when-setti.patch.
- commit 01ee8de
* Mon May 18 2020 dwagner@suse.de
- rcu: Remove rcu_swap_protected() (bsc#1171827).
- wireless/mediatek: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1171827).
- fs/afs: Replace rcu_swap_protected() with rcu_replace_pointer()
  (bsc#1171827).
- drivers/scsi: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1171827).
- drm/i915: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1171827).
- x86/kvm/pmu: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1171827).
- mt76: drop rcu read lock in mt76_rx_aggr_stop (bsc#1171827).
- commit a6fb099
* Mon May 18 2020 nsaenzjulienne@suse.de
- blacklist.conf: Append "ARM: dts: bcm283x: Disable dsi0 node"
  It's a device tree change, we don't maintain device trees.
- commit 2f253e6
* Mon May 18 2020 ailiop@suse.com
- blacklist.conf: add 5a57c05b56b6e
- commit a97a544
* Mon May 18 2020 ailiop@suse.com
- blacklist.conf: add 71912e08e06b7
- commit e4cf882
* Mon May 18 2020 nsaenzjulienne@suse.de
- net: broadcom: Select BROADCOM_PHY for BCMGENET (git-fixes).
- commit 45f06fc
* Mon May 18 2020 tbogendoerfer@suse.de
- bpf: Enforce returning 0 for fentry/fexit progs (bsc#1154353).
- bpf: Fix bug in mmap() implementation for BPF array map
  (bsc#1154353).
- ionic: call ionic_port_init after fw-upgrade (bsc#1167773).
- ionic: leave netdev mac alone after fw-upgrade (bsc#1167773).
- RDMA/uverbs: Move IB_EVENT_DEVICE_FATAL to destroy_uobj
  (jsc#SLE-8449).
- RDMA/uverbs: Do not discard the IB_EVENT_DEVICE_FATAL event
  (jsc#SLE-8449).
- ipv6: fix restrict IPV6_ADDRFORM operation (bsc#1171662).
- selftests/bpf: Validate frozen map contents stays frozen
  (bsc#1154353).
- ipv6: restrict IPV6_ADDRFORM operation (bsc#1171662).
- commit b0eba11
* Mon May 18 2020 dwagner@suse.de
- wireguard: send/receive: cond_resched() when processing worker
  ringbuffers (bsc#1169021 jsc#SLE-12250).
- wireguard: socket: remove errant restriction on looping to self
  (bsc#1169021 jsc#SLE-12250).
- wireguard: receive: use tunnel helpers for decapsulating ECN
  markings (bsc#1169021 jsc#SLE-12250).
- wireguard: queueing: cleanup ptr_ring in error path of
  packet_queue_init (bsc#1169021 jsc#SLE-12250).
- commit 3b1c8e3
* Mon May 18 2020 tiwai@suse.de
- clk: rockchip: fix incorrect configuration of rk3228 aclk_gpu*
  clocks (git-fixes).
- clk: Unlink clock if failed to prepare or enable (git-fixes).
- commit 1326aea
* Mon May 18 2020 jslaby@suse.cz
- net: ipv4: really enforce backoff for redirects (git-fixes).
- commit 439f9a6
* Mon May 18 2020 mkubecek@suse.cz
- series.conf: cleanup
- move kabi workaround to the right section:
  patches.kabi/snd-rawmidi-buffer_ref-kABI-workaround.patch
- commit 6394f10
* Mon May 18 2020 tiwai@suse.de
- ima: Set again build_ima_appraise variable (bsc#1171709).
- ima: Remove redundant policy rule set in add_rules()
  (bsc#1171709).
- ima: Fix ima digest hash table key calculation (bsc#1171709).
- ima: Fix return value of ima_write_policy() (bsc#1171709).
- ima: Set file->f_mode instead of file->f_flags in
  ima_calc_file_hash() (bsc#1171709).
- commit 9bfa29c
* Mon May 18 2020 mkubecek@suse.cz
- series.conf: cleanup
  Drop unneeded comment.
- commit c7bd9f9
* Sun May 17 2020 dbueso@suse.de
- ipc/util.c: sysvipc_find_ipc() incorrectly updates position
  index (bsc#1171236).
- kernel/gcov/fs.c: gcov_seq_next() should increase position index
  (bsc#1171236).
- fs/seq_file.c: seq_read(): add info message about buggy .next
  functions (bsc#1171236).
- selinux: sel_avc_get_stat_idx should increase position index
  (bsc#1171236).
- mm/swapfile.c: swap_next should increase position index
  (bsc#1171236).
- commit 02aa5d8
* Sun May 17 2020 tiwai@suse.de
- pinctrl: cherryview: Add missing spinlock usage in
  chv_gpio_irq_handler (git-fixes).
- pinctrl: baytrail: Enable pin configuration setting for GPIO
  chip (git-fixes).
- pinctrl: sunrisepoint: Fix PAD lock register offset for SPT-H
  (git-fixes).
- pinctrl: qcom: fix wrong write in update_dual_edge (git-fixes).
- pinctrl: actions: fix function group name for i2c0_group
  (git-fixes).
- commit 47ce68c
* Sat May 16 2020 lduncan@suse.com
- scsi: sg: add sg_remove_request in sg_common_write
  (bsc#1171790).
- commit 6f665e2
* Sat May 16 2020 lduncan@suse.com
- Blacklist git-fix that uses kABI not present yet in SLE.
  This uses get_unaligned_be24(), which isn't in our kernel yet,
  to clean up debug code, but it does not fix anything.
- commit 0389ede
* Sat May 16 2020 lduncan@suse.com
- scsi: mpt3sas: Fix kernel panic observed on soft HBA unplug
  (bsc#1171783).
- scsi: ufs: Clean up ufshcd_scale_clks() and clock scaling
  error out path (bsc#1171792).
- scsi: aha1740: Fix an errro handling path in aha1740_probe()
  (bsc#1171774).
- scsi: ufs: Fix ufshcd_hold() caused scheduling while atomic
  (bsc#1171795).
- scsi: ufs: fix Auto-Hibern8 error detection (bsc#1171794).
- block/drbd: delete invalid function drbd_md_mark_dirty_
  (bsc#1171773).
- scsi: sd: Fix optimal I/O size for devices that change reported
  values (bsc#1171789).
- scsi: ufs: Fix ufshcd_probe_hba() reture value in case
  ufshcd_scsi_add_wlus() fails (bsc#1171796).
- scsi: csiostor: Adjust indentation in csio_device_reset
  (bsc#1171777).
- scsi: qla4xxx: Adjust indentation in qla4xxx_mem_free
  (bsc#1171784).
- scsi: ufs: Recheck bkops level if bkops is disabled
  (bsc#1171798).
- scsi: fnic: fix invalid stack access (bsc#1171780).
- scsi: sd: Clear sdkp->protection_type if disk is reformatted
  without PI (bsc#1171787).
- scsi: iscsi: Fix a potential deadlock in the timeout handler
  (bsc#1171781).
- scsi: ufs: Disable autohibern8 feature in Cadence UFS
  (bsc#1171793).
- scsi: iscsi: qla4xxx: fix double free in probe (bsc#1171782).
- scsi: ufs: Give an unique ID to each ufs-bsg (bsc#1171797).
- scsi: scsi_transport_sas: Fix memory leak when removing devices
  (bsc#1171786).
- scsi: bnx2i: fix potential use after free (bsc#1171775).
- scsi: qla4xxx: fix double free bug (bsc#1171785).
- scsi: zorro_esp: Limit DMA transfers to 65536 bytes (except
  on Fastlane) (bsc#1171799).
- scsi: tracing: Fix handling of TRANSFER LENGTH == 0 for READ(6)
  and WRITE(6) (bsc#1171791).
- scsi: core: scsi_trace: Use get_unaligned_be*() (bsc#1171776).
- scsi: esas2r: unlock on error in esas2r_nvram_read_direct()
  (bsc#1171779).
- scsi: csiostor: Don't enable IRQs too early (bsc#1171778).
- scsi: sd: enable compat ioctls for sed-opal (bsc#1171788).
- commit f218358
* Sat May 16 2020 tiwai@suse.de
- umh: fix memory leak on execve failure (git-fixes).
- r8169: re-establish support for RTL8401 chip version
  (git-fixes).
- hwmon: (da9052) Synchronize access with mfd (git-fixes).
- commit c93a77b
* Sat May 16 2020 tiwai@suse.de
- kABI workaround for snd_rawmidi buffer_ref field addition
  (git-fixes).
- commit a26b757
* Sat May 16 2020 tiwai@suse.de
- ALSA: hda/realtek - Limit int mic boost for Thinkpad T530
  (git-fixes bsc#1171293).
- ALSA: hda/realtek - Add COEF workaround for ASUS ZenBook UX431DA
  (git-fixes).
- ALSA: hda/realtek: Enable headset mic of ASUS UX581LV with
  ALC295 (git-fixes).
- ALSA: hda/realtek - Enable headset mic of ASUS UX550GE with
  ALC295 (git-fixes).
- ALSA: hda/realtek - Enable headset mic of ASUS GL503VM with
  ALC295 (git-fixes).
- ALSA: hda/realtek: Add quirk for Samsung Notebook (git-fixes).
- ALSA: rawmidi: Fix racy buffer resize under concurrent accesses
  (git-fixes).
- ALSA: usb-audio: add mapping for ASRock TRX40 Creator
  (git-fixes).
- ALSA: hda/realtek - Fix S3 pop noise on Dell Wyse (git-fixes).
- Revert "ALSA: hda/realtek: Fix pop noise on ALC225" (git-fixes).
- ALSA: firewire-lib: fix 'function sizeof not defined' error
  of tracepoints format (git-fixes).
- ALSA: usb-audio: Add control message quirk delay for Kingston
  HyperX headset (git-fixes).
- commit 1c282f0
* Fri May 15 2020 ptesarik@suse.cz
- s390/qeth: refactor buffer pool code (git-fixes).
- s390/qeth: use page pointers to manage RX buffer pool
  (git-fixes).
- commit 78b8e17
* Fri May 15 2020 ptesarik@suse.cz
- s390/qdio: fill SBALEs with absolute addresses (git-fixes).
- commit 3a84ac3
* Fri May 15 2020 ptesarik@suse.cz
- blacklist.conf: Add unimportant S390 fixes.
- commit da76ba0
* Fri May 15 2020 ptesarik@suse.cz
- s390: Keep kABI after adding fields to struct lowcore
  (git-fixes).
- s390: prevent leaking kernel address in BEAR (git-fixes).
- commit 2432c42
* Fri May 15 2020 ptesarik@suse.cz
- Update upstream references and move to sorted section:
  patches.suse/s390-mm-fix-page-table-upgrade-vs-2ndary-address-mode
- commit 5b70b1c
* Fri May 15 2020 ptesarik@suse.cz
- s390/protvirt: fix compilation issue (git-fixes).
- s390/pci: do not set affinity for floating irqs (git-fixes).
- KVM: s390: Fix PV check in deliverable_irqs() (git-fixes).
- s390/cio: generate delayed uevent for vfio-ccw subchannels
  (git-fixes).
- s390/cio: avoid duplicated 'ADD' uevents (git-fixes).
- KVM: s390: vsie: Fix possible race when shadowing region 3
  tables (git-fixes).
- KVM: s390: vsie: Fix region 1 ASCE sanity shadow address checks
  (git-fixes).
- s390/diag: fix display of diagnose call statistics (git-fixes).
- s390/cpuinfo: fix wrong output when CPU0 is offline (git-fixes).
- scsi: zfcp: fix missing erp_lock in port recovery trigger for
  point-to-point (git-fixes).
- s390/gmap: return proper error code on ksm unsharing
  (git-fixes).
- s390/qeth: support net namespaces for L3 devices (git-fixes).
- s390/qeth: implement smarter resizing of the RX buffer pool
  (git-fixes).
- s390/qeth: cancel RX reclaim work earlier (git-fixes).
- s390/qeth: handle error when backing RX buffer (git-fixes).
- s390/qeth: don't reset default_out_queue (git-fixes).
- s390/qeth: fix off-by-one in RX copybreak check (git-fixes).
- s390/qeth: don't warn for napi with 0 budget (git-fixes).
- s390/qeth: vnicc Fix EOPNOTSUPP precedence (git-fixes).
- commit f4042da
* Fri May 15 2020 ptesarik@suse.cz
- s390/uv: Fix handling of length extensions (git-fixes).
- Refresh
  patches.suse/0008-s390-protvirt-introduce-host-side-setup.
- commit b147e1a
* Fri May 15 2020 ptesarik@suse.cz
- s390/qeth: consolidate QDIO queue setup (git-fixes).
- s390/startup: round down "mem" option to page boundary
  (git-fixes).
- commit 1751aa6
* Fri May 15 2020 ptesarik@suse.cz
- s390/cpum_cf: Add new extended counters for IBM z15 (bsc#1169763
  LTC#185290).
- commit 7b5f7a7
* Fri May 15 2020 ptesarik@suse.cz
- s390/ftrace: fix potential crashes when switching tracers
  (bsc#1171242 LTC#185786).
- commit 4872847
* Fri May 15 2020 hare@suse.de
- fnic: to not call 'scsi_done()' for unhandled commands
  (bsc#1168468, bsc#1171675).
- commit ab83c6a
* Fri May 15 2020 tiwai@suse.de
- ima: Use ima_hash_algo for collision detection in the
  measurement list (bsc#1171709).
- ima: Calculate and extend PCR with digests in ima_template_entry
  (bsc#1171709).
- ima: Allocate and initialize tfm for each PCR bank
  (bsc#1171709).
- ima: Switch to dynamically allocated buffer for template digests
  (bsc#1171709).
- ima: Store template digest directly in ima_template_entry
  (bsc#1171709).
- ima: Evaluate error in init_ima() (bsc#1171709).
- ima: Switch to ima_hash_algo for boot aggregate (bsc#1171709).
- commit b14498d
* Fri May 15 2020 tiwai@suse.de
- mmc: sdhci-acpi: Add SDHCI_QUIRK2_BROKEN_64_BIT_DMA for AMDI0040
  (git-fixes).
- mmc: block: Fix request completion in the CQE timeout path
  (git-fixes).
- mmc: core: Fix recursive locking issue in CQE recovery path
  (git-fixes).
- mmc: core: Check request type before completing the request
  (git-fixes).
- mmc: sdhci-pci-gli: Fix can not access GL9750 after reboot
  from Windows 10 (git-fixes).
- mmc: alcor: Fix a resource leak in the error path for ->probe()
  (git-fixes).
- mmc: sdhci-pci-gli: Fix no irq handler from suspend (git-fixes).
- HID: wacom: Report 2nd-gen Intuos Pro S center button status
  over BT (git-fixes).
- commit c8b265a
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Move allocation of the shost object to after xconf-
  and xport-data (bsc#1158050).
- commit 21f0bbc
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Fence early sysfs interfaces for accesses of shost
  objects (bsc#1158050).
- commit 14fe477
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Fence adapter status propagation for common statuses
  (bsc#1158050).
- commit 2239fe3
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Move p-t-p port allocation to after xport data
  (bsc#1158050).
- commit 6523a4a
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Fence fc_host updates during link-down handling
  (bsc#1158050).
- commit e19869e
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Move fc_host updates during xport data handling
  into fenced function (bsc#1158050).
- commit ed1083e
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Move shost updates during xconfig data handling
  into fenced function (bsc#1158050).
- commit 2b1bff7
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: Move shost modification after QDIO (re-)open into
  fenced function (bsc#1158050).
- commit 125f4c2
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: log FC Endpoint Security errors (bsc#1158050).
- commit 917028c
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: enhance handling of FC Endpoint Security errors
  (bsc#1158050).
- commit 36c135f
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: trace FC Endpoint Security of FCP devices and
  connections (bsc#1158050).
- commit 7e76f52
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: log FC Endpoint Security of connections
  (bsc#1158050).
- commit c39b6cd
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: report FC Endpoint Security in sysfs (bsc#1158050).
- commit f23d4ba
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: auto variables for dereferenced structs in open
  port handler (bsc#1158050).
- commit 59d992b
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: fix fc_host attributes that should be unknown on
  local link down (bsc#1158050).
- commit eeef336
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: wire previously driver-specific sysfs attributes
  also to fc_host (bsc#1158050).
- commit 6bad869
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: expose fabric name as common fc_host sysfs attribute
  (bsc#1158050).
- commit ea0cf94
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: fix wrong data and display format of SFP+
  temperature (bsc#1158050).
- commit 90e31fe
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: proper indentation to reduce confusion in
  zfcp_erp_required_act (bsc#1158050).
- commit 4e35fda
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: move maximum age of diagnostic buffers into a
  per-adapter variable (bsc#1158050).
- commit be264de
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: implicitly refresh config-data diagnostics when
  reading sysfs (bsc#1158050).
- commit 20412aa
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: introduce sysfs interface to read the local
  B2B-Credit (bsc#1158050).
- commit 843431c
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: implicitly refresh port-data diagnostics when
  reading sysfs (bsc#1158050).
- commit 161aea6
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: introduce sysfs interface for diagnostics of local
  SFP transceiver (bsc#1158050).
- commit a779192
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: support retrieval of SFP Data via Exchange Port Data
  (bsc#1158050).
- commit 5dc40b1
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: add diagnostics buffer for exchange config data
  (bsc#1158050).
- commit 57cb8ce
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: diagnostics buffer caching and use for exchange
  port data (bsc#1158050).
- commit dd2087b
* Thu May 14 2020 martin.wilck@suse.com
- scsi: zfcp: signal incomplete or error for sync exchange
  config/port data (bsc#1158050).
- commit c1722d3
* Thu May 14 2020 jack@suse.cz
- ext4: do not zeroout extents beyond i_disksize (bsc#1167851).
- commit af137fd
* Thu May 14 2020 bp@suse.de
- x86/smpboot: Remove the last ICPU() macro (bsc#1171644).
- commit 363d04a
* Thu May 14 2020 lhenriques@suse.com
- ceph: demote quotarealm lookup warning to a debug message
  (jsc#SES-1134).
- ceph: fix double unlock in handle_cap_export() (jsc#SES-1134).
- ceph: fix special error code in ceph_try_get_caps()
  (jsc#SES-1134).
- ceph: fix endianness bug when handling MDS session feature bits
  (jsc#SES-1134).
- commit f1fae63
* Thu May 14 2020 bp@suse.de
- ACPI: Convert to new X86 CPU match macros (bsc#1171644).
- ASoC: Intel: Convert to new X86 CPU match macros (bsc#1171644).
- cpufreq: Convert to new X86 CPU match macros (bsc#1171644).
- cpufreq/intel_pstate: Fix wrong macro conversion (bsc#1171644).
- crypto: Convert to new CPU match macros (bsc#1171644).
- EDAC: Convert to new X86 CPU match macros (bsc#1171644).
- extcon: axp288: Convert to new X86 CPU match macros
  (bsc#1171644).
- hwmon: Convert to new X86 CPU match macros (bsc#1171644).
- hwrng: via_rng: Convert to new X86 CPU match macros
  (bsc#1171644).
- intel_idle: Convert to new X86 CPU match macros (bsc#1171644).
- mmc: sdhci-acpi: Convert to new X86 CPU match macros
  (bsc#1171644).
- PCI: intel-mid: Convert to new X86 CPU match macros
  (bsc#1171644).
- platform/x86: Convert to new CPU match macros (bsc#1171644).
- powercap/intel_rapl: Convert to new X86 CPU match macros
  (bsc#1171644).
- thermal: Convert to new X86 CPU match macros (bsc#1171644).
- x86/cpu/bugs: Convert to new matching macros (bsc#1171644).
- x86/cpu: Cleanup the now unused CPU match macros (bsc#1171644).
- x86/intel: Aggregate big core client naming (bsc#1171644).
- x86/intel: Aggregate big core graphics naming (bsc#1171644).
- x86/intel: Aggregate big core mobile naming (bsc#1171644).
- x86/intel: Aggregate microserver naming (bsc#1171644).
- x86/kernel: Convert to new CPU match macros (bsc#1171644).
- x86/kvm: Convert to new CPU match macros (bsc#1171644).
- x86/perf/events: Convert to new CPU match macros (bsc#1171644).
- x86/platform: Convert to new CPU match macros (bsc#1171644).
- Refresh
  patches.suse/edac-i10nm-update-driver-to-support-different-bus-number-config-register-offsets.patch.
- Refresh
  patches.suse/edac-skx-i10nm-make-some-configurations-cpu-model-specific.patch.
- Refresh
  patches.suse/perf-x86-cstate-add-comet-lake-cpu-support.patch.
- Refresh
  patches.suse/perf-x86-cstate-update-c-state-counters-for-ice-lake.patch.
- Refresh
  patches.suse/perf-x86-intel-add-comet-lake-cpu-support.patch.
- Refresh
  patches.suse/perf-x86-msr-add-comet-lake-cpu-support.patch.
- Refresh
  patches.suse/platform-x86-intel_pmc_core-Add-Comet-Lake-CML-platf.patch.
- Refresh
  patches.suse/platform-x86-intel_pmc_core-update-Comet-Lake-platfo.patch.
- Refresh
  patches.suse/powercap-intel_rapl-add-support-for-CometLake-Mobile.
- Refresh
  patches.suse/powercap-intel_rapl-add-support-for-Cometlake-desktop.
- Refresh
  patches.suse/powercap-intel_rapl-add-support-for-TigerLake-Mobile.patch.
- Refresh
  patches.suse/x86-bugs-Add-ITLB_MULTIHIT-bug-infrastructure.patch.
- Refresh
  patches.suse/x86-cpu-Add-Tiger-Lake-to-Intel-family.patch.
- Refresh
  patches.suse/x86-cpu-Add-Tremont-to-the-cpu-vulnerability-whiteli.patch.
- Refresh
  patches.suse/x86-cpu-add-a-steppings-field-to-struct-x86_cpu_id.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance.patch.
- commit 424d9a3
* Thu May 14 2020 jroedel@suse.de
- Update
  patches.suse/pci-aer-add-pci_aer_raw_clear_status-to-unconditionally-clear-error-status
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update
  patches.suse/pci-aer-rationalize-error-status-register-clearing
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update
  patches.suse/pci-dpc-add-error-disconnect-recover-edr-support
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update
  patches.suse/pci-dpc-cache-dpc-capabilities-in-pci_init_capabilities
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update
  patches.suse/pci-dpc-expose-dpc_process_error-dpc_reset_link-for-use-by-edr
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update patches.suse/pci-dpc-move-dpc-data-into-struct-pci_dev
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update
  patches.suse/pci-err-remove-service-dependency-in-pcie_do_recovery
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- Update patches.suse/pci-err-return-status-of-pcie_do_recovery
  (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- commit dbc15d0
* Thu May 14 2020 ykaukab@suse.de
- efi: READ_ONCE rng seed size before munmap (jsc#SLE-12424).
- efi/random: Treat EFI_RNG_PROTOCOL output as bootloader randomness (jsc#SLE-12424).
- char/random: Add a newline at the end of the file (jsc#SLE-12424).
- fdt: add support for rng-seed (jsc#SLE-12424).
- arm64: map FDT as RW for early_init_dt_scan() (jsc#SLE-12424).
- commit 14ee05c
* Thu May 14 2020 msuchanek@suse.de
- rpm/check-for-config-changes: Ignore CONFIG_CC_VERSION_TEXT
- commit 8e6b05f
* Wed May 13 2020 mkubecek@suse.cz
- Update kabi files.
- update to "Snapshot 16" submission (commit 2c1dc3e59ade)
- commit 5277b75
* Wed May 13 2020 jack@suse.cz
- fanotify: merge duplicate events on parent and child
  (bsc#1171285).
- commit 31ead62
* Wed May 13 2020 mbenes@suse.cz
- blacklist.conf: 81b67439d147 ("x86/unwind/orc: Fix premature unwind stoppage due to IRET frames")
  Breaks kABI. SLE15-SP3 is the target.
- commit 9871f13
* Wed May 13 2020 mkubecek@suse.cz
- series.conf: whitespace cleanup
  No functional change.
- commit 2c1dc3e
* Wed May 13 2020 mbenes@suse.cz
- x86/unwind/orc: Fix error path for bad ORC entry type
  (bsc#1058115).
- commit 031383f
* Wed May 13 2020 mbenes@suse.cz
- x86/unwind/orc: Prevent unwinding before ORC initialization
  (bsc#1058115).
- commit d558feb
* Wed May 13 2020 mbenes@suse.cz
- x86/unwind/orc: Don't skip the first frame for inactive tasks
  (bsc#1058115).
- commit aa72d5b
* Wed May 13 2020 mbenes@suse.cz
- x86/unwind: Prevent false warnings for non-current tasks
  (bsc#1058115).
- commit 00ea671
* Wed May 13 2020 tbogendoerfer@suse.de
- Dropped jsc#PM and jsc#ECO references.
- Update
  patches.suse/Doc-networking-device_drivers-pensando-fix-ionic.rst.patch
  (bsc#1167773).
- Update
  patches.suse/Documentation-networking-device-drivers-Remove-stray.patch
  (bsc#1167773).
- Update
  patches.suse/dynamic_debug-provide-dynamic_hex_dump-stub.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-RSS-support.patch (bsc#1167773).
- Update
  patches.suse/ionic-Add-Rx-filter-and-rx_mode-ndo-support.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-Tx-and-Rx-handling.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-adminq-action.patch (bsc#1167773).
- Update
  patches.suse/ionic-Add-async-link-status-check-and-basic-stats.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-basic-adminq-support.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Add-basic-framework-for-IONIC-Network-device-d.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-basic-lif-support.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-coalesce-and-other-features.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-driver-stats.patch (bsc#1167773).
- Update
  patches.suse/ionic-Add-hardware-init-and-device-commands.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-initial-ethtool-support.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-interrupts-and-doorbells.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-management-of-rx-filters.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-netdev-event-handling.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-notifyq-support.patch
  (bsc#1167773).
- Update patches.suse/ionic-Add-port-management-commands.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Add-the-basic-NDO-callbacks-for-netdev-support.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Fix-an-error-code-in-ionic_lif_alloc.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Remove-set-but-not-used-variable-sg_desc.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Remove-unnecessary-ternary-operator-in-ionic_d.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-Remove-unused-including-linux-version.h.patch
  (bsc#1167773).
- Update patches.suse/ionic-add-Rx-dropped-packet-counter.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-add-a-watchdog-timer-to-monitor-heartbeat.patch
  (bsc#1167773).
- Update patches.suse/ionic-add-decode-for-IONIC_RC_ENOSUPP.patch
  (bsc#1167773).
- Update patches.suse/ionic-add-dynamic_debug-header.patch
  (bsc#1167773).
- Update patches.suse/ionic-add-heartbeat-check.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-add-lif_quiesce-to-wait-for-queue-activity-to-.patch
  (bsc#1167773).
- Update patches.suse/ionic-add-support-for-device-id-0x1004.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-add-timeout-error-checking-for-queue-disable.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-check-for-NULL-structs-on-teardown.patch
  (bsc#1167773).
- Update patches.suse/ionic-check-for-linkup-in-watchdog.patch
  (bsc#1167773).
- Update patches.suse/ionic-check-for-queues-before-deleting.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-clean-irq-affinity-on-queue-deinit.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-clean-tx-queue-of-unfinished-requests.patch
  (bsc#1167773).
- Update patches.suse/ionic-clean-up-bitflag-usage.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-clear-compiler-warning-on-hb-use-before-set.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-decouple-link-message-from-netdev-state.patch
  (bsc#1167773).
- Update patches.suse/ionic-deinit-rss-only-if-selected.patch
  (bsc#1167773).
- Update patches.suse/ionic-disable-the-queues-on-link-down.patch
  (bsc#1167773).
- Update patches.suse/ionic-drop-use-of-subdevice-tags.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-fw_status-read.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-rxq-comp-packet-type-mask.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-stats-memory-dereference.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-unused-assignment.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-up-struct-name-comments.patch
  (bsc#1167773).
- Update patches.suse/ionic-fix-vf-op-lock-usage.patch
  (bsc#1167773).
- Update patches.suse/ionic-ignore-eexist-on-rx-filter-add.patch
  (bsc#1167773).
- Update patches.suse/ionic-implement-ethtool-set-fec.patch
  (bsc#1167773).
- Update patches.suse/ionic-implement-support-for-rx-sgl.patch
  (bsc#1167773).
- Update patches.suse/ionic-improve-irq-numa-locality.patch
  (bsc#1167773).
- Update patches.suse/ionic-ionic_if-bits-for-sr-iov-support.patch
  (bsc#1167773).
- Update patches.suse/ionic-keep-ionic-dev-on-lif-init-fail.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-keep-users-rss-hash-across-lif-reset.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-leave-dev-cmd-request-contents-alone-on-FW-tim.patch
  (bsc#1167773).
- Update patches.suse/ionic-make-spdxcheck.py-happy.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-move-debugfs-add-delete-to-match-alloc-free.patch
  (bsc#1167773).
- Update patches.suse/ionic-move-irq-request-to-qcq-alloc.patch
  (bsc#1167773).
- Update patches.suse/ionic-only-save-good-lif-dentry.patch
  (bsc#1167773).
- Update patches.suse/ionic-print-data-for-unknown-xcvr-type.patch
  (bsc#1167773).
- Update patches.suse/ionic-print-pci-bus-lane-info.patch
  (bsc#1167773).
- Update patches.suse/ionic-remove-adminq-napi-instance.patch
  (bsc#1167773).
- Update patches.suse/ionic-remove-lifs-on-fw-reset.patch
  (bsc#1167773).
- Update patches.suse/ionic-remove-pragma-packed.patch
  (bsc#1167773).
- Update patches.suse/ionic-replay-filters-after-fw-upgrade.patch
  (bsc#1167773).
- Update patches.suse/ionic-report-users-coalesce-request.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-restrict-received-packets-to-mtu-size.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-reverse-an-interrupt-coalesce-calculation.patch
  (bsc#1167773).
- Update patches.suse/ionic-select-CONFIG_NET_DEVLINK.patch
  (bsc#1167773).
- Update patches.suse/ionic-set-station-addr-only-if-needed.patch
  (bsc#1167773).
- Update patches.suse/ionic-simplify-returns-in-devlink-info.patch
  (bsc#1167773).
- Update patches.suse/ionic-stop-devlink-warn-on-mgmt-device.patch
  (bsc#1167773).
- Update patches.suse/ionic-support-ethtool-rxhash-disable.patch
  (bsc#1167773).
- Update patches.suse/ionic-support-sr-iov-operations.patch
  (bsc#1167773).
- Update patches.suse/ionic-update-driver-version.patch
  (bsc#1167773).
- Update
  patches.suse/ionic-use-wait_on_bit_lock-rather-than-open-code.patch
  (bsc#1167773).
- Update
  patches.suse/net-ionic-Use-scnprintf-for-avoiding-potential-buffe.patch
  (bsc#1167773).
- commit cd1780f
* Wed May 13 2020 mkubecek@suse.cz
- update metadata of nvme patches and move them out from sorted section
  The nvme-5.8 branch in nvme repository got rebased fourth time in three
  weeks. Update Git-commit tags again and move the patches out of sorted
  section as keeping them there makes more harm than good.
- update upstream reference and move to "almost mainline" section:
  patches.suse/lpfc-Commonize-lpfc_async_xchg_ctx-state-and-flag-de.patch
  patches.suse/lpfc-Refactor-NVME-LS-receive-handling.patch
  patches.suse/lpfc-Refactor-Send-LS-Abort-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Request-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Response-support.patch
  patches.suse/lpfc-Refactor-lpfc-nvme-headers.patch
  patches.suse/lpfc-Refactor-nvmet_rcv_ctx-to-create-lpfc_async_xch.patch
  patches.suse/lpfc-nvme-Add-Receive-LS-Request-and-Send-LS-Respons.patch
  patches.suse/lpfc-nvmet-Add-Send-LS-Request-and-Abort-LS-Request-.patch
  patches.suse/lpfc-nvmet-Add-support-for-NVME-LS-request-hosthandl.patch
  patches.suse/nvme-fc-Add-Disconnect-Association-Rcv-support.patch
  patches.suse/nvme-fc-Ensure-private-pointers-are-NULL-if-no-data.patch
  patches.suse/nvme-fc-Sync-header-to-FC-NVME-2-rev-1.08.patch
  patches.suse/nvme-fc-Update-header-and-host-for-common-definition.patch
  patches.suse/nvme-fc-and-nvmet-fc-revise-LLDD-api-for-LS-receptio.patch
  patches.suse/nvme-fc-convert-assoc_active-flag-to-bit-op.patch
  patches.suse/nvme-fc-nvmet-fc-refactor-for-common-LS-definitions.patch
  patches.suse/nvme-fcloop-add-target-to-host-LS-request-support.patch
  patches.suse/nvme-fcloop-refactor-to-enable-target-to-host-LS.patch
  patches.suse/nvmet-fc-Add-Disconnect-Association-Xmt-support.patch
  patches.suse/nvmet-fc-Better-size-LS-buffers.patch
  patches.suse/nvmet-fc-Update-target-for-common-definitions-for-LS.patch
  patches.suse/nvmet-fc-add-LS-failure-messages.patch
  patches.suse/nvmet-fc-perform-small-cleanups-on-unneeded-checks.patch
  patches.suse/nvmet-fc-rename-ls_list-to-ls_rcv_list.patch
  patches.suse/nvmet-fc-track-hostport-handle-for-associations.patch
- commit 63b19d5
* Tue May 12 2020 ohering@suse.de
- Fix hv_alloc_hyperv_zeroed_page to actually return something (bsc#1171507)
  Refresh patches.suse/suse-hv-kabi.patch.
- commit 2870dc6
* Tue May 12 2020 oneukum@suse.com
- iwlwifi: mvm: fix non-ACPI function (git-fixes).
- commit 676dedd
* Tue May 12 2020 mkoutny@suse.com
- mm: don't prepare anon_vma if vma has VM_WIPEONFORK
  (bsc#1169681).
- Delete
  patches.suse/0002-mm-set-vm_next-and-vm_prev-to-NULL-in-vm_area_dup.patch.
  The added patch is a proactive git-fix, the removed patch is unnecessary
  member of the same series (bsc#1169681).
- commit a316e23
* Tue May 12 2020 mbenes@suse.cz
- x86/entry/64: Fix unwind hints in rewind_stack_do_exit()
  (bsc#1058115).
- commit 3901d59
* Tue May 12 2020 oneukum@suse.com
- pinctrl: denverton: Update pin names according to v1.08
  (bsc#1171514).
- commit 2f0f43d
* Tue May 12 2020 oneukum@suse.com
- pinctrl: denverton: Provide Interrupt Status register offset
  (bsc#1171514).
- commit 60af7d7
* Tue May 12 2020 mbenes@suse.cz
- x86/entry/64: Fix unwind hints in __switch_to_asm()
  (bsc#1058115).
- commit 9d0fdcf
* Tue May 12 2020 mbenes@suse.cz
- x86/entry/64: Fix unwind hints in kernel exit path
  (bsc#1058115).
- commit 5322f7b
* Tue May 12 2020 mbenes@suse.cz
- x86/entry/64: Fix unwind hints in register clearing code
  (bsc#1058115).
- commit 74bcafb
* Tue May 12 2020 mbenes@suse.cz
- objtool: Fix stack offset tracking for indirect CFAs
  (bsc#1169514).
- commit bcaa294
* Tue May 12 2020 jslaby@suse.cz
- blacklist.conf: add one net entry
- commit 8a6918a
* Tue May 12 2020 jslaby@suse.cz
- net: macb: Fix runtime PM refcounting (git-fixes).
- selftests: Fix suppress test in fib_tests.sh (git-fixes).
- commit b936936
* Tue May 12 2020 tbogendoerfer@suse.de
- Refresh
  patches.suse/net-mlx5-Remove-redundant-NULL-initializations.patch.
  Folded in merge commit 95e6ba5133163f8241c9ea2439369cec0452fec6 from Linus:
  [ Did an evil merge to silence a warning introduced by this pull - Linus ]
- commit 6693a9f
* Tue May 12 2020 tbogendoerfer@suse.de
- cxgb4: fix EOTID leak when disabling TC-MQPRIO offload
  (jsc#SLE-8389).
- ionic: refresh devinfo after fw-upgrade (bsc#1167773).
- ionic: no link check until after probe (bsc#1167773).
- net/mlx5e: Fix q counters on uplink representors (jsc#SLE-8464).
- net/mlx5: DR, On creation set CQ's arm_db member to right value
  (jsc#SLE-8464).
- net/mlx5: Expose port speed when possible (bsc#1171117).
- net/mlx5: Expose link speed directly (bsc#1171117).
- commit 0b73846
* Tue May 12 2020 mbenes@suse.cz
- tracing/kprobes: Fix a double initialization typo (git-fixes).
- commit 84310a8
* Tue May 12 2020 mbenes@suse.cz
- tracing: Add a vmalloc_sync_mappings() for safe measure
  (git-fixes).
- commit 2019d7b
* Tue May 12 2020 ohering@suse.de
- clocksource/drivers/hyper-v: Set TSC clocksource as default w/
  InvariantTSC (bsc#1170621).
- x86/hyperv: Allow guests to enable InvariantTSC (bsc#1170621).
- commit 16f337f
* Mon May 11 2020 dbueso@suse.de
- ipc/mqueue.c: change __do_notify() to bypass
  check_kill_permission() (bsc#1159886).
- vdso/datapage: Use correct clock mode name in comment
  (bsc#1164648,jsc#SLE-11493).
- time/namespace: Fix time_for_children symlink
  (bsc#1164648,jsc#SLE-11493).
- ipc/util.c: sysvipc_find_ipc() should increase position index
  (bsc#1171236).
- ipc/shm.c: make compat_ksys_shmctl() static (bsc#1159886).
- ipc/mqueue.c: fix a brace coding style issue (bsc#1159886).
- epoll: fix possible lost wakeup on epoll_ctl() path.
- commit dbaec66
* Mon May 11 2020 tiwai@suse.de
- usb: dwc3: gadget: Properly set maxpacket limit (git-fixes).
- wimax/i2400m: Fix potential urb refcnt leak (git-fixes).
- drm/amdgpu: Correctly initialize thermal controller for GPUs
  with Powerplay table v0 (e.g Hawaii) (git-fixes).
- remoteproc: qcom_q6v5_mss: fix a bug in q6v5_probe()
  (git-fixes).
- drm/amdgpu: Fix oops when pp_funcs is unset in ACPI event
  (git-fixes).
- mac80211: add ieee80211_is_any_nullfunc() (git-fixes).
- platform/x86: GPD pocket fan: Fix error message when temp-limits
  are out of range (git-fixes).
- PM / devfreq: Add missing locking while setting suspend_freq
  (git-fixes).
- remoteproc: Fix wrong rvring index computation (git-fixes).
- commit 4da097b
* Mon May 11 2020 jroedel@suse.de
- PCI/DPC: Add Error Disconnect Recover (EDR) support
  (bsc#1169263).
- Update config files.
- Refresh patches.suse/0001-kABI-more-hooks-for-PCI-changes.patch.
- commit dc2f3a4
* Mon May 11 2020 mfleming@suse.de
- x86/asm/64: Align start of __clear_user() loop to 16-bytes
  (bsc#1168461)
- commit 1bafa6b
* Mon May 11 2020 jroedel@suse.de
- kABI: Fix kABI after EDR backport (bsc#1169263, jsc#SLE-10700, jsc#SLE-9457, jsc#SLE-12300).
- commit 3c954c1
* Mon May 11 2020 oneukum@suse.com
- xhci: Fix handling halted endpoint even if endpoint ring
  appears empty (git-fixes).
- Refresh
  patches.suse/xhci-Don-t-clear-hub-TT-buffer-on-ep0-protocol-stall.patch.
- commit 6ca613f
* Mon May 11 2020 jslaby@suse.cz
- net: dsa: bcm_sf2: Ensure correct sub-node is parsed
  (networking-stable-20_04_09).
- mlxsw: spectrum_flower: Do not stop at FLOW_ACTION_VLAN_MANGLE
  (networking-stable-20_04_09).
- net: dsa: bcm_sf2: Do not register slave MDIO bus with OF
  (networking-stable-20_04_09).
- net_sched: fix a missing refcnt in tcindex_init()
  (networking-stable-20_04_09).
- net: stmmac: dwmac1000: fix out-of-bounds mac address reg
  setting (networking-stable-20_04_09).
- cxgb4: fix MPS index overwrite when setting MAC address
  (networking-stable-20_04_09).
- ipv6: don't auto-add link-local address to lag ports
  (networking-stable-20_04_09).
- net_sched: add a temporary refcnt for struct tcindex_data
  (networking-stable-20_04_09).
- commit 964e915
* Mon May 11 2020 ykaukab@suse.de
- clk: qoriq: add cpufreq platform device (bsc#1165455).
- cpufreq: qoriq: convert to a platform driver (bsc#1165455).
- commit e0e9680
* Mon May 11 2020 msuchanek@suse.de
- asm-generic/tlb: add missing CONFIG symbol (bsc#1156395).
- commit ee4dbba
* Mon May 11 2020 mkubecek@suse.cz
- supported.conf: cleanup
- fix path of wireguard module
- fix sort order
- commit 5ca7d5d
* Mon May 11 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/scsi-ibmvfc-Don-t-send-implicit-logouts-prior-to-NPI.patch
  patches.suse/scsi-ibmvscsi-Fix-WARN_ON-during-event-pool-release.patch
- commit 7f02596
* Mon May 11 2020 mkubecek@suse.cz
- update metadata of nvme patches
  The nvme-5.8 branch in nvme repository got rebased again, update Git-commit
  tags:
  patches.suse/lpfc-Commonize-lpfc_async_xchg_ctx-state-and-flag-de.patch
  patches.suse/lpfc-Refactor-NVME-LS-receive-handling.patch
  patches.suse/lpfc-Refactor-Send-LS-Abort-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Request-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Response-support.patch
  patches.suse/lpfc-Refactor-lpfc-nvme-headers.patch
  patches.suse/lpfc-Refactor-nvmet_rcv_ctx-to-create-lpfc_async_xch.patch
  patches.suse/lpfc-nvme-Add-Receive-LS-Request-and-Send-LS-Respons.patch
  patches.suse/lpfc-nvmet-Add-Send-LS-Request-and-Abort-LS-Request-.patch
  patches.suse/lpfc-nvmet-Add-support-for-NVME-LS-request-hosthandl.patch
  patches.suse/nvme-fc-Add-Disconnect-Association-Rcv-support.patch
  patches.suse/nvme-fc-Ensure-private-pointers-are-NULL-if-no-data.patch
  patches.suse/nvme-fc-Sync-header-to-FC-NVME-2-rev-1.08.patch
  patches.suse/nvme-fc-Update-header-and-host-for-common-definition.patch
  patches.suse/nvme-fc-and-nvmet-fc-revise-LLDD-api-for-LS-receptio.patch
  patches.suse/nvme-fc-convert-assoc_active-flag-to-bit-op.patch
  patches.suse/nvme-fc-nvmet-fc-refactor-for-common-LS-definitions.patch
  patches.suse/nvme-fcloop-add-target-to-host-LS-request-support.patch
  patches.suse/nvme-fcloop-refactor-to-enable-target-to-host-LS.patch
  patches.suse/nvmet-fc-Add-Disconnect-Association-Xmt-support.patch
  patches.suse/nvmet-fc-Better-size-LS-buffers.patch
  patches.suse/nvmet-fc-Update-target-for-common-definitions-for-LS.patch
  patches.suse/nvmet-fc-add-LS-failure-messages.patch
  patches.suse/nvmet-fc-perform-small-cleanups-on-unneeded-checks.patch
  patches.suse/nvmet-fc-rename-ls_list-to-ls_rcv_list.patch
  patches.suse/nvmet-fc-track-hostport-handle-for-associations.patch
- commit 0113fce
* Mon May 11 2020 wqu@suse.com
- btrfs: relocation: Work around dead relocation stage loop
  (bsc#1171417).
- commit f418462
* Mon May 11 2020 wqu@suse.com
- btrfs: relocation: Check cancel request after each extent  found
  (bsc#1171417).
- commit 9d1084e
* Mon May 11 2020 wqu@suse.com
- btrfs: relocation: Check cancel request after each data  page
  read (bsc#1171417).
- commit 6e7cf97
* Mon May 11 2020 wqu@suse.com
- btrfs: relocation: add error injection points for  cancelling
  balance (bsc#1171417).
- commit ef70462
* Sat May  9 2020 tiwai@suse.de
- staging: gasket: Check the return value of
  gasket_get_bar_index() (git-fixes).
- Revert "tty: serial: bcm63xx: fix missing clk_put() in
  bcm63xx_uart" (git-fixes).
- USB: serial: garmin_gps: add sanity checking for data length
  (git-fixes).
- drm: ingenic-drm: add MODULE_DEVICE_TABLE (git-fixes).
- commit e8b3583
* Fri May  8 2020 ykaukab@suse.de
- build tegra186 as a module (bsc#1171156)
- export MODULE_DEVICE_TABLE to allow building as module:
  add patches.suse/gpio-tegra186-export-MODULE_DEVICE_TABLE.patch
- update arm64 configs (GPIO_TEGRA186 y->m)
- add gpio-tegra186 entry to supported.conf
- soc/tegra: pmc: Enable PMIC wake event on Tegra186.
- commit 70ad6b5
* Fri May  8 2020 ykaukab@suse.de
- Update
  patches.suse/net-dsa-felix-Use-PHY_INTERFACE_MODE_INTERNAL-instea.patch
  upstream reference and move to sorted section.
- commit c046bd4
* Fri May  8 2020 ykaukab@suse.de
- Update patches.suse/net-mscc-fix-in-frame-extraction.patch upstream reference and move to sorted section.
- commit 28974d3
* Thu May  7 2020 jzerebecki@suse.com
- kernel-docs: Change Requires on python-Sphinx to earlier than version 3
  References: bsc#1166965
  From 3 on the internal API that the build system uses was rewritten in
  an incompatible way.
  See https://github.com/sphinx-doc/sphinx/issues/7421 and
  https://bugzilla.suse.com/show_bug.cgi?id=1166965#c16 for some details.
- commit cf60b5c
* Thu May  7 2020 msuchanek@suse.de
- libnvdimm: cover up nd_region changes (bsc#1162400).
- commit 528df6d
* Thu May  7 2020 msuchanek@suse.de
- libnvdimm: cover up struct nvdimm changes (bsc#1171742).
- commit 78df47c
* Thu May  7 2020 lhenriques@suse.com
- ceph: fix potential bad pointer deref in async dirops cb's
  (bsc#1171390).
- rbd: don't mess with a page vector in rbd_notify_op_lock()
  (bsc#1171391).
- rbd: don't test rbd_dev->opts in rbd_dev_image_release()
  (bsc#1171392).
- commit 11ed7ef
* Thu May  7 2020 msuchanek@suse.de
- libnvdimm: cover up nvdimm_security_ops changes (bsc#1171742).
- commit 37c125e
* Thu May  7 2020 msuchanek@suse.de
- libnvdimm: cover up nd_pfn_sb changes (bsc#1171759).
- commit 59fc719
* Thu May  7 2020 nsaenzjulienne@suse.de
- Update config files: Build w1 bus on arm64 (jsc#SLE-12203)
- supported.conf: support w1 core and thermometer support
- commit 73998d2
* Thu May  7 2020 tiwai@suse.de
- sched/psi: Fix OOB write when writing 0 bytes to PSI files
  (CVE-2020-0110 bsc#1171374).
- commit 0044c49
* Thu May  7 2020 tiwai@suse.de
- dp83640: reverse arguments to list_add_tail (git-fixes).
- batman-adv: Fix refcnt leak in batadv_v_ogm_process (git-fixes).
- batman-adv: Fix refcnt leak in batadv_store_throughput_override
  (git-fixes).
- batman-adv: Fix refcnt leak in batadv_show_throughput_override
  (git-fixes).
- batman-adv: fix batadv_nc_random_weight_tq (git-fixes).
- crypto: arch/nhpoly1305 - process in explicit 4k chunks
  (git-fixes).
- crypto: arch/lib - limit simd usage to 4k chunks (git-fixes).
- commit fbff5a5
* Thu May  7 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/bnxt_en-Fix-VF-anti-spoof-filter-setup.patch
  patches.suse/bnxt_en-Fix-VLAN-acceleration-handling-in-bnxt_fix_f.patch
  patches.suse/bnxt_en-Improve-AER-slot-reset.patch
  patches.suse/bnxt_en-Reduce-BNXT_MSIX_VEC_MAX-value-to-supported-.patch
  patches.suse/bnxt_en-Return-error-when-allocating-zero-size-conte.patch
  patches.suse/ibmvnic-Skip-fatal-error-reset-after-passive-init.patch
- commit 7b08e5b
* Wed May  6 2020 mkubecek@suse.cz
- add kabi reference files
- import from Public RC2 submission (commit b8c70f8e938e)
- enable kabi checking for -default and -preempt flavors
- commit 297cfce
* Wed May  6 2020 mbrugger@suse.com
- supported.conf: mark cuse as supported (bsc#1171279)
- commit 57d34e1
* Wed May  6 2020 bp@suse.de
- x86/cpu: Add a steppings field to struct x86_cpu_id
  (bsc#1152489).
- commit 0e87eea
* Wed May  6 2020 tiwai@suse.de
- PM: hibernate: Freeze kernel threads in software_resume()
  (git-fixes).
- PM: ACPI: Output correct message on target power state
  (git-fixes).
- dmaengine: dmatest: Fix iteration non-stop logic (git-fixes).
- drm/amd/display: Fix green screen issue after suspend
  (git-fixes).
- drm/edid: Fix off-by-one in DispID DTD pixel clock (git-fixes).
- mmc: sdhci-msm: Enable host capabilities pertains to R1b
  response (git-fixes).
- commit 2128020
* Wed May  6 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/powerplay: using the FCLK DPM table to set the MCLK'
- commit 8f1a5e9
* Wed May  6 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: Close race between cacheline_retire and free'
- commit 8f35802
* Wed May  6 2020 tzimmermann@suse.de
- drm/i915/gt: Stage the transfer of the virtual breadcrumb (bsc#1152489)
  * context changes
- commit dd7c1b9
* Wed May  6 2020 tzimmermann@suse.de
- drm/i915: Apply Wa_1406680159:icl,ehl as an engine workaround (bsc#1152489)
  * context changes
- commit 1b9f5c3
* Wed May  6 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gt: Avoid resetting ring->head outside of its timeline mutex'
- commit ce5eb60
* Wed May  6 2020 mbrugger@suse.com
- arm64: blacklist.conf: ignore commit that got reveted later
- commit ea9a578
* Wed May  6 2020 mbrugger@suse.com
- arm64: Update config files. (bsc#1170680)
  Enable CONFIG_KEXEC_SIG and CONFIG_KEXEC_IMAGE_VERIFY_SIG
- commit 83dffa3
* Wed May  6 2020 mbrugger@suse.com
- arm64: kexec_file: Fixed code style (bsc#1170680).
- arm64: kexec_file: add crash dump support (bsc#1170680).
- libfdt: include fdt_addresses.c (bsc#1170680).
- arm64: kexec: remove unnecessary debug prints (bsc#1170680).
- libfdt: define INT32_MAX and UINT32_MAX in libfdt_env.h
  (bsc#1170680).
- commit 3e603a5
* Wed May  6 2020 mbrugger@suse.com
- arm64: Use pr_warn instead of pr_warning (bsc#1170680).
- Refresh
  patches.suse/arm64-smp-fix-smp_send_stop-behaviour.patch.
- commit deabe43
* Wed May  6 2020 mbrugger@suse.com
- arm64: smp: Treat unknown boot failures as being 'stuck in
  kernel' (bsc#1170680).
- arm64: kexec_file: add rng-seed support (bsc#1170680).
- arm64/kexec: Use consistent convention of initializing
  'kxec_buf.mem' with KEXEC_BUF_MEM_UNKNOWN (bsc#1170680).
- commit b8854a2
* Wed May  6 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline tags:
  patches.suse/NFS-Directory-page-cache-pages-need-to-be-locked-whe.patch
  patches.suse/NFS-Fix-a-page-leak-in-nfs_destroy_unlinked_subreque.patch
  patches.suse/NFS-Fix-fix-of-show_nfs_errors.patch
  patches.suse/NFS-Fix-memory-leaks-and-corruption-in-readdir.patch
  patches.suse/NFS-Fix-races-nfs_page_group_destroy-vs-nfs_destroy_.patch
  patches.suse/NFS-Fix-use-after-free-issues-in-nfs_pageio_add_requ.patch
  patches.suse/NFS-Revalidate-the-file-mapping-on-all-fatal-writeba.patch
  patches.suse/NFS-Revalidate-the-file-size-on-a-fatal-write-error.patch
  patches.suse/NFS-alloc_nfs_open_context-must-use-the-file-cred-wh.patch
  patches.suse/NFS-pnfs-Fix-pnfs_generic_prepare_to_resend_writes.patch
  patches.suse/NFSD-fixing-possible-null-pointer-derefering-in-copy.patch
  patches.suse/NFSv2-Fix-a-typo-in-encode_sattr.patch
  patches.suse/NFSv4-pnfs-Return-valid-stateids-in-nfs_layout_find_.patch
  patches.suse/NFSv4-pnfs_roc-must-use-cred_fscmp-to-compare-creds.patch
  patches.suse/NFSv4-try-lease-recovery-on-NFS4ERR_EXPIRED.patch
  patches.suse/NFSv4.0-nfs4_do_fsinfo-should-not-do-implicit-lease-.patch
  patches.suse/NFSv4.1-fix-handling-of-backchannel-binding-in-BIND_.patch
  patches.suse/NFSv4.1-make-cachethis-no-for-writes.patch
  patches.suse/NFSv4.x-Drop-the-slot-if-nfs4_delegreturn_prepare-wa.patch
  patches.suse/NFSv4.x-Handle-bad-dead-sessions-correctly-in-nfs41_.patch
  patches.suse/SUNRPC-Fix-a-potential-buffer-overflow-in-svc_print_.patch
  patches.suse/SUNRPC-Fix-backchannel-RPC-soft-lockups.patch
  patches.suse/SUNRPC-Remove-unreachable-error-condition.patch
  patches.suse/nfs-Fix-potential-posix_acl-refcnt-leak-in-nfs3_set_.patch
  patches.suse/nfsd-Don-t-add-locks-to-closed-or-closing-open-state.patch
  patches.suse/nfsd-Fix-NFSv4-READ-on-RDMA-when-using-readv.patch
  patches.suse/nfsd-Return-the-correct-number-of-bytes-written-to-t.patch
  patches.suse/nfsd-depend-on-CRYPTO_MD5-for-legacy-client-tracking.patch
  patches.suse/nfsd-fix-delay-timer-on-32-bit-architectures.patch
  patches.suse/nfsd-fix-jiffies-time_t-mixup-in-LRU-list.patch
  patches.suse/nfsd-fsnotify-on-rmdir-under-nfsd-clients.patch
  patches.suse/nfsd-memory-corruption-in-nfsd4_lock.patch
  patches.suse/nfsd-remove-nfs4_reset_lease-declarations.patch
  patches.suse/nfsd4-fix-up-replay_matches_cache.patch
  patches.suse/sunrpc-expiry_time-should-be-seconds-not-timeval.patch
  patches.suse/svcrdma-Fix-double-svc_rdma_send_ctxt_put-in-an-erro.patch
  patches.suse/svcrdma-Fix-leak-of-transport-addresses.patch
- commit 913c3fc
* Tue May  5 2020 bp@suse.de
- x86/cpu: Add consistent CPU match macros (bsc#1152489).
- commit a70979e
* Tue May  5 2020 bp@suse.de
- x86/devicetable: Move x86 specific macro out of generic code
  (bsc#1152489).
- commit 9581d95
* Tue May  5 2020 msuchanek@suse.de
- nvdimm: Avoid race between probe and reading device attributes
  (bsc#1170442).
- commit daea9d3
* Tue May  5 2020 ailiop@suse.com
- xfs: add agf freeblocks verify in xfs_agf_verify (bsc#1171217
  CVE-2020-12655).
- commit 08016b2
* Tue May  5 2020 tiwai@suse.de
- xsk: Add missing check on user supplied headroom size
  (CVE-2020-12659 bsc#1171214).
- commit 57877bb
* Tue May  5 2020 tiwai@suse.de
- Update patch reference tags for mwifiex security fixes (CVE-2020-12653 bsc#1171195 CVE-2020-12654 bsc#1171202)
- commit 8da2e42
* Tue May  5 2020 tiwai@suse.de
- Update patch reference tag for a bfq security fix (CVE-2020-12657 bsc#1171205)
- commit a3037e6
* Tue May  5 2020 jslaby@suse.cz
- net: dsa: ksz: Select KSZ protocol tag
  (networking-stable-20_04_02).
- net, ip_tunnel: fix interface lookup with no key
  (networking-stable-20_04_02).
- sctp: fix possibly using a bad saddr with a given dst
  (networking-stable-20_04_02).
- sctp: fix refcount bug in sctp_wfree
  (networking-stable-20_04_02).
- ipv4: fix a RCU-list lock in fib_triestat_seq_show
  (networking-stable-20_04_02).
- commit 841d154
* Tue May  5 2020 tbogendoerfer@suse.de
- bnxt_en: Fix VLAN acceleration handling in bnxt_fix_features()
  (bsc#1171150).
- bnxt_en: Return error when allocating zero size context memory
  (bsc#1171150).
- bnxt_en: Improve AER slot reset (bsc#1171150).
- bnxt_en: Reduce BNXT_MSIX_VEC_MAX value to supported CQs per PF
  (bsc#1171150).
- bnxt_en: Fix VF anti-spoof filter setup (bsc#1171150).
- bnxt_en: Reset rings if ring reservation fails during open()
  (bsc#1171150).
- bnxt_en: Free context memory after disabling PCI in probe
  error path (bsc#1171150).
- bnxt_en: Return error if bnxt_alloc_ctx_mem() fails
  (bsc#1171150).
- bnxt_en: fix memory leaks in bnxt_dcbnl_ieee_getets()
  (bsc#1171150).
- bnxt_en: Fix Priority Bytes and Packets counters in ethtool -S
  (bsc#1171150).
- commit 0a89267
* Tue May  5 2020 mbenes@suse.cz
- xprtrdma: Fix trace point use-after-free race (git-fixes).
- commit 52af41b
* Tue May  5 2020 jslaby@suse.cz
- mlxsw: spectrum_mr: Fix list iteration in error path
  (networking-stable-20_03_28).
- net: dsa: tag_8021q: replace dsa_8021q_remove_header with
  __skb_vlan_pop (networking-stable-20_03_28).
- net: cbs: Fix software cbs to consider packet sending time
  (networking-stable-20_03_28).
- net: dsa: Fix duplicate frames flooded by learning
  (networking-stable-20_03_28).
- bnxt_en: Reset rings if ring reservation fails during open()
  (networking-stable-20_03_28).
- bnxt_en: Free context memory after disabling PCI in probe
  error path (networking-stable-20_03_28).
- bnxt_en: Return error if bnxt_alloc_ctx_mem() fails
  (networking-stable-20_03_28).
- bnxt_en: fix memory leaks in bnxt_dcbnl_ieee_getets()
  (networking-stable-20_03_28).
- bnxt_en: Fix Priority Bytes and Packets counters in ethtool -S
  (networking-stable-20_03_28).
- macsec: restrict to ethernet devices
  (networking-stable-20_03_28).
- ipv4: fix a RCU-list lock in inet_dump_fib()
  (networking-stable-20_03_28).
- tcp: repair: fix TCP_QUEUE_SEQ implementation
  (networking-stable-20_03_28).
- net: phy: dp83867: w/a for fld detect threshold bootstrapping
  issue (networking-stable-20_03_28).
- net: stmmac: dwmac-rk: fix error path in rk_gmac_probe
  (networking-stable-20_03_28).
- hsr: fix general protection fault in hsr_addr_is_self()
  (networking-stable-20_03_28).
- cxgb4: fix Txq restart check during backpressure
  (networking-stable-20_03_28).
- net/sched: act_ct: Fix leak of ct zone template on replace
  (networking-stable-20_03_28).
- net: ip_gre: Accept IFLA_INFO_DATA-less configuration
  (networking-stable-20_03_28).
- net: mvneta: Fix the case where the last poll did not process
  all rx (networking-stable-20_03_28).
- net_sched: cls_route: remove the right filter from hashtable
  (networking-stable-20_03_28).
- hsr: set .netnsok flag (networking-stable-20_03_28).
- hsr: add restart routine into hsr_get_node_list()
  (networking-stable-20_03_28).
- hsr: use rcu_read_lock() in hsr_get_node_{list/status}()
  (networking-stable-20_03_28).
- net/packet: tpacket_rcv: avoid a producer race condition
  (networking-stable-20_03_28).
- net: ip_gre: Separate ERSPAN newlink / changelink callbacks
  (networking-stable-20_03_28).
- net_sched: hold rtnl lock in tcindex_partial_destroy_work()
  (networking-stable-20_03_28).
- commit b6b5945
* Tue May  5 2020 mbenes@suse.cz
- svcrdma: Fix trace point use-after-free race (git-fixes).
- commit 44461e4
* Tue May  5 2020 tiwai@suse.de
- Revert "HID: wacom: generic: read the number of expected
  touches on a per collection basis" (git-fixes).
- HID: wacom: Read HID_DG_CONTACTMAX directly for non-generic
  devices (git-fixes).
- commit 16cdbdb
* Tue May  5 2020 neilb@suse.de
- NFSv4.1: fix handling of backchannel binding in
  BIND_CONN_TO_SESSION (bsc#1170630).
- commit a75f6f6
* Tue May  5 2020 neilb@suse.de
- SUNRPC: Remove unreachable error condition (git-fixes).
- nfs: Fix potential posix_acl refcnt leak in nfs3_set_acl
  (git-fixes).
- SUNRPC: Fix backchannel RPC soft lockups (git-fixes).
- nfsd: memory corruption in nfsd4_lock() (git-fixes).
- NFS: Fix use-after-free issues in nfs_pageio_add_request()
  (git-fixes).
- NFS: Fix races nfs_page_group_destroy() vs
  nfs_destroy_unlinked_subrequests() (git-fixes).
- NFS: Fix a page leak in nfs_destroy_unlinked_subrequests()
  (git-fixes).
- NFSv4/pnfs: Return valid stateids in
  nfs_layout_find_inode_by_stateid() (git-fixes).
- NFS: alloc_nfs_open_context() must use the file cred when
  available (git-fixes).
- svcrdma: Fix leak of transport addresses (git-fixes).
- SUNRPC: Fix a potential buffer overflow in 'svc_print_xprts()'
  (git-fixes).
- nfsd: fsnotify on rmdir under nfsd/clients/ (git-fixes).
- nfsd: Don't add locks to closed or closing open stateids
  (git-fixes).
- svcrdma: Fix double svc_rdma_send_ctxt_put() in an error path
  (git-fixes).
- nfsd: Fix NFSv4 READ on RDMA when using readv (git-fixes).
- NFSv4.1 make cachethis=no for writes (git-fixes).
- sunrpc: expiry_time should be seconds not timeval (git-fixes).
- nfsd: remove nfs4_reset_lease() declarations (git-fixes).
- nfsd: fix jiffies/time_t mixup in LRU list (git-fixes).
- nfsd: fix delay timer on 32-bit architectures (git-fixes).
- nfsd: Return the correct number of bytes written to the file
  (git-fixes).
- NFSv4.0: nfs4_do_fsinfo() should not do implicit lease renewals
  (git-fixes).
- NFSv4: try lease recovery on NFS4ERR_EXPIRED (git-fixes).
- NFS: Directory page cache pages need to be locked when read
  (git-fixes).
- NFS: Fix memory leaks and corruption in readdir (git-fixes).
- NFSv4: pnfs_roc() must use cred_fscmp() to compare creds
  (git-fixes).
- NFS: Fix fix of show_nfs_errors (git-fixes).
- NFS/pnfs: Fix pnfs_generic_prepare_to_resend_writes()
  (git-fixes).
- NFS: Revalidate the file mapping on all fatal writeback errors
  (git-fixes).
- NFS: Revalidate the file size on a fatal write error
  (git-fixes).
- nfsd: depend on CRYPTO_MD5 for legacy client tracking
  (git-fixes).
- NFSD fixing possible null pointer derefering in copy offload
  (git-fixes).
- nfsd4: fix up replay_matches_cache() (git-fixes).
- NFSv4.x: Drop the slot if nfs4_delegreturn_prepare waits for
  layoutreturn (git-fixes).
- NFSv4.x: Handle bad/dead sessions correctly in
  nfs41_sequence_process() (git-fixes).
- NFSv2: Fix a typo in encode_sattr() (git-fixes).
- commit d9c3108
* Mon May  4 2020 ailiop@suse.com
- xfs: acquire superblock freeze protection on eofblocks scans
  (git-fixes).
- commit ae8b96a
* Mon May  4 2020 ailiop@suse.com
- xfs: clear PF_MEMALLOC before exiting xfsaild thread
  (git-fixes).
- commit a472c36
* Mon May  4 2020 tbogendoerfer@suse.de
- RDMA/core: Fix overwriting of uobj in case of error
  (jsc#SLE-8449).
- RDMA/uverbs: Fix a race with disassociate and exit_mmap()
  (jsc#SLE-8449).
- commit fcb09af
* Mon May  4 2020 msuchanek@suse.de
- ibmvnic: Skip fatal error reset after passive init (bsc#1171078
  ltc#184239).
- commit b0e0859
* Mon May  4 2020 mbrugger@suse.com
- arm64: dts: allwinner: a64: Fix display clock register range
  (bsc#1171081).
- arm64: bcm2835: Drop select of nonexistent HAVE_ARM_ARCH_TIMER
  (bsc#1171079).
- ARM: bcm2835-rpi-zero-w: Add missing pinctrl name (bsc#1171075).
- arm64: alternative: fix build with clang integrated assembler
  (bsc#1171076).
- arm64: compat: Fix syscall number of compat_clock_getres
  (bsc#1171080).
- arm64: smp: fix crash_smp_send_stop() behaviour (bsc#1171082).
- arm64: smp: fix smp_send_stop() behaviour (bsc#1171083).
- compat: ARM64: always include asm-generic/compat.h
  (bsc#1171084).
- commit 559d336
* Mon May  4 2020 nsaenzjulienne@suse.de
- Update patches.suse/firmware-raspberrypi-introduce-vl805-init-routine.patch.
- commit 984c0bd
* Mon May  4 2020 jslaby@suse.cz
- blacklist.conf: add aer_inject entry
  It requires the new irq injection infrastructure.
- commit a8523ff
* Mon May  4 2020 jslaby@suse.cz
- Revert "serial: uartps: Fix uartps_major handling" (git-fixes).
- net: stmmac: dwmac-meson8b: Add missing boundary to RGMII TX
  clock array (git-fixes).
- commit 7b95e1e
* Mon May  4 2020 jslaby@suse.cz
- random: always use batched entropy for get_random_u{32,64}
  (git-fixes).
- commit 6e4b6dc
* Sun May  3 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/ALSA-pcm-oss-Place-the-plugin-buffer-overflow-checks.patch
  patches.suse/scsi-qla2xxx-check-UNLOADING-before-posting-async-wo.patch
  patches.suse/scsi-qla2xxx-set-UNLOADING-before-waiting-for-sessio.patch
- commit ed4ef69
* Sun May  3 2020 mkubecek@suse.cz
- update metadata of nvme patches
  The nvme-5.8 branch in nvme repository got rebased again, update Git-commit
  tags:
  patches.suse/lpfc-Commonize-lpfc_async_xchg_ctx-state-and-flag-de.patch
  patches.suse/lpfc-Refactor-NVME-LS-receive-handling.patch
  patches.suse/lpfc-Refactor-Send-LS-Abort-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Request-support.patch
  patches.suse/lpfc-Refactor-Send-LS-Response-support.patch
  patches.suse/lpfc-Refactor-lpfc-nvme-headers.patch
  patches.suse/lpfc-Refactor-nvmet_rcv_ctx-to-create-lpfc_async_xch.patch
  patches.suse/lpfc-nvme-Add-Receive-LS-Request-and-Send-LS-Respons.patch
  patches.suse/lpfc-nvmet-Add-Send-LS-Request-and-Abort-LS-Request-.patch
  patches.suse/lpfc-nvmet-Add-support-for-NVME-LS-request-hosthandl.patch
  patches.suse/nvme-fc-Add-Disconnect-Association-Rcv-support.patch
  patches.suse/nvme-fc-Ensure-private-pointers-are-NULL-if-no-data.patch
  patches.suse/nvme-fc-Sync-header-to-FC-NVME-2-rev-1.08.patch
  patches.suse/nvme-fc-Update-header-and-host-for-common-definition.patch
  patches.suse/nvme-fc-and-nvmet-fc-revise-LLDD-api-for-LS-receptio.patch
  patches.suse/nvme-fc-convert-assoc_active-flag-to-bit-op.patch
  patches.suse/nvme-fc-nvmet-fc-refactor-for-common-LS-definitions.patch
  patches.suse/nvme-fcloop-add-target-to-host-LS-request-support.patch
  patches.suse/nvme-fcloop-refactor-to-enable-target-to-host-LS.patch
  patches.suse/nvmet-fc-Add-Disconnect-Association-Xmt-support.patch
  patches.suse/nvmet-fc-Better-size-LS-buffers.patch
  patches.suse/nvmet-fc-Update-target-for-common-definitions-for-LS.patch
  patches.suse/nvmet-fc-add-LS-failure-messages.patch
  patches.suse/nvmet-fc-perform-small-cleanups-on-unneeded-checks.patch
  patches.suse/nvmet-fc-rename-ls_list-to-ls_rcv_list.patch
  patches.suse/nvmet-fc-track-hostport-handle-for-associations.patch
- commit a859813
* Sat May  2 2020 tiwai@suse.de
- PCI: Add ACS quirk for iProc PAXB (git-fixes).
- Refresh
  patches.suse/PCI-Add-ACS-quirk-for-Amazon-Annapurna-Labs-root-por.patch.
- commit aef108e
* Sat May  2 2020 tiwai@suse.de
- i2c: aspeed: Avoid i2c interrupt status clear race condition
  (git-fixes).
- i2c: amd-mp2-pci: Fix Oops in amd_mp2_pci_init() error handling
  (git-fixes).
- i2c: iproc: generate stop event for slave writes (git-fixes).
- drm/qxl: qxl_release use after free (git-fixes).
- drm/qxl: qxl_release leak in qxl_hw_surface_alloc() (git-fixes).
- drm/qxl: qxl_release leak in qxl_draw_dirty_fb() (git-fixes).
- mmc: sdhci-pci: Fix eMMC driver strength for BYT-based
  controllers (git-fixes).
- mmc: sdhci-xenon: fix annoying 1.8V regulator warning
  (git-fixes).
- mmc: cqhci: Avoid false "cqhci: CQE stuck on" by not open-coding
  timeout loop (git-fixes).
- mmc: meson-mx-sdio: remove the broken ->card_busy() op
  (git-fixes).
- mmc: meson-mx-sdio: Set MMC_CAP_WAIT_WHILE_BUSY (git-fixes).
- PCI: Move Apex Edge TPU class quirk to fix BAR assignment
  (git-fixes).
- hwmon: (jc42) Fix name to have no illegal characters
  (git-fixes).
- mac80211: fix channel switch trigger from unknown mesh peer
  (git-fixes).
- PCI: Add ACS quirk for Zhaoxin Root/Downstream Ports
  (git-fixes).
- PCI: Add ACS quirk for Zhaoxin multi-function devices
  (git-fixes).
- PCI: Add Zhaoxin Vendor ID (git-fixes).
- PCI: Avoid ASMedia XHCI USB PME# from D0 defect (git-fixes).
- PCI: Unify ACS quirk desired vs provided checking (git-fixes).
- PCI: Make ACS quirk implementations more uniform (git-fixes).
- commit 21a860f
* Sat May  2 2020 tiwai@suse.de
- ALSA: usb-audio: Correct a typo of NuPrime DAC-10 USB ID
  (git-fixes).
- ALSA: opti9xx: shut up gcc-10 range warning (git-fixes).
- ALSA: hda/hdmi: fix without unlocked before return (git-fixes).
- ALSA: hda/hdmi: fix race in monitor detection during probe
  (git-fixes).
- ALSA: hda/realtek - Two front mics on a Lenovo ThinkCenter
  (git-fixes).
- ALSA: line6: Fix POD HD500 audio playback (git-fixes).
- ALSA: hda: Match both PCI ID and SSID for driver blacklist
  (git-fixes).
- commit f537abd
* Sat May  2 2020 tiwai@suse.de
- Move the upstreamed sound and scsi patches to the mainline section
- commit f5d1d6a
* Sat May  2 2020 colyli@suse.de
- libnvdimm/region: Fix build error (bsc#1162400).
- libnvdimm/region: Introduce an 'align' attribute (bsc#1162400).
- commit cdf6722
* Sat May  2 2020 colyli@suse.de
- libnvdimm/region: Introduce NDD_LABELING (bsc#1162400).
- libnvdimm/namespace: Enforce memremap_compat_align()
  (bsc#1162400).
- libnvdimm/pfn: Prevent raw mode fallback if pfn-infoblock valid
  (bsc#1171743).
- commit f5c3d9e
* Sat May  2 2020 colyli@suse.de
- mm/memremap_pages: Introduce memremap_compat_align() (bsc#1162400).
- Update configs for the above change.
- Refresh patches.suse/powerpc-bpf-Enable-bpf_probe_read-str-on-powerpc-aga.patch.
- mm/memremap_pages: Kill unused __devm_memremap_pages()
  (bsc#1162400).
- libnvdimm/btt: fix variable 'rc' set but not used
  (bsc#1162400).
- libnvdimm/namsepace: Don't set claim_class on error
  (bsc#1162400).
- commit 312e489
* Sat May  2 2020 colyli@suse.de
- lib: Uplevel the pmem "region" ida to a global allocator
  (bc#1162400).
- Update configs for the above change.
- libnvdimm: Use PAGE_SIZE instead of SZ_4K for align check
  (bsc#1171759).
- libnvdimm/label: Remove the dpa align check (bsc#1171759).
- libnvdimm/pfn_dev: Add page size and struct page size to pfn
  superblock (bsc#1171759).
- commit c578923
* Sat May  2 2020 colyli@suse.de
- libnvdimm/pmem: Advance namespace seed for specific probe errors
  (bsc#1171743).
- libnvdimm/pfn_dev: Add a build check to make sure we notice when
  struct page size change (bsc#1171743).
- Refresh for the above changes,
  patches.suse/libnvdimm-namespace-Differentiate-between-probe-mapp.patch.
- commit 9e70235
* Fri May  1 2020 colyli@suse.de
- libnvdimm/region: Rewrite _probe_success() to _advance_seeds()
  (bsc#1171743).
- commit dd1569b
* Fri May  1 2020 colyli@suse.de
- libnvdimm/security: Introduce a 'frozen' attribute (bsc#1171742).
- Refresh for the above change,
  patches.suse/libnvdimm-prevent-nvdimm-from-requesting-key-when-security.patch.
- commit 307a9c7
* Fri May  1 2020 colyli@suse.de
- libnvdimm/of_pmem: Provide a unique name for bus provider
  (bsc#1171739).
- commit 3aff0cd
* Fri May  1 2020 rgoldwyn@suse.com
- fanotify: fix merging marks masks with FAN_ONDIR  (bsc#1170799).
- commit 5edf4ab
* Fri May  1 2020 tiwai@suse.de
- Revert an ASoC meson backport that is known to to break
  Delete patches.suse/ASoC-meson-axg-card-fix-codec-to-codec-link-setup.patch
  Add the commit to blacklist.conf, too
- commit d6f33c1
* Thu Apr 30 2020 msuchanek@suse.de
- libnvdimm: Out of bounds read in __nd_ioctl() (bsc#1065729).
- mm/memremap: drop unused SECTION_SIZE and SECTION_MASK
  (bsc#1162400 bsc#1170895 ltc#184375 ltc#185686).
- commit ceaa507
* Thu Apr 30 2020 tiwai@suse.de
- Update patch reference for a USB core fix (CVE-2020-12464 bsc#1170901)
- commit c3ba43e
* Thu Apr 30 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline, drop Git-repo and Git-commit:
  patches.suse/net-phy-realtek-fix-handling-of-RTL8105e-integrated-.patch
- commit d71cae8
* Thu Apr 30 2020 oneukum@suse.com
- Update
  patches.suse/mt76-fix-array-overflow-on-receiving-too-many-fragme.patch
  (bsc#1170828 CVE-2020-12465).
  Added bsc and CVE number
- commit 62c98d8
* Thu Apr 30 2020 tiwai@suse.de
- drm/i915: properly sanity check batch_start_offset (git-fixes).
- commit 6a1493c
* Thu Apr 30 2020 tiwai@suse.de
- tty: hvc: fix buffer overflow during hvc_alloc() (git-fixes).
- watchdog: reset last_hw_keepalive time at start (git-fixes).
- Revert "software node: Simplify software_node_release()
  function" (git-fixes).
- intel_th: msu: Fix window switching without windows (git-fixes).
- commit f284d1e
* Thu Apr 30 2020 tiwai@suse.de
- crypto: caam - fix the address of the last entry of S/G
  (git-fixes).
- USB: sisusbvga: Change port variable from signed to unsigned
  (git-fixes).
- usb-storage: Add unusual_devs entry for JMicron JMS566
  (git-fixes).
- xhci: prevent bus suspend if a roothub port detected a
  over-current condition (git-fixes).
- USB: Add USB_QUIRK_DELAY_CTRL_MSG and USB_QUIRK_DELAY_INIT
  for Corsair K70 RGB RAPIDFIRE (git-fixes).
- usb: typec: tcpm: Ignore CC and vbus changes in PORT_RESET
  change (git-fixes).
- cdc-acm: introduce a cool down (git-fixes).
- cdc-acm: close race betrween suspend() and acm_softint
  (git-fixes).
- USB: core: Fix free-while-in-use bug in the USB S-Glibrary
  (git-fixes).
- serial: sh-sci: Make sure status register SCxSR is read in
  correct sequence (git-fixes).
- staging: comedi: dt2815: fix writing hi byte of analog output
  (git-fixes).
- iwlwifi: mvm: fix inactive TID removal return value usage
  (git-fixes).
- iwlwifi: mvm: Do not declare support for ACK Enabled Aggregation
  (git-fixes).
- iwlwifi: mvm: beacon statistics shouldn't go backwards
  (git-fixes).
- drm/amd/display: Calculate scaling ratios on every medium/full
  update (git-fixes).
- drm/amd/display: Update stream adjust in
  dc_stream_adjust_vmin_vmax (git-fixes).
- drm/amd/display: Not doing optimize bandwidth if flip pending
  (git-fixes).
- xhci: Finetune host initiated USB3 rootport link suspend and
  resume (git-fixes).
- xhci: Wait until link state trainsits to U0 after setting
  USB_SS_PORT_LS_U0 (git-fixes).
- xhci: Ensure link state is U3 after setting USB_SS_PORT_LS_U3
  (git-fixes).
- PCI/PM: Add pcie_wait_for_link_delay() (git-fixes).
- PCI/ASPM: Allow re-enabling Clock PM (git-fixes).
- commit 69b68ab
* Thu Apr 30 2020 glin@suse.com
- bpf: Fix handling of XADD on BTF memory (bsc#1155518).
- bpf: Forbid XADD on spilled pointers for unprivileged users
  (bsc#1155518).
- commit 60505c2
* Wed Apr 29 2020 tiwai@suse.de
- net: phy: realtek: fix handling of RTL8105e-integrated PHY
  (git-fixes).
- commit 630c337
* Wed Apr 29 2020 tiwai@suse.de
- USB: hub: Fix handling of connect changes during sleep
  (git-fixes).
- usb: typec: altmode: Fix typec_altmode_get_partner sometimes
  returning an invalid pointer (git-fixes).
- usb: gadget: udc: atmel: Fix vbus disconnect handling
  (git-fixes).
- usb: gadget: udc: bdc: Remove unnecessary NULL checks in
  bdc_req_complete (git-fixes).
- geneve: use the correct nlattr array in NL_SET_ERR_MSG_ATTR
  (git-fixes).
- drivers: soc: xilinx: fix firmware driver Kconfig dependency
  (git-fixes).
- soc: imx: gpc: fix power up sequencing (git-fixes).
- hibernate: Allow uswsusp to write to swap (git-fixes).
- phy: uniphier-usb3ss: Add Pro5 support (git-fixes).
- padata: update documentation file path in MAINTAINERS
  (git-fixes).
- commit b521dd8
* Wed Apr 29 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/0001-btrfs-don-t-pass-system_chunk-into-can_overcommit.patch
  patches.suse/0001-btrfs-fix-force-usage-in-inc_block_group_ro.patch
  patches.suse/0002-btrfs-kill-min_allocable_bytes-in-inc_block_group_ro.patch
  patches.suse/0002-btrfs-take-overcommit-into-account-in-inc_block_grou.patch
  patches.suse/btrfs-check-rw_devices-not-num_devices-for-balance.patch
  patches.suse/btrfs-scrub-Don-t-check-free-space-before-marking-a-.patch
- commit 0c4ef8d
* Wed Apr 29 2020 msuchanek@suse.de
- scsi: ibmvscsi: Fix WARN_ON during event pool release
  (bsc#1170791 ltc#185128).
- commit 235b7cd
* Wed Apr 29 2020 wqu@suse.com
- btrfs: take overcommit into account in inc_block_group_ro
  (bsc#1156898).
- commit b4b780e
* Wed Apr 29 2020 wqu@suse.com
- btrfs: fix force usage in inc_block_group_ro (bsc#1156898).
- commit 9de9dbb
* Wed Apr 29 2020 wqu@suse.com
- btrfs: scrub: Don't check free space before marking a block
  group RO (bsc#1156898).
- Refresh
  patches.suse/0001-btrfs-scrub-Require-mandatory-block-group-RO-for-dev.patch.
- Refresh
  patches.suse/Btrfs-fix-block-group-remaining-RO-forever-after-err.patch.
- commit 0af353d
* Wed Apr 29 2020 wqu@suse.com
- btrfs: kill min_allocable_bytes in inc_block_group_ro
  (bsc#1156898).
- commit d02303e
* Wed Apr 29 2020 wqu@suse.com
- btrfs: don't pass system_chunk into can_overcommit
  (bsc#1156898).
- commit c373e8e
* Wed Apr 29 2020 wqu@suse.com
- btrfs: check rw_devices, not num_devices for balance
  (bsc#1156898).
- commit 1228d44
* Wed Apr 29 2020 tbogendoerfer@suse.de
- RDMA/bnxt_re: make bnxt_re_ib_init static (bsc#1170774).
- RDMA/bnxt_re: Wait for all the CQ events before freeing CQ
  data structures (bsc#1170774).
- RDMA/bnxt_re: Remove unnecessary sched count (bsc#1170774).
- RDMA/bnxt_re: Fix lifetimes in bnxt_re_task (bsc#1170774).
- RDMA/bnxt_re: Use ib_device_try_get() (bsc#1170774).
- RDMA/bnxt_re: Remove a redundant 'memset' (bsc#1170774).
- RDMA/bnxt_re: Remove set but not used variables 'pg' and 'idx'
  (bsc#1170774).
- RDMA/bnxt_re: Remove set but not used variable 'dev_attr'
  (bsc#1170774).
- RDMA/bnxt_re: Remove set but not used variable 'pg_size'
  (bsc#1170774).
- RDMA/bnxt_re: Use driver_unregister and unregistration API
  (bsc#1170774).
- RDMA/bnxt_re: Refactor device add/remove functionalities
  (bsc#1170774).
- RDMA/bnxt_re: Using vmalloc requires including vmalloc.h
  (bsc#1170774).
- RDMA/bnxt_re: use ibdev based message printing functions
  (bsc#1170774).
- RDMA/bnxt_re: Refactor doorbell management functions
  (bsc#1170774).
- RDMA/bnxt_re: Refactor notification queue management code
  (bsc#1170774).
- RDMA/bnxt_re: Refactor command queue management code
  (bsc#1170774).
- RDMA/bnxt_re: Refactor net ring allocation function
  (bsc#1170774).
- RDMA/bnxt_re: Refactor hardware queue memory allocation
  (bsc#1170774).
- RDMA/bnxt_re: Replace chip context structure with pointer
  (bsc#1170774).
- RDMA/bnxt_re: Refactor queue pair creation code (bsc#1170774).
- RDMA/bnxt_re: Use rdma_read_gid_hw_context to retrieve HW gid
  index (bsc#1170774).
- RDMA/core: Add helper function to retrieve driver gid context
  from gid attr (bsc#1170774).
- commit 63c9b07
* Tue Apr 28 2020 ptesarik@suse.cz
- s390/mm: fix page table upgrade vs 2ndary address mode accesses
  (bsc#1170030 CVE-2020-11884).
- commit 0b0d8cd
* Tue Apr 28 2020 bp@suse.de
- EDAC/i10nm: Update driver to support different bus number
  config register offsets (bsc#1159522).
- commit 796bb54
* Tue Apr 28 2020 mhocko@suse.com
- Update patches.suse/x86-mm-split-vmalloc_sync_all.patch
  (bsc#1165741, bsc#1166969).
- commit dc341e6
* Tue Apr 28 2020 bp@suse.de
- EDAC, {skx,i10nm}: Make some configurations CPU model specific
  (bsc#1159522).
- commit 7936538
* Tue Apr 28 2020 msuchanek@suse.de
- Update patches.suse/ibmvfc-don-t-send-implicit-logouts-prior-to-NPIV-log.patch
  to upstream version and rename to patches.suse/scsi-ibmvfc-Don-t-send-implicit-logouts-prior-to-NPI.patch
- commit d04a4dc
* Tue Apr 28 2020 dwagner@suse.de
- wireguard: Kconfig: select parent dependency for crypto
  (bsc#1169021 jsc#SLE-12250).
- commit 41bcd62
* Mon Apr 27 2020 lyan@suse.com
- KVM: s390: Return last valid slot if approx index is
  out-of-bounds (bsc#1133021).
- commit a035552
* Mon Apr 27 2020 dbueso@suse.de
- proc, time/namespace: Show clock symbolic names in
  /proc/pid/timens_offsets (bsc#1164648,jsc#SLE-11493).
- futex: Remove {get,drop}_futex_key_refs() (bsc#1149032).
- futex: Remove pointless mmgrap() + mmdrop() (bsc#1149032).
- locking/rtmutex: rcu: Add WRITE_ONCE() to rt_mutex ->owner
  (bsc#1149032).
- futex: Unbreak futex hashing (bsc#1149032).
- futex: Fix inode life-time issue (bsc#1149032).
- commit 7790db5
* Mon Apr 27 2020 ohering@suse.de
- x86: hyperv: report value of misc_features (git fixes).
- commit e231452
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Report crash data in die() when panic_on_oops is
  set (git fixes).
  Refresh patches.suse/suse-hv-kabi.patch
- commit 5afa1b8
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Report crash register data when
  sysctl_record_panic_msg is not set (git fixes).
- commit f165c68
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Report crash register data or kmsg before running
  crash kernel (git fixes).
- commit b120cb7
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Trigger crash enlightenment only once during
  system crash (git fixes).
- commit 1644d6f
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Free hv_panic_page when fail to register kmsg dump
  (git fixes).
- commit 918a3d5
* Mon Apr 27 2020 ohering@suse.de
- x86/Hyper-V: Unload vmbus channel in hv panic callback
  (git fixes).
  Refresh patches.suse/suse-hv-kabi.patch
- commit f66b321
* Mon Apr 27 2020 tiwai@suse.de
- drm/exynos: Fix cleanup of IOMMU related objects (git-fixes).
- commit 7669fb1
* Mon Apr 27 2020 tiwai@suse.de
- staging: comedi: Fix comedi_device refcnt leak in comedi_open
  (git-fixes).
- macsec: avoid to set wrong mtu (git-fixes).
- iwlwifi: pcie: actually release queue memory in TVQM
  (git-fixes).
- macvlan: fix null dereference in macvlan_device_event()
  (git-fixes).
- PM: sleep: core: Switch back to async_schedule_dev()
  (git-fixes).
- drm/meson: Delete an error message in meson_dw_hdmi_bind()
  (git-fixes).
- audit: check the length of userspace generated audit records
  (git-fixes).
- tpm/tpm_tis: Free IRQ if probing fails (git-fixes).
- tpm: fix wrong return value in tpm_pcr_extend (git-fixes).
- drm/amdkfd: kfree the wrong pointer (git-fixes).
- drm/nouveau/gr/gp107,gp108: implement workaround for HW hanging
  during init (git-fixes).
- drm/nouveau: workaround runpm fail by disabling PCI power
  management on certain intel bridges (git-fixes).
- drm/nouveau/svm: check for SVM initialized before migrating
  (git-fixes).
- drm/nouveau/svm: fix vma range check for migration (git-fixes).
- fbcon: fix null-ptr-deref in fbcon_switch (git-fixes).
- power: supply: bq27xxx_battery: Silence deferred-probe error
  (git-fixes).
- power: supply: axp288_charger: Add special handling for HP
  Pavilion x2 10 (git-fixes).
- power: supply: axp288_fuel_gauge: Broaden vendor check for
  Intel Compute Sticks (git-fixes).
- clk: tegra: Fix Tegra PMC clock out parents (git-fixes).
- clk: at91: usb: continue if clk_hw_round_rate() return zero
  (git-fixes).
- rtc: 88pm860x: fix possible race condition (git-fixes).
- NTB: ntb_transport: Use scnprintf() for avoiding potential
  buffer overflow (git-fixes).
- ntb_hw_switchtec: Fix ntb_mw_clear_trans error if size == 0
  (git-fixes).
- ntb_tool: Fix printk format (git-fixes).
- NTB: ntb_perf: Fix address err in perf_copy_chunk (git-fixes).
- NTB: Fix an error in get link status (git-fixes).
- cpufreq: imx6q: fix error handling (git-fixes).
- cpufreq: imx6q: Fixes unwanted cpu overclocking on i.MX6ULL
  (git-fixes).
- iio: industrialio-core: Fix debugfs read (git-fixes).
- libfs: fix infoleak in simple_attr_read() (git-fixes).
- drm/amdgpu: fix memory leak during TDR test(v2) (git-fixes).
- Fix built-in early-load Intel microcode alignment (git-fixes).
- cpufreq: s3c64xx: Remove pointless NULL check in
  s3c64xx_cpufreq_driver_init (git-fixes).
- commit d13e57f
* Mon Apr 27 2020 ohering@suse.de
- Drivers: hv: vmbus: Fix crash handler reset of Hyper-V synic
  (git fixes).
  Refresh patches.suse/suse-hv-kabi.patch
- commit 73a1fdb
* Mon Apr 27 2020 ohering@suse.de
- Drivers: hv: vmbus: Remove dependencies on guest page size
  (git fixes).
- commit 0eb9623
* Mon Apr 27 2020 oneukum@suse.com
- UAS: fix deadlock in error handling and PM flushing work
  (git-fixes).
- commit f10ebae
* Mon Apr 27 2020 oneukum@suse.com
- UAS: no use logging any details in case of ENODEV (git-fixes).
- commit 12e8b6e
* Mon Apr 27 2020 oneukum@suse.com
- USB: hub: Revert commit bd0e6c9614b9 ("usb: hub: try old
  enumeration scheme first for high speed devices") (git-fixes).
- commit 63272b5
* Mon Apr 27 2020 oneukum@suse.com
- xhci: Don't clear hub TT buffer on ep0 protocol stall
  (git-fixes).
- commit d0e1439
* Mon Apr 27 2020 oneukum@suse.com
- usb: dwc3: gadget: Fix request completion check (git-fixes).
- commit eb78203
* Mon Apr 27 2020 tzimmermann@suse.de
- drm/sun4i: sun6i_mipi_dsi: Add VCC-DSI regulator support (bsc#1152489)
  * manual patch refresh
- commit 66ebcc7
* Mon Apr 27 2020 oneukum@suse.com
- usb: dwc3: gadget: Do link recovery for SS and SSP (git-fixes).
- commit 87d561b
* Mon Apr 27 2020 oneukum@suse.com
- usb: dwc3: Fix GTXFIFOSIZ.TXFDEP macro name (git-fixes).
- commit 7eb2c31
* Mon Apr 27 2020 oneukum@suse.com
- usb: f_fs: Clear OS Extended descriptor counts to zero in
  ffs_data_reset() (git-fixes).
- commit 1fb0c5f
* Mon Apr 27 2020 oneukum@suse.com
- USB: early: Handle AMD's spec-compliant identifiers, too
  (git-fixes).
- commit 26634ce
* Mon Apr 27 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/cpuidle-menu-Allow-tick-to-be-stopped-if-PM-QoS-is-used.patch
  patches.suse/mm-vmscan.c-clean-code-by-removing-unnecessary-assignment.patch
  patches.suse/rcu-Allow-only-one-expedited-GP-to-run-concurrently-with-wakeups.patch
  patches.suse/rcu-Fix-missed-wakeup-of-exp_wq-waiters.patch
  patches.suse/sched-fair-Align-rq-avg_idle-and-rq-avg_scan_cost.patch
- commit f15a73a
* Mon Apr 27 2020 mgorman@suse.de
- sched/nohz: Avoid disabling the tick for very short durations
  (bnc#754690, bsc#1158748).
- Delete patches.suse/sched-throttle-nohz.patch.
- commit 0628907
* Mon Apr 27 2020 mgorman@suse.de
- sched/cpuacct: Use __this_cpu_add() instead of this_cpu_ptr()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 04cc379
* Mon Apr 27 2020 mgorman@suse.de
- sched/fair: Use __this_cpu_read() in wake_wide() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Align rq->avg_idle and rq->avg_scan_cost
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- mm/vmscan.c: clean code by removing unnecessary assignment
  (git fixes (mm/vmscan)).
- rcu: Allow only one expedited GP to run concurrently with
  wakeups (git fixes (rcu)).
- rcu: Fix missed wakeup of exp_wq waiters (git fixes (rcu)).
- cpuidle: menu: Allow tick to be stopped if PM QoS is used
  (bnc#1158748 (network regression)).
- commit cb72208
* Mon Apr 27 2020 tiwai@suse.de
- tty: rocket, avoid OOB access (git-fixes).
- tty: serial: bcm63xx: fix missing clk_put() in bcm63xx_uart
  (git-fixes).
- tty: serial: owl: add "much needed" clk_prepare_enable()
  (git-fixes).
- staging: vt6656: Fix calling conditions of vnt_set_bss_mode
  (git-fixes).
- staging: vt6656: Fix pairwise key entry save (git-fixes).
- staging: vt6656: Fix drivers TBTT timing counter (git-fixes).
- staging: vt6656: Don't set RCR_MULTICAST or RCR_BROADCAST by
  default (git-fixes).
- iio: core: remove extra semi-colon from
  devm_iio_device_register() macro (git-fixes).
- iio: adc: ti-ads8344: properly byte swap value (git-fixes).
- iio: st_sensors: rely on odr mask to know if odr can be set
  (git-fixes).
- iio: xilinx-xadc: Make sure not exceed maximum samplerate
  (git-fixes).
- iio: xilinx-xadc: Fix sequencer configuration for aux channels
  in simultaneous mode (git-fixes).
- iio: xilinx-xadc: Fix clearing interrupt when enabling trigger
  (git-fixes).
- iio: xilinx-xadc: Fix ADC-B powerdown (git-fixes).
- iio: adc: stm32-adc: fix sleep in atomic context (git-fixes).
- iio:ad7797: Use correct attribute_group (git-fixes).
- staging: gasket: Fix incongruency in handling of sysfs entries
  creation (git-fixes).
- commit 4fa06ba
* Mon Apr 27 2020 lyan@suse.com
- KVM: s390: vsie: Fix delivery of addressing exceptions
  (bsc#1133021).
- commit 2daae50
* Sun Apr 26 2020 tiwai@suse.de
- ALSA: pcm: oss: Place the plugin buffer overflow checks
  correctly (for 5.7) (bsc#1170522).
- commit b4d1953
* Sat Apr 25 2020 tiwai@suse.de
- ALSA: hda: Always use jackpoll helper for jack update after
  resume (git-fixes).
- ALSA: hda/realtek - Add new codec supported for ALC245
  (git-fixes).
- ALSA: usb-audio: Fix usb audio refcnt leak when getting spdif
  (git-fixes).
- ALSA: usb-audio: Add connector notifier delegation (git-fixes).
- ASoC: wm8960: Fix wrong clock after suspend & resume
  (git-fixes).
- ASoC: rsnd: Fix "status check failed" spam for multi-SSI
  (git-fixes).
- ASoC: rsnd: Don't treat master SSI in multi SSI setup as parent
  (git-fixes).
- ASoC: meson: axg-card: fix codec-to-codec link setup
  (git-fixes).
- ASoC: dapm: fixup dapm kcontrol widget (git-fixes).
- ASoC: SOF: Intel: add min/max channels for SSP on
  Baytrail/Broadwell (git-fixes).
- ASoC: rsnd: Fix HDMI channel mapping for multi-SSI mode
  (git-fixes).
- ASoC: rsnd: Fix parent SSI start/stop in multi-SSI mode
  (git-fixes).
- ASoC: codecs: hdac_hdmi: Fix incorrect use of
  list_for_each_entry (git-fixes).
- ASoC: topology: Fix endianness issue (git-fixes).
- ASoC: q6dsp6: q6afe-dai: add missing channels to MI2S DAIs
  (git-fixes).
- ASoC: sgtl5000: Fix VAG power-on handling (git-fixes).
- ASoC: madera: Remove a couple of stray blank lines (git-fixes).
- ASoC: qcom: common: Silence duplicate parse error messages
  (git-fixes).
- soc/stm/stm32_sub_sai: Add missing '\n' in log messages
  (git-fixes).
- ASoC: tas571x: disable regulators on failed probe (git-fixes).
- ASoC: topology: Check return value of soc_tplg_dai_config
  (git-fixes).
- ASoC: topology: Check return value of pcm_new_ver (git-fixes).
- ASoC: topology: Check soc_tplg_add_route return value
  (git-fixes).
- ASoC: topology: Check return value of soc_tplg_*_create
  (git-fixes).
- ASoC: topology: Check return value of soc_tplg_create_tlv
  (git-fixes).
- ALSA: usb-audio: Apply async workaround for Scarlett 2i4 2nd
  gen (git-fixes).
- ALSA: usx2y: Fix potential NULL dereference (git-fixes).
- ALSA: usb-audio: Add quirk for Focusrite Scarlett 2i2
  (git-fixes).
- ALSA: usb-audio: Add static mapping table for ALC1220-VB-based
  mobos (git-fixes).
- ALSA: hda: Remove ASUS ROG Zenith from the blacklist
  (git-fixes).
- ALSA: hda/realtek - Fix unexpected init_amp override
  (git-fixes).
- ALSA: usb-audio: Filter out unsupported sample rates on
  Focusrite devices (git-fixes).
- ALSA: hda/hdmi: Add module option to disable audio component
  binding (git-fixes).
- commit 9aa515f
* Fri Apr 24 2020 mkubecek@suse.cz
- config: clean up s390x/zfcpdump
  Sync some config options in s390x/zfcpdump with SLE15-SP2. These did differ
  from SLE15-SP2 without apparent reason (for zfcpdump, that is):
  - FRONTSWAP (y -> n)
  - CMA (y -> n)
  - ZPOOL (y -> n)
  - REGULATOR (y -> n)
  - HARDENED_USERCOPY (y -> n)
  - CRYPTO (y -> n)
  - CRC_T10DIF (y -> n)
- commit 118d550
* Fri Apr 24 2020 msuchanek@suse.de
- Update
  patches.suse/powerpc-pseries-ddw-Extend-upper-limit-for-huge-DMA-.patch
  (FATE#327775 bsc#1142685 bsc#1167867 ltc#179509 ltc#184616).
- commit 54d9eaa
* Thu Apr 23 2020 dwagner@suse.de
- scsi: qla2xxx: check UNLOADING before posting async work
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: set UNLOADING before waiting for session deletion
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: Fix regression warnings (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: Remove non functional code (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- scsi: qla2xxx: add ring buffer for tracing debug logs
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bsc#1157169).
- commit 0ed2831
* Thu Apr 23 2020 dwagner@suse.de
- Fix meta data for FC-NVME-2 patches
  The branch of the maintainer got rebased. Update the commit id accordingly.
- commit e17d7e2
* Thu Apr 23 2020 tzimmermann@suse.de
- Revert "drm/panel: simple: Add support for Sharp LQ150X1LG11 panels" (bsc#1152472)
- commit 5a48ac0
* Thu Apr 23 2020 tzimmermann@suse.de
- drm/sun4i: dsi: Remove incorrect use of runtime PM (bsc#1152472)
  * manual patch refresh
- commit 1f5ded0
* Thu Apr 23 2020 tzimmermann@suse.de
- fbcon: fix null-ptr-deref in fbcon_switch (bsc#1152472)
- commit a5735e6
* Thu Apr 23 2020 shung-hsi.yu@suse.com
- net: fec_ptp: Use platform_get_irq_xxx_optional() to avoid
  error message (bsc#1161695).
- net: fec_main: Use platform_get_irq_byname_optional() to avoid
  error message (bsc#1161695).
- commit 7080d97
* Wed Apr 22 2020 tiwai@suse.de
- irqchip/mbigen: Free msi_desc on device teardown (git-fixes).
- i2c: altera: use proper variable to hold errno (git-fixes).
- i2c: designware: platdrv: Remove DPM_FLAG_SMART_SUSPEND flag
  on BYT and CHT (git-fixes).
- drm/amd/powerplay: force the trim of the mclk dpm_levels if
  OD is enabled (git-fixes).
- watchdog: sp805: fix restart handler (git-fixes).
- mac80211: fix race in ieee80211_register_hw() (git-fixes).
- mac80211_hwsim: Use kstrndup() in place of kasprintf()
  (git-fixes).
- commit 158e556
* Wed Apr 22 2020 tiwai@suse.de
- Revert ACPI EC patch that was reverted in stable tree
  Delete:
  patches.suse/ACPI-EC-Do-not-clear-boot_ec_is_ecdt-in-acpi_ec_add.patch.
- commit 4ca2cd1
* Wed Apr 22 2020 mbenes@suse.cz
- objtool: Make BP scratch register warning more robust
  (bsc#1169514).
- commit 21d4b08
* Wed Apr 22 2020 mbenes@suse.cz
- objtool: Fix switch table detection in .text.unlikely
  (bsc#1169514).
- commit c2b49a3
* Wed Apr 22 2020 tbogendoerfer@suse.de
- ionic: fix unused assignment (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: add dynamic_debug header (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- commit 61e55e9
* Wed Apr 22 2020 tbogendoerfer@suse.de
- net/mlx5e: Fix nest_level for vlan pop action (bsc#1154353).
- ionic: set station addr only if needed (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: replay filters after fw upgrade (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- net: icmp6: do not select saddr from iif when route has prefsrc
  set (bsc#1154353).
- commit da058f0
* Tue Apr 21 2020 oneukum@suse.com
- PCI: endpoint: Fix for concurrent memory allocation in OB
  address region (git-fixes).
- commit efb90c5
* Tue Apr 21 2020 oneukum@suse.com
- mmc: sdhci-of-at91: fix memleak on clk_get failure (git-fixes).
- commit df10885
* Tue Apr 21 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/ext4-Avoid-freeing-inodes-on-dirty-list.patch
  patches.suse/fs-Avoid-leaving-freed-inode-on-dirty-list.patch
  patches.suse/writeback-Export-inode_io_list_del.patch
- commit 9d7a667
* Tue Apr 21 2020 nstange@suse.de
- icmp: allow icmpv6_ndo_send to work with CONFIG_IPV6=n
  (bsc#1169021 jsc#SLE-12250).
- commit 8129fee
* Tue Apr 21 2020 nstange@suse.de
- crypto: arm64/poly1305 - ignore build files (bsc#1169021
  jsc#SLE-12250).
- commit 5860f7d
* Tue Apr 21 2020 tiwai@suse.de
- Update references for ptp security fixes (CVE-2020-10690, bsc#1170056)
- commit 0efc222
* Tue Apr 21 2020 oneukum@suse.com
- padata: always acquire cpu_hotplug_lock before pinst->lock
  (git-fixes).
- commit d5448e4
* Tue Apr 21 2020 oneukum@suse.com
- padata: validate cpumask without removed CPU during offline
  (git-fixes).
- commit e4437ab
* Tue Apr 21 2020 jack@suse.cz
- ext4: Avoid freeing inodes on dirty list (bsc#1168423).
- writeback: Export inode_io_list_del() (bsc#1168423).
- fs: Avoid leaving freed inode on dirty list (bsc#1168423).
- commit 86af897
* Tue Apr 21 2020 jslaby@suse.cz
- PCI: endpoint: Fix for concurrent memory allocation in OB
  address region (git-fixes).
- PCI: endpoint: Cast the page number to phys_addr_t (git-fixes).
- commit 3e58a3a
* Tue Apr 21 2020 mhocko@suse.com
- mm: set vm_next and vm_prev to NULL in vm_area_dup()
  (bnc#1169681).
- Revert "mm/rmap.c: reuse mergeable anon_vma as parent when fork"
  (bnc#1169681).
- commit f7b4d10
* Tue Apr 21 2020 glin@suse.com
- bpf: Prevent re-mmap()'ing BPF map as writable for initially
  r/o mapping (bsc#1155518).
- xsk: Fix out of boundary write in __xsk_rcv_memcpy
  (bsc#1155518).
- kbuild, btf: Fix dependencies for DEBUG_INFO_BTF (bsc#1155518).
- commit ac4792a
* Mon Apr 20 2020 nstange@suse.de
- wireguard: noise: error out precomputed DH during handshake
  rather than config (bsc#1169021 jsc#SLE-12250).
- commit e14e578
* Mon Apr 20 2020 nstange@suse.de
- wireguard: receive: remove dead code from default packet type
  case (bsc#1169021 jsc#SLE-12250).
- commit c43a23b
* Mon Apr 20 2020 nstange@suse.de
- wireguard: queueing: account for skb->protocol==0 (bsc#1169021
  jsc#SLE-12250).
- commit 9e6b83e
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: test using new 64-bit time_t (bsc#1169021
  jsc#SLE-12250).
- commit 60756ac
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: remove duplicated include <sys/types.h>
  (bsc#1169021 jsc#SLE-12250).
- commit b51ae0c
* Mon Apr 20 2020 nstange@suse.de
- wireguard: socket: remove extra call to synchronize_net
  (bsc#1169021 jsc#SLE-12250).
- commit 182535b
* Mon Apr 20 2020 nstange@suse.de
- wireguard: send: account for mtu=0 devices (bsc#1169021
  jsc#SLE-12250).
- commit 2f73731
* Mon Apr 20 2020 nstange@suse.de
- wireguard: receive: reset last_under_load to zero (bsc#1169021
  jsc#SLE-12250).
- commit 5207bec
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: reduce complexity and fix make races
  (bsc#1169021 jsc#SLE-12250).
- commit 9718224
* Mon Apr 20 2020 nstange@suse.de
- wireguard: device: use icmp_ndo_send helper (bsc#1169021
  jsc#SLE-12250).
- commit 76ba369
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: tie socket waiting to target pid
  (bsc#1169021 jsc#SLE-12250).
- commit bf1d7e5
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: cleanup CONFIG_ENABLE_WARN_DEPRECATED
  (bsc#1169021 jsc#SLE-12250).
- commit fe77b94
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: ensure non-addition of peers with failed
  precomputation (bsc#1169021 jsc#SLE-12250).
- commit ad7678e
* Mon Apr 20 2020 nstange@suse.de
- wireguard: noise: reject peers with low order public keys
  (bsc#1169021 jsc#SLE-12250).
- commit 8542988
* Mon Apr 20 2020 nstange@suse.de
- wireguard: allowedips: fix use-after-free in
  root_remove_peer_lists (bsc#1169021 jsc#SLE-12250).
- commit 2be5b62
* Mon Apr 20 2020 nstange@suse.de
- net: introduce skb_list_walk_safe for skb segment walking
  (bsc#1169021 jsc#SLE-12250).
- commit 1ec4578
* Mon Apr 20 2020 nstange@suse.de
- wireguard: socket: mark skbs as not on list when receiving
  via gro (bsc#1169021 jsc#SLE-12250).
- commit a45554a
* Mon Apr 20 2020 nstange@suse.de
- wireguard: queueing: do not account for pfmemalloc when clearing
  skb header (bsc#1169021 jsc#SLE-12250).
- commit dd22191
* Mon Apr 20 2020 nstange@suse.de
- wireguard: selftests: remove ancient kernel compatibility code
  (bsc#1169021 jsc#SLE-12250).
- commit e478c39
* Mon Apr 20 2020 nstange@suse.de
- wireguard: allowedips: use kfree_rcu() instead of call_rcu()
  (bsc#1169021 jsc#SLE-12250).
- commit 8c0e1e0
* Mon Apr 20 2020 nstange@suse.de
- wireguard: main: remove unused include <linux/version.h>
  (bsc#1169021 jsc#SLE-12250).
- commit 3a111bf
* Mon Apr 20 2020 nstange@suse.de
- wireguard: global: fix spelling mistakes in comments
  (bsc#1169021 jsc#SLE-12250).
- commit 79a082d
* Mon Apr 20 2020 mkubecek@suse.cz
- Update
  patches.suse/tcp-dccp-fix-possible-race-__inet_lookup_established.patch
  references (add bsc#1151794).
- commit 0f4b072
* Mon Apr 20 2020 colyli@suse.de
- block: Fix partition support for host aware zoned block devices
  (git fixes (block layer)).
- commit 2826707
* Mon Apr 20 2020 msuchanek@suse.de
- powerpc/sstep: Fix DS operand in ld encoding to appropriate
  value (bsc#1065729).
- commit ffe7728
* Mon Apr 20 2020 colyli@suse.de
- block: fix busy device checking in blk_drop_partitions again
  (git fixes (block layer)).
- scsi: sd_sbc: Fix sd_zbc_report_zones() (git fixes (block
  layer)).
- block: allow partitions on host aware zone devices (git fixes
  (block layer)).
- block: refactor rescan_partitions (bsc#1169493).
- null_blk: Fix zoned command return code (git fixes (block
  layer)).
- commit 2eec3ac
* Mon Apr 20 2020 tabraham@suse.com
- EDAC: skx_common: downgrade message importance on missing PCI
  device (bsc#1165581).
- commit 33acab9
* Mon Apr 20 2020 colyli@suse.de
- rbd: call rbd_dev_unprobe() after unwatching and flushing
  notifies (git fixes (block layer)).
- commit b8a8f93
* Mon Apr 20 2020 colyli@suse.de
- rbd: avoid a deadlock on header_rwsem when flushing notifies
  (git fixes (block layer)).
- commit 39eb136
* Mon Apr 20 2020 colyli@suse.de
- block: fix busy device checking in blk_drop_partitions (git
  fixes (block layer)).
- commit a502c37
* Mon Apr 20 2020 mbenes@suse.cz
- tracing: Fix the race between registering 'snapshot' event
  trigger and triggering 'snapshot' operation (git-fixes).
- commit e9b7241
* Mon Apr 20 2020 colyli@suse.de
- dm writecache: add cond_resched to avoid CPU hangs (git fixes
  (block layer)).
- dm integrity: fix a crash with unusually large tag size (git
  fixes (block layer)).
- dm zoned: remove duplicate nr_rnd_zones increase in
  dmz_init_zone() (git fixes (block layer)).
- commit bae04d0
* Mon Apr 20 2020 colyli@suse.de
- Revert "bcache: ignore pending signals when creating gc and
  allocator thread" (git fixes (block layer)).
- commit 389cb15
* Mon Apr 20 2020 colyli@suse.de
- block: rework zone reporting (git fixes (block layer)).
- Refresh for the above change,
  patches.suse/dm-zoned-reduce-overhead-of-backing-device-checks.patch.
- commit e2e1ac1
* Mon Apr 20 2020 mbenes@suse.cz
- tracing: Disable trace_printk() on post poned tests (git-fixes).
- commit a1f20fd
* Mon Apr 20 2020 colyli@suse.de
- null_blk: clean up report zones (git fixes (block layer)).
- null_blk: clean up the block device operations (git fixes
  (block layer)).
- block: Remove partition support for zoned block devices (git
  fixes (block layer)).
- commit 47f4ca0
* Mon Apr 20 2020 colyli@suse.de
- block: Simplify report zones execution (git fixes (block
  layer)).
- block: cleanup the !zoned case in blk_revalidate_disk_zones
  (git fixes (block layer)).
- block: Enhance blk_revalidate_disk_zones() (git fixes (block
  layer)).
- block: add zone open, close and finish operations (git fixes
  (block layer)).
- commit c73ea39
* Mon Apr 20 2020 colyli@suse.de
- block: Simplify REQ_OP_ZONE_RESET_ALL handling (git fixes
  (block layer)).
- block: Remove REQ_OP_ZONE_RESET plugging (git fixes (block
  layer)).
- commit 1d004e0
* Mon Apr 20 2020 colyli@suse.de
- dm: make dm_table_find_target return NULL (git fixes (block
  layer)).
- null_blk: fix inline misuse (git fixes (block layer)).
- null_blk: create a helper for zoned devices (git fixes
  (block layer)).
- null_blk: move duplicate code to callers (git fixes (block
  layer)).
- commit 9efd841
* Mon Apr 20 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/ibmvfc-don-t-send-implicit-logouts-prior-to-NPIV-log.patch
- commit cb5e73f
* Mon Apr 20 2020 neilb@suse.de
- fs/filesystems.c: downgrade user-reachable WARN_ONCE() to
  pr_warn_once() (bsc#1163463).
- commit 399801b
* Fri Apr 17 2020 tiwai@suse.de
- ALSA: hda: call runtime_allow() for all hda controllers
  (git-fixes).
- ALSA: hda: Explicitly permit using autosuspend if runtime PM
  is supported (git-fixes).
- ALSA: hda: Skip controller resume if not needed (git-fixes).
- ALSA: hda: Keep the controller initialization even if no codecs
  found (git-fixes).
- ALSA: hda: Release resources at error in delayed probe
  (git-fixes).
- ALSA: hda: Honor PM disablement in PM freeze and thaw_noirq ops
  (git-fixes).
- ALSA: hda: Don't release card at firmware loading error
  (git-fixes).
- ALSA: usb-audio: Check mapping at creating connector controls,
  too (git-fixes).
- ALSA: usb-audio: Don't create jack controls for PCM terminals
  (git-fixes).
- ALSA: usb-audio: Don't override ignore_ctl_error value from
  the map (git-fixes).
- ALSA: usb-audio: Filter error from connector kctl ops, too
  (git-fixes).
- ALSA: hda/realtek - Enable the headset mic on Asus FX505DT
  (git-fixes).
- commit 8a08089
* Fri Apr 17 2020 tiwai@suse.de
- arm, bpf: Fix offset overflow for BPF_MEM BPF_DW (git-fixes).
- nl80211: fix NL80211_ATTR_FTM_RESPONDER policy (git-fixes).
- net: phy: micrel: use genphy_read_status for KSZ9131
  (git-fixes).
- arm, bpf: Fix bugs with ALU64 {RSH, ARSH} BPF_K shift by 0
  (git-fixes).
- keys: Fix proc_keys_next to increase position index (git-fixes).
- drm/amdgpu: unify fw_write_wait for new gfx9 asics (git-fixes).
- libata: Return correct status in sata_pmp_eh_recover_pm()
  when ATA_DFLAG_DETACH is set (git-fixes).
- Input: i8042 - add Acer Aspire 5738z to nomux list (git-fixes).
- net: phy: micrel: kszphy_resume(): add delay after
  genphy_resume() before accessing PHY registers (git-fixes).
- vfio: platform: Switch to platform_get_irq_optional()
  (git-fixes).
- PCI: Add boot interrupt quirk mechanism for Xeon chipsets
  (git-fixes).
- ALSA: doc: Document PC Beep Hidden Register on Realtek ALC256
  (git-fixes).
- drm/scheduler: fix rare NULL ptr race (git-fixes).
- drm/dp_mst: Fix clearing payload state on topology disable
  (git-fixes).
- crypto: ccree - dec auth tag size from cryptlen map (git-fixes).
- crypto: ccree - only try to map auth tag if needed (git-fixes).
- crypto: ccree - protect against empty or NULL scatterlists
  (git-fixes).
- irqchip/gic-v4: Provide irq_retrigger to avoid circular locking
  dependency (git-fixes).
- ACPI: EC: Do not clear boot_ec_is_ecdt in acpi_ec_add()
  (git-fixes).
- acpi/x86: ignore unspecified bit positions in the ACPI global
  lock field (git-fixes).
- firmware: fix a double abort case with fw_load_sysfs_fallback
  (git-fixes).
- usb: dwc3: core: add support for disabling SS instances in
  park mode (git-fixes).
- xhci: bail out early if driver can't accress host in resume
  (git-fixes).
- media: venus: firmware: Ignore secure call error on first resume
  (git-fixes).
- media: allegro: fix type of gop_length in channel_create message
  (git-fixes).
- media: i2c: ov5695: Fix power on and off sequences (git-fixes).
- media: ti-vpe: cal: fix disable_irqs to only the intended target
  (git-fixes).
- media: venus: hfi_parser: Ignore HEVC encoding for V1
  (git-fixes).
- pstore/platform: fix potential mem leak if pstore_init_fs failed
  (git-fixes).
- tpm: Don't make log failures fatal (git-fixes).
- i2c: pca-platform: Use platform_irq_get_optional (git-fixes).
- i2c: st: fix missing struct parameter description (git-fixes).
- bus: sunxi-rsb: Return correct data when mixing 16-bit and
  8-bit reads (git-fixes).
- soc: fsl: dpio: register dpio irq handlers after dpio create
  (git-fixes).
- Input: tm2-touchkey - add support for Coreriver TC360 variant
  (git-fixes).
- i2c: jz4780: silence log flood on txabrt (git-fixes).
- mmc: sdhci-of-esdhc: fix esdhc_reset() for different controller
  versions (git-fixes).
- cpufreq: Cancel policy update work scheduled before freeing
  (git-fixes).
- commit e5ee52f
* Fri Apr 17 2020 ailiop@suse.com
- xfs: reflink should force the log out if mounted with wsync
  (git-fixes).
- commit 2e7b82b
* Fri Apr 17 2020 ailiop@suse.com
- xfs: factor out a new xfs_log_force_inode helper (git-fixes).
- commit 9fd128e
* Fri Apr 17 2020 ailiop@suse.com
- xfs: don't write a corrupt unmount record to force summary
  counter recalc (git-fixes).
- commit 6add31e
* Fri Apr 17 2020 ailiop@suse.com
- xfs: don't allow log IO to be throttled (git-fixes).
- commit 925e53f
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove some stale comments from the log code (git-fixes).
- commit b869987
* Fri Apr 17 2020 ailiop@suse.com
- xfs: refactor unmount record writing (git-fixes).
- commit 60c7c2f
* Fri Apr 17 2020 ailiop@suse.com
- xfs: merge xlog_commit_record with xlog_write_done (git-fixes).
- commit 6169e00
* Fri Apr 17 2020 ailiop@suse.com
- xfs: split xlog_ticket_done (git-fixes).
- commit 3540978
* Fri Apr 17 2020 ailiop@suse.com
- xfs: kill XLOG_TIC_INITED (git-fixes).
- commit 1c52baf
* Fri Apr 17 2020 ailiop@suse.com
- xfs: refactor and split xfs_log_done() (git-fixes).
- commit 27f5afa
* Fri Apr 17 2020 ailiop@suse.com
- xfs: re-order initial space accounting checks in xlog_write
  (git-fixes).
- commit d2e492c
* Fri Apr 17 2020 ailiop@suse.com
- xfs: don't try to write a start record into every iclog
  (git-fixes).
- commit 62148c3
* Fri Apr 17 2020 ailiop@suse.com
- xfs: shutdown on failure to add page to log bio (git-fixes).
- commit cb7737c
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove xlog_state_want_sync (git-fixes).
- commit 99f092d
* Fri Apr 17 2020 ailiop@suse.com
- xfs: move the ioerror check out of xlog_state_clean_iclog
  (git-fixes).
- commit f23116d
* Fri Apr 17 2020 ailiop@suse.com
- xfs: refactor xlog_state_clean_iclog (git-fixes).
- commit e43b3ed
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove the aborted parameter to xlog_state_done_syncing
  (git-fixes).
- commit eaff4cc
* Fri Apr 17 2020 ailiop@suse.com
- xfs: simplify log shutdown checking in xfs_log_release_iclog
  (git-fixes).
- commit d486a9f
* Fri Apr 17 2020 ailiop@suse.com
- xfs: simplify the xfs_log_release_iclog calling convention
  (git-fixes).
- commit 5b62921
* Fri Apr 17 2020 ailiop@suse.com
- xfs: factor out a xlog_wait_on_iclog helper (git-fixes).
- commit 371f1e3
* Fri Apr 17 2020 ailiop@suse.com
- xfs: merge xlog_cil_push into xlog_cil_push_work (git-fixes).
- commit 22531f1
* Fri Apr 17 2020 ailiop@suse.com
- xfs: cleanup xfs_log_unmount_write (git-fixes).
- commit 47964dc
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove dead code from xfs_log_unmount_write (git-fixes).
- commit 15d084c
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove the unused return value from xfs_log_unmount_write
  (git-fixes).
- commit 7daf110
* Fri Apr 17 2020 ailiop@suse.com
- xfs: don't ever return a stale pointer from __xfs_dir3_free_read
  (git-fixes).
- commit e98d8e7
* Fri Apr 17 2020 ailiop@suse.com
- xfs: fix buffer corruption reporting when
  xfs_dir3_free_header_check fails (git-fixes).
- commit 0d51de1
* Fri Apr 17 2020 ailiop@suse.com
- xfs: add a function to deal with corrupt buffers post-verifiers
  (git-fixes).
- commit cdad8b5
* Fri Apr 17 2020 ailiop@suse.com
- xfs: fix iclog release error check race with shutdown
  (git-fixes).
- commit 2814941
* Fri Apr 17 2020 ailiop@suse.com
- xfs: don't check for AG deadlock for realtime files in bunmapi
  (git-fixes).
- commit fc993c5
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove the XLOG_STATE_DO_CALLBACK state (git-fixes).
- commit c72277f
* Fri Apr 17 2020 ailiop@suse.com
- xfs: turn ic_state into an enum (git-fixes).
- commit 1f9b2d3
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove the unused XLOG_STATE_ALL and XLOG_STATE_UNUSED
  flags (git-fixes).
- commit 22ec56e
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove dead ifdef XFSERRORDEBUG code (git-fixes).
- commit f73533e
* Fri Apr 17 2020 ailiop@suse.com
- xfs: call xlog_state_release_iclog with l_icloglock held
  (git-fixes).
- commit e2ae7c9
* Fri Apr 17 2020 ailiop@suse.com
- xfs: move the locking from xlog_state_finish_copy to the callers
  (git-fixes).
- commit 4fc8e18
* Fri Apr 17 2020 ailiop@suse.com
- xfs: remove the unused ic_io_size field from xlog_in_core
  (git-fixes).
- commit cc60ace
* Fri Apr 17 2020 ailiop@suse.com
- xfs: pass the correct flag to xlog_write_iclog (git-fixes).
- commit d0ba340
* Thu Apr 16 2020 mbenes@suse.cz
- x86/xen: fix booting 32-bit pv guest (bsc#1071995).
- commit de745ab
* Thu Apr 16 2020 mbenes@suse.cz
- x86/xen: Make the secondary CPU idle tasks reliable
  (bsc#1071995).
- commit b937a33
* Thu Apr 16 2020 mbenes@suse.cz
- x86/xen: Make the boot CPU idle task reliable (bsc#1071995).
- commit 7555345
* Thu Apr 16 2020 oneukum@suse.com
- Update
  patches.suse/media-stv06xx-add-missing-descriptor-sanity-checks.patch
  (bsc#1168854). Pending CVE request, adding bsc so that it is not lost
- commit 3e4aa5f
* Thu Apr 16 2020 oneukum@suse.com
- Update
  patches.suse/media-xirlink_cit-add-missing-descriptor-sanity-chec.patch
  (bsc#1168952). Pending CVE request, adding bsc so this is not lost.
- commit 98ac2ff
* Thu Apr 16 2020 msuchanek@suse.de
- tools/test/nvdimm: Fix out of tree build (bsc#1156395).
- commit bec0a07
* Thu Apr 16 2020 msuchanek@suse.de
- Refresh patches.suse/tools-testing-nvdimm-Fix-compilation-failure-without.patch.
- commit 48bddf2
* Thu Apr 16 2020 msuchanek@suse.de
- ibmvfc: don't send implicit logouts prior to NPIV login
  (bsc#1169625 ltc#184611).
- commit 1026f14
* Thu Apr 16 2020 jslaby@suse.cz
- net: systemport: fix index check to avoid an array out of
  bounds access (networking-stable-20_03_14).
- taprio: Fix sending packets without dequeueing them
  (networking-stable-20_03_14).
- net: memcg: fix lockdep splat in inet_csk_accept()
  (networking-stable-20_03_14).
- net: dsa: Don't instantiate phylink for CPU/DSA ports unless
  needed (networking-stable-20_03_14).
- net/packet: tpacket_rcv: do not increment ring index on drop
  (networking-stable-20_03_14).
- net: fec: validate the new settings in fec_enet_set_coalesce()
  (networking-stable-20_03_14).
- net: macsec: update SCI upon MAC address change
  (networking-stable-20_03_14).
- ipv6/addrconf: call ipv6_mc_up() for non-Ethernet interface
  (networking-stable-20_03_14).
- net: memcg: late association of sock to memcg
  (networking-stable-20_03_14).
- ipvlan: do not use cond_resched_rcu() in
  ipvlan_process_multicast() (networking-stable-20_03_14).
- cgroup, netclassid: periodically release file_lock on classid
  updating (networking-stable-20_03_14).
- ipvlan: add cond_resched_rcu() while processing muticast backlog
  (networking-stable-20_03_14).
- ipvlan: don't deref eth hdr before checking it's set
  (networking-stable-20_03_14).
- sfc: detach from cb_page in efx_copy_channel()
  (networking-stable-20_03_14).
- inet_diag: return classid for all socket types
  (networking-stable-20_03_14).
- net: stmmac: dwmac1000: Disable ACS if enhanced descs are not
  used (networking-stable-20_03_14).
- gre: fix uninit-value in __iptunnel_pull_header
  (networking-stable-20_03_14).
- bonding/alb: make sure arp header is pulled before accessing it
  (networking-stable-20_03_14).
- net: nfc: fix bounds checking bugs on "pipe"
  (networking-stable-20_03_14).
- net: hns3: fix a not link up issue when fibre port supports
  autoneg (networking-stable-20_03_14).
- slip: make slhc_compress() more robust against malicious packets
  (networking-stable-20_03_14).
- net: dsa: fix phylink_start()/phylink_stop() calls
  (networking-stable-20_03_14).
- selftests/net/fib_tests: update addr_metric_test for peer
  route testing (networking-stable-20_03_14).
- net/ipv6: remove the old peer route if change it to a new one
  (networking-stable-20_03_14).
- net/ipv6: need update peer route when modify metric
  (networking-stable-20_03_14).
- net: taprio: add missing attribute validation for txtime delay
  (networking-stable-20_03_14).
- net: fq: add missing attribute validation for orphan mask
  (networking-stable-20_03_14).
- fib: add missing attribute validation for tun_id
  (networking-stable-20_03_14).
- devlink: validate length of region addr/len
  (networking-stable-20_03_14).
- devlink: validate length of param values
  (networking-stable-20_03_14).
- net/ipv6: use configured metric when add peer route
  (networking-stable-20_03_14).
- net: dsa: mv88e6xxx: fix lockup on warm boot
  (networking-stable-20_03_14).
- netlink: Use netlink header as base to calculate bad attribute
  offset (networking-stable-20_03_14).
- r8152: check disconnect status after long sleep
  (networking-stable-20_03_14).
- commit 4f8bc32
* Wed Apr 15 2020 ddiss@suse.de
- patches.suse/0005-scsi-target-use-the-stack-for-XCOPY-passthrough-cmds.patch:
  (bsc#1164514).
- patches.suse/0004-scsi-target-increase-XCOPY-I-O-size.patch:
  (bsc#1164514).
- patches.suse/0003-scsi-target-avoid-per-loop-XCOPY-buffer-allocations.patch:
  (bsc#1164514).
- patches.suse/0002-scsi-target-drop-xcopy-DISK-BLOCK-LENGTH-debug.patch:
  (bsc#1164514).
- patches.suse/0001-scsi-target-use-define-for-xcopy-descriptor-len.patch:
  (bsc#1164514).
- commit 35bd511
* Wed Apr 15 2020 jroedel@suse.de
- PCI/AER: Rationalize error status register clearing
  (bsc#1169263).
- PCI/DPC: Expose dpc_process_error(), dpc_reset_link() for use
  by EDR (bsc#1169263).
- PCI/AER: Add pci_aer_raw_clear_status() to unconditionally
  clear Error Status (bsc#1169263).
- PCI/DPC: Cache DPC capabilities in pci_init_capabilities()
  (bsc#1169263).
- PCI/ERR: Return status of pcie_do_recovery() (bsc#1169263).
- PCI/ERR: Remove service dependency in pcie_do_recovery()
  (bsc#1169263).
- PCI/DPC: Move DPC data into struct pci_dev (bsc#1169263).
- commit 01b5293
* Wed Apr 15 2020 bp@suse.de
- x86/microcode/AMD: Increase microcode PATCH_MAX_SIZE
  (bsc#1169005).
- commit 92271b2
* Wed Apr 15 2020 aaptel@suse.com
- Refresh
  patches.suse/cifs-ignore-cached-share-root-handle-closing-errors.patch.
- commit c6f232e
* Wed Apr 15 2020 ptesarik@suse.cz
- s390/zcrypt: use kvmalloc instead of kmalloc for 256k alloc
  (bsc#1169003 LTC#185029).
- commit efd0cc2
* Wed Apr 15 2020 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix H_CEDE return code for nested guests
  (bsc#1156395).
- commit 30499af
* Wed Apr 15 2020 mkubecek@suse.cz
- update patches metadata
- update upstream references and resort:
  patches.suse/nvme-fc-Revert-add-module-to-ops-template-to-allow-m.patch
  patches.suse/nvme-fcloop-fix-deallocation-of-working-context.patch
  patches.suse/nvme-fix-deadlock-caused-by-ANA-update-wrong-locking.patch
  patches.suse/nvme-inherit-stable-pages-constraint-in-the-mpath-st.patch
  patches.suse/nvme-rdma-Replace-comma-with-a-semicolon.patch
  patches.suse/nvmet-fc-fix-typo-in-comment.patch
  patches.suse/nvmet-fix-NULL-dereference-when-removing-a-referral.patch
  patches.suse/nvmet-rdma-fix-bonding-failover-possible-NULL-deref.patch
- fix Patch-mainline:
  patches.suse/nvme-Check-for-readiness-more-quickly-to-speed-up-bo.patch
  patches.suse/nvme-code-cleanup-nvme_identify_ns_desc.patch
  patches.suse/nvme-fabrics-Use-scnprintf-for-avoiding-potential-bu.patch
  patches.suse/nvme-log-additional-message-for-controller-status.patch
  patches.suse/nvme-multipath-do-not-reset-on-unknown-status.patch
  patches.suse/nvme-remove-unused-return-code-from-nvme_alloc_ns.patch
  patches.suse/nvme-tcp-Set-SO_PRIORITY-for-all-host-sockets.patch
  patches.suse/nvmet-check-sscanf-value-for-subsys-serial-attr.patch
  patches.suse/nvmet-configfs-code-cleanup.patch
  patches.suse/nvmet-make-ctrl-id-configurable.patch
  patches.suse/nvmet-make-ctrl-model-configurable.patch
  patches.suse/nvmet-tcp-set-SO_PRIORITY-for-accepted-sockets.patch
- commit 66e0350
* Wed Apr 15 2020 yousaf.kaukab@suse.com
- Revert "cpufreq: arm64: prevent module unload (bsc#1168476)."
  This reverts commit 59dc6e32df1940481a3955a2caf2e64f735a0831.
- commit c363644
* Wed Apr 15 2020 msuchanek@suse.de
- rpm/check-for-config-changes: Ignore CONFIG_LD_VERSION
- commit e60242e
* Wed Apr 15 2020 jslaby@suse.cz
- udp: rehash on disconnect (networking-stable-20_03_01).
- net/tls: Fix to avoid gettig invalid tls record
  (networking-stable-20_03_01).
- Revert "net: dev: introduce support for sch BYPASS for lockless
  qdisc" (networking-stable-20_03_01).
- qede: Fix race between rdma destroy workqueue and link change
  event (networking-stable-20_03_01).
- sctp: move the format error check out of __sctp_sf_do_9_1_abort
  (networking-stable-20_03_01).
- net: sched: correct flower port blocking
  (networking-stable-20_03_01).
- net: dsa: b53: Ensure the default VID is untagged
  (networking-stable-20_03_01).
- net: macb: ensure interface is not suspended on at91rm9200
  (networking-stable-20_03_01).
- net: fib_rules: Correctly set table field when table number
  exceeds 8 bits (networking-stable-20_03_01).
- ipv6: Fix nlmsg_flags when splitting a multipath route
  (networking-stable-20_03_01).
- ipv6: Fix route replacement with dev-only route
  (networking-stable-20_03_01).
- commit 7f4f9c7
* Wed Apr 15 2020 ggherdovich@suse.cz
- x86, sched: Don't enable static key when starting secondary CPUs
  (bsc#1169518).
- commit 7e982dc
* Wed Apr 15 2020 yousaf.kaukab@suse.com
- thermal/drivers/cpufreq_cooling: Fix return of
  cpufreq_set_cur_state (bsc#1168476).
- commit 1bb91ae
* Wed Apr 15 2020 bp@suse.de
- EDAC/mce_amd: Make fam_ops static global (jsc#SLE-11833).
- commit a2a7430
* Wed Apr 15 2020 mkoutny@suse.com
- cgroup: cgroup_procs_next should increase position index
  (bsc#1169524).
- commit e8538bb
* Wed Apr 15 2020 mbenes@suse.cz
- btrfs: separate definition of assertion failure handlers
  (bsc#1169514).
- commit 47cc410
* Wed Apr 15 2020 mbenes@suse.cz
- objtool: Add relocation check for alternative sections
  (bsc#1169514).
- commit ddcfb2d
* Wed Apr 15 2020 ggherdovich@suse.cz
- Refresh
  patches.suse/x86-sched-Account-for-CPUs-with-less-than-4-cores-in.patch.
- commit fe74002
* Wed Apr 15 2020 mbenes@suse.cz
- objtool: Add is_static_jump() helper (bsc#1169514).
- commit d3f8210
* Wed Apr 15 2020 jslaby@suse.cz
- selftests/powerpc: Turn off timeout setting for benchmarks,
  dscr, signal, tm (git-fixes).
- selftests/powerpc: Add tlbie_test in .gitignore (git-fixes).
- tools: gpio: Fix out-of-tree build regression (git-fixes).
- commit 32ce8b5
* Wed Apr 15 2020 bp@suse.de
- EDAC/amd64: Drop some family checks for newer systems
  (jsc#SLE-11833).
- commit c3845bc
* Wed Apr 15 2020 yousaf.kaukab@suse.com
- ahci: Add support for Amazon's Annapurna Labs SATA controller
  (bsc#1169013).
- commit 4296517
* Wed Apr 15 2020 jslaby@suse.cz
- blacklist.conf: add three cleanups
- commit cf5b455
* Wed Apr 15 2020 bp@suse.de
- EDAC/amd64: Add family ops for Family 19h Models 00h-0Fh
  (jsc#SLE-11833).
- commit 6188ac8
* Wed Apr 15 2020 jslaby@suse.cz
- PCI: dwc: Fix dw_pcie_ep_raise_msix_irq() to get correct MSI-X
  table address (git-fixes).
- PCI: endpoint: Fix ->set_msix() to take BIR and offset as
  arguments (git-fixes).
- commit c6334e6
* Wed Apr 15 2020 tzimmermann@suse.de
- fbmem: Adjust indentation in fb_prepare_logo and fb_blank (bsc#1152489)
- commit bcb3d94
* Wed Apr 15 2020 mkubecek@suse.cz
- config: refresh
  No functional change, only menu structure comments and one line move.
- commit cbac380
* Wed Apr 15 2020 tbogendoerfer@suse.de
- cxgb4: free MQPRIO resources in shutdown path (jsc#SLE-8389).
- RDMA/hns: Fix a wrong judgment of return value (jsc#SLE-8449).
- RDMA/hns: Fix wrong judgments of udata->outlen (jsc#SLE-8449).
- RDMA/core: Remove the duplicate header file (jsc#SLE-8449).
- IB/mlx5: Optimize u64 division on 32-bit arches (jsc#SLE-8446).
- RDMA/mlx5: Prevent UMR usage with RO only when we have RO caps
  (jsc#SLE-8446).
- net: hns3: fix for fraglist SKB headlen not handling correctly
  (bsc#1154353).
- net: hns3: drop the WQ_MEM_RECLAIM flag when allocating WQ
  (bsc#1154353).
- selftests/bpf: Fix test_progs's parsing of test numbers
  (bsc#1154353).
- bnxt_en: Fix "fw.mgmt" and "fw.nsci" info via devlink info_get
  cb (jsc#SLE-8371 bsc#1153274).
- taprio: do not use BIT() in TCA_TAPRIO_ATTR_FLAG_* definitions
  (bsc#1154353).
- sfc: fix XDP-redirect in this driver (jsc#SLE-8314).
- libbpf: Ignore incompatible types with matching name during
  CO-RE relocation (bsc#1154353).
- sfc: remove unused variable 'efx_default_channel_type'
  (jsc#SLE-8314).
- commit 655c6cc
* Wed Apr 15 2020 tzimmermann@suse.de
- OMAP: DSS2: remove non-zero check on variable r (bsc#1152489)
- commit 82ee31e
* Wed Apr 15 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline ("Queued" is for patches going to get into mainline):
  patches.suse/drm-i915-Fix-ref-mutex-deadlock-in-i915_active_wait.patch
- commit f1086d5
* Wed Apr 15 2020 mkubecek@suse.cz
- supported.conf: cleanup
  Make the comment consistent with the rest of the file.
- commit c905a51
* Wed Apr 15 2020 bp@suse.de
- EDAC/mce_amd: Always load on SMCA systems (jsc#SLE-11833).
- commit f330d60
* Wed Apr 15 2020 mkubecek@suse.cz
- improve patch metadata
- make Patch-mainline more explicit:
  patches.suse/bfq-tune-slice-idle.patch
- commit 6fb07af
* Wed Apr 15 2020 jslaby@suse.cz
- Refresh
  patches.suse/0001-efi-fix-a-race-and-a-buffer-overflow-while-reading-e.patch.
  One more update on an upstreamed patch.
- commit 0bed50c
* Wed Apr 15 2020 jslaby@suse.cz
- Refresh
  patches.suse/KEYS-reaching-the-keys-quotas-correctly.patch.
- Refresh
  patches.suse/PCI-pciehp-Add-DMI-table-for-in-band-presence-detect.patch.
- Refresh
  patches.suse/PCI-pciehp-Disable-in-band-presence-detect-when-poss.patch.
- Refresh
  patches.suse/PCI-pciehp-Wait-for-PDS-if-in-band-presence-is-disab.patch.
- Refresh
  patches.suse/edac-mc-carve-out-error-increment-into-a-separate-function.patch.
- Refresh
  patches.suse/edac-mc-change-mci-device-removal-to-use-put_device.patch.
- Refresh
  patches.suse/edac-mc-determine-mci-pointer-from-the-error-descriptor.patch.
- Refresh
  patches.suse/edac-mc-pass-the-error-descriptor-to-error-reporting-functions.patch.
- Refresh
  patches.suse/edac-mc-remove-detail-string-and-cleanup-error-string-generation.patch.
- Refresh
  patches.suse/edac-mc-remove-enable_per_layer_report-function-argument.patch.
- Refresh patches.suse/edac-mc-remove-per-layer-counters.patch.
- Refresh
  patches.suse/edac-mc-reorder-functions-edac_mc_alloc.patch.
- Refresh
  patches.suse/edac-mc-report-unknown-memory-on-too-many-dimm-labels-found.patch.
- Refresh
  patches.suse/edac-mc-split-edac_mc_alloc-into-smaller-functions.patch.
- Refresh
  patches.suse/edac-store-error-type-in-struct-edac_raw_error_desc.patch.
- Refresh
  patches.suse/efi-x86-add-tpm-related-efi-tables-to-unencrypted-mapping-checks.patch.
- Refresh
  patches.suse/x86-amd_nb-char-amd64-agp-use-amd_nb_num-accessor.patch.
- Refresh
  patches.suse/x86-intel_pstate-Handle-runtime-turbo-disablement-en.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance-on-ATOM.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance-on-ATOM_GOLDMONT.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance-on-SK.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance-on-XE.patch.
- Refresh
  patches.suse/x86-sched-Add-support-for-frequency-invariance.patch.
  Update upstream status and sort them all.
- commit 6e97756
* Tue Apr 14 2020 bp@suse.de
- x86/amd_nb: Add Family 19h PCI IDs (jsc#SLE-11833).
- Refresh
  patches.suse/x86-amd_nb-char-amd64-agp-use-amd_nb_num-accessor.patch.
- commit ffdd1b6
* Tue Apr 14 2020 rgoldwyn@suse.com
- exfat: add Kconfig and Makefile (JSC#SLE-9489).
  Also changes config files and supported.conf to incorporate exfat
- exfat: add nls operations (JSC#SLE-9489).
- exfat: add misc operations (JSC#SLE-9489).
- exfat: add exfat cache (JSC#SLE-9489).
- exfat: add bitmap operations (JSC#SLE-9489).
- exfat: add fat entry operations (JSC#SLE-9489).
- exfat: add file operations (JSC#SLE-9489).
- exfat: add directory operations (JSC#SLE-9489).
- exfat: add inode operations (JSC#SLE-9489).
- exfat: add super block operations (JSC#SLE-9489).
- exfat: add in-memory and on-disk structures and headers
  (JSC#SLE-9489).
- vfs: Create fs_context-aware mount_bdev() replacement
  (JSC#SLE-9489).
- commit 3b40335
* Tue Apr 14 2020 lhenriques@suse.com
- ceph: fix snapshot directory timestamps (jsc#SES-1134).
- ceph: wait for async creating inode before requesting new max
  size (jsc#SES-1134).
- ceph: don't skip updating wanted caps when cap is stale
  (jsc#SES-1134).
- ceph: request new max size only when there is auth cap
  (jsc#SES-1134).
- ceph: cleanup return error of try_get_cap_refs() (jsc#SES-1134).
- ceph: return ceph_mdsc_do_request() errors from __get_parent()
  (jsc#SES-1134).
- ceph: check all mds' caps after page writeback (jsc#SES-1134).
- ceph: update i_requested_max_size only when sending cap msg
  to auth mds (jsc#SES-1134).
- ceph: simplify calling of ceph_get_fmode() (jsc#SES-1134).
- ceph: remove delay check logic from ceph_check_caps()
  (jsc#SES-1134).
- ceph: consider inode's last read/write when calculating wanted
  caps (jsc#SES-1134).
- ceph: always renew caps if mds_wanted is insufficient
  (jsc#SES-1134).
- ceph: update dentry lease for async create (jsc#SES-1134).
- ceph: attempt to do async create when possible (jsc#SES-1134).
- ceph: cache layout in parent dir on first sync create
  (jsc#SES-1134).
- ceph: add new MDS req field to hold delegated inode number
  (jsc#SES-1134).
- ceph: decode interval_sets for delegated inos (jsc#SES-1134).
- ceph: make ceph_fill_inode non-static (jsc#SES-1134).
- ceph: perform asynchronous unlink if we have sufficient caps
  (jsc#SES-1134).
- ceph: don't take refs to want mask unless we have all bits
  (jsc#SES-1134).
- ceph: cap tracking for async directory operations
  (jsc#SES-1134).
- ceph: make __take_cap_refs non-static (jsc#SES-1134).
- ceph: add infrastructure for waiting for async create to
  complete (jsc#SES-1134).
- ceph: track primary dentry link (jsc#SES-1134).
- ceph: add flag to designate that a request is asynchronous
  (jsc#SES-1134).
- ceph: more caps.c lockdep assertions (jsc#SES-1134).
- ceph: clean up kick_flushing_inode_caps() (jsc#SES-1134).
- libceph: directly skip to the end of redirect reply
  (jsc#SES-1134).
- libceph: simplify ceph_monc_handle_map() (jsc#SES-1134).
- ceph: return ETIMEDOUT errno to userland when request timed out
  (jsc#SES-1134).
- ceph: re-org copy_file_range and fix some error paths
  (jsc#SES-1134).
- ceph: move to a dedicated slabcache for mds requests
  (jsc#SES-1134).
- ceph: reorganize fields in ceph_mds_request (jsc#SES-1134).
- ceph: replace zero-length array with flexible-array member
  (jsc#SES-1134).
- ceph: check if file lock exists before sending unlock request
  (jsc#SES-1134).
- ceph: move ceph_osdc_{read,write}pages to ceph.ko
  (jsc#SES-1134).
- ceph: don't ClearPageChecked in ceph_invalidatepage()
  (jsc#SES-1134).
- libceph: drop CEPH_DEFINE_SHOW_FUNC (jsc#SES-1134).
- ceph: check inode type for
  CEPH_CAP_FILE_{CACHE,RD,REXTEND,LAZYIO} (jsc#SES-1134).
- ceph: add refcounting for Fx caps (jsc#SES-1134).
- ceph: register MDS request with dir inode from the start
  (jsc#SES-1134).
- commit 5555f78
* Tue Apr 14 2020 jack@suse.cz
- bfq: Tune slice_idle (bsc#1168838).
- commit cd1f013
* Tue Apr 14 2020 oneukum@suse.com
- mt76: mt76x02: fix coverage_class type (git-fixes).
- commit 17e4f02
* Tue Apr 14 2020 oneukum@suse.com
- blacklist.conf: cosmetic change only
- commit c7bf43b
* Tue Apr 14 2020 oneukum@suse.com
- padata: fix uninitialized return value in padata_replace()
  (git-fixes).
- commit 3620d06
* Tue Apr 14 2020 msuchanek@suse.de
- Revert "powerpc/64: irq_work avoid interrupt when called with
  hardware irqs enabled" (bsc#1156395).
- commit 6d41ca5
* Tue Apr 14 2020 tiwai@suse.de
- drm/i915: Fix ref->mutex deadlock in i915_active_wait()
  (stable-5.4.y).
- commit 35b215a
* Tue Apr 14 2020 tiwai@suse.de
- drm/sun4i: dsi: Avoid hotplug race with DRM driver bind
  (git-fixes).
- commit 725ce8a
* Tue Apr 14 2020 tiwai@suse.de
- pwm: pca9685: Fix PWM/GPIO inter-operation (git-fixes).
- pwm: renesas-tpu: Fix late Runtime PM enablement (git-fixes).
- pwm: rcar: Fix late Runtime PM enablement (git-fixes).
- pwm: meson: Fix confusing indentation (git-fixes).
- pwm: bcm2835: Dynamically allocate base (git-fixes).
- ipmi: fix hung processes in __get_guid() (git-fixes).
- drm/i915/gem: Flush all the reloc_gpu batch (git-fixes).
- platform/chrome: cros_ec_rpmsg: Fix race with host event
  (git-fixes).
- acpi/nfit: improve bounds checking for 'func' (git-fixes).
- drm/sun4i: dsi: Allow binding the host without a panel
  (git-fixes).
- drm/sun4i: dsi: Use NULL to signify "no panel" (git-fixes).
- drm/sun4i: dsi: Remove unused drv from driver context
  (git-fixes).
- Bluetooth: RFCOMM: fix ODEBUG bug in rfcomm_dev_ioctl
  (git-fixes).
- commit 3034d25
* Tue Apr 14 2020 kbuild@suse.de
- Delete patches.kabi/* workarounds
- commit 70f1868
* Tue Apr 14 2020 mkubecek@suse.cz
- supported.conf: fix order of entries (sort)
- commit ead7ceb
* Tue Apr 14 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-lpfc-Change-default-SCSI-LUN-QD-to-64.patch
  patches.suse/scsi-lpfc-Fix-crash-after-handling-a-pci-error.patch
  patches.suse/scsi-lpfc-Fix-crash-in-target-side-cable-pulls-hitti.patch
  patches.suse/scsi-lpfc-Fix-erroneous-cpu-limit-of-128-on-I-O-stat.patch
  patches.suse/scsi-lpfc-Fix-kasan-slab-out-of-bounds-error-in-lpfc.patch
  patches.suse/scsi-lpfc-Fix-lockdep-error-register-non-static-key.patch
  patches.suse/scsi-lpfc-Fix-lpfc-overwrite-of-sg_cnt-field-in-nvme.patch
  patches.suse/scsi-lpfc-Fix-scsi-host-template-for-SLI3-vports.patch
  patches.suse/scsi-lpfc-Fix-update-of-wq-consumer-index-in-lpfc_sl.patch
  patches.suse/scsi-lpfc-Make-debugfs-ktime-stats-generic-for-NVME-.patch
  patches.suse/scsi-lpfc-Remove-prototype-FIPS-DSS-options-from-SLI.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.0.patch
- commit 8c32594
* Tue Apr 14 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patch out of sorted section:
  patches.suse/cifs-ignore-cached-share-root-handle-closing-errors.patch
- commit d749c1b
* Tue Apr 14 2020 jgross@suse.com
- xen/blkfront: fix memory allocation flags in
  blkfront_setup_indirect() (bsc#1168486).
- commit 97066fb
* Mon Apr 13 2020 dbueso@suse.de
- time/namespace: Add max_time_namespaces ucount (bsc#1164648,jsc#SLE-11493).
- commit 15be678
* Mon Apr 13 2020 colyli@suse.de
- blacklist.conf: add following commits, disable them temporarily,
  a4a8d286586d4b28c8517a51db8d86954aadc74b
  3918e0667bbac99400b44fa5aef3f8be2eeada4a
  When add them back when dm back port done.
- commit 23511fe
* Mon Apr 13 2020 colyli@suse.de
- lib/raid6/test: fix build on distros whose /bin/sh is not bash
  (git fixes (block layer)).
- Revert "dm: always call blk_queue_split() in dm_process_bio()"
  (git fixes (block layer)).
- coresight: do not use the BIT() macro in the UAPI header
  (git fixes (block layer)).
- pid: Improve the comment about waiting in zap_pid_ns_processes
  (git fixes (block layer)).
- dm verity fec: fix memory leak in verity_fec_dtr (git fixes
  (block layer)).
- null_blk: Fix the null_add_dev() error path (git fixes
  (block layer)).
- blk-mq: Keep set->nr_hw_queues and set->map[].nr_queues in sync
  (git fixes (block layer)).
- dm: fix congested_fn for request-based device (git fixes
  (block layer)).
- dm zoned: Fix reference counter initial value of chunk works
  (git fixes (block layer)).
- dm writecache: verify watermark during resume (git fixes
  (block layer)).
- dm: report suspended device during destroy (git fixes (block
  layer)).
- dm cache: fix a crash due to incorrect work item cancelling
  (git fixes (block layer)).
- dm integrity: fix invalid table returned due to argument count
  mismatch (git fixes (block layer)).
- dm integrity: fix a deadlock due to offloading to an incorrect
  workqueue (git fixes (block layer)).
- dm integrity: fix recalculation when moving from journal mode
  to bitmap mode (git fixes (block layer)).
- lib/stackdepot.c: fix global out-of-bounds in stack_slabs
  (git fixes (block layer)).
- drivers/block/zram/zram_drv.c: fix error return codes not
  being returned in writeback_store (git fixes (block layer)).
- dm: fix potential for q->make_request_fn NULL pointer (git fixes
  (block layer)).
- dm thin metadata: use pool locking at end of
  dm_pool_metadata_close (git fixes (block layer)).
- dm writecache: fix incorrect flush sequence when doing SSD
  mode commit (git fixes (block layer)).
- dm crypt: fix benbi IV constructor crash if used in
  authenticated mode (git fixes (block layer)).
- dm space map common: fix to ensure new block isn't already in
  use (git fixes (block layer)).
- dm zoned: support zone sizes smaller than 128MiB (git fixes
  (block layer)).
- padata: update documentation (git fixes (block layer)).
- block: fix an integer overflow in logical block size (git fixes
  (block layer)).
- compat_ioctl: block: handle Persistent Reservations (git fixes
  (block layer)).
- dm thin: Flush data device before committing metadata (git fixes
  (block layer)).
- dm thin metadata: Add support for a pre-commit callback (git
  fixes (block layer)).
- dm btree: increase rebalance threshold in __rebalance2()
  (git fixes (block layer)).
- dm mpath: remove harmful bio-based optimization (git fixes
  (block layer)).
- block: fix memleak of bio integrity data (git fixes (block
  layer)).
- block: sed-opal: fix sparse warning: convert __be64 data
  (git fixes (block layer)).
- block: sed-opal: fix sparse warning: obsolete array init
  (git fixes (block layer)).
- commit 7a0b356
* Sun Apr 12 2020 mkubecek@suse.cz
- constrants: fix malformed XML
  Closing tag of an element is "</foo>", not "<foo/>".
  Fixes: 8b37de2eb835 ("rpm/constraints.in: Increase memory for kernel-docs")
- commit 4a8ca28
* Sun Apr 12 2020 tiwai@suse.de
- Refresh patches.suse/ALSA-pcm-oss-Fix-regression-by-buffer-overflow-fix-a.patch
  Mark the upstream commit id to be ignored; the chery-picked patch supercedes it
- commit 5705a3a
* Sat Apr 11 2020 tiwai@suse.de
- ASoC: cs4270: pull reset GPIO low then high (git-fixes).
- ASoC: rt5645: Add platform-data for Medion E1239T (git-fixes).
- ASoC: Intel: bytcr_rt5640: Add quirk for MPMAN MPWIN895CL tablet
  (git-fixes).
- ASoC: Intel: atom: Fix uninitialized variable compiler warning
  (git-fixes).
- ASoC: Intel: atom: Check drv->lock is locked in
  sst_fill_and_send_cmd_unlocked (git-fixes).
- ASoC: Intel: atom: Take the drv->lock mutex before calling
  sst_send_slot_map() (git-fixes).
- ASoC: topology: use name_prefix for new kcontrol (git-fixes).
- ASoC: rt5682: Fix build error without CONFIG_I2C (git-fixes).
- ASoC: dpcm: allow start or stop during pause for backend
  (git-fixes).
- ASoC: dapm: connect virtual mux with default value (git-fixes).
- ASoC: Intel: bdw-rt5677: Remove ignore_suspend flag from SSP0
  dai link (git-fixes).
- ASoC: Intel: haswell: Remove ignore_suspend flag from SSP0
  dai link (git-fixes).
- ASoC: Intel: broadwell: Remove ignore_suspend flag from SSP0
  dai link (git-fixes).
- ASoC: fix regwmask (git-fixes).
- ALSA: hda: Add driver blacklist (git-fixes).
- ALSA: usb-audio: Add mixer workaround for TRX40 and co
  (git-fixes).
- ALSA: hda/realtek - Add quirk for MSI GL63 (git-fixes).
- ALSA: ice1724: Fix invalid access for enumerated ctl items
  (git-fixes).
- ALSA: hda: Fix potential access overflow in beep helper
  (git-fixes).
- ALSA: hda/realtek - Add HP new mute led supported for ALC236
  (git-fixes).
- ALSA: hda/realtek - Add supported new mute Led for HP
  (git-fixes).
- ALSA: usb-audio: Add registration quirk for Kingston HyperX
  Cloud Alpha S (git-fixes).
- ALSA: usb-audio: Add Pioneer DJ DJM-250MK2 quirk (git-fixes).
- ALSA: pcm: oss: Fix regression by buffer overflow fix (again)
  (git-fixes).
- ALSA: hda/realtek - Add quirk for Lenovo Carbon X1 8th gen
  (git-fixes).
- commit fa71152
* Thu Apr  9 2020 dwagner@suse.de
- crypto: arm/poly1305 - add artifact to .gitignore files
  (bsc#1169021 jsc#SLE-12250).
- crypto: x86/curve25519 - leave r12 as spare register
  (bsc#1169021 jsc#SLE-12250).
- crypto: x86/curve25519 - replace with formally verified
  implementation (bsc#1169021 jsc#SLE-12250).
- crypto: arm64/chacha - correctly walk through blocks
  (bsc#1169021 jsc#SLE-12250).
- crypto: x86/curve25519 - support assemblers with no adx support
  (bsc#1169021 jsc#SLE-12250).
- crypto: chacha20poly1305 - prevent integer overflow on large
  input (bsc#1169021 jsc#SLE-12250).
- icmp: introduce helper for nat'd source address in network
  device context (bsc#1169021 jsc#SLE-12250).
- crypto: Kconfig - allow tests to be disabled when manager is
  disabled (bsc#1169021 jsc#SLE-12250).
- wireguard: selftests: import harness makefile for test suite
  (bsc#1169021 jsc#SLE-12250).
- net: WireGuard secure network tunnel (bsc#1169021
  jsc#SLE-12250).
- Update config files: enable WIREGUARD on all archs.
- Update supported.conf: mark new drivers/net/wireguard as unsupported.
- crypto: arm/chacha - fix build failured when kernel mode NEON
  is disabled (bsc#1169021 jsc#SLE-12250).
- crypto: x86/poly1305 - emit does base conversion itself
  (bsc#1169021 jsc#SLE-12250).
- crypto: chacha20poly1305 - add back missing test vectors and
  test chunking (bsc#1169021 jsc#SLE-12250).
- crypto: x86/poly1305 - fix .gitignore typo (bsc#1169021
  jsc#SLE-12250).
- crypto: curve25519 - Fix selftest build error (bsc#1169021
  jsc#SLE-12250).
- Update supported.conf: mark new lib/crypto/libcurve25519-generic as
  unsupported.
- crypto: {arm,arm64,mips}/poly1305 - remove redundant
  non-reduction from emit (bsc#1169021 jsc#SLE-12250).
- crypto: x86/poly1305 - wire up faster implementations for kernel
  (bsc#1169021 jsc#SLE-12250).
- Update config files: a value of 11 is now required for
  CRYPTO_LIB_POLY1305_RSIZE on x86_64.
- crypto: x86/poly1305 - import unmodified cryptogams
  implementation (bsc#1169021 jsc#SLE-12250).
- crypto: poly1305 - add new 32 and 64-bit generic versions
  (bsc#1169021 jsc#SLE-12250).
- crypto: lib/curve25519 - re-add selftests (bsc#1169021
  jsc#SLE-12250).
- crypto: chacha - fix warning message in header file (bsc#1169021
  jsc#SLE-12250).
- crypto: arm/curve25519 - add arch-specific key generation
  function (bsc#1169021 jsc#SLE-12250).
- crypto: arch - conditionalize crypto api in arch glue for lib
  code (bsc#1169021 jsc#SLE-12250).
- crypto: lib/chacha20poly1305 - use chacha20_crypt() (bsc#1169021
  jsc#SLE-12250).
- crypto: x86/chacha - only unregister algorithms if registered
  (bsc#1169021 jsc#SLE-12250).
- crypto: chacha_generic - remove unnecessary setkey() functions
  (bsc#1169021 jsc#SLE-12250).
- crypto: lib/chacha20poly1305 - reimplement crypt_from_sg()
  routine (bsc#1169021 jsc#SLE-12250).
- crypto: chacha20poly1305 - import construction and selftest
  from Zinc (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_CHACHA20POLY1305 on all archs.
- Update supported.conf: mark new lib/crypto/libchacha20poly1305 as
  unsupported.
- crypto: arm/curve25519 - wire up NEON implementation
  (bsc#1169021 jsc#SLE-12250).
- crypto: arm/curve25519 - import Bernstein and Schwabe's
  Curve25519 ARM implementation (bsc#1169021 jsc#SLE-12250).
- crypto: curve25519 - x86_64 library and KPP implementations
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_CURVE25519_X86 on x86_64, which in
  turn implies CRYPTO_ARCH_HAVE_LIB_CURVE25519.
- Update supported.conf: mark new arch/x86/crypto/curve25519-x86_64 as
  unsupported.
- crypto: lib/curve25519 - work around Clang stack spilling issue
  (bsc#1169021 jsc#SLE-12250).
- crypto: curve25519 - implement generic KPP driver (bsc#1169021
  jsc#SLE-12250).
- Update config files: enable CRYPTO_CURVE25519 on all archs.
- Update supported.conf: mark new crypto/curve25519-generic as unsupported.
- crypto: curve25519 - add kpp selftest (bsc#1169021
  jsc#SLE-12250).
- crypto: curve25519 - generic C library implementations
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_CURVE25519 on all archs, which in
  turn implies CRYPTO_LIB_CURVE25519_GENERIC.
- Update supported.conf: mark new lib/crypto/libcurve25519 as unsupported.
- crypto: blake2s - x86_64 SIMD implementation (bsc#1169021
  jsc#SLE-12250).
- Update config files: enable CRYPTO_BLAKE2S_X86 on x86_64, which in turn
  implies CRYPTO_ARCH_HAVE_LIB_BLAKE2S.
- Update supported.conf: mark new arch/x86/crypto/blake2s-x86_64 as
  unsupported.
- crypto: blake2s - implement generic shash driver (bsc#1169021
  jsc#SLE-12250).
- Update config files: enable CRYPTO_BLAKE2S on all archs.
- Update supported.conf: mark new crypto/blake2s_generic as unsupported.
- crypto: testmgr - add test cases for Blake2s (bsc#1169021
  jsc#SLE-12250).
- crypto: blake2s - generic C library implementation and selftest
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_BLAKE2S on all archs, which in
  turn implies CRYPTO_LIB_BLAKE2S_GENERIC.
- Update supported.conf: mark new lib/crypto/libblake2s and
  lib/crypto/libblake2s-generic as unsupported.
- crypto: mips/poly1305 - incorporate OpenSSL/CRYPTOGAMS optimized
  implementation (bsc#1169021 jsc#SLE-12250).
- crypto: arm/poly1305 - incorporate OpenSSL/CRYPTOGAMS NEON
  implementation (bsc#1169021 jsc#SLE-12250).
- crypto: arm64/poly1305 - incorporate OpenSSL/CRYPTOGAMS NEON
  implementation (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_POLY1305_NEON on arm64, which in turn
  implies CRYPTO_ARCH_HAVE_LIB_POLY1305;
  a value of 9 is required for the internal CRYPTO_LIB_POLY1305_RSIZE on
  arm64.
- Update supported.conf: mark new arch/arm64/crypto/poly1305-neon as
  unsupported.
- crypto: x86/poly1305 - expose existing driver as poly1305
  library (bsc#1169021 jsc#SLE-12250).
- Update config files: CRYPTO_POLY1305_X86_64 implies
  CRYPTO_ARCH_HAVE_LIB_POLY1305 on x86_64 now;
  a value of 4 is required for the internal CRYPTO_LIB_POLY1305_RSIZE on
  x86_64.
- crypto: x86/poly1305 - depend on generic library not generic
  shash (bsc#1169021 jsc#SLE-12250).
- crypto: poly1305 - expose init/update/final library interface
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_POLY1305 on all archs and set the
  internal CRYPTO_LIB_POLY1305_RSIZE to 1 (the common default value among
  all archs for now).
- crypto: x86/poly1305 - unify Poly1305 state struct with generic
  code (bsc#1169021 jsc#SLE-12250).
- crypto: poly1305 - move core routines into a separate library
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_POLY1305_GENERIC on all archs.
- Update supported.conf: mark new lib/crypto/libpoly1305 as supported.
- crypto: chacha - unexport chacha_generic routines (bsc#1169021
  jsc#SLE-12250).
- crypto: mips/chacha - wire up accelerated 32r2 code from Zinc
  (bsc#1169021 jsc#SLE-12250).
- crypto: mips/chacha - import 32r2 ChaCha code from Zinc
  (bsc#1169021 jsc#SLE-12250).
- crypto: arm/chacha - expose ARM ChaCha routine as library
  function (bsc#1169021 jsc#SLE-12250).
- crypto: arm/chacha - remove dependency on generic ChaCha driver
  (bsc#1169021 jsc#SLE-12250).
- crypto: arm/chacha - import Eric Biggers's scalar accelerated
  ChaCha code (bsc#1169021 jsc#SLE-12250).
- crypto: arm64/chacha - expose arm64 ChaCha routine as library
  function (bsc#1169021 jsc#SLE-12250).
- Update config files: CRYPTO_CHACHA20_NEON implies
  CRYPTO_ARCH_HAVE_LIB_CHACHA on arm64 now.
- crypto: arm64/chacha - depend on generic chacha library instead
  of crypto driver (bsc#1169021 jsc#SLE-12250).
- crypto: x86/chacha - expose SIMD ChaCha routine as library
  function (bsc#1169021 jsc#SLE-12250).
- Update config files: CRYPTO_CHACHA20_X86_64 implies
  CRYPTO_ARCH_HAVE_LIB_CHACHA on x86_64 now.
- crypto: x86/chacha - depend on generic chacha library instead
  of crypto driver (bsc#1169021 jsc#SLE-12250).
- crypto: chacha - move existing library code into lib/crypto
  (bsc#1169021 jsc#SLE-12250).
- Update config files: enable CRYPTO_LIB_CHACHA_GENERIC and
  CRYPTO_LIB_CHACHA on all archs.
- Update supported.conf: mark new lib/crypto/libchacha as unsupported.
- crypto: lib - tidy up lib/crypto Kconfig and Makefile
  (bsc#1169021 jsc#SLE-12250).
- commit 121a35e
* Thu Apr  9 2020 mgorman@suse.de
- cgroup, rstat: Revert "cgroup: Add memory barriers to plug
  cgroup_rstat_updated() race window" (bsc#1158748).
- commit f88fb2e
* Thu Apr  9 2020 oneukum@suse.com
- Refresh patches.suse/0001-kABI-more-hooks-for-PCI-changes.patch.
  (bsc#1168999)
  For some unknown reason (likely a macro), changing
  struct pci_fixup breaks things left and right.
  Removing the padding
- commit bbd0eda
* Thu Apr  9 2020 jwiesner@suse.com
- ipvlan: do not add hardware address of master to its unicast
  filter list (bsc#1137325).
- commit 51a58f4
* Thu Apr  9 2020 aaptel@suse.com
- cifs: ignore cached share root handle closing errors
  (bsc#1166780).
- commit 1f63b4d
* Thu Apr  9 2020 mgorman@suse.de
- Update config files to disable CONFIG_TRACE_IRQFLAGS (bsc#1169078).
- commit 35b5c01
* Thu Apr  9 2020 mkubecek@suse.cz
- kabi: drop kabi reference files (stop checking kabi)
  After the SLE15 SP2 release schedule update, it's too early to enforce
  kabi and there are some upcoming requests which either cannot be
  implemented without kabi change or would require too complicated hacks.
  Drop kabi reference files so that kabi won't be checked until they are
  added back again.
- commit 16aa8e7
* Thu Apr  9 2020 hare@suse.de
- lpfc: nvmet: Add Send LS Request and Abort LS Request support (bsc#1169045).
- lpfc: nvmet: Add support for NVME LS request hosthandle (bsc#1169045).
- lpfc: nvme: Add Receive LS Request and Send LS Response (bsc#1169045).
- lpfc: Refactor Send LS Response support (bsc#1169045).
- lpfc: Refactor Send LS Abort support (bsc#1169045).
- lpfc: Refactor Send LS Request support (bsc#1169045).
- lpfc: Refactor NVME LS receive handling (bsc#1169045).
- lpfc: Commonize lpfc_async_xchg_ctx state and flag (bsc#1169045).
- lpfc: Refactor nvmet_rcv_ctx to create lpfc_async_xchg_ctx (bsc#1169045).
- lpfc: Refactor lpfc nvme headers (bsc#1169045).
- nvme-fcloop: add target to host LS request support (bsc#1169045).
- nvme-fcloop: refactor to enable target to host LS (bsc#1169045).
- nvmet-fc: Add Disconnect Association Xmt support (bsc#1169045).
- nvmet-fc: rename ls_list to ls_rcv_list (bsc#1169045).
- nvmet-fc: track hostport handle for associations (bsc#1169045).
- nvmet-fc: perform small cleanups on unneeded checks (bsc#1169045).
- nvmet-fc: add LS failure messages (bsc#1169045).
- nvme-fc: Add Disconnect Association Rcv support (bsc#1169045).
- nvmet-fc: Update target for common definitions for LS (bsc#1169045).
- nvme-fc: Update header and host for common definitions for LS (bsc#1169045).
- nvme-fc: convert assoc_active flag to bit op (bsc#1169045).
- nvme-fc: Ensure private pointers are NULL if no data (bsc#1169045).
- nvmet-fc: Better size LS buffers (bsc#1169045).
- nvme-fc nvmet-fc: refactor for common LS definitions (bsc#1169045).
- nvme-fc and nvmet-fc: revise LLDD api for LS reception and LS (bsc#1169045).
- nvme-fc: Sync header to FC-NVME-2 rev 1.08 (bsc#1169045).
- nvme-fc: Revert "add module to ops template to allow module (bsc#1169045).
- nvme: fix deadlock caused by ANA update wrong locking (bsc#1169045).
- nvmet-rdma: fix bonding failover possible NULL deref (bsc#1169045).
- nvmet: fix NULL dereference when removing a referral (bsc#1169045).
- nvme: inherit stable pages constraint in the mpath stack (bsc#1169045).
- nvmet-fc: fix typo in comment (bsc#1169045).
- nvme-rdma: Replace comma with a semicolon (bsc#1169045).
- nvme-fcloop: fix deallocation of working context (bsc#1169045).
- commit afa84e7
* Thu Apr  9 2020 hare@suse.de
- scripts/git_sort/git_sort.py: Update nvme repositories
- commit 45cef90
* Thu Apr  9 2020 hare@suse.de
- nvme-fabrics: Use scnprintf() for avoiding potential buffer overflow (bsc#1161930).
- nvme-multipath: do not reset on unknown status (bsc#1161930).
- nvme: Check for readiness more quickly, to speed up boot time (bsc#1161930).
- nvme: log additional message for controller status (bsc#1161930).
- nvme: code cleanup nvme_identify_ns_desc() (bsc#1161930).
- nvmet-tcp: set MSG_MORE only if we actually have more to send (bsc#1161930).
- commit 0215ed6
* Thu Apr  9 2020 msuchanek@suse.de
- rpm/constraints.in: Increase memory for kernel-docs
  References: https://build.opensuse.org/request/show/792664
- commit 8b37de2
* Thu Apr  9 2020 hare@suse.de
- nvmet-tcp: set SO_PRIORITY for accepted sockets (bsc#1169045).
- nvme-tcp: Set SO_PRIORITY for all host sockets (bsc#1169045).
- nvmet: check sscanf value for subsys serial attr (bsc#1169045).
- nvmet: make ctrl model configurable (bsc#1169045).
- nvmet: make ctrl-id configurable (bsc#1169045).
- nvmet: configfs code cleanup (bsc#1169045).
- nvme: remove unused return code from nvme_alloc_ns (bsc#1169045).
- nvme-rdma: Avoid double freeing of async event data (bsc#1169045).
- nvme-pci: Hold cq_poll_lock while completing CQEs (bsc#1169045).
- nvme-multipath: Fix memory leak with ana_log_buf (bsc#1169045).
- nvme: Fix uninitialized-variable warning (bsc#1169045).
- nvme-pci: Use single IRQ vector for old Apple models (bsc#1169045).
- nvme/pci: Add sleep quirk for Samsung and Toshiba drives (bsc#1169045).
- nvme/pci: move cqe check after device shutdown (bsc#1169045).
- nvme: prevent warning triggered by nvme_stop_keep_alive (bsc#1169045).
- nvme/tcp: fix bug on double requeue when send fails (bsc#1169045).
- nvmet: update AEN list and array at one place (bsc#1169045).
- nvmet: Fix controller use after free (bsc#1169045).
- nvmet: Fix error print message at nvmet_install_queue (bsc#1169045).
- nvme-pci: remove nvmeq->tags (bsc#1169045).
- nvmet: fix dsm failure when payload does not match sgl (bsc#1169045).
- nvmet: fix per feat data len for get_feature (bsc#1169045).
- nvme/pci: Fix read queue count (bsc#1169045).
- nvme/pci Limit write queue sizes to possible cpus (bsc#1169045).
- nvme/pci: Fix write and poll queue types (bsc#1169045).
- nvme/pci: Remove last_cq_head (bsc#1169045).
- nvme: Namepace identification descriptor list is optional (bsc#1169045).
- commit 583ef0e
* Thu Apr  9 2020 jroedel@suse.de
- PCI: pciehp: Fix MSI interrupt race (bsc#1159037).
- commit 41635b6
* Thu Apr  9 2020 tiwai@suse.de
- Fix mmc CMD6 timeout spams (bsc#1169056)
  The patch
  patches.suse/mmc-core-Default-to-generic_cmd6_time-as-timeout-in-.patch.
  triggers spamming wrt MMC CMD6 timeout default.  This has been already
  reverted in stable queue, too, so let's kill it.
  This also requires the refresh of
  patches.suse/mmc-core-Allow-host-controllers-to-require-R1B-for-C.patch.
- commit d264c89
* Thu Apr  9 2020 hare@suse.de
- nvme-fc: fix double-free scenarios on hw queues (bsc#1169045).
- nvme: else following return is not needed (bsc#1169045).
- nvme: add error message on mismatching controller ids (bsc#1169045).
- nvme_fc: add module to ops template to allow module (bsc#1169045).
- nvme-fc: Avoid preallocating big SGL for data (bsc#1169045).
- nvme-rdma: Avoid preallocating big SGL for data (bsc#1169045).
- nvme: hwmon: add quirk to avoid changing temperature (bsc#1169045).
- nvme: hwmon: provide temperature min and max values for each (bsc#1169045).
- nvme: Discard workaround for non-conformant devices (bsc#1169045).
- commit ad5c1b6
* Thu Apr  9 2020 hare@suse.de
- nvme: Add hardware monitoring support (bsc#1169045).
- Update config files.
- commit 7065393
* Thu Apr  9 2020 hare@suse.de
- nvmet: Introduce common execute function for get_log_page and identify (bsc#1169045).
- commit 9f41df0
* Thu Apr  9 2020 jroedel@suse.de
- iommu/virtio: Fix freeing of incomplete domains (bsc#1169049).
- iommu/vt-d: Fix mm reference leak (bsc#1169050).
- iommu/amd: Fix the configuration of GCR3 table root pointer
  (bsc#1169048).
- iommu/vt-d: Fix page request descriptor size (bsc#1169051).
- KVM: x86: Fix CPUID range checks for Hypervisor and Centaur
  classes (bsc#1169052).
- KVM: x86: Trace the original requested CPUID function in
  kvm_cpuid() (bsc#1169053).
- commit 02f2b47
* Thu Apr  9 2020 hare@suse.de
- nvmet: stop using bio_set_op_attrs (bsc#1169045).
- nvmet: add plugging for read/write when ns is bdev (bsc#1169045).
- nvmet: clean up command parsing a bit (bsc#1169045).
- nvmet: fill discovery controller sn, fr and mn correctly (bsc#1169045).
- nvmet: Open code nvmet_req_execute() (bsc#1169045).
- nvmet: Remove the data_len field from the nvmet_req struct (bsc#1169045).
- nvmet: Introduce nvmet_dsm_len() helper (bsc#1169045).
- nvmet: Cleanup discovery execute handlers (bsc#1169045).
- nvmet-tcp: Don't set the request's data_len (bsc#1169045).
- nvmet-tcp: Don't check data_len in nvmet_tcp_map_data() (bsc#1169045).
- nvme: Introduce nvme_lba_to_sect() (bsc#1169045).
- nvme: Cleanup and rename nvme_block_nr() (bsc#1169045).
- nvme: move common call to nvme_cleanup_cmd to core layer (bsc#1169045).
- nvme: introduce "Command Aborted By host" status code (bsc#1169045).
- nvmet-rdma: add unlikely check at nvmet_rdma_map_sgl_keyed (bsc#1169045).
- nvmet: add unlikely check at nvmet_req_alloc_sgl (bsc#1169045).
- nvmet: use bio_io_error instead of duplicating it (bsc#1169045).
- nvme: introduce nvme_is_aen_req function (bsc#1169045).
- nvme-fc: ensure association_id is cleared regardless of a Disconnet LS (bsc#1169045).
- nvme-fc: clarify error messages (bsc#1169045).
- nvme-fc: Set new cmd set indicator in nvme-fc cmnd iu (bsc#1169045).
- nvme-fc and nvmet-fc: sync with FC-NVME-2 header changes (bsc#1169045).
- nvme-fc: Sync nvme-fc header to FC-NVME-2 (bsc#1169045).
- commit 2d3a577
* Thu Apr  9 2020 hare@suse.de
- nvme-multipath: remove unused groups_only mode in ana log (bsc#1169045).
- nvme: Wait for reset state when required (bsc#1169045).
- nvme: Prevent resets during paused controller state (bsc#1169045).
- nvme: Restart request timers in resetting state (bsc#1169045).
- nvme: Remove ADMIN_ONLY state (bsc#1169045).
- nvme-pci: Free tagset if no IO queues (bsc#1169045).
- nvme: retain split access workaround for capability reads (bsc#1169045).
- nvme: fix possible deadlock when nvme_update_formats fails (bsc#1169045).
- commit a98e6f9
* Thu Apr  9 2020 dwagner@suse.de
- scsi: core: avoid repetitive logging of device offline messages
  (bsc#1145929).
- commit 4217986
* Thu Apr  9 2020 wqu@suse.com
- btrfs: qgroup: Mark qgroup inconsistent if we're inherting
  snapshot to a new qgroup (bsc#1165823).
- commit f82cb6e
* Thu Apr  9 2020 neilb@suse.de
- SUNRPC: fix krb5p mount to provide large enough buffer in
  rq_rcvsize (bsc#1168236).
- commit 973a971
* Wed Apr  8 2020 mkubecek@suse.cz
- config: refresh
- commit 60a481d
* Wed Apr  8 2020 yousaf.kaukab@suse.com
- cpufreq: arm64: prevent module unload (bsc#1168476).
- commit 59dc6e3
* Wed Apr  8 2020 tiwai@suse.de
- misc: pci_endpoint_test: Fix to support > 10 pci-endpoint-test
  devices (git-fixes).
- pinctrl: sprd: Use the correct pin output configuration
  (git-fixes).
- pxa168fb: fix release function mismatch in probe failure
  (git-fixes).
- mt76: remove variable 'val' set but not used (git-fixes).
- irqchip/bcm2835: Quiesce IRQs left enabled by bootloader
  (git-fixes).
- iio: potentiostat: lmp9100: fix
  iio_triggered_buffer_{predisable,postenable} positions
  (git-fixes).
- iio: si1133: read 24-bit signed integer for measurement
  (git-fixes).
- staging: kpc2000: prevent underflow in cpld_reconfigure()
  (git-fixes).
- pstore: pstore_ftrace_seq_next should increase position index
  (git-fixes).
- libata: Remove extra scsi_host_put() in ata_scsi_add_hosts()
  (git-fixes).
- r8169: fix PHY driver check on platforms w/o module softdeps
  (git-fixes).
- i2c: nvidia-gpu: Handle timeout correctly in
  gpu_i2c_check_status() (git-fixes).
- geneve: move debug check after netdev unregister (git-fixes).
- lib/test_kasan.c: fix memory leak in kmalloc_oob_krealloc_more()
  (git-fixes).
- lib/ubsan: don't serialize UBSAN report (git-fixes).
- commit a79673f
* Wed Apr  8 2020 tiwai@suse.de
- drm/vc4: Fix HDMI mode validation (git-fixes).
- drm: amd/acp: fix broken menu structure (git-fixes).
- drm/v3d: Replace wait_for macros to remove use of msleep
  (git-fixes).
- drm/amd/display: Fix wrongly passed static prefix (git-fixes).
- drm: Remove PageReserved manipulation from drm_pci_alloc
  (git-fixes).
- drm/crc: Actually allow to change the crc source (git-fixes).
- drm/drm_dp_mst:remove set but not used variable 'origlen'
  (git-fixes).
- drm/amdgpu: fix typo for vcn1 idle check (git-fixes).
- drm/amd/display: Add link_rate quirk for Apple 15" MBP 2017
  (git-fixes).
- drm/bochs: downgrade pci_request_region failure from error to
  warning (git-fixes).
- drm/amdgpu: correct ROM_INDEX/DATA offset for VEGA20
  (git-fixes).
- commit 3d01994
* Wed Apr  8 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/slcan-Don-t-transmit-uninitialized-stack-data-in-pad.patch
- commit 26aaf48
* Wed Apr  8 2020 tiwai@suse.de
- thermal: devfreq_cooling: inline all stubs for
  CONFIG_DEVFREQ_THERMAL=n (git-fixes).
- thermal: qoriq: Fix a compiling issue (git-fixes).
- mfd: dln2: Fix sanity checking for endpoints (git-fixes).
- tun: Don't put_page() for all negative return values from XDP
  program (git-fixes).
- PCI/ERR: Update error status after reset_link() (git-fixes).
- PCI/ERR: Combine pci_channel_io_frozen cases (git-fixes).
- mei: me: add cedar fork device ids (git-fixes).
- extcon: axp288: Add wakeup support (git-fixes).
- fbdev: potential information leak in do_fb_ioctl() (git-fixes).
- watchdog: iTCO_wdt: Make ICH_RES_IO_SMI optional (git-fixes).
- watchdog: iTCO_wdt: Export vendorsupport (git-fixes).
- fat: fix uninit-memory access for partial initialized inode
  (git-fixes).
- commit 58be4d2
* Wed Apr  8 2020 ggherdovich@suse.cz
- x86, sched: Account for CPUs with less than 4 cores in
  freq. invariance (boo#1166664).
- commit 949f5c1
* Wed Apr  8 2020 ggherdovich@suse.cz
- x86, sched: Bail out of frequency invariance if base frequency
  is unknown (bsc#1167878).
- commit f094f17
* Tue Apr  7 2020 msuchanek@suse.de
- Refresh patches.suse/powerpc-pseries-Fix-MCE-handling-on-pseries.patch.
- commit 901c022
* Tue Apr  7 2020 msuchanek@suse.de
- s390x: zfcpdump: disable CONFIG_RELOCATABLE (bsc#1168847).
- commit 77366c6
* Tue Apr  7 2020 mkubecek@suse.cz
- series.conf: cleanup
- move into sorted section:
  patches.suse/slcan-Don-t-transmit-uninitialized-stack-data-in-pad.patch
- commit 6de7fc6
* Tue Apr  7 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/btrfs-qgroup-ensure-qgroup_rescan_running-is-only-se.patch
- commit 5232dd1
* Tue Apr  7 2020 mgorman@suse.de
- Update config files to disable CONFIG_UCLAMP_TASK (bsc#1168888).
- commit 00c1c4e
* Tue Apr  7 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patches out of sorted section
- commit 362f0b0
* Tue Apr  7 2020 oneukum@suse.com
- Update
  patches.suse/media-ov519-add-missing-endpoint-sanity-checks.patch
  (CVE-2020-11608 bsc#1168829). Added cve number
- commit a2db40e
* Tue Apr  7 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/Documentation-ABI-Add-ABI-documentation-for-sys-kern.patch
  patches.suse/Documentation-ABI-Mark-sys-kernel-fadump_-sysfs-file.patch
  patches.suse/cpufreq-powernv-Fix-unsafe-notifiers.patch
  patches.suse/cpufreq-powernv-Fix-use-after-free.patch
  patches.suse/powerpc-64-Prevent-stack-protection-in-early-boot.patch
  patches.suse/powerpc-64-Setup-a-paca-before-parsing-device-tree-e.patch
  patches.suse/powerpc-64-tm-Don-t-let-userspace-set-regs-trap-via-.patch
  patches.suse/powerpc-64s-Fix-section-mismatch-warnings-from-boot-.patch
  patches.suse/powerpc-book3s64-Fix-error-handling-in-mm_iommu_do_a.patch
  patches.suse/powerpc-drmem-avoid-NULL-pointer-dereference-when-dr.patch
  patches.suse/powerpc-fadump-Reorganize-sys-kernel-fadump_-sysfs-f.patch
  patches.suse/powerpc-fadump-sysfs-for-fadump-memory-reservation.patch
  patches.suse/powerpc-powernv-Move-core-and-fadump_release_opalcor.patch
  patches.suse/powerpc-pseries-Fix-of_read_drc_info_cell-to-point-a.patch
  patches.suse/powerpc-pseries-Handle-UE-event-for-memcpy_mcsafe.patch
  patches.suse/powerpc-smp-Use-nid-as-fallback-for-package_id.patch
  patches.suse/powerpc-vmlinux.lds-Explicitly-retain-.gnu.hash.patch
  patches.suse/powerpc-xive-Use-XIVE_BAD_IRQ-instead-of-zero-to-cat.patch
  patches.suse/sysfs-Wrap-__compat_only_sysfs_link_entry_to_kobj-fu.patch
- commit 895f36d
* Tue Apr  7 2020 pjakobsson@suse.de
- supported.conf: Mark mali-dp as supported
  References: bsc#1168596
  Used on NXP LS1028A devices.
- commit 3682c9a
* Tue Apr  7 2020 glin@suse.com
- bpf: Verifier, do_refine_retval_range may clamp umin to 0
  incorrectly (bsc#1155518).
- bpf: Explicitly memset some bpf info structures declared on
  the stack (bsc#1155518).
- bpf: Explicitly memset the bpf_attr structure (bsc#1155518).
- commit b866c91
* Tue Apr  7 2020 neilb@suse.de
- MM: replace PF_LESS_THROTTLE with PF_LOCAL_THROTTLE
  (bsc#1163403).
- Deprecate NR_UNSTABLE_NFS, use NR_WRITEBACK (bsc#1163403).
- commit 73cedab
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc/irq: Use current_stack_pointer in do_IRQ()
  (bsc#1156395).
- powerpc/irq: Use current_stack_pointer in check_stack_overflow()
  (bsc#1156395).
- powerpc: Add current_stack_pointer as a register global
  (bsc#1156395).
- powerpc: Rename current_stack_pointer() to current_stack_frame()
  (bsc#1156395).
- commit dfb328d
* Mon Apr  6 2020 jack@suse.cz
- blacklist.conf: Blacklist 1ac994525b9d
- commit 536164b
* Mon Apr  6 2020 jack@suse.cz
- mm/filemap.c: don't bother dropping mmap_sem for zero size
  readahead (bsc#1168768).
- commit 73bb347
* Mon Apr  6 2020 jack@suse.cz
- blacklist.conf: Blacklist 780f66e59231
- commit f5700fa
* Mon Apr  6 2020 jack@suse.cz
- ext4: fix incorrect group count in ext4_fill_super error message
  (bsc#1168765).
- commit fe1e977
* Mon Apr  6 2020 jack@suse.cz
- ext4: fix incorrect inodes per group in error message
  (bsc#1168764).
- commit 30375fd
* Mon Apr  6 2020 jack@suse.cz
- Move merged patches to sorted section.
- commit cd90775
* Mon Apr  6 2020 jack@suse.cz
  patches.suse/ext4-Avoid-ENOSPC-when-avoiding-to-reuse-recently-de.patch,
  patches.suse/ext4-Unregister-sysfs-path-before-destroying-jbd2-journal.patch,
  patches.suse/ext4-do-not-commit-super-on-read-only-bdev.patch: Update
  tags
- commit 9574818
* Mon Apr  6 2020 jack@suse.cz
- patches.suse/ext4-Check-for-non-zero-journal-inum-in-ext4_calculate_overhead.patches:
  Update patch tags
- commit 2c9a584
* Mon Apr  6 2020 jack@suse.cz
- partitions/efi: Fix partition name parsing in GUID partition
  entry (bsc#1168763).
- commit 0cdb51e
* Mon Apr  6 2020 jack@suse.cz
- block: keep bdi->io_pages in sync with max_sectors_kb for
  stacked devices (bsc#1168762).
- commit bab38c6
* Mon Apr  6 2020 jack@suse.cz
- blacklist.conf: Blacklist f01b411f41f9
- commit a9128f0
* Mon Apr  6 2020 jack@suse.cz
- block/diskstats: more accurate approximation of io_ticks for
  slow disks (bsc#1168761).
- commit fbbe9dc
* Mon Apr  6 2020 jack@suse.cz
- block, bfq: fix use-after-free in bfq_idle_slice_timer_body
  (bsc#1168760).
- commit 1b05c31
* Mon Apr  6 2020 tiwai@suse.de
- ASoC: jz4740-i2s: Fix divider written at incorrect offset in
  register (git-fixes).
- commit 8642419
* Mon Apr  6 2020 tiwai@suse.de
- xarray: Fix early termination of xas_for_each_marked
  (git-fixes).
- XArray: Fix xas_pause for large multi-index entries (git-fixes).
- XArray: Fix xa_find_next for large multi-index entries
  (git-fixes).
- commit b6feec2
* Mon Apr  6 2020 tiwai@suse.de
- media: imx: Propagate quantization and encoding in CSI
  (git-fixes).
- blacklist.conf:
- commit 43a1dba
* Mon Apr  6 2020 tiwai@suse.de
- tty: evh_bytechan: Fix out of bounds accesses (git-fixes).
- rtc: imx-sc: Align imx sc msg structs to 4 (git-fixes).
- rtc: cmos: Use spin_lock_irqsave() in cmos_interrupt()
  (git-fixes).
- rtc: zynqmp: Clear alarm interrupt status before interrupt
  enable (git-fixes).
- gpio: siox: use raw spinlock for irq related locking
  (git-fixes).
- soc: mediatek: knows_txdone needs to be set in Mediatek CMDQ
  helper (git-fixes).
- PCI: qcom: Fix the fixup of PCI_VENDOR_ID_QCOM (git-fixes).
- PCI: endpoint: Fix clearing start entry in configfs (git-fixes).
- PCI: pciehp: Fix indefinite wait on sysfs requests (git-fixes).
- PCI/ASPM: Clear the correct bits when enabling L1 substates
  (git-fixes).
- misc: rtsx: set correct pcr_ops for rts522A (git-fixes).
- PCI/switchtec: Fix init_completion race condition with
  poll_wait() (git-fixes).
- PM / Domains: Allow no domain-idle-states DT property in genpd
  when parsing (git-fixes).
- PM: sleep: wakeup: Skip wakeup_source_sysfs_remove() if device
  is not there (git-fixes).
- phy: ti: gmii-sel: do not fail in case of gmii (git-fixes).
- phy: ti: gmii-sel: fix set of copy-paste errors (git-fixes).
- commit b2ac503
* Mon Apr  6 2020 tiwai@suse.de
- clk: imx: clk-gate2: Pass the device to the register function
  (git-fixes).
- clk: imx8mm: Fix the CLKO1 source select list (git-fixes).
- clk: qcom: clk-rpmh: Wait for completion when enabling clocks
  (git-fixes).
- clk: sprd: fix to get a correct ibias of pll (git-fixes).
- clk: at91: usb: use proper usbs_mask (git-fixes).
- clk: at91: sam9x60: fix usb clock parents (git-fixes).
- clk: at91: sam9x60: Don't use audio PLL (git-fixes).
- clk: ingenic/jz4770: Exit with error if CGU init failed
  (git-fixes).
- clk: sunxi-ng: sun8i-de2: Add rotation core clocks and reset
  for A83T (git-fixes).
- clk: sunxi-ng: sun8i-de2: H6 doesn't have rotate core
  (git-fixes).
- clk: sunxi-ng: sun8i-de2: Add rotation core clocks and reset
  for A64 (git-fixes).
- clk: sunxi-ng: sun8i-de2: Split out H5 definitions (git-fixes).
- clk: ti: Fix dm814x clkctrl for ethernet (git-fixes).
- clk: imx: Align imx sc clock parent msg structs to 4
  (git-fixes).
- clk: imx: Align imx sc clock msg structs to 4 (git-fixes).
- clk: ti: am43xx: Fix clock parent for RTC clock (git-fixes).
- commit 2f7671e
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc: define helpers to get L1 icache sizes (bsc#1156395).
- commit 780726d
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc/hash64/devmap: Use H_PAGE_THP_HUGE when setting up
  huge devmap PTE entries (bsc#1156395).
- commit 86ebd4a
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc/kprobes: Ignore traps that happened in real mode
  (bsc#1065729).
- commit fc55c00
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc/mm: Fix missing KUAP disable in flush_coherent_icache()
  (bsc#1156395).
- powerpc: Convert flush_icache_range & friends to C
  (bsc#1156395).
- powerpc/32: don't use CPU_FTR_COHERENT_ICACHE (bsc#1156395).
- commit 9ea5bb3
* Mon Apr  6 2020 mbenes@suse.cz
- ftrace/kprobe: Show the maxactive number on kprobe_events
  (git-fixes).
- commit 090d00e
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc: Make setjmp/longjmp signature standard (bsc#1156395).
- powerpc: Add attributes for setjmp/longjmp (bsc#1156395).
- commit 918fd5d
* Mon Apr  6 2020 ykaukab@suse.de
- PM / QoS: Redefine FREQ_QOS_MAX_DEFAULT_VALUE to S32_MAX
  (bsc#1168476).
- ACPI: processor: Add QoS requests for all CPUs (bsc#1168476).
- commit d3f0646
* Mon Apr  6 2020 ykaukab@suse.de
- cpufreq: Fix policy initialization for internal governor drivers
  (bsc#1168476).
- cpufreq: Avoid creating excessively large stack frames
  (bsc#1168476).
- cpufreq: Avoid leaving stale IRQ work items during CPU offline
  (bsc#1168476).
- cpufreq: Register drivers only after CPU devices have been
  registered (bsc#1168476).
- cpufreq: Clarify the comment in cpufreq_set_policy()
  (bsc#1168476).
- PM: QoS: Invalidate frequency QoS requests after removal
  (bsc#1168476).
- PM: QoS: Drop frequency QoS types from device PM QoS
  (bsc#1168476).
- cpufreq: Use per-policy frequency QoS (bsc#1168476).
- PM: QoS: Introduce frequency QoS (bsc#1168476).
- ACPI: processor: Avoid NULL pointer dereferences at init time
  (bsc#1168476).
- Documentation: cpufreq: Update policy notifier documentation
  (bsc#1168476).
- cpufreq: Remove CPUFREQ_ADJUST and CPUFREQ_NOTIFY policy
  notifier events (bsc#1168476).
- ACPI: cpufreq: Switch to QoS requests instead of cpufreq
  notifier (bsc#1168476).
- video: pxafb: Remove cpufreq policy notifier (bsc#1168476).
- video: sa1100fb: Remove cpufreq policy notifier (bsc#1168476).
- arch_topology: Use CPUFREQ_CREATE_POLICY instead of
  CPUFREQ_NOTIFY (bsc#1168476).
- cpufreq: powerpc_cbe: Switch to QoS requests for freq limits
  (bsc#1168476).
- cpufreq: powerpc: macintosh: Switch to QoS requests for freq
  limits (bsc#1168476).
- thermal: cpu_cooling: Switch to QoS requests for freq limits
  (bsc#1168476).
- cpufreq: Add policy create/remove notifiers back (bsc#1168476).
- cpufreq: intel_pstate: Implement QoS supported freq constraints
  (bsc#1168476).
- commit 9298b0f
* Mon Apr  6 2020 ptesarik@suse.cz
- s390/pci: Fix unexpected write combine on resource (bsc#1168553
  LTC#184760).
- commit 0e9a5c8
* Mon Apr  6 2020 msuchanek@suse.de
- powerpc/pseries/ddw: Extend upper limit for huge DMA window
  for persistent memory (FATE#327775 bsc#1142685 ltc#179509).
- commit 0b3bfc8
* Mon Apr  6 2020 dwagner@suse.de
- scsi: qla2xxx: Fix I/Os being passed down when FC device is
  being deleted (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- commit a560046
* Mon Apr  6 2020 oneukum@suse.com
- blacklist.conf: already done in 045706bff837ee89c13f1ace173db71922c1c40b
- commit 255a9d4
* Mon Apr  6 2020 oneukum@suse.com
- blacklist.conf: already done in b32196e35bd7bbc8038db1aba1fbf022dc469b6a
- commit c52adb6
* Mon Apr  6 2020 ptesarik@suse.cz
- s390/mm: fix panic in gup_fast on large pud (bsc#1167197
  LTC#184507).
- commit a8ed0dc
* Mon Apr  6 2020 oneukum@suse.com
- blacklist.conf: fixes only logged messages
- commit 8266fdf
* Mon Apr  6 2020 wqu@suse.com
- btrfs: qgroup: ensure qgroup_rescan_running is only set when
  the worker is at least queued (bsc#1168670).
- Delete
  patches.suse/btrfs-qgroups-fix-rescan-worker-running-races.patch.
- commit acca6e8
* Mon Apr  6 2020 pvorel@suse.cz
- nfsd: remove read permission bit for ctl sysctl (git-fixes).
- commit 6b806f6
* Sun Apr  5 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-kvm-s390-disallow-invalid-bits-in-kvm_valid_regs-and-kvm_dirty_regs
  patches.suse/0002-kvm-s390-mark-_insn32_query-as-_always_inline
  patches.suse/0003-kvm-s390-cleanup-kvm_arch_init-error-path
  patches.suse/0004-kvm-s390-cleanup-initial-cpu-reset
  patches.suse/0005-kvm-s390-add-new-reset-vcpu-api
- commit e3cd9b7
* Sun Apr  5 2020 mkubecek@suse.cz
- Update kabi files.
- commit 038f102
* Sat Apr  4 2020 ailiop@suse.com
- xfs: fix use-after-free when aborting corrupt attr inactivation
  (git-fixes).
- commit bef8807
* Fri Apr  3 2020 ptesarik@suse.cz
- KVM: s390: protvirt: Add initial vm and cpu lifecycle handling
  (jsc#SLE-7512 bsc#1165545).
- Update kabi files.
- commit f7edc36
* Fri Apr  3 2020 ptesarik@suse.cz
- KVM: s390: protvirt: Implement interrupt injection (jsc#SLE-7512
  bsc#1165545).
- Update kabi files.
- commit 992821a
* Fri Apr  3 2020 ptesarik@suse.cz
- KVM: s390: protvirt: Instruction emulation (jsc#SLE-7512
  bsc#1165545).
- commit 19e482f
* Fri Apr  3 2020 ptesarik@suse.cz
- mm/gup/writeback: add callbacks for inaccessible pages
  (jsc#SLE-7512 bsc#1165545).
- commit 2700b97
* Fri Apr  3 2020 msuchanek@suse.de
- scsi: ibmvfc: Fix NULL return compiler warning (bsc#1161951
  ltc#183551).
- commit 8a47623
* Fri Apr  3 2020 msuchanek@suse.de
- powerpc/pseries: Fix MCE handling on pseries (bsc#1168575
  ltc#183501).
- commit ef26231
* Fri Apr  3 2020 msuchanek@suse.de
- scsi: lpfc: Change default SCSI LUN QD to 64 (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
  Patch split off
  patches.suse/scsi-lpfc-Fix-erroneous-cpu-limit-of-128-on-I-O-stat.patch
  in upstream repository.
- Refresh patches.suse/scsi-lpfc-Fix-erroneous-cpu-limit-of-128-on-I-O-stat.patch.
- Refresh patches.suse/scsi-lpfc-Make-debugfs-ktime-stats-generic-for-NVME-.patch.
- Refresh patches.suse/scsi-lpfc-Remove-prototype-FIPS-DSS-options-from-SLI.patch.
- Refresh patches.suse/scsi-lpfc-Update-lpfc-version-to-12.8.0.0.patch.
- commit a4a3d20
* Fri Apr  3 2020 yousaf.kaukab@suse.com
- config: arm64: enable cpufreq driver for Jetson Nano and TX1
  References: jsc#SLE-9391
- commit 57d2fdd
* Fri Apr  3 2020 mkubecek@suse.cz
- Update kabi files.
  Update to Snapshot 10 submission (commit c4804773a3be).
- commit 46da16d
* Fri Apr  3 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/pinctrl-bcm2835-add-support-for-all-gpios-on-bcm2711.patch
  patches.suse/pinctrl-bcm2835-drop-unused-define.patch
  patches.suse/pinctrl-bcm2835-refactor-platform-data.patch
  patches.suse/scsi-fc-Update-Descriptor-definition-and-add-RDF-and.patch
  patches.suse/scsi-ibmvfc-Avoid-loss-of-all-paths-during-SVC-node-.patch
  patches.suse/scsi-lpfc-Clean-up-hba-max_lun_queue_depth-checks.patch
  patches.suse/scsi-lpfc-Fix-RQ-buffer-leakage-when-no-IOCBs-availa.patch
  patches.suse/scsi-lpfc-Fix-broken-Credit-Recovery-after-driver-lo.patch
  patches.suse/scsi-lpfc-Fix-compiler-warning-on-frame-size.patch
  patches.suse/scsi-lpfc-Fix-coverity-errors-in-fmdi-attribute-hand.patch
  patches.suse/scsi-lpfc-Fix-lpfc_io_buf-resource-leak-in-lpfc_get_.patch
  patches.suse/scsi-lpfc-Fix-registration-of-ELS-type-support-in-fd.patch
  patches.suse/scsi-lpfc-Fix-release-of-hwq-to-clear-the-eq-relatio.patch
  patches.suse/scsi-lpfc-Remove-handler-for-obsolete-ELS-Read-Port-.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.6.0.4.patch
  patches.suse/scsi-lpfc-add-RDF-registration-and-Link-Integrity-FP.patch
  patches.suse/scsi-lpfc-fix-spelling-mistake-Notication-Notificati.patch
  patches.suse/scsi-qla2xxx-Add-16.0GT-for-PCI-String.patch
  patches.suse/scsi-qla2xxx-Add-beacon-LED-config-sysfs-interface.patch
  patches.suse/scsi-qla2xxx-Add-changes-in-preparation-for-vendor-e.patch
  patches.suse/scsi-qla2xxx-Add-deferred-queue-for-processing-ABTS-.patch
  patches.suse/scsi-qla2xxx-Add-endianizer-macro-calls-to-fc-host-s.patch
  patches.suse/scsi-qla2xxx-Add-fixes-for-mailbox-command.patch
  patches.suse/scsi-qla2xxx-Add-ql2xrdpenable-module-parameter-for-.patch
  patches.suse/scsi-qla2xxx-Add-sysfs-node-for-D-Port-Diagnostics-A.patch
  patches.suse/scsi-qla2xxx-Add-vendor-extended-FDMI-commands.patch
  patches.suse/scsi-qla2xxx-Add-vendor-extended-RDP-additions-and-a.patch
  patches.suse/scsi-qla2xxx-Avoid-setting-firmware-options-twice-in.patch
  patches.suse/scsi-qla2xxx-Check-locking-assumptions-at-runtime-in.patch
  patches.suse/scsi-qla2xxx-Cleanup-ELS-PUREX-iocb-fields.patch
  patches.suse/scsi-qla2xxx-Convert-MAKE_HANDLE-from-a-define-into-.patch
  patches.suse/scsi-qla2xxx-Correction-to-selection-of-loopback-ech.patch
  patches.suse/scsi-qla2xxx-Display-message-for-FCE-enabled.patch
  patches.suse/scsi-qla2xxx-Fix-FCP-SCSI-FC4-flag-passing-error.patch
  patches.suse/scsi-qla2xxx-Fix-NPIV-instantiation-after-FW-dump.patch
  patches.suse/scsi-qla2xxx-Fix-RDP-respond-data-format.patch
  patches.suse/scsi-qla2xxx-Fix-RDP-response-size.patch
  patches.suse/scsi-qla2xxx-Fix-control-flags-for-login-logout-IOCB.patch
  patches.suse/scsi-qla2xxx-Fix-qla2x00_echo_test-based-on-ISP-type.patch
  patches.suse/scsi-qla2xxx-Fix-sparse-warning-reported-by-kbuild-b.patch
  patches.suse/scsi-qla2xxx-Fix-sparse-warnings-triggered-by-the-PC.patch
  patches.suse/scsi-qla2xxx-Force-semaphore-on-flash-validation-fai.patch
  patches.suse/scsi-qla2xxx-Handle-NVME-status-iocb-correctly.patch
  patches.suse/scsi-qla2xxx-Handle-cases-for-limiting-RDP-response-.patch
  patches.suse/scsi-qla2xxx-Improved-secure-flash-support-messages.patch
  patches.suse/scsi-qla2xxx-Move-free-of-fcport-out-of-interrupt-co.patch
  patches.suse/scsi-qla2xxx-Print-portname-for-logging-in-qla24xx_l.patch
  patches.suse/scsi-qla2xxx-Remove-restriction-of-FC-T10-PI-and-FC-.patch
  patches.suse/scsi-qla2xxx-Return-appropriate-failure-through-BSG-.patch
  patches.suse/scsi-qla2xxx-Save-rscn_gen-for-new-fcport.patch
  patches.suse/scsi-qla2xxx-Serialize-fc_port-alloc-in-N2N.patch
  patches.suse/scsi-qla2xxx-Set-Nport-ID-for-N2N.patch
  patches.suse/scsi-qla2xxx-Show-correct-port-speed-capabilities-fo.patch
  patches.suse/scsi-qla2xxx-Simplify-the-code-for-aborting-SCSI-com.patch
  patches.suse/scsi-qla2xxx-Suppress-endianness-complaints-in-qla2x.patch
  patches.suse/scsi-qla2xxx-Update-BPM-enablement-semantics.patch
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.24-k.patch
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.25-k.patch
  patches.suse/scsi-qla2xxx-Use-FC-generic-update-firmware-options-.patch
  patches.suse/scsi-qla2xxx-Use-QLA_FW_STOPPED-macro-to-propagate-f.patch
  patches.suse/scsi-qla2xxx-Use-a-dedicated-interrupt-handler-for-h.patch
  patches.suse/scsi-qla2xxx-Use-correct-ISP28xx-active-FW-region.patch
  patches.suse/scsi-qla2xxx-Use-endian-macros-to-assign-static-fiel.patch
  patches.suse/scsi-qla2xxx-add-more-FW-debug-information.patch
  patches.suse/scsi-qla2xxx-fix-FW-resource-count-values.patch
  patches.suse/scsi-target-convert-boolean-se_dev_attrib-types-to-b.patch
  patches.suse/scsi-target-fix-unmap_zeroes_data-boolean-initialisa.patch
  patches.suse/scsi-target-use-an-enum-to-track-emulate_ua_intlck_c.patch
  patches.suse/scsi-tcm_qla2xxx-Make-qlt_alloc_qfull_cmd-set-cmd-se.patch
- commit e921d75
* Fri Apr  3 2020 tiwai@suse.de
- mtd: spinand: Do not erase the block before writing a bad
  block marker (git-fixes).
- mtd: spinand: Explicitly use MTD_OPS_RAW to write the bad
  block marker to OOB (git-fixes).
- mtd: spinand: Stop using spinand->oobbuf for buffering bad
  block markers (git-fixes).
- mtd: rawnand: free the nand_device object (git-fixes).
- mtd: phram: fix a double free issue in error path (git-fixes).
- mtd: lpddr: Fix a double free in probe() (git-fixes).
- i2c: smbus: remove outdated references to irq level triggers
  (git-fixes).
- ASoC: Intel: mrfld: fix incorrect check on p->sink (git-fixes).
- ASoC: sun8i-codec: Remove unused dev from codec struct
  (git-fixes).
- ASoC: Intel: mrfld: return error codes when an error occurs
  (git-fixes).
- ASoC: stm32: spdifrx: fix regmap status check (git-fixes).
- pinctrl: actions: Fix functions groups names for S700 SoC
  (git-fixes).
- remoteproc: Fix NULL pointer dereference in rproc_virtio_notify
  (git-fixes).
- remoteproc: qcom_q6v5_mss: Reload the mba region on coredump
  (git-fixes).
- remoteproc: qcom_q6v5_mss: Don't reassign mpss region on
  shutdown (git-fixes).
- include/bitmap.h: add missing parameter in docs (git-fixes).
- mac80211: fix authentication with iwlwifi/mvm (git-fixes).
- mac80211: Check port authorization in the ieee80211_tx_dequeue()
  case (git-fixes).
- nl80211: fix NL80211_ATTR_CHANNEL_WIDTH attribute type
  (git-fixes).
- slcan: not call free_netdev before rtnl_unlock in slcan_open
  (git-fixes).
- commit 784cfac
* Fri Apr  3 2020 tiwai@suse.de
- ALSA: pcm.h: add for_each_pcm_streams() (git-fixes).
- commit 03a4da5
* Fri Apr  3 2020 tiwai@suse.de
- ALSA: usb-audio: Fix case when USB MIDI interface has more
  than one extra endpoint descriptor (git-fixes).
- ALSA: hda/realtek - Remove now-unnecessary XPS 13 headphone
  noise fixups (git-fixes).
- ALSA: hda/realtek - Set principled PC Beep configuration for
  ALC256 (git-fixes).
- ALSA: usx2y: use for_each_pcm_streams() macro (git-fixes).
- ALSA: hda: default enable CA0132 DSP support (git-fixes).
- ALSA: usb-audio: Inform devices that need delayed registration
  (git-fixes).
- ALSA: usb-audio: Add delayed_register option (git-fixes).
- ALSA: usb-audio: Rewrite registration quirk handling
  (git-fixes).
- ALSA: core: Add snd_device_get_state() helper (git-fixes).
- ALSA: usb-audio: Create a registration quirk for Kingston
  HyperX Amp (0951:16d8) (git-fixes).
- ALSA: usb-audio: Fix mixer controls' USB interface for Kingston
  HyperX Amp (0951:16d8) (git-fixes).
- ALSA: hda: Use scnprintf() for string truncation (git-fixes).
- ALSA: pcm: Fix superfluous snprintf() usage (git-fixes).
- ALSA: pcm: oss: Simplify plugin frame size calculations
  (git-fixes).
- ALSA: usb-audio: Fix missing braces in some struct inits
  (git-fixes).
- ALSA: usb-audio: Add support for MOTU MicroBook IIc (git-fixes).
- ALSA: korg1212: fix if-statement empty body warnings
  (git-fixes).
- ALSA: usb-audio: Parse source ID of UAC2 effect unit
  (git-fixes).
- usb: audio-v2: Add uac2_effect_unit_descriptor definition
  (git-fixes).
- ALSA: usb-audio: Add support for Presonus Studio 1810c
  (git-fixes).
- ALSA: pcm: oss: Unlock mutex temporarily for sleeping at
  read/write (git-fixes).
- ALSA: usb-audio: Don't create a mixer element with bogus volume
  range (git-fixes).
- ALSA: hda_codec: Replace zero-length array with flexible-array
  member (git-fixes).
- ALSA: hda/ca0132 - Replace zero-length array with flexible-array
  member (git-fixes).
- ALSA: usb-midi: Replace zero-length array with flexible-array
  member (git-fixes).
- ALSA: core: Replace zero-length array with flexible-array member
  (git-fixes).
- ALSA: info: remove redundant assignment to variable c
  (git-fixes).
- ALSA: ali5451: remove redundant variable capture_flag
  (git-fixes).
- ALSA: hda: remove redundant assignment to variable timeout
  (git-fixes).
- ALSA: hdsp: remove redundant assignment to variable err
  (git-fixes).
- ALSA: pcm: Use a macro for parameter masks to reduce the needed
  cast (git-fixes).
- ALSA: pcm: Use standard macros for fixing PCM format cast
  (git-fixes).
- ALSA: usb-audio: Use pcm_for_each_format() macro for PCM format
  iterations (git-fixes).
- ALSA: pcm: More helper macros for reducing snd_pcm_format_t cast
  (git-fixes).
- ALSA: emu10k1: Fix endianness annotations (git-fixes).
- ALSA: via82xx: Fix endianness annotations (git-fixes).
- ALSA: hda/hdmi: Move ELD parse and jack reporting into
  update_eld() (git-fixes).
- ALSA: hda/hdmi: Move runtime PM resume into
  hdmi_present_sense_via_verbs() (git-fixes).
- ALSA: hda/hdmi: Don't use standard hda_jack for generic HDMI
  jacks (git-fixes).
- ALSA: hda/hdmi: Reduce hda_jack_tbl lookup at unsol event
  handling (git-fixes).
- ALSA: hda/realtek - a fake key event is triggered by running
  shutup (git-fixes).
- ALSA: hda/realtek: Enable mute LED on an HP system (git-fixes).
- ALSA: hda/ca0132 - Add Recon3Di quirk to handle integrated
  sound on EVGA X99 Classified motherboard (git-fixes).
- commit f898dc5
* Fri Apr  3 2020 tiwai@suse.de
- slcan: Don't transmit uninitialized stack data in padding
  (CVE-2020-11494 bsc#1168424).
- commit 246f367
* Fri Apr  3 2020 wqu@suse.com
- btrfs: do not zero f_bavail if we have available space
  (bsc#1168081).
- commit 77d5937
* Thu Apr  2 2020 tiwai@suse.de
- USB: cdc-acm: fix close_delay and closing_wait units in
  TIOCSSERIAL (git-fixes).
- Refresh
  patches.suse/USB-cdc-acm-fix-rounding-error-in-TIOCSSERIAL.patch.
- commit 8731e73
* Thu Apr  2 2020 tiwai@suse.de
- USB: cdc-acm: restore capability check order (git-fixes).
- usb: gadget: f_fs: Fix use after free issue as part of queue
  failure (git-fixes).
- USB: serial: io_edgeport: fix slab-out-of-bounds read in
  edge_interrupt_callback (git-fixes).
- USB: serial: option: add Wistron Neweb D19Q1 (git-fixes).
- USB: serial: option: add BroadMobi BM806U (git-fixes).
- USB: serial: option: add support for ASKEY WWHC050 (git-fixes).
- usb: musb: fix crash with highmen PIO and usbmon (git-fixes).
- usb: gadget: composite: Inform controller driver of self-powered
  (git-fixes).
- usb: dwc3: gadget: Wrap around when skip TRBs (git-fixes).
- usb: dwc3: gadget: Don't clear flags before transfer ended
  (git-fixes).
- seccomp: Add missing compat_ioctl for notify (git-fixes).
- tpm: ibmvtpm: Wait for buffer to be set before proceeding
  (git-fixes).
- tpm: tpm2_bios_measurements_next should increase position index
  (git-fixes).
- tpm: tpm1_bios_measurements_next should increase position index
  (git-fixes).
- vti6: Fix memory leak of skb if input policy check fails
  (git-fixes).
- USB: serial: pl2303: add device-id for HP LD381 (git-fixes).
- USB: serial: option: add ME910G1 ECM composition 0x110b
  (git-fixes).
- usb: quirks: add NO_LPM quirk for RTL8153 based ethernet
  adapters (git-fixes).
- usb: host: xhci-plat: add a shutdown (git-fixes).
- USB: Disable LPM on WD19's Realtek Hub (git-fixes).
- usb: xhci: apply XHCI_SUSPEND_DELAY to AMD XHCI controller
  1022:145c (git-fixes).
- tty: fix compat TIOCGSERIAL checking wrong function ptr
  (git-fixes).
- tty: fix compat TIOCGSERIAL leaking uninitialized memory
  (git-fixes).
- seccomp: Check that seccomp_notif is zeroed out by the user
  (git-fixes).
- commit 6e62c53
* Thu Apr  2 2020 tiwai@suse.de
- mmc: core: Respect MMC_CAP_NEED_RSP_BUSY for eMMC sleep command
  (git-fixes).
- mmc: sdhci-tegra: Fix busy detection by enabling
  MMC_CAP_NEED_RSP_BUSY (git-fixes).
- mmc: sdhci-omap: Fix busy detection by enabling
  MMC_CAP_NEED_RSP_BUSY (git-fixes).
- mmc: core: Respect MMC_CAP_NEED_RSP_BUSY for erase/trim/discard
  (git-fixes).
- mmc: core: Allow host controllers to require R1B for CMD6
  (git-fixes).
- mmc: core: Default to generic_cmd6_time as timeout in
  __mmc_switch() (git-fixes).
- commit a7a7a34
* Thu Apr  2 2020 tiwai@suse.de
- media: i2c: video-i2c: fix build errors due to 'imply hwmon'
  (git-fixes).
- media: vivid: fix incorrect PA assignment to HDMI outputs
  (git-fixes).
- media: imx: imx7-media-csi: Fix video field handling
  (git-fixes).
- media: imx: imx7-media-csi: Remove unneeded register read
  (git-fixes).
- media: imx: imx7_mipi_csis: Power off the source when stopping
  streaming (git-fixes).
- media: xirlink_cit: add missing descriptor sanity checks
  (git-fixes).
- media: stv06xx: add missing descriptor sanity checks
  (git-fixes).
- media: ov519: add missing endpoint sanity checks (git-fixes).
- media: v4l2-fwnode: fix v4l2_fwnode_parse_link handling
  (git-fixes).
- media: ti-vpe: cal: fix a kernel oops when unloading module
  (git-fixes).
- media: tda10071: fix unsigned sign extension overflow
  (git-fixes).
- media: v4l2-core: fix entity initialization in
  device_register_subdev (git-fixes).
- media: v4l2-core: fix a use-after-free bug of sd->devnode
  (git-fixes).
- media: vsp1: tidyup VI6_HGT_LBn_H() macro (git-fixes).
- media: staging/imx: Missing assignment in
  imx_media_capture_device_register() (git-fixes).
- media: hantro: Read be32 words starting at every fourth byte
  (git-fixes).
- media: dib0700: fix rc endpoint lookup (git-fixes).
- media: flexcop-usb: fix endpoint sanity check (git-fixes).
- media: usbtv: fix control-message timeouts (git-fixes).
- commit 80da5af
* Thu Apr  2 2020 tbogendoerfer@suse.de
- ionic: print data for unknown xcvr type (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- commit e353704
* Thu Apr  2 2020 tbogendoerfer@suse.de
- ionic: remove lifs on fw reset (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: disable the queues on link down (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: check for queues before deleting (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: clean tx queue of unfinished requests (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: move irq request to qcq alloc (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: move debugfs add/delete to match alloc/free (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: check for linkup in watchdog (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: decouple link message from netdev state (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: check for NULL structs on teardown (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: clean irq affinity on queue deinit (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: ignore eexist on rx filter add (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: only save good lif dentry (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: leave dev cmd request contents alone on FW timeout
  (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: add timeout error checking for queue disable (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: add decode for IONIC_RC_ENOSUPP (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: remove adminq napi instance (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: deinit rss only if selected (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: stop devlink warn on mgmt device (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: add support for device id 0x1004 (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: print pci bus lane info (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: support ethtool rxhash disable (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: clean up bitflag usage (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: improve irq numa locality (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: remove pragma packed (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: keep ionic dev on lif init fail (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ice: add additional E810 device id (jsc#SLE-7966 bsc#1157177).
- ionic: make spdxcheck.py happy (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- net: ionic: Use scnprintf() for avoiding potential buffer
  overflow (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- commit dca9c4d
* Thu Apr  2 2020 oneukum@suse.com
- USB: serial: pl2303: add device-id for HP LD381 (git-fixes).
- commit f358c73
* Thu Apr  2 2020 ptesarik@suse.cz
- KVM: S390: protvirt: Introduce instruction data area bounce
  buffer (jsc#SLE-7512 bsc#1165545).
- Update kabi files.
- commit fb23a46
* Thu Apr  2 2020 oneukum@suse.com
- USB: serial: option: add ME910G1 ECM composition 0x110b
  (git-fixes).
- commit d394d40
* Thu Apr  2 2020 oneukum@suse.com
- usb: quirks: add NO_LPM quirk for RTL8153 based ethernet
  adapters (git-fixes).
- commit 4366db0
* Thu Apr  2 2020 oneukum@suse.com
- usb: host: xhci-plat: add a shutdown (git-fixes).
- commit d6ce28e
* Thu Apr  2 2020 tiwai@suse.de
- staging: wlan-ng: fix use-after-free Read in
  hfa384x_usbin_callback (git-fixes).
- staging: wlan-ng: fix ODEBUG bug in prism2sta_disconnect_usb
  (git-fixes).
- staging: rtl8188eu: Add ASUS USB-N10 Nano B1 to device table
  (git-fixes).
- net: qmi_wwan: add support for ASKEY WWHC050 (git-fixes).
- commit cae14b2
* Thu Apr  2 2020 oneukum@suse.com
- USB: Disable LPM on WD19's Realtek Hub (git-fixes).
- commit 545e2ba
* Thu Apr  2 2020 tiwai@suse.de
- maillbox: bcm-flexrm-mailbox: handle cmpl_pool dma allocation
  failure (git-fixes).
- HID: fix Kconfig word ordering (git-fixes).
- hwrng: imx-rngc - fix an error path (git-fixes).
- mac80211: set IEEE80211_TX_CTRL_PORT_CTRL_PROTO for nl80211 TX
  (git-fixes).
- mac80211: mark station unauthorized before key removal
  (git-fixes).
- mac80211: drop data frames without key on encrypted links
  (git-fixes).
- i2c: hix5hd2: add missed clk_disable_unprepare in remove
  (git-fixes).
- Input: synaptics - enable RMI on HP Envy 13-ad105ng (git-fixes).
- mac80211: Do not send mesh HWMP PREQ if HWMP is disabled
  (git-fixes).
- commit 1a471a8
* Thu Apr  2 2020 oneukum@suse.com
- usb: xhci: apply XHCI_SUSPEND_DELAY to AMD XHCI controller
  1022:145c (git-fixes).
- commit 84b09ec
* Thu Apr  2 2020 tiwai@suse.de
- crypto: caam - update xts sector size for large input length
  (git-fixes).
- crypto: caam/qi2 - fix chacha20 data size error (git-fixes).
- crypto: mxs-dcp - fix scatterlist linearization for hash
  (git-fixes).
- crypto: arm64/sha-ce - implement export/import (git-fixes).
- crypto: tcrypt - fix printed skcipher [a]sync mode (git-fixes).
- crypto: rng - Fix a refcounting bug in crypto_rng_reset()
  (git-fixes).
- ahci: Add Intel Comet Lake H RAID PCI ID (git-fixes).
- commit c24e76c
* Thu Apr  2 2020 oneukum@suse.com
- xhci: Do not open code __print_symbolic() in xhci trace events
  (git-fixes).
- commit fed4fc3
* Thu Apr  2 2020 ptesarik@suse.cz
- KVM: s390: protvirt: Add SCLP interrupt handling (jsc#SLE-7512
  bsc#1165545).
- Update kabi files.
- commit 4f3b7b8
* Thu Apr  2 2020 ptesarik@suse.cz
- s390/mm: provide memory management functions for protected
  KVM guests (jsc#SLE-7512 bsc#1165545).
- Update kabi files.
- commit 9c9391b
* Thu Apr  2 2020 oneukum@suse.com
- blacklist.conf: code cleanup that breaks kABI
- commit 0354bc9
* Thu Apr  2 2020 ptesarik@suse.cz
- KVM: s390: protvirt: Add KVM api documentation (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: introduce and enable KVM_CAP_S390_PROTECTED
  (jsc#SLE-7512 bsc#1165545).
- DOCUMENTATION: Protected virtual machine introduction and IPL
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Add UV cpu reset calls (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: do not inject interrupts after start
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Mask PSW interrupt bits for interception
  104 and 112 (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Support cmd 5 operation state (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: Report CPU state to Ultravisor
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: UV calls in support of diag308 0, 1
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Add program exception injection
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Only sync fmt4 registers (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: Do only reset registers that are accessible
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: disallow one_reg (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: STSI handling (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Write sthyi data to instruction data area
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390/mm: handle guest unpin events (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: handle secure guest prefix pages
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Add new gprs location handling
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Handle spec exception loops (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: Handle SE notification interceptions
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390/mm: Make pages accessible before destroying the guest
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: protvirt: Secure memory is not mergeable
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: add new variants of UV CALL (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: protvirt: Add UV debug trace (jsc#SLE-7512
  bsc#1165545).
- KVM: s390/interrupt: do not pin adapter interrupt pages
  (jsc#SLE-7512 bsc#1165545).
- s390/protvirt: Add sysfs firmware interface for Ultravisor
  information (jsc#SLE-7512 bsc#1165545).
- s390/mm: add (non)secure page access exceptions handlers
  (jsc#SLE-7512 bsc#1165545).
- s390/protvirt: add ultravisor initialization (jsc#SLE-7512
  bsc#1165545).
- s390/protvirt: introduce host side setup (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: Also reset registers in sync regs for initial cpu
  reset (jsc#SLE-7512 bsc#1165545).
- KVM: s390: Add new reset vcpu API (jsc#SLE-7512 bsc#1165545).
- KVM: s390: Cleanup initial cpu reset (jsc#SLE-7512 bsc#1165545).
- KVM: s390: Cleanup kvm_arch_init error path (jsc#SLE-7512
  bsc#1165545).
- KVM: s390: mark __insn32_query() as __always_inline
  (jsc#SLE-7512 bsc#1165545).
- KVM: s390: Disallow invalid bits in kvm_valid_regs and
  kvm_dirty_regs (jsc#SLE-7512 bsc#1165545).
- commit 8e1956a
* Thu Apr  2 2020 jslaby@suse.cz
- char/random: silence a lockdep splat with printk() (git-fixes).
- commit dce5b06
* Wed Apr  1 2020 msuchanek@suse.de
- powerpc/vmlinux.lds: Explicitly retain .gnu.hash (bsc#1148868).
- commit 0843abc
* Wed Apr  1 2020 msuchanek@suse.de
- powerpc/64/tm: Don't let userspace set regs->trap via sigreturn
  (bsc#1118338 ltc#173734).
- commit 3d1d975
* Wed Apr  1 2020 msuchanek@suse.de
- powerpc/pseries: Handle UE event for memcpy_mcsafe (jsc#SLE-7730
  jsc#SLE-8330).
- commit 823260c
* Wed Apr  1 2020 msuchanek@suse.de
- powerpc/xive: Use XIVE_BAD_IRQ instead of zero to catch non
  configured IPIs (bsc#1085030).
- commit e5b59c4
* Wed Apr  1 2020 mgorman@suse.de
- Update config files to disable CONFIG_KERNEL_HEADER_TEST (bsc#1168354).
- commit bc323e4
* Wed Apr  1 2020 msuchanek@suse.de
- powerpc/64: Prevent stack protection in early boot
  (bsc#1156395).
- powerpc/64: Setup a paca before parsing device tree etc
  (bsc#1156395).
- commit 196aec2
* Wed Apr  1 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/sched-core-Don-t-skip-remote-tick-for-idle-CPUs.patch
  patches.suse/timers-nohz-Update-NOHZ-load-in-remote-tick.patch
- commit 41bab0e
* Wed Apr  1 2020 mkubecek@suse.cz
- update patch metadata
- update upstream reference:
  patches.suse/net-bpfilter-remove-superfluous-testing-message.patch
- commit 9f9b3f8
* Wed Apr  1 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/media-go7007-Fix-URB-type-for-interrupt-handling.patch
  patches.suse/mmc-sdhci-introduce-sdhci_set_power_and_bus_voltage.patch
  patches.suse/mmc-sdhci-iproc-add-custom-set_power-callback-for-bcm2711.patch
- commit 69e3868
* Wed Apr  1 2020 jack@suse.cz
- ext4: Avoid ENOSPC when avoiding to reuse recently deleted
  inodes (bsc#1165019).
- commit ac99ab8
* Wed Apr  1 2020 tiwai@suse.de
- Delete patches.suse/i2c-i801-Do-not-add-ICH_RES_IO_SMI-for-the-iTCO_wdt-.patch (bsc#1168297)
  The patch caused a regression on DNV board.
- commit e88f35c
* Wed Apr  1 2020 lhenriques@suse.com
- ceph: fix memory leak in ceph_cleanup_snapid_map()
  (jsc#SES-1134).
- libceph: fix alloc_msg_with_page_vector() memory leaks
  (jsc#SES-1134).
- ceph: check POOL_FLAG_FULL/NEARFULL in addition to
  OSDMAP_FULL/NEARFULL (jsc#SES-1134).
- commit c22ae0e
* Wed Apr  1 2020 glin@suse.com
- net/bpfilter: remove superfluous testing message (bsc#1155518).
- commit 8cf8e50
* Wed Apr  1 2020 tbogendoerfer@suse.de
- vti: fix packet tx through bpf_redirect() in XinY cases
  (bsc#1154353).
- RDMA/core: Ensure security pkey modify is not lost
  (jsc#SLE-8449).
- net/mlx5e: Do not recover from a non-fatal syndrome
  (jsc#SLE-8464).
- net/mlx5e: Fix ICOSQ recovery flow with Striding RQ
  (jsc#SLE-8464).
- net/mlx5e: Fix missing reset of SW metadata in Striding RQ reset
  (jsc#SLE-8464).
- net/mlx5e: Enhance ICOSQ WQE info fields (jsc#SLE-8464).
- net/mlx5e: kTLS, Fix TCP seq off-by-1 issue in TX resync flow
  (jsc#SLE-8464).
- net/mlx5: DR, Fix postsend actions write length (jsc#SLE-8464).
- cxgb4: fix throughput drop during Tx backpressure (jsc#SLE-8389
  bnc#1151927 5.3.10).
- mlxsw: pci: Only issue reset when system is ready (bsc#1154488).
- net: ena: fix incorrect setting of the number of msix vectors
  (bsc#1154492).
- cxgb4: fix delete filter entry fail in unload path
  (jsc#SLE-8389).
- net_sched: keep alloc_hash updated after hash allocation
  (bsc#1154353).
- bpf/btf: Fix BTF verification of enum members in struct/union
  (bsc#1154353).
- bpf: Initialize storage pointers to NULL to prevent freeing
  garbage pointer (bsc#1154353).
- commit f057e20
* Wed Apr  1 2020 glin@suse.com
- bpf: Simplify reg_set_min_max_inv handling (bsc#1167722,
  CVE-2020-8835).
- bpf: Fix tnum constraints for 32-bit comparisons (bsc#1167722,
  CVE-2020-8835).
- bpf: Reliably preserve btf_trace_xxx types (bsc#1155518).
- commit 0eb8897
* Wed Apr  1 2020 tiwai@suse.de
- Crypto: chelsio - Fixes a deadlock between rtnl_lock and
  uld_mutex (git-fixes).
- Crypto: chelsio - Fixes a hang issue during driver registration
  (git-fixes).
- ath9k: Handle txpower changes even when TPC is disabled
  (git-fixes).
- mwifiex: set needed_headroom, not hard_header_len (git-fixes).
- brcmfmac: abort and release host after error (git-fixes).
- platform/x86: asus_wmi: Fix return value of fan_boost_mode_store
  (git-fixes).
- platform/x86: pmc_atom: Add Lex 2I385SW to critclk_systems
  DMI table (git-fixes).
- serial: sprd: Fix a dereference warning (git-fixes).
- firmware: arm_sdei: fix possible double-lock on hibernate
  error path (git-fixes).
- firmware: arm_sdei: fix double-lock on hibernate with shared
  events (git-fixes).
- fbdev/g364fb: Fix build failure (git-fixes).
- commit 342cd4b
* Wed Apr  1 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline tag:
  patches.suse/modpost-move-the-namespace-field-in-Module.symvers-last.patch
- commit af8306c
* Wed Apr  1 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/ethtool-Factored-out-similar-ethtool-link-settings-f.patch
  patches.suse/modpost-return-error-if-module-is-missing-ns-imports.patch
  patches.suse/net-ethtool-Introduce-link_ksettings-API-for-virtual.patch
- commit 177866a
* Tue Mar 31 2020 mgorman@suse.de
- kthread: Do not preempt current task if it is going to
  call schedule() (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/fair: Improve spreading of utilization (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched: Avoid scale real weight down to zero (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/core: Distribute tasks within affinity masks (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Fix enqueue_task_fair warning (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/core: Remove duplicate assignment in sched_tick_remote()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- timers/nohz: Update NOHZ load in remote tick (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/core: Don't skip remote tick for idle CPUs (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit 1264b2f
* Tue Mar 31 2020 mgorman@suse.de
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/sched-fair-Fix-kernel-build-warning-in-test_idle_cores-for-SMT-NUMA.patch.
  patches.suse/sched-fair-Fix-reordering-of-enqueue-dequeue_task_fair.patch.
  patches.suse/sched-fair-Fix-runnable_avg-for-throttled-cfs.patch.
  patches.suse/sched-fair-Optimize-select_idle_core.patch.
  patches.suse/sched-fair-Take-into-account-runnable_avg-to-classify-group.patch.
  patches.suse/sched-fair-fix-condition-of-avg_load-calculation.patch.
  patches.suse/sched-fair-fix-statistics-for-find_idlest_group.patch.
  patches.suse/sched-fair-reorder-enqueue-dequeue_task_fair-path.patch.
  patches.suse/sched-numa-Acquire-RCU-lock-for-checking-idle-cores-during-NUMA-balancing.patch.
  patches.suse/sched-numa-Bias-swapping-tasks-based-on-their-preferred-node.patch.
  patches.suse/sched-numa-Distinguish-between-the-different-task_numa_migrate-failure-cases.patch.
  patches.suse/sched-numa-Find-an-alternative-idle-CPU-if-the-CPU-is-part-of-an-active-NUMA-balance.patch.
  patches.suse/sched-numa-Prefer-using-an-idle-cpu-as-a-migration-target-instead-of-comparing-tasks.patch.
  patches.suse/sched-numa-Stop-an-exhastive-search-if-a-reasonable-swap-candidate-or-idle-CPU-is-found.patch.
  patches.suse/sched-numa-Trace-when-no-candidate-CPU-was-found-on-the-preferred-node.patch.
  patches.suse/sched-numa-Use-similar-logic-to-the-load-balancer-for-moving-between-domains-with-spare-capacity.patch.
  patches.suse/sched-numa-replace-runnable_load_avg-by-load_avg.patch.
  patches.suse/sched-pelt-Add-a-new-runnable-average-signal.patch.
  patches.suse/sched-pelt-Remove-unused-runnable-load-average.patch.
  patches.suse/sched-topology-Don-t-enable-EAS-on-SMT-systems.patch.
- commit ecd3b4e
* Tue Mar 31 2020 ohering@suse.de
- clocksource/drivers/hyper-v: Make sched clock return nanoseconds
  correctly (git-fixes).
- commit 5751e50
* Tue Mar 31 2020 tiwai@suse.de
- thermal: Add a sanity check for invalid state at stats update
  (bsc#1166535).
- commit c368806
* Tue Mar 31 2020 glin@suse.com
- bpf: Undo incorrect __reg_bound_offset32 handling (bsc#1167722, CVE-2020-8835).
- commit ef6c245
* Mon Mar 30 2020 nmoreychaisemartin@suse.com
- net/mlx5_core: Set IB capability mask1 to fix ib_srpt connection failure (bsc#1167903)
- commit b92b72c
* Mon Mar 30 2020 ptesarik@suse.cz
- kabi/severities: Exempt IBM z/Architecture internal symbols.
- commit 61f446e
* Mon Mar 30 2020 nstange@suse.de
- kABI: shield fsnotify.h #include in libfs.c from kABI checker
  (bsc#1159198).
- commit c381542
* Mon Mar 30 2020 ptesarik@suse.cz
- s390/dasd: fix data corruption for thin provisioned devices
  (bsc#1167201 LTC#184504).
- Delete
  patches.suse/s390-dasd-disable-ese-support-due-to-possible-data-c.patch.
- commit 5c48dc0
* Mon Mar 30 2020 jeyu@suse.de
- Update patches.suse/modpost-move-the-namespace-field-in-Module.symvers-last.patch.
- update patch metadata/upstream references and move into the sorted section.
- commit 678cbc3
* Mon Mar 30 2020 ykaukab@suse.de
- usb: host: xhci-tegra: Implement basic ELPG support
  (bsc#1167765).
- usb: host: xhci-tegra: Add XUSB controller context
  (bsc#1167765).
- usb: host: xhci-tegra: Add support for XUSB context save/restore
  (bsc#1167765).
- usb: host: xhci-tegra: Enable runtime PM as late as possible
  (bsc#1167765).
- usb: host: xhci-tegra: Reuse stored register base address
  (bsc#1167765).
- usb: host: xhci-tegra: Extract firmware enable helper
  (bsc#1167765).
- usb: host: xhci-tegra: Use CNR as firmware ready indicator
  (bsc#1167765).
- usb: host: xhci-tegra: Avoid a fixed duration sleep
  (bsc#1167765).
- usb: host: xhci-tegra: Separate firmware request and load
  (bsc#1167765).
- usb: host: xhci-tegra: Fix "tega" -> "tegra" typo (bsc#1167765).
- commit da4b20d
* Mon Mar 30 2020 glin@suse.com
- net/bpfilter: fix dprintf usage for /dev/kmsg (bsc#1155518).
- bpf/btf: Fix BTF verification of enum members in struct/union
  (bsc#1155518).
- bpf: Fix cgroup ref leak in cgroup_bpf_inherit on out-of-memory
  (bsc#1155518).
- bpf: Initialize storage pointers to NULL to prevent freeing
  garbage pointer (bsc#1155518).
- commit 0e26614
* Sun Mar 29 2020 msuchanek@suse.de
- Disable hibernation on s390x (bsc#1167650).
- [mkubecek] update s390x kabi reference files (incompatible):
  CONFIG_HIBERNATION y->n, CONFIG_PM y->n
- commit f392251
* Sun Mar 29 2020 mkubecek@suse.cz
- series.conf: whitespace cleanup
- commit 963e602
* Sat Mar 28 2020 tonyj@suse.de
- blacklist.conf: add git-fixes that are in perf userspace package
- commit 4dabd66
* Sat Mar 28 2020 tonyj@suse.de
- perf/x86/amd: Add missing L2 misses event spec to AMD Family
  17h's event map (git-fixes).
- perf/x86/amd: Constrain Large Increment per Cycle events
  (git-fixes).
- perf/x86/intel/uncore: Fix missing marker for
  snr_uncore_imc_freerunning_events (git-fixes).
- perf/x86/intel: Fix PT PMI handling (git-fixes).
- perf/x86/intel/bts: Fix the use of page_private() (git-fixes).
- perf/x86/cstate: Update C-state counters for Ice Lake
  (git-fixes).
- commit c1a8c50
* Fri Mar 27 2020 bp@suse.de
- vhost: Check docket sk_family instead of call getname
  (bsc#1167629 CVE-2020-10942).
- commit b04a498
* Fri Mar 27 2020 msuchanek@suse.de
- powerpc/64s: Fix section mismatch warnings from boot code
  (bsc#1148868).
- commit 74f4898
* Fri Mar 27 2020 jbohac@suse.cz
- net: ena: Add PCI shutdown handler to allow safe kexec
  (bsc#1167421, bsc#1167423).
- commit 9ba04ea
* Fri Mar 27 2020 dwagner@suse.de
- lpfc kABI fixes for 12.8.0.0 (bsc#1164777 bsc#1164780
  bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.8.0.0 (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Remove prototype FIPS/DSS options from SLI-3
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Make debugfs ktime stats generic for NVME and SCSI
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix erroneous cpu limit of 128 on I/O statistics
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix crash in target side cable pulls hitting
  WAIT_FOR_UNREG (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- scsi: lpfc: Fix update of wq consumer index in
  lpfc_sli4_wq_release (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- scsi: lpfc: Fix crash after handling a pci error (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix scsi host template for SLI3 vports (bsc#1164777
  bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix lpfc overwrite of sg_cnt field in
  nvmefc_tgt_fcp_req (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- scsi: lpfc: Fix lockdep error - register non-static key
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: Fix kasan slab-out-of-bounds error in
  lpfc_unreg_login (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- scsi: lpfc: fix spelling mistake "Notication" -> "Notification"
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: lpfc: add RDF registration and Link Integrity FPIN logging
  (bsc#1164777 bsc#1164780 bsc#1165211 jsc#SLE-8654).
- scsi: fc: Update Descriptor definition and add RDF and
  Link Integrity FPINs (bsc#1164777 bsc#1164780 bsc#1165211
  jsc#SLE-8654).
- commit 8ee63af
* Fri Mar 27 2020 dwagner@suse.de
- Refresh series.conf
- patches.suse/scsi-target-convert-boolean-se_dev_attrib-types-to-b.patch
- patches.suse/scsi-target-fix-unmap_zeroes_data-boolean-initialisa.patch
- patches.suse/scsi-target-use-an-enum-to-track-emulate_ua_intlck_c.patch
- commit ee2196b
* Fri Mar 27 2020 tiwai@suse.de
- Input: avoid BIT() macro usage in the serio.h UAPI header
  (git-fixes).
- Input: raydium_i2c_ts - fix error codes in
  raydium_i2c_boot_trigger() (git-fixes).
- commit 6acc495
* Fri Mar 27 2020 dwagner@suse.de
- net/mlx5: Add stub for mlx5_eswitch_mode (jsc#SLE-8464).
- commit 154e4ec
* Fri Mar 27 2020 mgorman@suse.de
- sched/fair: Fix negative imbalance in imbalance calculation
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 4f5edea
* Fri Mar 27 2020 bp@suse.de
- perf/x86/amd: Add support for Large Increment per Cycle Events
  (jsc#SLE-11831).
- commit 43457d3
* Thu Mar 26 2020 ptesarik@suse.cz
- s390/setup: Fix secure ipl message (bsc#1163524 LTC#183960).
- commit dea2aed
* Thu Mar 26 2020 tbogendoerfer@suse.de
- blacklist.conf: bdd68860a044 is a dup of 17df5ae1b3e1
- commit d81f030
* Thu Mar 26 2020 tbogendoerfer@suse.de
- Documentation: networking: device drivers: Remove stray
  asterisks (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- Doc: networking/device_drivers/pensando: fix ionic.rst warnings
  (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: select CONFIG_NET_DEVLINK (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- commit 4199ffe
* Thu Mar 26 2020 tbogendoerfer@suse.de
- ionic: fix vf op lock usage (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: fix fw_status read (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: fix rxq comp packet type mask (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: clear compiler warning on hb use before set (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: restrict received packets to mtu size (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: add Rx dropped packet counter (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: drop use of subdevice tags (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: support sr-iov operations (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: ionic_if bits for sr-iov support (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: keep users rss hash across lif reset (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Remove set but not used variable 'sg_desc' (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: update driver version (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: implement support for rx sgl (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: add a watchdog timer to monitor heartbeat (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: add heartbeat check (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: reverse an interrupt coalesce calculation (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: fix up struct name comments (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: add lif_quiesce to wait for queue activity to stop
  (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: implement ethtool set-fec (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: report users coalesce request (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: use wait_on_bit_lock() rather than open code (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: simplify returns in devlink info (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- dynamic_debug: provide dynamic_hex_dump stub (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: fix stats memory dereference (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Fix an error code in ionic_lif_alloc() (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Remove unnecessary ternary operator in
  ionic_debugfs_add_ident (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: Remove unused including <linux/version.h> (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Add coalesce and other features (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add RSS support (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: Add driver stats (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: Add netdev-event handling (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add Tx and Rx handling (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add initial ethtool support (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add async link status check and basic stats (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Add Rx filter and rx_mode ndo support (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Add management of rx filters (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add the basic NDO callbacks for netdev support
  (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: Add notifyq support (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add adminq action (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- ionic: Add basic adminq support (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add interrupts and doorbells (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add basic lif support (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add port management commands (bsc#1167773 jsc#PM-1588
  jsc#ECO-1386).
- ionic: Add hardware init and device commands (bsc#1167773
  jsc#PM-1588 jsc#ECO-1386).
- ionic: Add basic framework for IONIC Network device driver
  (bsc#1167773 jsc#PM-1588 jsc#ECO-1386).
- Update config files.
- supported.conf: mark ionic supported (bsc#1167773 jsc#PM-1588 jsc#ECO-1386)
- commit 7927437
* Thu Mar 26 2020 msuchanek@suse.de
- update patch metadata and move it into sorted section
  Rename patches.suse/powerpc-pseries-fix-of_read_drc_info_cell-to-point-at-next-record.patch
  to patches.suse/powerpc-pseries-Fix-of_read_drc_info_cell-to-point-a.patch,
  update to upstream version, update upstream references and move into sorted section.
- commit 58f6e72
* Thu Mar 26 2020 mbrugger@suse.com
- Revert "net: bcmgenet: use RGMII loopback for MAC reset"
  (bsc#1167769).
- commit b9b9649
* Thu Mar 26 2020 jack@suse.cz
- ext4: Check for non-zero journal inum in ext4_calculate_overhead
  (bsc#1167288).
- commit 4a32d11
* Thu Mar 26 2020 tiwai@suse.de
- r8169: re-enable MSI on RTL8168c (git-fixes).
- net: phy: mdio-bcm-unimac: Fix clock handling (git-fixes).
- NFC: fdp: Fix a signedness bug in fdp_nci_send_patch()
  (git-fixes).
- vxlan: check return value of gro_cells_init() (git-fixes).
- net: phy: mdio-mux-bcm-iproc: check clk_prepare_enable()
  return value (git-fixes).
- iwlwifi: yoyo: don't add TLV offset when reading FIFOs
  (git-fixes).
- iwlwifi: consider HE capability when setting LDPC (git-fixes).
- gpiolib: acpi: Add quirk to ignore EC wakeups on HP x2 10 CHT +
  AXP288 model (git-fixes).
- gpiolib: acpi: Add quirk to ignore EC wakeups on HP x2 10 BYT +
  AXP288 model (git-fixes).
- gpiolib: acpi: Rework honor_wakeup option into an ignore_wake
  option (git-fixes).
- gpiolib: acpi: Correct comment for HP x2 10 honor_wakeup quirk
  (git-fixes).
- gpiolib: Fix irq_disable() semantics (git-fixes).
- intel_th: pci: Add Elkhart Lake CPU support (git-fixes).
- staging: rtl8188eu: Add device id for MERCUSYS MW150US v2
  (git-fixes).
- staging/speakup: fix get_word non-space look-ahead (git-fixes).
- drm/amd/amdgpu: Fix GPR read from debugfs (v2) (git-fixes).
- drm/lease: fix WARNING in idr_destroy (git-fixes).
- mmc: rtsx_pci: Fix support for speed-modes that relies on tuning
  (git-fixes).
- mmc: sdhci-cadence: set SDHCI_QUIRK2_PRESET_VALUE_BROKEN for
  UniPhier (git-fixes).
- altera-stapl: altera_get_note: prevent write beyond end of 'key'
  (git-fixes).
- spi: spi_register_controller(): free bus id on error paths
  (git-fixes).
- spi/zynqmp: remove entry that causes a cs glitch (git-fixes).
- spi: pxa2xx: Add CS control clock quirk (git-fixes).
- spi: qup: call spi_qup_pm_resume_runtime before suspending
  (git-fixes).
- spi: spi-omap2-mcspi: Support probe deferral for DMA channels
  (git-fixes).
- drm/amd/display: fix dcc swath size calculations on dcn1
  (git-fixes).
- drm/amd/display: Clear link settings on MST disable connector
  (git-fixes).
- drm/amdgpu: clean wptr on wb when gpu recovery (git-fixes).
- drm/mediatek: Find the cursor plane instead of hard coding it
  (git-fixes).
- drm/exynos: hdmi: don't leak enable HDMI_EN regulator if probe
  fails (git-fixes).
- drm/exynos: dsi: fix workaround for the legacy clock name
  (git-fixes).
- drm/exynos: dsi: propagate error value and silence meaningless
  warning (git-fixes).
- mmc: sdhci-cadence: use struct_size() helper (git-fixes).
- commit 963c6b7
* Thu Mar 26 2020 mhocko@suse.com
- selftests: vm: drop dependencies on page flags from mlock2 tests
  (bnc#1167384).
- commit 93ec8db
* Thu Mar 26 2020 mkubecek@suse.cz
- Update kabi files.
  Update from RC2 kernel submission (commit 2cc5c6f40e3f).
- commit bc36e97
* Wed Mar 25 2020 jack@suse.cz
- ext4: do not commit super on read-only bdev (bsc#1167288
  bsc#1167338).
- commit 3e272f3
* Wed Mar 25 2020 jack@suse.cz
- ext4: Unregister sysfs path before destroying jbd2 journal
  (bsc#1167338 bsc#1167288).
- commit 536d85c
* Wed Mar 25 2020 tiwai@suse.de
- struct phy_device kABI compatibility workaround (git-fixes).
- commit feeaa43
* Wed Mar 25 2020 tiwai@suse.de
- net: phy: fix MDIO bus PM PHY resuming (git-fixes).
- commit d42c758
* Wed Mar 25 2020 tiwai@suse.de
- net: phy: Avoid multiple suspends (git-fixes).
- commit c95182b
* Wed Mar 25 2020 tiwai@suse.de
- drm/bridge: dw-hdmi: fix AVI frame colorimetry (git-fixes).
- alarmtimer: Make alarmtimer platform device child of RTC device
  (git-fixes).
- commit ba8679d
* Wed Mar 25 2020 tiwai@suse.de
- virtio-blk: improve virtqueue error to BLK_STS (bsc#1167649).
- commit 0db14dd
* Wed Mar 25 2020 vbabka@suse.cz
- mm, slub: prevent kmalloc_node crashes and memory leaks
  (bsc#1167657, VM functionality).
- commit 4697f85
* Wed Mar 25 2020 vbabka@suse.cz
- mm: slub: be more careful about the double cmpxchg of freelist
  (bsc#1167657, VM functionality).
- commit e8bce3b
* Wed Mar 25 2020 vbabka@suse.cz
- mm: slub: add missing TID bump in kmem_cache_alloc_bulk()
  (bsc#1167657, VM functionality).
- commit 0108e02
* Wed Mar 25 2020 mkubecek@suse.cz
- fix patch metadata
- fix wrong Patch-mainline:
  patches.suse/0001-Revert-serial-uartlite-Add-runtime-support.patch
  patches.suse/0001-Revert-serial-uartlite-Do-not-use-static-struct-uart.patch
  patches.suse/0001-Revert-serial-uartlite-Move-the-uart-register.patch
  patches.suse/0001-pinctrl-baytrail-Really-serialize-all-register-acces.patch
- commit a449950
* Wed Mar 25 2020 oneukum@suse.com
- pinctrl: baytrail: Really serialize all register accesses
  (git-fixes).
- Refresh
  patches.suse/pinctrl-baytrail-Do-not-clear-IRQ-flags-on-direct-ir.patch.
- commit 3060b4c
* Wed Mar 25 2020 oneukum@suse.com
- Revert "serial-uartlite: Move the uart register" (git-fixes).
- commit 7d98e39
* Wed Mar 25 2020 oneukum@suse.com
- Revert "serial-uartlite: Do not use static struct uart_driver
  out of probe()" (git-fixes).
- commit 053f110
* Wed Mar 25 2020 oneukum@suse.com
- Revert "serial-uartlite: Add runtime support" (git-fixes).
- commit 869ee8e
* Tue Mar 24 2020 mkubecek@suse.cz
- update patch metadata
- improve Patch-mainline tag:
  patches.suse/rcuwait-Let-rcuwait_wake_up-return-whether-or-not-a-.patch
- commit f21d25e
* Tue Mar 24 2020 dbueso@suse.de
- rcuwait: Let rcuwait_wake_up() return whether or not a task was awoken (bsc#1167594).
- commit e399edf
* Tue Mar 24 2020 ptesarik@suse.cz
- Update config files: Increase NR_CPUS to 768 on arm64 to support the
  extra cores on a Marvell ThunderX3 SoC (jsc#SLE-9971).
- [mkubecek] update kabi reference files (incompatible):
  NR_CPUS raised from 480 to 768 on aarch64
- commit d52fc74
* Tue Mar 24 2020 bp@suse.de
- x86/MCE/AMD, EDAC/mce_amd: Add new Load Store unit McaType
  (jsc#SLE-11833).
- commit a9c59e2
* Tue Mar 24 2020 colyli@suse.de
- md: rename wb stuffs (bsc#1166003).
- Update with kabi fix for the above change,
  patches.kabi/md-backport-kabi.patch.
- Refresh for the above change,
  patches.suse/md-display-timeout-error.patch.
- commit eabced8
* Tue Mar 24 2020 colyli@suse.de
- raid5: remove worker_cnt_per_group argument from
  alloc_thread_groups (bsc#1166003).
- commit ffebcdb
* Tue Mar 24 2020 tiwai@suse.de
- KEYS: reaching the keys quotas correctly (bsc#1167517).
- commit 39a6103
* Tue Mar 24 2020 oneukum@suse.com
- kABI: more hooks for PCI changes (bsc#1141558).
- [mkubecek] update kabi reference files (incompatible):
  SUSE kabi padding added to some PCI related structures
- commit 29f5545
* Tue Mar 24 2020 tbogendoerfer@suse.de
- net: hns3: fix RMW issue for VLAN filter switch (bsc#1154353).
- netfilter: nf_tables: fix infinite loop when expr is not
  available (bsc#1154353).
- bnxt_en: fix error handling when flashing from file (sc#SLE-8371
  bsc#1153274 bsc#1163419).
- bnxt_en: reinitialize IRQs when MTU is modified (sc#SLE-8371
  bsc#1153274 bsc#1163419).
- bnxt_en: add newline to netdev_*() format strings (sc#SLE-8371
  bsc#1153274 bsc#1163419).
- bnxt_en: Issue PCIe FLR in kdump kernel to cleanup pending DMAs
  (sc#SLE-8371 bsc#1153274 bsc#1163419).
- bnxt_en: Improve device shutdown method (sc#SLE-8371 bsc#1153274
  bsc#1163419).
- commit 6ec4eab
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: add enospc debug messages for ticket failure   (bsc#1141456).
- Refresh
  patches.suse/btrfs-dump_space_info-when-encountering-total_bytes_pinned-0-at-umount.patch.
- commit b0b4b45
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: do not account global reserve in can_overcommit (bsc#1141456).
- commit cbebbcb
* Tue Mar 24 2020 mbrugger@suse.com
- supported.conf: mark synopsys_edac as supported.
  Used in Xilinx ZynqMP devices.
- commit 8d84988
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: use btrfs_try_granting_tickets in update_global_rsv (bsc#1141456).
- commit 2c7e1da
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: always reserve our entire size for the global reserve (bsc#1141456).
- commit 0ded727
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: change the minimum global reserve size (bsc#1141456).
- commit 20a34ab
* Tue Mar 24 2020 mbenes@suse.cz
- tracing: Add 'hist:' to hist trigger error log error string
  (bsc#1164917).
- commit c0e7e4a
* Tue Mar 24 2020 mbenes@suse.cz
- tracing: Add hist trigger error messages for sort specification
  (bsc#1164917).
- commit 9b80622
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: unexport the temporary exported functions (bsc#1162831).
- commit 795367d
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group cleanup code (bsc#1162831).
- Refresh
  patches.suse/0001-btrfs-qgroup-Always-free-PREALLOC-META-reserve-in-bt.patch.
- Refresh
  patches.suse/btrfs-dump_space_info-when-encountering-total_bytes_pinned-0-at-umount.patch.
- commit b3b0455
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the alloc_profile helpers (bsc#1162831).
- commit d4eb35f
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the chunk allocation code (bsc#1162831).
- commit 2694f31
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group space accounting helpers (bsc#1162831).
- commit cfbc882
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: export block group accounting helpers (bsc#1162831).
- commit 1701266
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the dirty bg writeout code (bsc#1162831).
- commit e9dcb00
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate inc/dec_block_group_ro code (bsc#1162831).
- Refresh
  patches.suse/0001-btrfs-qgroup-Always-free-PREALLOC-META-reserve-in-bt.patch.
- commit abe1d44
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: temporarily export btrfs_get_restripe_target (bsc#1162831).
- commit dcd4303
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group read/creation code (bsc#1162831).
- Refresh
  patches.suse/0001-btrfs-block-group-Fix-a-memory-leak-due-to-missing-b.patch.
- commit 4cffeef
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group removal code (bsc#1162831).
- commit 313711e
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: temporarily export inc_block_group_ro (bsc#1162831).
- commit 9260ebc
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group caching code (bsc#1162831).
- commit 610d6da
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: make caching_thread use btrfs_find_next_key (bsc#1162831).
- commit 32ee695
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: temporarily export fragment_free_space (bsc#1162831).
- commit b52844f
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: export the caching control helpers (bsc#1162831).
- commit 96ba87a
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: export the excluded extents helpers (bsc#1162831).
- commit 0c5df27
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: export the block group caching helpers (bsc#1162831).
- commit 01de231
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate nocow and reservation helpers (bsc#1162831).
- commit e4a70ac
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group ref counting stuff (bsc#1162831).
- commit 81d13e7
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: migrate the block group lookup code (bsc#1162831).
- commit fe38e12
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: move basic block_group definitions to their own header (bsc#1162831).
- commit a828471
* Tue Mar 24 2020 nborisov@suse.com
- btrfs: move btrfs_add_free_space out of a header file (bsc#1162831).
- commit c5144d6
* Mon Mar 23 2020 tiwai@suse.de
- USB: cdc-acm: fix rounding error in TIOCSSERIAL (git-fixes).
- usb: typec: ucsi: displayport: Fix a potential race during
  registration (git-fixes).
- usb: typec: ucsi: displayport: Fix NULL pointer dereference
  (git-fixes).
- commit 864c13e
* Mon Mar 23 2020 tiwai@suse.de
- rtc: max8907: add missing select REGMAP_IRQ (git-fixes).
- serial: 8250_exar: add support for ACCES cards (git-fixes).
- serial: ar933x_uart: set UART_CS_{RX,TX}_READY_ORIDE
  (git-fixes).
- commit ae8a796
* Mon Mar 23 2020 tiwai@suse.de
- net: phy: bcm63xx: fix OOPS due to missing driver name
  (git-fixes).
- net: phy: avoid clearing PHY interrupts twice in irq handler
  (git-fixes).
- net: phy: mscc: fix firmware paths (git-fixes).
- net: phy: restore mdio regs in the iproc mdio driver
  (git-fixes).
- net: phy: fixed_phy: fix use-after-free when checking link GPIO
  (git-fixes).
- commit 9488907
* Mon Mar 23 2020 tiwai@suse.de
- intel_th: Fix user-visible error codes (git-fixes).
- iio: chemical: sps30: fix missing triggered buffer dependency
  (git-fixes).
- iio: st_sensors: remap SMO8840 to LIS2DH12 (git-fixes).
- iio: light: vcnl4000: update sampling periods for vcnl4040
  (git-fixes).
- iio: light: vcnl4000: update sampling periods for vcnl4200
  (git-fixes).
- iio: accel: adxl372: Set iio_chan BE (git-fixes).
- iio: magnetometer: ak8974: Fix negative raw values in sysfs
  (git-fixes).
- iio: trigger: stm32-timer: disable master mode when stopping
  (git-fixes).
- iio: adc: stm32-dfsdm: fix sleep in atomic context (git-fixes).
- iio: adc: at91-sama5d2_adc: fix differential channels in
  triggered mode (git-fixes).
- mmc: sdhci-of-at91: fix cd-gpios for SAMA5D2 (git-fixes).
- mac80211: rx: avoid RCU list traversal under mutex (git-fixes).
- commit 9bd80d9
* Mon Mar 23 2020 tiwai@suse.de
- HID: add ALWAYS_POLL quirk to lenovo pixart mouse (git-fixes).
- HID: google: add moonball USB id (git-fixes).
- HID: hid-bigbenff: fix race condition for scheduled work during
  removal (git-fixes).
- HID: hid-bigbenff: call hid_hw_stop() in case of error
  (git-fixes).
- HID: hid-bigbenff: fix general protection fault caused by
  double kfree (git-fixes).
- HID: i2c-hid: add Trekstor Surfbook E11B to descriptor override
  (git-fixes).
- HID: apple: Add support for recent firmware on Magic Keyboards
  (git-fixes).
- commit 5f6c3d6
* Mon Mar 23 2020 nborisov@suse.com
- Fix patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch
  Fix earlier refresh.
- commit 479cae8
* Mon Mar 23 2020 lyan@suse.com
- Revert sgi_iodev for kabi break (bsc#1166547).
- commit 1393f42
* Mon Mar 23 2020 ykaukab@suse.de
- apei/ghes: Do not delay GHES polling (bsc#1166982).
- commit b9901b6
* Mon Mar 23 2020 jslaby@suse.cz
- net: dsa: tag_qca: Make sure there is headroom for tag
  (networking-stable-20_02_19).
- net/sched: flower: add missing validation of TCA_FLOWER_FLAGS
  (networking-stable-20_02_19).
- net/sched: matchall: add missing validation of
  TCA_MATCHALL_FLAGS (networking-stable-20_02_19).
- net/smc: fix leak of kernel memory to user space
  (networking-stable-20_02_19).
- core: Don't skip generic XDP program execution for cloned SKBs
  (networking-stable-20_02_19).
- commit f564699
* Mon Mar 23 2020 jroedel@suse.de
- Refresh patches.suse/x86-mm-split-vmalloc_sync_all.patch.
- commit 52f4443
* Mon Mar 23 2020 jroedel@suse.de
- blacklist.conf: Add 02d715b4a818 iommu/vt-d: Fix RCU list debugging warnings
- commit edb9131
* Mon Mar 23 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/signal-avoid-double-atomic-counter-increments-for-user-accounting.patch
- commit 4c51946
* Mon Mar 23 2020 mgorman@suse.de
- sched/fair: Clear SMT siblings after determining the core is
  not idle (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit fafc10a
* Mon Mar 23 2020 mgorman@suse.de
- sched/fair: fix condition of avg_load calculation (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit db78afd
* Mon Mar 23 2020 mgorman@suse.de
- signal: avoid double atomic counter increments for user
  accounting (bnc#1167415 (Kernel core performance backports)).
- commit 6ff4a7e
* Mon Mar 23 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/cgroup-iterate-tasks-that-did-not-finish-do_exit.patch
- commit 5b30728
* Mon Mar 23 2020 bp@suse.de
- EDAC/synopsys: Do not print an error with back-to-back
  snprintf() calls (bsc#1152489).
- commit 3d8b07b
* Mon Mar 23 2020 bp@suse.de
- perf/amd/uncore: Replace manual sampling check with
  CAP_NO_INTERRUPT flag (bsc#1152489).
- commit 509a4ff
* Mon Mar 23 2020 bp@suse.de
- x86/mce: Fix logic and comments around MSR_PPIN_CTL
  (bsc#1152489).
- commit c2e64b7
* Mon Mar 23 2020 bp@suse.de
- x86/pkeys: Manually set X86_FEATURE_OSPKE to preserve existing
  changes (bsc#1152489).
- commit 062e80e
* Mon Mar 23 2020 lyan@suse.com
- KVM: arm/arm64: vgic: Use a single IO device per redistributor
  (bsc#1166547).
- commit 0aaedec
* Sun Mar 22 2020 bp@suse.de
- efi/x86: Add TPM related EFI tables to unencrypted mapping
  checks (bsc#1159816).
- commit 0d7e2e6
* Sat Mar 21 2020 tiwai@suse.de
- ALSA: hda/realtek - Enable the headset of Acer N50-600 with
  ALC662 (git-fixes).
- ALSA: hda/realtek - Enable headset mic of Acer X2660G with
  ALC662 (git-fixes).
- ALSA: seq: oss: Fix running status after receiving sysex
  (git-fixes).
- ALSA: seq: virmidi: Fix running status after receiving sysex
  (git-fixes).
- ALSA: pcm: oss: Remove WARNING from snd_pcm_plug_alloc() checks
  (git-fixes).
- ALSA: hda/realtek: Fix pop noise on ALC225 (git-fixes).
- ALSA: line6: Fix endless MIDI read loop (git-fixes).
- ALSA: pcm: oss: Avoid plugin buffer overflow (git-fixes).
- commit ed262e3
* Fri Mar 20 2020 ptesarik@suse.cz
- s390/pci: Fix possible deadlock in recover_store() (bsc#1165187
  LTC#184105).
- commit 121df27
* Fri Mar 20 2020 ptesarik@suse.cz
- s390/pci: Recover handle in clp_set_pci_fn() (bsc#1165187
  LTC#184105).
- commit 5d2c6ee
* Fri Mar 20 2020 ptesarik@suse.cz
- s390/pkey: fix missing length of protected key on return
  (git-fixes).
- s390/zcrypt: Fix CCA cipher key gen with clear key value
  function (git-fixes).
- commit 6bb7487
* Fri Mar 20 2020 ptesarik@suse.cz
- s390/mm: fix dynamic pagetable upgrade for hugetlbfs
  (bsc#1165181 LTC#184104).
- commit 5c2c836
* Fri Mar 20 2020 jeyu@suse.de
- module: avoid setting info->name early in case we can fall back to
  info->mod->name (git-fixes).
- commit eebf8d1
* Fri Mar 20 2020 jeyu@suse.de
- blacklist.conf: blacklist f6d061d61712
- commit 72a83b2
* Fri Mar 20 2020 mkoutny@suse.com
- cgroup: memcg: net: do not associate sock with unrelated cgroup
  (bsc#1167241).
- commit 844ea7f
* Fri Mar 20 2020 colyli@suse.de
- md: fix a typo s/creat/create (bsc#1166003).
- commit 5717a6b
* Fri Mar 20 2020 colyli@suse.de
- md/raid6: fix algorithm choice under larger PAGE_SIZE
  (bsc#1166003).
- raid6/test: fix a compilation warning (bsc#1166003).
- raid6/test: fix a compilation error (bsc#1166003).
- commit b4c3abd
* Fri Mar 20 2020 colyli@suse.de
- md-bitmap: small cleanups (bsc#1166003).
- md: make sure desc_nr less than MD_SB_DISKS (bsc#1166003).
- md: raid1: check rdev before reference in raid1_sync_request
  func (bsc#1166003).
- drivers/md/raid5.c: use the new spelling of
  RWH_WRITE_LIFE_NOT_SET (bsc#1166003).
- md: avoid invalid memory access for array sb->dev_roles
  (bsc#1166003).
- md/raid1: avoid soft lockup under high load (bsc#1166003).
- commit f5e32ec
* Fri Mar 20 2020 colyli@suse.de
- md: no longer compare spare disk superblock events in super_load
  (bsc#1166003).
- commit ac7ff9d
* Fri Mar 20 2020 colyli@suse.de
- md/bitmap: avoid race window between md_bitmap_resize and
  bitmap_file_clear_bit (bsc#1166003).
- commit 1195535
* Thu Mar 19 2020 mkoutny@suse.com
- cgroup: Iterate tasks that did not finish do_exit()
  (bsc#1167151).
- commit 16348dc
* Thu Mar 19 2020 yousaf.kaukab@suse.com
- arm64: fix config and supported.conf for MTD devices on NXP boards
  References: bsc#1167137
  Get rid of CONFIG_MTD_PHYSMAP_COMPAT and enable CONFIG_MTD_PHYSMAP_OF.
  Compat maps of zero length (CONFIG_MTD_PHYSMAP_LEN=0x0) doesn't make
  sense and driver initialization is bound to fail.
  Update supported.conf to include required modules.
- commit c23c1f0
* Thu Mar 19 2020 jeyu@suse.de
- modpost: return error if module is missing ns imports and
  MODULE_ALLOW_MISSING_NAMESPACE_IMPORTS=n (jsc#SLE-10158).
- Refresh patches.suse/supported-flag.
- Refresh patches.suse/supported-flag-modverdir.
- commit 686d15e
* Thu Mar 19 2020 msuchanek@suse.de
- cpufreq: powernv: Fix unsafe notifiers (bsc#1065729).
- cpufreq: powernv: Fix use-after-free (bsc#1065729).
- powerpc: fix hardware PMU exception bug on PowerVM compatibility
  mode systems (bsc#1056686).
- commit c0f95eb
* Wed Mar 18 2020 nborisov@suse.com
- Btrfs: fix race leading to metadata space leak after task
  received  signal (bsc#1141456).
- Refresh
  patches.suse/btrfs-run-btrfs_try_granting_tickets-if-a-priority-ticket-fails.patch.
- commit 0d2889a
* Wed Mar 18 2020 colyli@suse.de
- raid5: use bio_end_sector in r5_next_bio (bsc#1166003).
- raid5: remove STRIPE_OPS_REQ_PENDING (bsc#1166003).
- md: add feature flag MD_FEATURE_RAID0_LAYOUT (bsc#1166003).
- md/raid5: use bio_end_sector to calculate last_sector (bsc#1166003).
- commit 7e33890
* Wed Mar 18 2020 colyli@suse.de
- md raid0/linear: Mark array as 'broken' and fail BIOs if a member is
  gone (bsc#1166003).
- Refresh for the above change,
  patches.suse/md-raid0-avoid-RAID0-data-corruption-due-to-layout-c.patch.
- commit a563707
* Wed Mar 18 2020 colyli@suse.de
- raid5 improve too many read errors msg by adding limits (bsc#1166003).
- raid1: factor out a common routine to handle the
  completion of sync write (bsc#1166003).
- md: allow last device to be forcibly removed from RAID1/RAID10 (bsc#1166003).
- Update with kabi fix for the above change,
  patches.kabi/md-backport-kabi.patch
- md: Convert to use int_pow() (bsc#1166003).
- commit aa334d3
* Wed Mar 18 2020 hare@suse.de
- nvme: Translate more status codes to blk_status_t (bsc#1156510).
- nvme: Fix parsing of ANA log page (bsc#1166658).
- nvme: resync include/linux/nvme.h with nvmecli (bsc#1156510).
- commit 672f1cb
* Wed Mar 18 2020 colyli@suse.de
- md/raid10: end bio when the device faulty (bsc#1166003).
- Refresh for the above change,
  patches.suse/md-display-timeout-error.patch.
- commit 760aa49
* Wed Mar 18 2020 colyli@suse.de
- raid1: use an int as the return value of raise_barrier() (bsc#1166003).
- commit 5ac4a79
* Wed Mar 18 2020 jack@suse.cz
- ext4: potential crash on allocation error in
  ext4_alloc_flex_bg_array() (bsc#1166940).
- commit a1c176a
* Wed Mar 18 2020 tiwai@suse.de
- ARM: 8961/2: Fix Kbuild issue caused by per-task stack protector
  GCC plugin (git-fixes).
- ARM: 8958/1: rename missed uaccess .fixup section (git-fixes).
- ARM: 8957/1: VDSO: Match ARMv8 timer in cntvct_functional()
  (git-fixes).
- efi: Add a sanity check to efivar_store_raw() (git-fixes).
- drm/i915: be more solid in checking the alignment (git-fixes).
- mt76: fix array overflow on receiving too many fragments for
  a packet (git-fixes).
- ARM: imx: build v7_cpu_resume() unconditionally (git-fixes).
- drm/amd/display: remove duplicated assignment to grph_obj_type
  (git-fixes).
- commit 7fe5a8f
* Wed Mar 18 2020 tiwai@suse.de
- blacklist.conf: Add a reverted amdgpu entry
- commit 916aa15
* Tue Mar 17 2020 jack@suse.cz
- blktrace: fix dereference after null check (bsc#1159285).
- commit df5056f
* Tue Mar 17 2020 jack@suse.cz
- blacklist.conf: Blacklist d87683620489
- commit 87e4a94
* Tue Mar 17 2020 jack@suse.cz
- jbd2: fix ocfs2 corrupt when clearing block group bits
  (bsc#1166878).
- commit 4ccf692
* Tue Mar 17 2020 jack@suse.cz
- io_uring: fix __io_iopoll_check deadlock in io_sq_thread
  (bsc#1166876).
- commit 47c1bb0
* Tue Mar 17 2020 jack@suse.cz
- io_uring: prevent sq_thread from spinning when it should stop
  (bsc#1166875).
- commit 59a5904
* Tue Mar 17 2020 jack@suse.cz
- ecryptfs: replace BUG_ON with error handling code (bsc#1166874).
- commit 7eb7c45
* Tue Mar 17 2020 jack@suse.cz
- ecryptfs: fix a memory leak bug in ecryptfs_init_messaging()
  (bsc#1166872).
- commit 58a8bc1
* Tue Mar 17 2020 jack@suse.cz
- ecryptfs: fix a memory leak bug in parse_tag_1_packet()
  (bsc#1166871).
- commit c7ebfb4
* Tue Mar 17 2020 jack@suse.cz
- ext4: fix race between writepages and enabling EXT4_EXTENTS_FL
  (bsc#1166870).
- commit d4cc10a
* Tue Mar 17 2020 jack@suse.cz
- ext4: rename s_journal_flag_rwsem to s_writepages_rwsem
  (bsc#1166868).
- commit 3fea683
* Tue Mar 17 2020 jack@suse.cz
- ext4: fix potential race between s_flex_groups online resizing
  and access (bsc#1166867).
- commit 8b31558
* Tue Mar 17 2020 jack@suse.cz
- ext4: fix potential race between s_group_info online resizing
  and access (bsc#1166866).
- commit 8fec0cb
* Tue Mar 17 2020 jack@suse.cz
- ext4: fix potential race between online resizing and write
  operations (bsc#1166864).
- commit 8ac7c77
* Tue Mar 17 2020 jack@suse.cz
- ext4: add cond_resched() to __ext4_find_entry() (bsc#1166862).
- commit 098ad12
* Tue Mar 17 2020 jack@suse.cz
- ext4: fix a data race in EXT4_I(inode)->i_disksize
  (bsc#1166861).
- commit ff7b112
* Tue Mar 17 2020 jack@suse.cz
- ext4: don't assume that mmp_nodename/bdevname have NUL
  (bsc#1166860).
- commit 26f5b12
* Tue Mar 17 2020 jack@suse.cz
- block, bfq: get a ref to a group when adding it to a service
  tree (bsc#1166859).
- commit 0cc750a
* Tue Mar 17 2020 jack@suse.cz
- blacklist.conf: Blacklist 4d8340d0d4d9
- commit a9eb92c
* Tue Mar 17 2020 tiwai@suse.de
- i2c: gpio: suppress error on probe defer (git-fixes).
- i2c: i801: Do not add ICH_RES_IO_SMI for the iTCO_wdt device
  (git-fixes).
- iwlwifi: mvm: Do not require PHY_SKU NVM section for 3168
  devices (bsc#1166632).
- crypto: pcrypt - Fix user-after-free on module unload
  (git-fixes).
- iwlwifi: mvm: fix NVM check for 3168 devices (git-fixes).
- ASoC: pcm: update FE/BE trigger order based on the command
  (git-fixes).
- commit 0ca34dd
* Tue Mar 17 2020 bp@suse.de
- x86/amd_nb, char/amd64-agp: Use amd_nb_num() accessor
  (bsc#1152489).
- [mkubecek] update kabi files (incompatible):
  - drop amd_nb_misc_ids symbol (no longer exported so that we can add more
    device ids later)
- commit bb3cbed
* Mon Mar 16 2020 dbueso@suse.de
- sys/sysinfo: Respect boottime inside time namespace
  (bsc#1164648,jsc#SLE-11493).
- commit 695315f
* Mon Mar 16 2020 nborisov@suse.com
- btrfs: run btrfs_try_granting_tickets if a priority ticket fails
  (bsc#1141456).
- btrfs: only check priority tickets for priority flushing
  (bsc#1141456).
- btrfs: Account for trans_block_rsv in may_commit_transaction
  (bsc#1141456).
- btrfs: allow us to use up to 90%% of the global rsv for unlink
  (bsc#1141456).
- btrfs: Improve global reserve stealing logic (bsc#1141456).
- btrfs: force chunk allocation if our global rsv is larger than
  metadata (bsc#1141456).
- commit 0e267e6
* Mon Mar 16 2020 tzimmermann@suse.de
- drm/virtio: module_param_named() requires linux/moduleparam.h (bsc#1152489)
- commit bbc436c
* Mon Mar 16 2020 jroedel@suse.de
- iommu/vt-d: Fix debugfs register reads (bsc#1166769).
- commit acf3bd7
* Mon Mar 16 2020 nborisov@suse.com
- Refresh patches.suse/btrfs-dump_space_info-when-encountering-total_bytes_pinned-0-at-umount.patch.
- commit 867843d
* Mon Mar 16 2020 tzimmermann@suse.de
- drm/i915/gt: Close race between cacheline_retire and free (bsc#1152489)
  Additional changes:
  * Added i915_active_acquire_if_busy() to
  drivers/gpu/drm/i915/i915_active.{c,h}. See upstream
  commit b1e3177bd1d8f
- commit 0111275
* Mon Mar 16 2020 tzimmermann@suse.de
- drm/virtio: make resource id workaround runtime switchable. (bsc#1152489)
- commit 370ca9c
* Mon Mar 16 2020 jroedel@suse.de
- x86/ioremap: Map EFI runtime services data as encrypted for SEV
  (bsc#1160508).
- commit 27cbc80
* Mon Mar 16 2020 mkubecek@suse.cz
- Add kabi reference files - import from KotD (commit 49476dcf3399)
  Enable kabi checking for -default and -preempt flavors.
- commit fe7e9d8
* Mon Mar 16 2020 jroedel@suse.de
- iommu/vt-d: Populate debugfs if IOMMUs are detected
  (bsc#1166728).
- iommu/vt-d: Ignore devices with out-of-spec domain number
  (bsc#1166727).
- iommu/vt-d: Fix the wrong printing in RHSA parsing
  (bsc#1166726).
- iommu/vt-d: quirk_ioat_snb_local_iommu: replace WARN_TAINT
  with pr_warn + add_taint (bsc#1166729).
- iommu/vt-d: dmar: replace WARN_TAINT with pr_warn + add_taint
  (bsc#1166723).
- iommu/vt-d: Fix RCU-list bugs in intel_iommu_init()
  (bsc#1166725).
- iommu/dma: Fix MSI reservation allocation (bsc#1166722).
- iommu/vt-d: Fix a bug in intel_iommu_iova_to_phys() for huge
  page (bsc#1166724).
- commit eb2e9ee
* Sun Mar 15 2020 ailiopoulos@suse.com
- xfs: report corruption only as a regular error (bsc#1166687).
- commit abd2d39
* Sun Mar 15 2020 ailiopoulos@suse.com
- xfs: add a XFS_IS_CORRUPT macro (bsc#1166686).
- commit 877ee95
* Sun Mar 15 2020 ailiopoulos@suse.com
- xfs: make the assertion message functions take a mount parameter
  (bsc#1166685).
- commit 7bd7696
* Fri Mar 13 2020 ailiopoulos@suse.com
- xfs: check attribute leaf block structure (bsc#1166153).
- commit 1008e2c
* Fri Mar 13 2020 jslaby@suse.cz
- net: dsa: microchip: enable module autoprobe
  (networking-stable-20_02_09).
- net: dsa: b53: Always use dev->vlan_enabled in
  b53_configure_vlan() (networking-stable-20_02_09).
- net: stmmac: fix a possible endless loop
  (networking-stable-20_02_09).
- net: systemport: Avoid RBUF stuck in Wake-on-LAN mode
  (networking-stable-20_02_09).
- net: mvneta: move rx_dropped and rx_errors in per-cpu stats
  (networking-stable-20_02_09).
- qed: Fix timestamping issue for L2 unicast ptp packets
  (networking-stable-20_02_09).
- net: macb: Limit maximum GEM TX length in TSO
  (networking-stable-20_02_09).
- net: macb: Remove unnecessary alignment check for TSO
  (networking-stable-20_02_09).
- bonding/alb: properly access headers in bond_alb_xmit()
  (networking-stable-20_02_09).
- devlink: report 0 after hitting end in region read
  (networking-stable-20_02_09).
- net_sched: fix a resource leak in tcindex_set_parms()
  (networking-stable-20_02_09).
- commit c82701f
* Fri Mar 13 2020 nsaenzjulienne@suse.de
- mmc: sdhci: iproc: Add custom set_power() callback for bcm2711
  (bsc#1165954).
- mmc: sdhci: Introduce sdhci_set_power_and_bus_voltage()
  (bsc#1165954).
- commit a751850
* Fri Mar 13 2020 ailiopoulos@suse.com
- fs: add generic UNRESVSP and ZERO_RANGE ioctl handlers
  (bsc#1165806, bsc#1165807).
- commit 59a3783
* Fri Mar 13 2020 ailiopoulos@suse.com
- xfs: don't implement XFS_IOC_RESVSP / XFS_IOC_RESVSP64
  (bsc#1165806, bsc#1165807).
- commit 17753e3
* Fri Mar 13 2020 duwe@suse.de
- crypto: arm{,64} neon: memzero_explicit aes-cbc key
  (bsc#1165167, FIPS).
- commit cb788e3
* Fri Mar 13 2020 ptesarik@suse.cz
- Refresh
  patches.suse/scsi-ibmvfc-Avoid-loss-of-all-paths-during-SVC-node-.patch.
- commit bb81764
* Fri Mar 13 2020 tiwai@suse.de
- drm/i915: Defer semaphore priority bumping to a workqueue
  (git-fixes).
- drm/i915/gvt: Fix dma-buf display blur issue on CFL (git-fixes).
- drm/i915/gvt: Fix unnecessary schedule timer when no vGPU exits
  (git-fixes).
- nl80211: add missing attribute validation for channel switch
  (git-fixes).
- nl80211: add missing attribute validation for beacon report
  scanning (git-fixes).
- nl80211: add missing attribute validation for critical protocol
  indication (git-fixes).
- batman-adv: Don't schedule OGM for disabled interface
  (git-fixes).
- macvlan: add cond_resched() during multicast processing
  (git-fixes).
- nfc: add missing attribute validation for vendor subcommand
  (git-fixes).
- nfc: add missing attribute validation for deactivate target
  (git-fixes).
- nfc: add missing attribute validation for SE API (git-fixes).
- tipc: add missing attribute validation for MTU property
  (git-fixes).
- team: add missing attribute validation for array index
  (git-fixes).
- team: add missing attribute validation for port ifindex
  (git-fixes).
- macsec: add missing attribute validation for port (git-fixes).
- can: add missing attribute validation for termination
  (git-fixes).
- nl802154: add missing attribute validation for dev_type
  (git-fixes).
- nl802154: add missing attribute validation (git-fixes).
- firmware: imx: Align imx_sc_msg_req_cpu_start to 4 (git-fixes).
- firmware: imx: scu-pd: Align imx sc msg structs to 4
  (git-fixes).
- firmware: imx: misc: Align imx sc msg structs to 4 (git-fixes).
- firmware: imx: scu: Ensure sequential TX (git-fixes).
- tty:serial:mvebu-uart:fix a wrong return (git-fixes).
- usb: dwc3: gadget: Update chain bit correctly when using sg list
  (git-fixes).
- usb: storage: Add quirk for Samsung Fit flash (git-fixes).
- usb: quirks: add NO_LPM quirk for Logitech Screen Share
  (git-fixes).
- media: hantro: Fix broken media controller links (git-fixes).
- media: mc-entity.c: use & to check pad flags, not ==
  (git-fixes).
- media: v4l2-mem2mem.c: fix broken links (git-fixes).
- dmaengine: tegra-apb: Prevent race conditions of tasklet vs
  free list (git-fixes).
- dmaengine: tegra-apb: Fix use-after-free (git-fixes).
- audit: always check the netlink payload length in
  audit_receive_msg() (git-fixes).
- audit: fix error handling in audit_data_to_entry() (git-fixes).
- watchdog: da9062: do not ping the hw during stop() (git-fixes).
- habanalabs: patched cb equals user cb in device memset
  (git-fixes).
- habanalabs: do not halt CoreSight during hard reset (git-fixes).
- habanalabs: halt the engines before hard-reset (git-fixes).
- usb: gadget: serial: fix Tx stall after buffer overflow
  (git-fixes).
- usb: gadget: ffs: ffs_aio_cancel(): Save/restore IRQ flags
  (git-fixes).
- usb: gadget: composite: Support more than 500mA MaxPower
  (git-fixes).
- drm/modes: Allow DRM_MODE_ROTATE_0 when applying video mode
  parameters (git-fixes).
- drm/modes: Make sure to parse valid rotation value from cmdline
  (git-fixes).
- drm/msm/dsi/pll: call vco set rate explicitly (git-fixes).
- drm/msm/dsi: save pll state before dsi host is powered off
  (git-fixes).
- drm: msm: Fix return type of dsi_mgr_connector_mode_valid for
  kCFI (git-fixes).
- drm/msm/mdp5: rate limit pp done timeout warnings (git-fixes).
- ALSA: hda: do not override bus codec_mask in link_get()
  (git-fixes).
- vfio-ccw: Use the correct style for SPDX License Identifier
  (git-fixes).
- commit d192c28
* Fri Mar 13 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-padata-initialize-pd-cpu-with-effective-cpumask.patch
  patches.suse/0001-padata-pcrypt-take-CPU-hotplug-lock-internally-in-pa.patch
  patches.suse/0001-padata-unbind-parallel-jobs-from-specific-CPUs.patch
  patches.suse/0001-padata-use-separate-workqueues-for-parallel-and-seri.patch
  patches.suse/0001-workqueue-unconfine-alloc-apply-free_workqueue_attrs.patch
- commit c637d96
* Fri Mar 13 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/ibmvnic-Do-not-process-device-remove-during-device-r.patch
- commit aed6449
* Thu Mar 12 2020 tiwai@suse.de
- Move the upstreamed ipmi_si patch into sorted section
- commit ca4ab45
* Thu Mar 12 2020 dbueso@suse.de
- pid: Fix error return value in some cases
  (bsc#1164648,jsc#SLE-11493).
- commit 2c02126
* Thu Mar 12 2020 msuchanek@suse.de
- blacklist.conf: expand wildcards.
- commit 7232917
* Thu Mar 12 2020 tiwai@suse.de
- arm64: dts: qcom: Add Lenovo Yoga C630 (jsc#SLE-9418).
- commit 5c6966e
* Thu Mar 12 2020 tiwai@suse.de
- x86/intel: Disable HPET on Intel Ice Lake platforms (git-fixes).
- x86/intel: Disable HPET on Intel Coffee Lake H platforms
  (git-fixes).
- commit df3778b
* Thu Mar 12 2020 tiwai@suse.de
- pinctrl: core: Remove extra kref_get which blocks hogs being
  freed (git-fixes).
- pinctrl: imx: scu: Align imx sc msg structs to 4 (git-fixes).
- pinctrl: meson-gxl: fix GPIOX sdio pins (git-fixes).
- virtio_balloon: Adjust label in virtballoon_probe (git-fixes).
- virtio_ring: Fix mem leak with vring_new_virtqueue()
  (git-fixes).
- Revert "PM / devfreq: Modify the device name as devfreq(X)
  for sysfs" (git-fixes).
- nfc: pn544: Fix occasional HW initialization failure
  (git-fixes).
- NFC: pn544: Fix a typo in a debug message (git-fixes).
- gpio: xilinx: Fix bug where the wrong GPIO register is written
  to (git-fixes).
- irqchip/gic-v3: Only provision redistributors that are enabled
  in ACPI (git-fixes).
- virtio_balloon: prevent pfn array overflow (git-fixes).
- clk: Use parent node pointer during registration if necessary
  (git-fixes).
- gpu/drm: ingenic: Avoid null pointer deference in plane atomic
  update (git-fixes).
- gpio: gpio-grgpio: fix possible sleep-in-atomic-context bugs
  in grgpio_irq_map/unmap() (git-fixes).
- fore200e: Fix incorrect checks of NULL pointer dereference
  (git-fixes).
- NFC: port100: Convert cpu_to_le16(le16_to_cpu(E1) + E2) to
  use le16_add_cpu() (git-fixes).
- irqchip/mbigen: Set driver .suppress_bind_attrs to avoid remove
  problems (git-fixes).
- ACPICA: Disassembler: create buffer fields in
  ACPI_PARSE_LOAD_PASS1 (git-fixes).
- gpio: add gpiod_toggle_active_low() (git-fixes).
- XArray: Fix xas_find returning too many entries (git-fixes).
- XArray: Fix xa_find_after with multi-index entries (git-fixes).
- XArray: Fix infinite loop with entry at ULONG_MAX (git-fixes).
- XArray: Fix xas_pause at ULONG_MAX (git-fixes).
- commit aac43c5
* Thu Mar 12 2020 yousaf.kaukab@suse.com
- Revert "tick/common: Make tick_periodic() check for missing ticks"
  This reverts commit 4d65090f1171433dc9438813b674f86d4925eb9c.
  Patch causes hard lockup. See [1] for details. Issue is fixed with
  Marvell frimware v7.4.1
  [1]: https://lkml.org/lkml/2020/3/6/1245
- commit be5e348
* Thu Mar 12 2020 ptesarik@suse.cz
- Enable CONFIG_KEXEC_SIG on s390x (jsc#SLE-8923).
- commit 3dbf242
* Wed Mar 11 2020 tiwai@suse.de
- Update patch reference for console security fix (CVE-2020-8647 bsc#1162929 CVE-2020-8649 bsc#1162931)
- commit 3e9c1d2
* Wed Mar 11 2020 oneukum@suse.com
- padata, pcrypt: take CPU hotplug lock internally in
  padata_alloc_possible (git-fixes).
- commit aad348d
* Wed Mar 11 2020 mhocko@suse.com
- x86/mm: Split vmalloc_sync_all() (bsc#1165741).
- commit 6f59f79
* Wed Mar 11 2020 oneukum@suse.com
- workqueue: unconfine alloc/apply/free_workqueue_attrs()
  (git-fixes).
- commit 00cf9ef
* Wed Mar 11 2020 oneukum@suse.com
- crypto: pcrypt - Avoid deadlock by using per-instance padata
  queues (git-fixes).
- commit 2487df7
* Wed Mar 11 2020 oneukum@suse.com
- padata: unbind parallel jobs from specific CPUs (git-fixes).
- Refresh
  patches.suse/0001-padata-Remove-broken-queue-flushing.patch.
- commit f5446c1
* Wed Mar 11 2020 mkubecek@suse.cz
- patch metadata cleanup
- drop duplicate References line:
  patches.suse/sched-fair-fix-statistics-for-find_idlest_group.patch
- commit d4e3168
* Wed Mar 11 2020 mkubecek@suse.cz
- series.conf: tidy up
- "inherited SP1 patches for review" section is emtpy, drop the header
- drop a pointless comment
- commit d5cfa09
* Wed Mar 11 2020 oneukum@suse.com
- padata: use separate workqueues for parallel and serial work
  (git-fixes).
- commit 93a8f87
* Wed Mar 11 2020 nborisov@suse.com
- refresh and enable: patches.suse/btrfs-dump_space_info-when-encountering-total_bytes_pinned-0-at-umount.patch
- commit 0883fb3
* Wed Mar 11 2020 nborisov@suse.com
- refresh and enable: patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch
- commit e7ac692
* Wed Mar 11 2020 mgorman@suse.de
- sched/fair: Fix reordering of enqueue/dequeue_task_fair()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Fix runnable_avg for throttled cfs (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/topology: Don't enable EAS on SMT systems (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/numa: Acquire RCU lock for checking idle cores during
  NUMA balancing (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/fair: Fix kernel build warning in test_idle_cores()
  for !SMT NUMA (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- commit 54c1e7e
* Wed Mar 11 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-fix-statistics-for-find_idlest_group.patch.
- commit 19f7ff2
* Wed Mar 11 2020 jslaby@suse.cz
- vt: selection, push sel_lock up (bnc#1162928 CVE-2020-8648).
- vt: selection, push console lock down (bnc#1162928
  CVE-2020-8648).
- commit 826e708
* Wed Mar 11 2020 mkubecek@suse.cz
- supported.conf: cleanup
  Remove entries for modules which are only built into vmlinuz image and no
  longer as a module on any supported architecture.
- commit 442ceef
* Wed Mar 11 2020 tbogendoerfer@suse.de
- net: export netdev_next_lower_dev_rcu() (bsc#1154353).
- commit 50e6fb7
* Wed Mar 11 2020 mkubecek@suse.cz
- supported.conf: proper sort
  While having all modules belonging to internal KMPs (i.e. marked with
  "+foo-kmp" style guards) on top of supported.conf might seem intentional,
  it was in fact only a side effect of a bug in supported-conf-fixup which
  did not expect guards with a dash ('-').
  Sort the file properly now to avoid potential mistakes resulting from wrong
  order of entries.
- commit 26973fc
* Wed Mar 11 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-crypto-pcrypt-remove-padata-cpumask-notifier.patch
  patches.suse/0001-padata-Replace-delayed-timer-with-immediate-workqueu.patch
  patches.suse/0001-padata-allocate-workqueue-internally.patch
  patches.suse/0001-padata-initialize-pd-cpu-with-effective-cpumask.patch
  patches.suse/0001-padata-make-padata_do_parallel-find-alternate-callba.patch
  patches.suse/0001-padata-purge-get_cpu-and-reorder_via_wq-from-padata_.patch
  patches.suse/0001-virtio-blk-fix-hw_queue-stopped-on-arbitrary-error.patch
- commit bc937a8
* Wed Mar 11 2020 msuchanek@suse.de
- ibmvnic: Do not process device remove during device reset
  (bsc#1065729).
- commit cc9dad3
* Tue Mar 10 2020 msuchanek@suse.de
- ibmvnic: Warn unknown speed message only when carrier is present
  (bsc#1065729).
- commit e9a3130
* Tue Mar 10 2020 dbueso@suse.de
- arm64/spinlock: fix a -Wunused-function warning (bsc#1149032).
- locking/rwsem: Fix kernel crash when spinning on
  RWSEM_OWNER_UNKNOWN (bsc#1149032).
- futex: Fix kernel-doc notation warning (bsc#1149032).
- commit 4912275
* Tue Mar 10 2020 dbueso@suse.de
- Revert "ipc,sem: remove uneeded sem_undo_list lock usage in
  exit_sem()" (bsc#1159886).
- powerpc/spinlocks: Fix oops in __spin_yield() on bare metal
  (bsc#1149032).
- powerpc/spinlocks: Rename SPLPAR-only spinlocks (bsc#1149032).
- commit 4b45f4c
* Tue Mar 10 2020 oneukum@suse.com
- padata: initialize pd->cpu with effective cpumask (git-fixes).
- Refresh
  patches.suse/0001-padata-Remove-broken-queue-flushing.patch.
- commit c8738d9
* Tue Mar 10 2020 oneukum@suse.com
- padata: purge get_cpu and reorder_via_wq from padata_do_serial
  (git-fixes).
- commit 32854ac
* Tue Mar 10 2020 oneukum@suse.com
- padata: Replace delayed timer with immediate workqueue in
  padata_reorder (git-fixes).
- Refresh
  patches.suse/0001-padata-Remove-broken-queue-flushing.patch.
- commit ab62460
* Tue Mar 10 2020 oneukum@suse.com
- padata: Remove broken queue flushing (git-fixes).
- commit feb9def
* Tue Mar 10 2020 oneukum@suse.com
- crypto: pcrypt - remove padata cpumask notifier (git-fixes).
- commit 61ed2ae
* Tue Mar 10 2020 oneukum@suse.com
- padata: make padata_do_parallel find alternate callback CPU
  (git-fixes).
- commit 1bf4612
* Tue Mar 10 2020 oneukum@suse.com
- padata: allocate workqueue internally (git-fixes).
- commit c16372d
* Tue Mar 10 2020 tbogendoerfer@suse.de
- RDMA/odp: Ensure the mm is still alive before creating an
  implicit child (jsc#SLE-8449).
- IB/mlx5: Fix implicit ODP race (jsc#SLE-8446).
- RDMA/core: Fix pkey and port assignment in get_new_pps
  (jsc#SLE-8449).
- RDMA/rw: Fix error flow during RDMA context initialization
  (jsc#SLE-8449).
- RDMA/core: Fix use of logical OR in get_new_pps (jsc#SLE-8449).
- commit 76634af
* Tue Mar 10 2020 oneukum@suse.com
- virtio-blk: fix hw_queue stopped on arbitrary error (git-fixes).
- commit 1b95f96
* Tue Mar 10 2020 dwagner@suse.de
- i2c: exynos5: Remove IRQF_ONESHOT (bsc#1162702).
- i2c: hix5hd2: Remove IRQF_ONESHOT (bsc#1162702).
- commit b6d534c
* Tue Mar 10 2020 ailiopoulos@suse.com
- xfs: constify the buffer pointer arguments to error functions
  (bsc#1166226).
- commit a8f2d26
* Tue Mar 10 2020 jlee@suse.com
- Delete
  patches.suse/0057-acpi-Disable-APEI-error-injection-if-the-kernel-is-l.patch.
  Removed this patch because it was not sent to kernel mainline with other
  kernel lockdown patches. Maintainers didn't reponse for why this patch
  not be sent. So, I removed this patch to align mainline kernel.
- commit cfa2dff
* Tue Mar 10 2020 nsaenzjulienne@suse.de
- mmc: sdhci-pci-gli: Enable MSI interrupt for GL975x (git-fixes).
- commit b05ab91
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/sun4i: Add separate DE3 VI layer formats (bsc#1152472)
- commit 9c87cd6
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/virtio: fix resource id creation race (bsc#1152489)
- commit 875669e
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/radeon: Inline drm_get_pci_dev (bsc#1152472)
- commit 27b152d
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/i915: Update drm/i915 bug filing URL (bsc#1152489)
- commit e0978de
* Tue Mar 10 2020 nsaenzjulienne@suse.de
- Refresh: patches.suse/firmware-raspberrypi-introduce-vl805-init-routine.patch
  There is a missing inline in a function declaration. As this is a bug in
  the upstream submission, a subsequent series will be sent.
- commit 24cdb0d
* Tue Mar 10 2020 jlee@suse.com
- efi: fix a race and a buffer overflow while reading efivars
  via sysfs (bsc#1164893).
- commit 57ac0e8
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/nouveau/kms/gv100-: Re-set LUT after clearing for modesets (bsc#1152472)
- commit 6746148
* Tue Mar 10 2020 tzimmermann@suse.de
- drm/vgem: Close use-after-free race in vgem_gem_create (bsc#1152472)
- commit 65490f2
* Tue Mar 10 2020 tzimmermann@suse.de
- Revert "drm/amd/display: Don't skip link training for empty dongle" (bsc#1152489)
- commit 62bee52
* Tue Mar 10 2020 tzimmermann@suse.de
- vgacon: Fix a UAF in vgacon_invert_region (bsc#1152472)
- commit b9949b5
* Tue Mar 10 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/usercopy-Avoid-soft-lockups-in-test_check_nonzero_us.patch
- commit 1ec8a33
* Tue Mar 10 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-iwlwifi-mvm-remove-d0i3_ap_sta_id.patch
  patches.suse/0001-iwlwifi-mvm-remove-last-leftovers-of-d0i3.patch
  patches.suse/0001-iwlwifi-mvm-remove-the-d0i3-entry-exit-flow.patch
  patches.suse/0001-iwlwifi-mvm-remove-the-tx-defer-for-d0i3.patch
  patches.suse/0001-iwlwifi-mvm-start-to-remove-the-code-for-d0i3.patch
  patches.suse/0001-iwlwifi-remove-all-the-d0i3-references.patch
- commit c0e601f
* Tue Mar 10 2020 mkubecek@suse.cz
- series.conf: cleanup
- move into sorted section
  patches.suse/scsi-target-fix-unmap_zeroes_data-boolean-initialisa.patch
  patches.suse/scsi-target-convert-boolean-se_dev_attrib-types-to-b.patch
  patches.suse/scsi-target-use-an-enum-to-track-emulate_ua_intlck_c.patch
- commit 2ee4b82
* Tue Mar 10 2020 ailiopoulos@suse.com
- xfs: fix attr leaf header freemap.size underflow (bsc#1166164).
- commit 33188db
* Tue Mar 10 2020 ailiopoulos@suse.com
- xfs: fix some memory leaks in log recovery (bsc#1166162).
- commit 0fc66f0
* Tue Mar 10 2020 ailiopoulos@suse.com
- xfs: attach dquots before performing xfs_swap_extents
  (bsc#1166161).
- commit 1da5af8
* Tue Mar 10 2020 ailiopoulos@suse.com
- xfs: range check ri_cnt when recovering log items (bsc#1166160).
- commit 90b681f
* Tue Mar 10 2020 ailiopoulos@suse.com
- xfs: always log corruption errors (bsc#1166158).
- commit 4ceca97
* Tue Mar 10 2020 ailiopoulos@suse.com
- xfs: replace -EIO with -EFSCORRUPTED for corrupt metadata
  (bsc#1166156).
- commit 8aae262
* Tue Mar 10 2020 ailiopoulos@suse.com
- xfs: namecheck directory entry names before listing them
  (bsc#1166155).
- commit bd61b8e
* Tue Mar 10 2020 ailiopoulos@suse.com
- xfs: namecheck attribute names before listing them
  (bsc#1166154).
- commit eddc1b8
* Tue Mar 10 2020 ailiopoulos@suse.com
- xfs: cap longest free extent to maximum allocatable
  (bsc#1166152).
- commit 9db4cae
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: Fix deadlock between AGI and AGF when target_ip exists
  in xfs_rename() (bsc#1166149).
- commit 2f06de6
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: check log iovec size to make sure it's plausibly a buffer
  log format (bsc#1166147).
- commit 266b31b
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: convert EIO to EFSCORRUPTED when log contents are invalid
  (bsc#1166145).
- commit 343511d
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: also call xfs_file_iomap_end_delalloc for zeroing
  operations (bsc#1166144).
- commit 5e9fd03
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: fix inode fork extent count overflow (bsc#1166143).
- commit 016eaf4
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: log proper length of superblock (bsc#1166140).
- commit 3caa90e
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: convert inode to extent format after extent merge due to
  shift (bsc#1166136).
- commit d852ad3
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: Use WARN_ON_ONCE for bailout mount-operation (bsc#1166133).
- commit cc00b41
* Mon Mar  9 2020 ailiopoulos@suse.com
- xfs: fix maxicount division by zero error (bsc#1166132).
- commit d8d261a
* Mon Mar  9 2020 jeyu@suse.de
- rpm/kabi.pl: account for namespace field being moved last
  Upstream is moving the namespace field in Module.symvers last in order to
  preserve backwards compatibility with kmod tools (depmod, etc). Fix the kabi.pl
  script to expect the namespace field last. Since split() ignores trailing empty
  fields and delimeters, switch to using tr to count how many fields/tabs are in
  a line. Also, in load_symvers(), pass LIMIT of -1 to split() so it does not
  strip trailing empty fields, as namespace is an optional field.
- commit a3bb253
* Mon Mar  9 2020 dbueso@suse.de
- lib/vdso: Only read hrtimer_res when needed in
  __cvdso_clock_getres() (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Check for right timens offsets after fork
  and exec (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add a simple perf test for clock_gettime()
  (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add timer offsets test
  (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add procfs selftest
  (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add a test for clock_nanosleep()
  (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add a test for timerfd
  (bsc#1164648,jsc#SLE-11493).
- selftests/timens: Add Time Namespace test for supported clocks
  (bsc#1164648,jsc#SLE-11493).
- fs/proc: Introduce /proc/pid/timens_offsets
  (bsc#1164648,jsc#SLE-11493).
- x86/vdso: Zap vvar pages when switching to a time namespace
  (bsc#1164648,jsc#SLE-11493).
- x86/vdso: On timens page fault prefault also VVAR page
  (bsc#1164648,jsc#SLE-11493).
- x86/vdso: Handle faults on timens page
  (bsc#1164648,jsc#SLE-11493).
- time: Allocate per-timens vvar page (bsc#1164648,jsc#SLE-11493).
- x86/vdso: Add time napespace page (bsc#1164648,jsc#SLE-11493).
- update x86_64 configs: GENERIC_VDSO_TIME_NS=y, TIME_NS=y
- x86/vdso: Provide vdso_data offset on vvar_page
  (bsc#1164648,jsc#SLE-11493).
- lib/vdso: Prepare for time namespace support
  (bsc#1164648,jsc#SLE-11493).
- refresh config files (drop TIME_NS - no longer available)
- x86/vdso: Restrict splitting VVAR VMA
  (bsc#1164648,jsc#SLE-11493).
- fs/proc: Respect boottime inside time namespace for /proc/uptime
  (bsc#1164648,jsc#SLE-11493).
- posix-timers: Make clock_nanosleep() time namespace aware
  (bsc#1164648,jsc#SLE-11493).
- hrtimers: Prepare hrtimer_nanosleep() for time namespaces
  (bsc#1164648,jsc#SLE-11493).
- alarmtimer: Make nanosleep() time namespace aware
  (bsc#1164648,jsc#SLE-11493).
- posix-timers: Make timer_settime() time namespace aware
  (bsc#1164648,jsc#SLE-11493).
- timerfd: Make timerfd_settime() time namespace aware
  (bsc#1164648,jsc#SLE-11493).
- time: Add do_timens_ktime_to_host() helper
  (bsc#1164648,jsc#SLE-11493).
- posix-clocks: Wire up clock_gettime() with timens offsets
  (bsc#1164648,jsc#SLE-11493).
- posix-timers: Use clock_get_ktime() in common_timer_get()
  (bsc#1164648,jsc#SLE-11493).
- posix-clocks: Introduce clock_get_ktime() callback
  (bsc#1164648,jsc#SLE-11493).
- alarmtimer: Provide get_timespec() callback
  (bsc#1164648,jsc#SLE-11493).
- alarmtimer: Rename gettime() callback to get_ktime()
  (bsc#1164648,jsc#SLE-11493).
- posix-clocks: Rename .clock_get_timespec() callbacks accordingly
  (bsc#1164648,jsc#SLE-11493).
- posix-clocks: Rename the clock_get() callback to
  clock_get_timespec() (bsc#1164648,jsc#SLE-11493).
- time: Add timens_offsets to be used for tasks in time namespace
  (bsc#1164648,jsc#SLE-11493).
- ns: Introduce Time Namespace (bsc#1164648,jsc#SLE-11493).
- update config files: TIME_NS=y (=n in s390x/zfcpdump)
- lib/vdso: Mark do_hres() and do_coarse() as __always_inline
  (bsc#1164648,jsc#SLE-11493).
- lib/vdso: Add unlikely() hint into vdso_read_begin()
  (bsc#1164648,jsc#SLE-11493).
- lib/vdso: Avoid duplication in __cvdso_clock_getres()
  (bsc#1164648,jsc#SLE-11493).
- lib/vdso: Let do_coarse() return 0 to simplify the callsite
  (bsc#1164648,jsc#SLE-11493).
- lib/vdso: Make __cvdso_clock_getres() static
  (bsc#1164648,jsc#SLE-11493).
- clone3: ensure copy_thread_tls is implemented
  (bsc#1163988,bsc#1164648,jsc#SLE-11493).
- ubsan, x86: Annotate and allow
  __ubsan_handle_shift_out_of_bounds() in uaccess regions
  (bsc#1164648,jsc#SLE-11493).
- fork: extend clone3() to support setting a PID
  (bsc#1164648,jsc#SLE-11493).
- clone3: add CLONE_CLEAR_SIGHAND (bsc#1164648,jsc#SLE-11493).
- tools headers UAPI: Sync sched.h with the kernel
  (bsc#1164648,jsc#SLE-11493).
- usercopy: Avoid soft lockups in test_check_nonzero_user()
  (bsc#1164648,jsc#SLE-11493).
- lib: test_user_copy: style cleanup (bsc#1164648,jsc#SLE-11493).
- usercopy: Add parentheses around assignment in
  test_copy_struct_from_user (bsc#1164648,jsc#SLE-11493).
- clone3: switch to copy_struct_from_user()
  (bsc#1164648,jsc#SLE-11493).
- lib: introduce copy_struct_from_user() helper
  (bsc#1164648,jsc#SLE-11493).
- sched: add kernel-doc for struct clone_args
  (bsc#1164648,jsc#SLE-11493).
- commit 992f679
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- kprobes: Fix optimize_kprobe()/unoptimize_kprobe() cancellation
  logic (git-fixes).
- commit d42d5d9
* Mon Mar  9 2020 dbueso@suse.de
- Delete
  patches.suse/clone3-ensure-copy_thread_tls-is-implemented.patch.
- commit 5c13d46
* Mon Mar  9 2020 oneukum@suse.com
- usb: core: port: do error out if usb_autopm_get_interface()
  fails (git-fixes).
- usb: core: hub: do error out if usb_autopm_get_interface()
  fails (git-fixes).
- commit 011bc72
* Mon Mar  9 2020 tiwai@suse.de
- Revert "drm/fbdev: Fallback to non tiled mode if all tiles
  not present" (bsc#1051510).
- commit 07e015b
* Mon Mar  9 2020 jeyu@suse.de
- modpost: move the namespace field in Module.symvers last
  (jsc#SLE-10158).
- Refresh patches.suse/supported-flag.
- commit d026ef9
* Mon Mar  9 2020 oneukum@suse.com
- USB: misc: iowarrior: add support for 2 OEMed devices
  (git-fixes).
- commit e40d2a1
* Mon Mar  9 2020 oneukum@suse.com
- USB: Fix novation SourceControl XL after suspend (git-fixes).
- commit 25b0137
* Mon Mar  9 2020 jroedel@suse.de
- KVM: VMX: check descriptor table exits on instruction emulation
  (bsc#1166091).
- commit bf59879
* Mon Mar  9 2020 tiwai@suse.de
- drm/i915/selftests: Fix return in assert_mmap_offset()
  (git-fixes).
- drm/i915: Program MBUS with rmw during initialization
  (git-fixes).
- drm/sun4i: Fix DE2 VI layer format support (git-fixes).
- drm/sun4i: de2/de3: Remove unsupported VI layer formats
  (git-fixes).
- drm/i915/gvt: Fix orphan vgpu dmabuf_objs' lifetime (git-fixes).
- drm/i915/gvt: Separate display reset from ALL_ENGINES reset
  (git-fixes).
- drm/amdgpu: Drop DRIVER_USE_AGP (git-fixes).
- drm/i915: Wean off drm_pci_alloc/drm_pci_free (git-fixes).
- drm/i915/gt: Protect defer_request() from new waiters
  (git-fixes).
- drm/msm/dpu: fix BGR565 vs RGB565 confusion (git-fixes).
- drm/amdgpu/gfx10: disable gfxoff when reading rlc clock
  (git-fixes).
- drm/amdgpu/gfx9: disable gfxoff when reading rlc clock
  (git-fixes).
- drm/amdgpu/soc15: fix xclk for raven (git-fixes).
- drm/amd/display: Check engine is not NULL before acquiring
  (git-fixes).
- drm/amd/display: Do not set optimized_require to false after
  plane disable (git-fixes).
- drm/msm: Set dma maximum segment size for mdss (git-fixes).
- drm/amdgpu/smu10: fix smu10_get_clock_by_type_with_voltage
  (git-fixes).
- drm/amdgpu/smu10: fix smu10_get_clock_by_type_with_latency
  (git-fixes).
- drm/amdgpu/display: handle multiple numbers of fclks in
  dcn_calcs.c (v2) (git-fixes).
- drm/amdkfd: Fix a bug in SDMA RLC queue counting under HWS mode
  (git-fixes).
- drm/amd/display: do not allocate display_mode_lib unnecessarily
  (git-fixes).
- drm/nouveau/disp/nv50-: prevent oops when no channel method
  map provided (git-fixes).
- drm/nouveau/mmu: fix comptag memory leak (git-fixes).
- drm/amd/display: fixup DML dependencies (git-fixes).
- drm/amd/display: Clear state after exiting fixed active VRR
  state (git-fixes).
- drm/nouveau/fault/gv100-: fix memory leak on module unload
  (git-fixes).
- drm/nouveau/drm/ttm: Remove set but not used variable 'mem'
  (git-fixes).
- drm/nouveau/gr/gk20a,gm200-: add terminators to method lists
  read from fw (git-fixes).
- drm/mediatek: handle events when enabling/disabling crtc
  (git-fixes).
- drm/amdkfd: Fix permissions of hang_hws (git-fixes).
- drm/amdgpu: fix KIQ ring test fail in TDR of SRIOV (git-fixes).
- drm: remove the newline for CRC source name (git-fixes).
- drm/amdgpu: Ensure ret is always initialized when using
  SOC15_WAIT_ON_RREG (git-fixes).
- drm/gma500: Fixup fbdev stolen size usage evaluation
  (git-fixes).
- drm/fbdev: Fallback to non tiled mode if all tiles not present
  (git-fixes).
- commit c42f713
* Mon Mar  9 2020 tiwai@suse.de
- dma-buf: free dmabuf->name in dma_buf_release() (git-fixes).
- dmaengine: imx-sdma: Fix the event id check to include RX
  event for UART6 (git-fixes).
- dmaengine: imx-sdma: fix context cache (git-fixes).
- dmaengine: coh901318: Fix a double lock bug in dma_tc_handle()
  (git-fixes).
- clocksource: davinci: only enable clockevents once tim34 is
  initialized (git-fixes).
- cmd64x: potential buffer overflow in cmd64x_program_timings()
  (git-fixes).
- dmaengine: Store module owner in dma_device struct (git-fixes).
- dmaengine: change alignment of mux_configure32 and
  fsl_edma_chan_mux (git-fixes).
- commit b143f5d
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- net: bcmgenet: Clear ID_MODE_DIS in EXT_RGMII_OOB_CTRL when
  not needed (git-fixes).
- dma-direct: relax addressability checks in dma_direct_supported
  (git-fixes).
- kprobes: Set unoptimized flag after unoptimizing code
  (git-fixes).
- dma-direct: don't check swiotlb=force in dma_direct_map_resource
  (git-fixes).
- Refresh: patches.suse/dma-direct-exclude-dma_direct_map_resource-from-the-min_low_pfn-check.patch
- dma/direct: turn ARCH_ZONE_DMA_BITS into a variable (git-fixes).
- Refresh: patches.suse/dma-direct-avoid-a-forward-declaration-for-phys_to_dma.patch
- Refresh: patches.suse/dma-mapping-treat-dev-bus_dma_mask-as-a-dma-limit.patch
- Refresh: patches.suse/dma-mapping-treat-dev-bus_dma_mask-as-a-dma-limit.patch
- commit ee87f08
* Mon Mar  9 2020 tiwai@suse.de
- blacklist.conf: Add dma/imx-sdma entries that have been reverted
- commit f53a68f
* Mon Mar  9 2020 tiwai@suse.de
- usb: core: hub: fix unhandled return by employing a void
  function (git-fixes).
- commit 9ef677e
* Mon Mar  9 2020 tiwai@suse.de
- usb: core: port: do error out if usb_autopm_get_interface()
  fails (git-fixes).
- usb: core: hub: do error out if usb_autopm_get_interface()
  fails (git-fixes).
- staging: vt6656: fix sign of rx_dbm to bb_pre_ed_rssi
  (git-fixes).
- vt: vt_ioctl: fix race in VT_RESIZEX (git-fixes).
- vt: fix scrollback flushing on background consoles (git-fixes).
- USB: misc: iowarrior: add support for the 100 device
  (git-fixes).
- usb: dwc2: Fix SET/CLEAR_FEATURE and GET_STATUS flows
  (git-fixes).
- usb: dwc2: Fix in ISOC request length checking (git-fixes).
- usb: gadget: composite: Fix bMaxPower for SuperSpeedPlus
  (git-fixes).
- usb: dwc3: gadget: Check for IOC/LST bit in TRB->ctrl fields
  (git-fixes).
- usb: gadget: udc-xilinx: Fix xudc_stop() kernel-doc format
  (git-fixes).
- USB: misc: iowarrior: add support for the 28 and 28L devices
  (git-fixes).
- USB: misc: iowarrior: add support for 2 OEMed devices
  (git-fixes).
- USB: Fix novation SourceControl XL after suspend (git-fixes).
- xhci: Fix memory leak when caching protocol extended capability
  PSI tables - take 2 (git-fixes).
- USB: quirks: blacklist duplicate ep on Sound Devices USBPre2
  (git-fixes).
- USB: core: add endpoint-blacklist quirk (git-fixes).
- usb: dwc3: debug: fix string position formatting mixup with
  ret and len (git-fixes).
- USB: hub: Don't record a connect-change event during
  reset-resume (git-fixes).
- usb: charger: assign specific number for enum value (git-fixes).
- usb: uas: fix a plug & unplug racing (git-fixes).
- USB: hub: Fix the broken detection of USB3 device in SMSC hub
  (git-fixes).
- xhci: apply XHCI_PME_STUCK_QUIRK to Intel Comet Lake platforms
  (git-fixes).
- xhci: fix runtime pm enabling for quirky Intel hosts
  (git-fixes).
- xhci: Force Maximum Packet size for Full-speed bulk devices
  to valid range (git-fixes).
- xprtrdma: Fix DMA scatter-gather list mapping imbalance
  (git-fixes).
- uio: fix a sleep-in-atomic-context bug in
  uio_dmem_genirq_irqcontrol() (git-fixes).
- usb: musb: omap2430: Get rid of musb .set_vbus for omap2430 glue
  (git-fixes).
- usb: gadget: udc: fix possible sleep-in-atomic-context bugs
  in gr_probe() (git-fixes).
- usb: dwc2: Fix IN FIFO allocation (git-fixes).
- usbip: Fix unsafe unaligned pointer usage (git-fixes).
- wan/hdlc_x25: fix skb handling (git-fixes).
- wan: ixp4xx_hss: fix compile-testing on 64-bit (git-fixes).
- watchdog/softlockup: Enforce that timestamp is valid on boot
  (git-fixes).
- usb: dwc3: use proper initializers for property entries
  (git-fixes).
- commit 7d830dc
* Mon Mar  9 2020 tiwai@suse.de
- tty: serial: fsl_lpuart: free IDs allocated by IDA (git-fixes).
- spi: bcm63xx-hsspi: Really keep pll clk enabled (git-fixes).
- spi: atmel-quadspi: fix possible MMIO window size overrun
  (git-fixes).
- spi: spidev: Fix CS polarity if GPIO descriptors are used
  (git-fixes).
- tty: serial: qcom_geni_serial: Fix RX cancel command failure
  (git-fixes).
- tty: serial: imx: setup the correct sg entry for tx dma
  (git-fixes).
- tty/serial: atmel: manage shutdown in case of RS485 or ISO7816
  mode (git-fixes).
- thunderbolt: Prevent crash if non-active NVMem file is read
  (git-fixes).
- tpm: Initialize crypto_id of allocated_banks to HASH_ALGO__LAST
  (git-fixes).
- soc/tegra: fuse: Fix build with Tegra194 configuration
  (git-fixes).
- tty: synclink_gt: Adjust indentation in several functions
  (git-fixes).
- tty: synclinkmp: Adjust indentation in several functions
  (git-fixes).
- commit f7b10ec
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- USB: pci-quirks: Add Raspberry Pi 4 quirk (bsc#1163560).
- soc: bcm2835: Sync xHCI reset firmware property with downstream
  (bsc#1163560).
- PCI: brcmstb: Wait for Raspberry Pi's firmware when present
  (bsc#1163560).
- firmware: raspberrypi: Introduce vl805 init routine
  (bsc#1163560).
- commit e30de5f
* Mon Mar  9 2020 tiwai@suse.de
- regulator: stm32-vrefbuf: fix a possible overshoot when
  re-enabling (git-fixes).
- staging: rtl8723bs: Fix potential overuse of kernel memory
  (git-fixes).
- staging: rtl8188eu: Fix potential overuse of kernel memory
  (git-fixes).
- staging: rtl8723bs: Fix potential security hole (git-fixes).
- staging: rtl8188eu: Fix potential security hole (git-fixes).
- staging: rtl8723bs: fix copy of overlapping memory (git-fixes).
- serial: 8250: Check UPF_IRQ_SHARED in advance (git-fixes).
- serdev: ttyport: restore client ops on deregistration
  (git-fixes).
- reset: uniphier: Add SCSSI reset control for each channel
  (git-fixes).
- remoteproc: Initialize rproc_class before use (git-fixes).
- staging: rtl8188: avoid excessive stack usage (git-fixes).
- rtw88: fix rate mask for 1SS chip (git-fixes).
- rtlwifi: rtl_pci: Fix -Wcast-function-type (git-fixes).
- commit b3aad35
* Mon Mar  9 2020 tiwai@suse.de
- phy: mapphone-mdm6600: Fix timeouts by adding wake-up handling
  (git-fixes).
- phy: mapphone-mdm6600: Fix write timeouts with shorter GPIO
  toggle interval (git-fixes).
- qmi_wwan: unconditionally reject 2 ep interfaces (git-fixes).
- radeon: insert 10ms sleep in dce5_crtc_load_lut (git-fixes).
- pinctrl: baytrail: Do not clear IRQ flags on direct-irq enabled
  pins (git-fixes).
- pinctrl: sh-pfc: sh7269: Fix CAN function GPIOs (git-fixes).
- pinctrl: sh-pfc: sh7264: Fix CAN function GPIOs (git-fixes).
- r8169: check that Realtek PHY driver module is loaded
  (git-fixes).
- commit 1f5e949
* Mon Mar  9 2020 tiwai@suse.de
- PCI: Fix pci_add_dma_alias() bitmask size (git-fixes).
- PCI: Increase D3 delay for AMD Ryzen5/7 XHCI controllers
  (git-fixes).
- PCI: Add generic quirk for increasing D3hot delay (git-fixes).
- PCI: iproc: Apply quirk_paxc_bridge() for module as well as
  built-in (git-fixes).
- commit 124e17e
* Mon Mar  9 2020 tiwai@suse.de
- mac80211: Remove a redundant mutex unlock (git-fixes).
- ipmi:ssif: Handle a possible NULL pointer reference (git-fixes).
- mac80211: fix wrong 160/80+80 MHz setting (git-fixes).
- mac80211: consider more elements in parsing CRC (git-fixes).
- iwlwifi: mvm: Check the sta is not NULL in iwl_mvm_cfg_he_sta()
  (git-fixes).
- iwlwifi: mvm: Fix thermal zone registration (git-fixes).
- media: uvcvideo: Add a quirk to force GEO GC6500 Camera
  bits-per-pixel value (git-fixes).
- media: sti: bdisp: fix a possible sleep-in-atomic-context bug
  in bdisp_device_run() (git-fixes).
- media: i2c: mt9v032: fix enum mbus codes and frame sizes
  (git-fixes).
- media: v4l2-device.h: Explicitly compare grp{id,mask} to zero
  in v4l2_device macros (git-fixes).
- media: cx23885: Add support for AVerMedia CE310B (git-fixes).
- orinoco: avoid assertion in case of NULL pointer (git-fixes).
- iwlegacy: Fix -Wcast-function-type (git-fixes).
- ipw2x00: Fix -Wcast-function-type (git-fixes).
- commit 57f0620
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- PCI: brcmstb: Fix build on 32bit ARM platforms with older
  compilers (jsc#SLE-7772).
- commit ca7a98f
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- delete: patches.suse/linux-log2-h-add-roundup-rounddown_pow_two64-family-of-functions.patch
  Not needed anymore
- commit c7ab3e3
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- update and move into sorted section: patches.suse/pci-brcmstb-add-msi-support.patch
- commit 71e1948
* Mon Mar  9 2020 nsaenzjulienne@suse.de
- refresh and move into sorted section:
  patches.suse/pci-brcmstb-add-broadcom-stb-pcie-host-controller-driver.patch
- commit b774a70
* Mon Mar  9 2020 martin.wilck@suse.com
- drm/i915/execlists: Always force a context reload when rewinding
  RING_TAIL (bsc#1161207).
- commit 8af101c
* Mon Mar  9 2020 vbabka@suse.cz
- Refresh
  patches.suse/mm-hotplug-fix-page-online-with-debug_pagealloc-compiled-but-not-enabled.patch.
- commit went mainline from a non-git maintainer repository, add proper metadata
- commit e59a6b6
* Mon Mar  9 2020 tiwai@suse.de
- blacklist.conf: Add input/rmi4 revert patch that was already blacklisted
- commit 730af68
* Mon Mar  9 2020 tiwai@suse.de
- i2c: altera: Fix potential integer overflow (git-fixes).
- Input: synaptics - remove the LEN0049 dmi id from topbuttonpad
  list (git-fixes).
- Input: synaptics - enable SMBus on ThinkPad L470 (git-fixes).
- Input: synaptics - switch T470s to RMI4 by default (git-fixes).
- Input: edt-ft5x06 - work around first register access error
  (git-fixes).
- ide: serverworks: potential overflow in svwks_set_pio_mode()
  (git-fixes).
- commit 99877db
* Mon Mar  9 2020 tiwai@suse.de
- hwmon: (adt7462) Fix an error return in ADT7462_REG_VOLT()
  (git-fixes).
- HID: alps: Fix an error handling path in
  'alps_input_configured()' (git-fixes).
- HID: hiddev: Fix race in in hiddev_disconnect() (git-fixes).
- HID: core: increase HID report buffer size to 8KiB (git-fixes).
- HID: core: fix off-by-one memset in hid_report_raw_event()
  (git-fixes).
- HID: ite: Only bind to keyboard USB interface on Acer SW5-012
  keyboard dock (git-fixes).
- commit 3cf2320
* Mon Mar  9 2020 tiwai@suse.de
- floppy: check FDC index for errors before assigning it
  (CVE-2020-9383 bsc#1165111).
- commit 47c6d94
* Mon Mar  9 2020 tiwai@suse.de
- crypto: rename sm3-256 to sm3 in hash_algo_name (git-fixes).
- driver core: platform: fix u32 greater or equal to zero
  comparison (git-fixes).
- driver core: Print device when resources present in
  really_probe() (git-fixes).
- driver core: platform: Prevent resouce overflow from causing
  infinite loops (git-fixes).
- crypto: chtls - Fixed memory leak (git-fixes).
- commit 934bfba
* Mon Mar  9 2020 tiwai@suse.de
- bus: ti-sysc: Fix 1-wire reset quirk (git-fixes).
- cfg80211: add missing policy for NL80211_ATTR_STATUS_CODE
  (git-fixes).
- cfg80211: check wiphy driver existence for drvinfo report
  (git-fixes).
- commit 518082f
* Mon Mar  9 2020 tiwai@suse.de
- ACPI: watchdog: Fix gas->access_width usage (git-fixes).
- ACPICA: Introduce ACPI_ACCESS_BYTE_WIDTH() macro (git-fixes).
- b43legacy: Fix -Wcast-function-type (git-fixes).
- ACPI: button: Add DMI quirk for Razer Blade Stealth 13 late
  2019 lid switch (git-fixes).
- commit d4fdd22
* Mon Mar  9 2020 tiwai@suse.de
- amdgpu/gmc_v9: save/restore sdpif regs during S3 (git-fixes).
- ASoC: Intel: sof_rt5682: Ignore the speaker amp when there
  isn't one (git-fixes).
- ASoC: soc-topology: fix endianness issues (git-fixes).
- ASoC: SOF: Intel: hda: Add iDisp4 DAI (git-fixes).
- ASoC: intel: sof_rt5682: Add support for tgl-max98357a-rt5682
  (git-fixes).
- ASoC: intel: sof_rt5682: Add quirk for number of HDMI DAI's
  (git-fixes).
- ASoC: SOF: Intel: hda: Fix SKL dai count (git-fixes).
- commit b3e9ee6
* Mon Mar  9 2020 tiwai@suse.de
- ALSA: ctl: allow TLV read operation for callback type of
  element in locked case (git-fixes).
- ALSA: usx2y: Adjust indentation in snd_usX2Y_hwdep_dsp_status
  (git-fixes).
- commit d5a4d9f
* Mon Mar  9 2020 tiwai@suse.de
- ASoC: wm8741: Fix typo in Kconfig prompt (git-fixes).
- ASoC: SOF: Fix snd_sof_ipc_stream_posn() (git-fixes).
- ASoC: dapm: Correct DAPM handling of active widgets during
  shutdown (git-fixes).
- ASoC: Intel: Skylake: Fix available clock counter incrementation
  (git-fixes).
- ASoC: meson: g12a: add tohdmitx reset (git-fixes).
- ASoC: pcm512x: Fix unbalanced regulator enable call in probe
  error path (git-fixes).
- ASoC: soc-core: fix for_rtd_codec_dai_rollback() macro
  (git-fixes).
- ASoC: topology: Fix memleak in soc_tplg_manifest_load()
  (git-fixes).
- ASoC: topology: Fix memleak in soc_tplg_link_elems_load()
  (git-fixes).
- ASoC: pcm: Fix possible buffer overflow in dpcm state sysfs
  output (git-fixes).
- ASoC: intel: skl: Fix possible buffer overflow in debug outputs
  (git-fixes).
- ASoC: intel: skl: Fix pin debug prints (git-fixes).
- ALSA: hda/realtek - Enable the headset of ASUS B9450FA with
  ALC294 (git-fixes).
- ALSA: hda/realtek - Fix silent output on Gigabyte X570 Aorus
  Master (git-fixes).
- ALSA: hda/realtek - Add Headset Button supported for ThinkPad X1
  (git-fixes).
- ALSA: hda/realtek - Add Headset Mic supported (git-fixes).
- ALSA: hda/realtek - Fix a regression for mute led on Lenovo
  Carbon X1 (git-fixes).
- commit 533eaf3
* Sat Mar  7 2020 msuchanek@suse.de
- powerpc/pseries: fix of_read_drc_info_cell() to point at next
  record (bsc#1165980 ltc#183834).
- commit 1ae6694
* Sat Mar  7 2020 msuchanek@suse.de
- libnvdimm/pfn_dev: Don't clear device memmap area during
  generic namespace probe (bsc#1165929 bsc#1165950 bsc#1166323).
- commit dd773b9
* Fri Mar  6 2020 ailiopoulos@suse.com
- xfs: also remove cached ACLs when removing the underlying attr
  (bsc#1165873).
- commit 8ec3453
* Fri Mar  6 2020 ddiss@suse.de
- patches.suse/scsi-target-use-an-enum-to-track-emulate_ua_intlck_c.patch:
  (bsc#1163617).
- patches.suse/scsi-target-convert-boolean-se_dev_attrib-types-to-b.patch:
  (bsc#1163617).
- patches.suse/scsi-target-fix-unmap_zeroes_data-boolean-initialisa.patch:
  (bsc#1163617).
- commit 182fa83
* Fri Mar  6 2020 dwagner@suse.de
- sched/rt, workqueue: Use PREEMPTION (bsc#1162702).
- sched/core: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, locking: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, mm: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, btrfs: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, fs: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, xen: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, net: Use CONFIG_PREEMPTION.patch (bsc#1162702).
- sched/rt, xtensa: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, sparc: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, sh: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, s390: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, riscv: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, parisc: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, nios2: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, nds32: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, MIPS: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, microblaze: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, ia64: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, hexagon: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, h8300: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, csky: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, c6x: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, ARC: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, powerpc: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, arm64: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/rt, ARM: Use CONFIG_PREEMPTION (bsc#1162702).
- rcu: Use CONFIG_PREEMPTION where appropriate (bsc#1162702).
- m68k/coldfire: Use CONFIG_PREEMPTION (bsc#1162702).
- backlight: Kconfig: jornada720: Use CONFIG_PREEMPTION
  (bsc#1162702).
- drm/i810: Refer to `PREEMPTION' in comment (bsc#1162702).
- media: cec-gpio: Use CONFIG_PREEMPTION (bsc#1162702).
- commit d311e76
* Fri Mar  6 2020 dwagner@suse.de
- x86/kvm: Use CONFIG_PREEMPTION (bsc#1162702).
- x86/dumpstack: Indicate PREEMPT_RT in dumps (bsc#1162702).
- x86: Use CONFIG_PREEMPTION (bsc#1162702).
  Refresh patches.suse/x86-xen-32-Make-xen_iret_crit_fixup-independent-of-f.patch
- kprobes: Use CONFIG_PREEMPTION (bsc#1162702).
- tracing: Use CONFIG_PREEMPTION (bsc#1162702).
- locking/spinlocks: Use CONFIG_PREEMPTION (bsc#1162702).
- rcu: Use CONFIG_PREEMPTION (bsc#1162702).
- sched/preempt: Use CONFIG_PREEMPTION where appropriate
  (bsc#1162702).
  Refresh patches.suse/sched-fair-Rework-load_balance.patch
- commit 6a43532
* Fri Mar  6 2020 jslaby@suse.cz
- selftests: Install settings files to fix TIMEOUT failures
  (git-fixes).
- commit b511dec
* Fri Mar  6 2020 msuchanek@suse.de
- powerpc/smp: Use nid as fallback for package_id (bsc#1165813
  ltc#184091).
- commit 6ff58c9
* Fri Mar  6 2020 msuchanek@suse.de
- update powerpc fadump patches
- update to version in maintainer repository and move into sorted section:
  Refresh patches.suse/powerpc-fadump-sysfs-for-fadump-memory-reservation.patch.
  patches.suse/powerpc-fadump-sysfs-for-fadump-memory-reservation.patch
  patches.suse/Documentation-ABI-add-ABI-documentation-for-sys-kern.patch -> patches.suse/Documentation-ABI-Add-ABI-documentation-for-sys-kern.patch
  patches.suse/Documentation-ABI-mark-sys-kernel-fadump_-sysfs-file.patch -> patches.suse/Documentation-ABI-Mark-sys-kernel-fadump_-sysfs-file.patch
  patches.suse/powerpc-fadump-reorganize-sys-kernel-fadump_-sysfs-f.patch -> patches.suse/powerpc-fadump-Reorganize-sys-kernel-fadump_-sysfs-f.patch
  patches.suse/powerpc-powernv-move-core-and-fadump_release_opalcor.patch -> patches.suse/powerpc-powernv-Move-core-and-fadump_release_opalcor.patch
  patches.suse/sysfs-wrap-__compat_only_sysfs_link_entry_to_kobj-fu.patch -> patches.suse/sysfs-Wrap-__compat_only_sysfs_link_entry_to_kobj-fu.patch
- commit 3b382c0
* Fri Mar  6 2020 msuchanek@suse.de
- treewide: remove redundant IS_ERR() before error code check (bsc#1156395).
- Refresh patches.suse/sysfs-wrap-__compat_only_sysfs_link_entry_to_kobj-fu.patch.
- commit 4eaa7b9
* Fri Mar  6 2020 msuchanek@suse.de
- powerpc/book3s64: Fix error handling in mm_iommu_do_alloc()
  (bsc#1156395).
- commit aca1a7b
* Fri Mar  6 2020 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patches out of sorted section
  No effect on expanded tree.
- commit 6151f14
* Fri Mar  6 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/cifs-Use-define-in-cifs_dbg.patch
  patches.suse/cifs-add-missing-mount-option-to-proc-mounts.patch
  patches.suse/cifs-don-t-leak-EAGAIN-for-stat-during-reconnect.patch
  patches.suse/cifs-fix-potential-mismatch-of-UNC-paths.patch
  patches.suse/cifs-fix-rename-by-ensuring-source-handle-opened-wit.patch
  patches.suse/fs-cifs-Initialize-filesystem-timestamp-ranges.patch
- commit ec2b8cb
* Fri Mar  6 2020 msuchanek@suse.de
- update patches.suse/powerpc-drmem-avoid-NULL-pointer-dereference-when-dr.patch
- update to version from maintainer repository and move into sorted section
- commit 9c11a0c
* Fri Mar  6 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-mac80211-pass-the-vif-to-cancel_remain_on_channel.patch
- commit a0c00c0
* Fri Mar  6 2020 jdelvare@suse.de
- scsi: fnic: do not queue commands during fwreset (bsc#1146539).
- commit c38dde7
* Thu Mar  5 2020 msuchanek@suse.de
- Delete patches which cause regression (bsc#1165527 ltc#184149).
- Delete patches.suse/powerpc-avoid-adjusting-memory_limit-for-capture-ker.patch.
- Delete patches.suse/powerpc-reserve-memory-for-capture-kernel-after-huge.patch.
- commit f7abbd0
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: fix potential SKB leak on TXQ TX (git-fixes).
- commit 1ac0a4b
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: remove last leftovers of d0i3 (git-fixes).
- commit dde7e54
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: remove d0i3_ap_sta_id (git-fixes).
- commit fd2b562
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: remove the d0i3 entry/exit flow (git-fixes).
- commit 84ff808
* Thu Mar  5 2020 yousaf.kaukab@suse.com
- tick/common: Make tick_periodic() check for missing ticks
  (bsc#1164534).
- commit 4d65090
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: remove the tx defer for d0i3 (git-fixes).
- commit ec16006
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: remove all the d0i3 references (git-fixes).
- commit beb11dd
* Thu Mar  5 2020 oneukum@suse.com
- iwlwifi: mvm: start to remove the code for d0i3 (git-fixes).
- commit 4ff93db
* Thu Mar  5 2020 oneukum@suse.com
- mac80211: pass the vif to cancel_remain_on_channel (git-fixes).
- commit f9393f5
* Thu Mar  5 2020 jslaby@suse.cz
- rxrpc: Fix service call disconnection (git-fixes).
- commit 4266941
* Thu Mar  5 2020 jack@suse.cz
- blktrace: Protect q->blk_trace with RCU (bsc#1159285
  CVE-2019-19768).
- commit c44e53f
* Thu Mar  5 2020 jslaby@suse.cz
- gtp: use __GFP_NOWARN to avoid memalloc warning
  (networking-stable-20_02_05).
- l2tp: Allow duplicate session creation with UDP
  (networking-stable-20_02_05).
- net: hsr: fix possible NULL deref in hsr_handle_frame()
  (networking-stable-20_02_05).
- net: stmmac: Delete txtimer in suspend()
  (networking-stable-20_02_05).
- rxrpc: Fix NULL pointer deref due to call->conn being cleared
  on disconnect (networking-stable-20_02_05).
- rxrpc: Fix missing active use pinning of rxrpc_local object
  (networking-stable-20_02_05).
- rxrpc: Fix insufficient receive notification generation
  (networking-stable-20_02_05).
- rxrpc: Fix use-after-free in rxrpc_put_local()
  (networking-stable-20_02_05).
- tcp: clear tp->segs_{in|out} in tcp_disconnect()
  (networking-stable-20_02_05).
- tcp: clear tp->data_segs{in|out} in tcp_disconnect()
  (networking-stable-20_02_05).
- tcp: clear tp->delivered in tcp_disconnect()
  (networking-stable-20_02_05).
- tcp: clear tp->total_retrans in tcp_disconnect()
  (networking-stable-20_02_05).
- commit 3758fff
* Thu Mar  5 2020 jslaby@suse.cz
- net: dsa: bcm_sf2: Forcibly configure IMP port for 1Gb/sec
  (git-fixes).
- net: dsa: bcm_sf2: Only 7278 supports 2Gb/sec IMP port
  (git-fixes).
- commit 7361c96
* Thu Mar  5 2020 jslaby@suse.cz
- udp: segment looped gso packets correctly
  (networking-stable-20_01_30).
- rxrpc: Fix use-after-free in rxrpc_receive_data()
  (networking-stable-20_01_30).
- net_sched: ematch: reject invalid TCF_EM_SIMPLE
  (networking-stable-20_01_30).
- net: include struct nhmsg size in nh nlmsg size
  (networking-stable-20_01_30).
- net_sched: walk through all child classes in tc_bind_tclass()
  (networking-stable-20_01_30).
- net_sched: fix ops->bind_class() implementations
  (networking-stable-20_01_30).
- commit a2d67cb
* Thu Mar  5 2020 palcantara@suse.de
- smb3: Fix regression in time handling (bsc#1164565).
- commit 76489e8
* Thu Mar  5 2020 palcantara@suse.de
- fs: cifs: Initialize filesystem timestamp ranges (bsc#1164565).
- commit 4bd8d12
* Wed Mar  4 2020 palcantara@suse.de
- fs: cifs: Fix atime update check vs mtime (bsc#1164565).
- commit 0137273
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/mediatek: disable all the planes in atomic_disable (bsc#1152489)
- commit beb3e57
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/mcde: Some fixes to handling video mode (bsc#1152472)
- commit 29f754d
* Wed Mar  4 2020 tzimmermann@suse.de
- drm: rcar-du: Recognize "renesas,vsps" in addition to "vsps" (bsc#1152489)
- commit 56e3aa3
* Wed Mar  4 2020 jslaby@suse.cz
- net: bcmgenet: Use netif_tx_napi_add() for TX NAPI
  (networking-stable-20_01_27).
- commit 9e56daf
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/radeon: fix bad DMA from INTERRUPT_CNTL2'
- commit b3a8eb6
* Wed Mar  4 2020 jslaby@suse.cz
- net: systemport: Fixed queue mapping in internal ring map
  (networking-stable-20_01_20).
- net: dsa: bcm_sf2: Configure IMP port for 2Gb/sec
  (networking-stable-20_01_20).
- net: dsa: sja1105: Don't error out on disabled ports with no
  phy-mode (networking-stable-20_01_20).
- net: dsa: tag_qca: fix doubled Tx statistics
  (networking-stable-20_01_20).
- net: dsa: tag_gswip: fix typo in tagger name
  (networking-stable-20_01_20).
- net: ethernet: ave: Avoid lockdep warning
  (networking-stable-20_01_20).
- net/wan/fsl_ucc_hdlc: fix out of bounds write on array utdm_info
  (networking-stable-20_01_20).
- hv_netvsc: Fix memory leak when removing rndis device
  (networking-stable-20_01_20).
- commit 7f37dbf
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix license on Kconfig and Makefiles'
- commit 5173cd9
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: add default clocks if not able to fetch them'
- commit 666a2d4
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix bad DMA from INTERRUPT_CNTL2'
- commit 1874918
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/amdgpu: Set no-retry as default."'
- commit b4576bc
* Wed Mar  4 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/smu: add metrics table lock for arcturus (v2)'
- commit f64b7b2
* Wed Mar  4 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/0001-crypto-atmel-Fix-build-error-of-CRYPTO_AUTHENC.patch
  patches.suse/0001-tools-lib-traceevent-Remove-unneeded-qsort-and-uses-.patch
  patches.suse/0001-usb-host-xhci-update-event-ring-dequeue-pointer-on-p.patch
- commit d776890
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: remove redundant variable r and redundant return (bsc#1152489)
- commit 9635a45
* Wed Mar  4 2020 tbogendoerfer@suse.de
- supported.conf: mark hinic driver supported (bsc#1165618)
- commit d183caf
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: remove ras_reserve_vram in ras injection (bsc#1152489)
- commit e39df99
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu/discovery: reserve discovery data at the top of VRAM (bsc#1152489)
- commit 87c3ae9
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: add invalidate semaphore limit for SRIOV and picasso in (bsc#1152472)
- commit 8bb0283
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: avoid using invalidate semaphore for picasso (bsc#1152472)
- commit 7a93979
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: invalidate mmhub semaphore workaround in gmc9/gmc10 (bsc#1152472)
- commit f513a95
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: initialize vm_inv_eng0_sem for gfxhub and mmhub (bsc#1152472)
- commit cc4b76c
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu/gfx10: re-init clear state buffer after gpu reset (bsc#1152472)
- commit 8c64b3d
* Wed Mar  4 2020 tzimmermann@suse.de
- drm/amdgpu: cleanup creating BOs at fixed location (v2) (bsc#1152489)
- commit 633a2a8
* Wed Mar  4 2020 glin@suse.com
- samples/bpf: Don't try to remove user's homedir on clean
  (bsc#1155518).
- samples/bpf: Xdp_redirect_cpu fix missing tracepoint attach
  (bsc#1155518).
- commit 11d150a
* Wed Mar  4 2020 jslaby@suse.cz
- PCI: pciehp: Add DMI table for in-band presence detection
  disabled (bnc#1162576 jsc#SLE-11112).
- PCI: pciehp: Wait for PDS if in-band presence is disabled
  (bnc#1162576 jsc#SLE-11112).
- PCI: pciehp: Disable in-band presence detect when possible
  (bnc#1162576 jsc#SLE-11112).
- commit 6963c35
* Wed Mar  4 2020 glin@suse.com
- bpf, offload: Replace bitwise AND by logical AND in
  bpf_prog_offload_info_fill (bsc#1155518).
- samples: bpf: Drop doubled variable declaration in xdpsock
  (bsc#1155518).
- samples/bpf: xdpsock: Add option to specify transmit fill
  pattern (bsc#1155518).
- samples/bpf: xdpsock: Add option to specify tx packet size
  (bsc#1155518).
- samples/bpf: xdpsock: Add option to specify number of packets
  to send (bsc#1155518).
- samples/bpf: xdpsock: Add option to specify batch size
  (bsc#1155518).
- samples/bpf: xdpsock: Use common code to handle signal and
  main exit (bsc#1155518).
- samples/bpf: xdpsock: Add duration option to specify how long
  to run (bsc#1155518).
- riscv, bpf: Fix broken BPF tail calls (bsc#1155518).
- samples/bpf: Attach XDP programs in driver mode by default
  (bsc#1155518).
- libbpf: Don't attach perf_buffer to offline/missing CPUs
  (bsc#1155518).
- libbpf: Extract and generalize CPU mask parsing logic
  (bsc#1155518).
- samples/bpf: Add missing option to xdpsock usage (bsc#1155518).
- samples/bpf: Remove duplicate option from xdpsock (bsc#1155518).
- samples/bpf: Use Rx-only and Tx-only sockets in xdpsock
  (bsc#1155518).
- samples/bpf: Add XDP_SHARED_UMEM support to xdpsock
  (bsc#1155518).
- samples: bpf: update map definition to new syntax BTF-defined
  map (bsc#1155518).
- samples/bpf: Trivial - fix spelling mistake in usage
  (bsc#1155518).
- samples/bpf: fix xdpsock l2fwd tx for unaligned mode
  (bsc#1155518).
- samples/bpf: use hugepages in xdpsock app (bsc#1155518).
- samples/bpf: add buffer recycling for unaligned chunks to
  xdpsock (bsc#1155518).
- samples/bpf: add unaligned chunks mode support to xdpsock
  (bsc#1155518).
- samples/bpf: add use of need_wakeup flag in xdpsock
  (bsc#1155518).
- samples/bpf: make xdp_fwd more practically usable via devmap
  lookup (bsc#1155518).
- samples/bpf: xdp_fwd rename devmap name to be xdp_tx_ports
  (bsc#1155518).
- commit ebecd6a
* Tue Mar  3 2020 mkubecek@suse.cz
- supported.conf: fix broken dependencies
  Recently added modules mscc_felix and tag_ocelot are marked as supported
  but depend on unsupported modules dsa_core and mscc_ocelot_common which
  breaks dependencies in aarch64 kernel-default package and therefore also
  aarch64/default and aarch/preempt build.
  Mark dsa_core and mscc_ocelot_common as supported as well.
- commit 102e871
* Tue Mar  3 2020 palcantara@suse.de
- cifs: do d_move in rename (bsc#1164565).
- commit 500b81b
* Tue Mar  3 2020 palcantara@suse.de
- cifs: add SMB2_open() arg to return POSIX data (bsc#1164565).
- commit ee82400
* Tue Mar  3 2020 palcantara@suse.de
- cifs: plumb smb2 POSIX dir enumeration (bsc#1164565).
- commit 3127734
* Tue Mar  3 2020 palcantara@suse.de
- cifs: add smb2 POSIX info level (bsc#1164565).
- commit 0cbf023
* Tue Mar  3 2020 palcantara@suse.de
- cifs: rename posix create rsp (bsc#1164565).
- commit 4b07bca
* Tue Mar  3 2020 palcantara@suse.de
- cifs: print warning once if mounting with vers=1.0
  (bsc#1164565).
- commit a59d8f7
* Tue Mar  3 2020 palcantara@suse.de
- smb3: fix performance regression with setting mtime
  (bsc#1164565).
- commit 4e529a9
* Tue Mar  3 2020 palcantara@suse.de
- cifs: make use of cap_unix(ses) in cifs_reconnect_tcon()
  (bsc#1164565).
- commit 5e21989
* Tue Mar  3 2020 palcantara@suse.de
- cifs: use mod_delayed_work() for &server->reconnect if already
  queued (bsc#1164565).
- commit b9b1327
* Tue Mar  3 2020 palcantara@suse.de
- cifs: call wake_up(&server->response_q) inside of
  cifs_reconnect() (bsc#1164565).
- commit 7684617
* Tue Mar  3 2020 palcantara@suse.de
- cifs: handle prefix paths in reconnect (bsc#1164565).
- commit 62ccc7c
* Tue Mar  3 2020 palcantara@suse.de
- cifs: potential unintitliazed error code in cifs_getattr()
  (bsc#1164565).
- commit a4ddb9f
* Tue Mar  3 2020 palcantara@suse.de
- cifs: do not ignore the SYNC flags in getattr (bsc#1164565).
- commit fc2ab55
* Tue Mar  3 2020 palcantara@suse.de
- cifs: Use #define in cifs_dbg (bsc#1164565).
- commit 12c009d
* Tue Mar  3 2020 palcantara@suse.de
- cifs: fix rename() by ensuring source handle opened with DELETE
  bit (bsc#1164565).
- commit 270fcbb
* Tue Mar  3 2020 palcantara@suse.de
- cifs: add missing mount option to /proc/mounts (bsc#1164565).
- commit 3115514
* Tue Mar  3 2020 dwagner@suse.de
- Drop patches.suse/qla2xxx-Enable-T10-DIF-with-FC-NVMe-enabled.patch
  The driver update to 10.01.00.25-k replaces the dropped patch.
- commit d25382d
* Tue Mar  3 2020 dwagner@suse.de
- scsi: qla2xxx: Update driver version to 10.01.00.25-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Set Nport ID for N2N (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Handle NVME status iocb correctly (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove restriction of FC T10-PI and FC-NVMe
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Serialize fc_port alloc in N2N (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix NPIV instantiation after FW dump
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix RDP respond data format (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Force semaphore on flash validation failure
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: add more FW debug information (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Update BPM enablement semantics (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: fix FW resource count values (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use a dedicated interrupt handler for
  'handshake-required' ISPs (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Return appropriate failure through BSG Interface
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Improved secure flash support messages
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix FCP-SCSI FC4 flag passing error (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use FC generic update firmware options routine
  for ISP27xx (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Avoid setting firmware options twice
  in 24xx_update_fw_options (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Add 16.0GT for PCI String (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Convert MAKE_HANDLE() from a define into an
  inline function (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix sparse warnings triggered by the PCI state
  checking code (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Suppress endianness complaints in
  qla2x00_configure_local_loop() (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Simplify the code for aborting SCSI commands
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix sparse warning reported by kbuild bot
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- commit 54d9078
* Tue Mar  3 2020 dwagner@suse.de
- Refresh patches.suse/scsi-ibmvfc-Avoid-loss-of-all-paths-during-SVC-node-.patch.
- commit f3b4108
* Tue Mar  3 2020 palcantara@suse.de
- cifs: fix potential mismatch of UNC paths (bsc#1164565).
- commit 47e9729
* Tue Mar  3 2020 palcantara@suse.de
- cifs: don't leak -EAGAIN for stat() during reconnect
  (bsc#1164565).
- commit 8f37e30
* Tue Mar  3 2020 jack@suse.cz
- tools/testing/nvdimm: Fix compilation failure without
  CONFIG_DEV_DAX_PMEM_COMPAT (bsc#1159523).
- commit 08c88c8
* Tue Mar  3 2020 tbogendoerfer@suse.de
- mlxsw: pci: Wait longer before accessing the device after reset
  (bsc#1154488).
- sched: act: count in the size of action flags bitfield
  (bsc#1154353).
- net: genetlink: return the error code when attribute parsing
  fails (bsc#1154353).
- commit 28120f1
* Tue Mar  3 2020 trenn@suse.com
- powercap/intel_rapl: add support for TigerLake Mobile
  (bsc#1164993, bsc#1165102).
- commit aa3d1d3
* Tue Mar  3 2020 oneukum@suse.com
- usb: host: xhci: update event ring dequeue pointer on purpose
  (git-fixes).
- commit fbca080
* Tue Mar  3 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/acpi-watchdog-allow-disabling-wdat-at-boot.patch
  patches.suse/acpi-watchdog-set-default-timeout-in-probe.patch
- commit b455329
* Mon Mar  2 2020 lyan@suse.com
- KVM: arm64: pmu: Reset sample period on overflow handling
  (bsc#1133021).
- KVM: arm64: pmu: Set the CHAINED attribute before creating
  the in-kernel event (bsc#1133021).
- arm64: KVM: Handle PMCR_EL0.LC as RES1 on pure AArch64 systems
  (bsc#1133021).
- KVM: arm64: pmu: Fix cycle counter truncation (bsc#1133021).
- commit d9abd96
* Mon Mar  2 2020 msuchanek@suse.de
- powerpc/pseries: update device tree before ejecting hotplug
  uevents (bsc#1165404 ltc#183498).
- powerpc/pseries: group lmb operation and memblock's (bsc#1165404
  ltc#183498).
- commit 6d4f5d6
* Mon Mar  2 2020 msuchanek@suse.de
- ibmvfc: Fix NULL return compiler warning (bsc#1161951
  ltc#183551).
- commit 7015eca
* Mon Mar  2 2020 palcantara@suse.de
- cifs: make sure we do not overflow the max EA buffer size
  (bsc#1164565).
- commit 187fa15
* Mon Mar  2 2020 palcantara@suse.de
- cifs: enable change notification for SMB2.1 dialect
  (bsc#1164565).
- commit 18efac6
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix mode output in debugging statements (bsc#1164565).
- commit 921b85b
* Mon Mar  2 2020 palcantara@suse.de
- smb3: Add defines for new information level, FileIdInformation
  (bsc#1164565).
- commit 6421d32
* Mon Mar  2 2020 palcantara@suse.de
-  smb3: print warning once if posix context returned on open
  (bsc#1164565).
- commit 1c772a2
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add one more dynamic tracepoint missing from strict
  fsync path (bsc#1164565).
- commit 756599a
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix mode bits from dir listing when mounted with
  modefromsid (bsc#1164565).
- commit 577afbb
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add SMB3 change notification support (bsc#1164565).
- commit fd3741d
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix soft mounts hanging in the reconnect code
  (bsc#1164565).
- commit bd3733d
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Add tracepoints for errors on flush or fsync
  (bsc#1164565).
- commit c47bf63
* Mon Mar  2 2020 palcantara@suse.de
- cifs: log warning message (once) if out of disk space
  (bsc#1164565).
- commit 0a33490
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fail i/o on soft mounts if sessionsetup errors out
  (bsc#1164565).
- commit 79eff03
* Mon Mar  2 2020 palcantara@suse.de
- smb3: fix problem with null cifs super block with previous patch
  (bsc#1164565).
- commit 4f17f73
* Mon Mar  2 2020 palcantara@suse.de
- SMB3: Backup intent flag missing from some more ops
  (bsc#1164565).
- commit cea0ba2
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix soft mounts hanging in the reconnect code
  (bsc#1164565).
- commit 53d1815
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Fix task struct use-after-free on reconnect (bsc#1164565).
- commit d8da619
* Mon Mar  2 2020 palcantara@suse.de
- cifs: use PTR_ERR_OR_ZERO() to simplify code (bsc#1164565).
- commit ae626b0
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add support for fallocate mode 0 for non-sparse files
  (bsc#1164565).
- commit 0bd12eb
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix NULL dereference in match_prepath (bsc#1164565).
- commit 0dec827
* Mon Mar  2 2020 palcantara@suse.de
- smb3: fix default permissions on new files when mounting with
  modefromsid (bsc#1164565).
- commit 5854994
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Add support for setting owner info, dos attributes,
  and create time (bsc#1164565).
- commit fc7a4ec
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove set but not used variable 'server' (bsc#1164565).
- commit d7bd290
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix memory allocation in __smb2_handle_cancelled_cmd()
  (bsc#1164565).
- commit 2e77717
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix mount options set in automount (bsc#1164565).
- commit 23cc00f
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix unitialized variable poential problem with network
  I/O cache lock patch (bsc#1164565).
- commit 683e390
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix return value in __update_cache_entry (bsc#1164565).
- commit 0d6d00e
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Avoid doing network I/O while holding cache lock
  (bsc#1164565).
- commit 21b1bb8
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix potential deadlock when updating vol in
  cifs_reconnect() (bsc#1164565).
- commit 7f4c5eb
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Merge is_path_valid() into get_normalized_path()
  (bsc#1164565).
- commit 90e6c2e
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Introduce helpers for finding TCP connection
  (bsc#1164565).
- commit 278b9d9
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Get rid of kstrdup_const()'d paths (bsc#1164565).
- commit 136ec9a
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Clean up DFS referral cache (bsc#1164565).
- commit b1680d8
* Mon Mar  2 2020 palcantara@suse.de
- cifs: set correct max-buffer-size for smb2_ioctl_init()
  (bsc#1164565).
- commit 4203783
* Mon Mar  2 2020 palcantara@suse.de
- cifs: use compounding for open and first query-dir for readdir()
  (bsc#1164565).
- commit e47a329
* Mon Mar  2 2020 palcantara@suse.de
- cifs: create a helper function to parse the query-directory
  response buffer (bsc#1164565).
- commit 0960f35
* Mon Mar  2 2020 palcantara@suse.de
- cifs: prepare SMB2_query_directory to be used with compounding
  (bsc#1164565).
- commit f065422
* Mon Mar  2 2020 palcantara@suse.de
- fs/cifs/cifssmb.c: use true,false for bool variable
  (bsc#1164565).
- commit dd0ed6f
* Mon Mar  2 2020 palcantara@suse.de
- fs/cifs/smb2ops.c: use true,false for bool variable
  (bsc#1164565).
- commit 21e8ec0
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Optimize readdir on reparse points (bsc#1164565).
- commit 1966fae
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Adjust indentation in smb2_open_file (bsc#1164565).
- commit 331c9ed
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Close cached root handle only if it has a lease
  (bsc#1164565).
- commit 47dfff5
* Mon Mar  2 2020 palcantara@suse.de
- SMB3: Fix crash in SMB2_open_init due to uninitialized field
  in compounding path (bsc#1164565).
- commit 4b50b8c
* Mon Mar  2 2020 palcantara@suse.de
- smb3: fix refcount underflow warning on unmount when no
  directory leases (bsc#1164565).
- commit 39393bb
* Mon Mar  2 2020 palcantara@suse.de
- smb3: improve check for when we send the security descriptor
  context on create (bsc#1164565).
- commit 4083b73
* Mon Mar  2 2020 palcantara@suse.de
- smb3: fix mode passed in on create for modetosid mount option
  (bsc#1164565).
- commit c05fc9d
* Mon Mar  2 2020 palcantara@suse.de
- smb3: query attributes on file close (bsc#1164565).
- commit 6280b64
* Mon Mar  2 2020 palcantara@suse.de
- smb3: remove unused flag passed into close functions
  (bsc#1164565).
- commit 1cc8c7f
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove redundant assignment to pointer pneg_ctxt
  (bsc#1164565).
- commit e68dc80
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: fix a white space issue in cifs_get_inode_info()
  (bsc#1164565).
- commit 10fc15b
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix retrieval of DFS referrals in cifs_mount()
  (bsc#1164565).
- commit 22772da
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix potential softlockups while refreshing DFS cache
  (bsc#1164565).
- commit 694eb6e
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix lookup of root ses in DFS referral cache
  (bsc#1164565).
- commit 2cf9686
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Fix use-after-free bug in cifs_reconnect() (bsc#1164565).
- commit d57d122
* Mon Mar  2 2020 palcantara@suse.de
- smb3: dump in_send and num_waiters stats counters by default
  (bsc#1164565).
- commit e81c291
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Properly process SMB3 lease breaks (bsc#1164565).
- commit 579b98d
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: refactor cifs_get_inode_info() (bsc#1164565).
- commit 0b80dd7
* Mon Mar  2 2020 palcantara@suse.de
- cifs: don't use 'pre:' for MODULE_SOFTDEP (bsc#1164565).
- commit 44b1acc
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Return -EAGAIN when transport is reconnecting
  (bsc#1164565).
- commit 44743f5
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Only queue work for error recovery on memory
  registration (bsc#1164565).
- commit 4c66f23
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add debug messages for closing unmatched open
  (bsc#1164565).
- commit 47f85b3
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Do not miss cancelled OPEN responses (bsc#1164565).
- commit 6d9d8e6
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Fix NULL pointer dereference in mid callback
  (bsc#1164565).
- commit 220efe8
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Close open handle after interrupted close (bsc#1164565).
- commit a0e0f78
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Respect O_SYNC and O_DIRECT flags during reconnect
  (bsc#1164565).
- commit 5d00439
* Mon Mar  2 2020 palcantara@suse.de
- smb3: remove confusing dmesg when mounting with encryption
  ("seal") (bsc#1164565).
- commit 26d3f50
* Mon Mar  2 2020 palcantara@suse.de
- cifs: close the shared root handle on tree disconnect
  (bsc#1164565).
- commit 5fba990
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Return directly after a failed build_path_from_dentry()
  in cifs_do_create() (bsc#1164565).
- commit 5bdda87
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Use common error handling code in smb2_ioctl_query_info()
  (bsc#1164565).
- commit 7c9d0d2
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: Use memdup_user() rather than duplicating its
  implementation (bsc#1164565).
- commit ac9ac99
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Return -ECONNABORTED when trasnport is not in
  connected state (bsc#1164565).
- commit 1d4896f
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Add messages on RDMA session destroy and
  reconnection (bsc#1164565).
- commit c884cac
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Return -EINVAL when the number of iovs exceeds
  SMBDIRECT_MAX_SGE (bsc#1164565).
- commit 342a436
* Mon Mar  2 2020 palcantara@suse.de
- cifs: smbd: Invalidate and deregister memory registration on
  re-send for direct I/O (bsc#1164565).
- commit 95bdb07
* Mon Mar  2 2020 palcantara@suse.de
- cifs: Don't display RDMA transport on reconnect (bsc#1164565).
- commit 901256b
* Mon Mar  2 2020 palcantara@suse.de
- CIFS: remove set but not used variables 'cinode' and 'netfid'
  (bsc#1164565).
- commit da66a8f
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add support for flock (bsc#1164565).
- commit 61dc219
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove unused variable 'sid_user' (bsc#1164565).
- commit 5c64672
* Mon Mar  2 2020 palcantara@suse.de
- cifs: rename a variable in SendReceive() (bsc#1164565).
- commit 054c459
* Mon Mar  2 2020 palcantara@suse.de
- fix memory leak in large read decrypt offload (bsc#1164565).
- commit 7880d1c
* Mon Mar  2 2020 msuchanek@suse.de
- Revert "Revert "sign also s390x kernel images (bsc#1163524)""
  This reverts commit 6326fe1a81221fb3ce28ff84532bd48a182f7731.
  pesign should now be able to sign s390 kernels.
- commit e9175e5
* Mon Mar  2 2020 msuchanek@suse.de
- blacklist.conf: Blacklist unsupported ppc platforms.
- commit b290d11
* Mon Mar  2 2020 msuchanek@suse.de
- net/ethtool: Introduce link_ksettings API for virtual network
  devices (bsc#1136157 ltc#177197).
  Delete patches.suse/ibmveth-Update-ethtool-settings-to-reflect-virtual-p.patch.
- ethtool: Factored out similar ethtool link settings for virtual
  devices to core (bsc#1136157 ltc#177197).
- commit 4638559
* Mon Mar  2 2020 jdelvare@suse.de
- Refresh
  patches.suse/acpi-watchdog-allow-disabling-wdat-at-boot.patch.
- Refresh
  patches.suse/acpi-watchdog-set-default-timeout-in-probe.patch.
  Add upstream commit IDs and move to the sorted section.
- commit 678d8e6
* Mon Mar  2 2020 ohering@suse.de
- hv_netvsc: Fix unwanted wakeup in netvsc_attach() (git-fixes).
- commit c3cdac3
* Mon Mar  2 2020 palcantara@suse.de
- smb3: remove noisy debug message and minor cleanup
  (bsc#1164565).
- commit f116adb
* Mon Mar  2 2020 palcantara@suse.de
- smb3: cleanup some recent endian errors spotted by updated
  sparse (bsc#1164565).
- commit b63cc8a
* Mon Mar  2 2020 palcantara@suse.de
- smb3: missing ACL related flags (bsc#1164565).
- commit ddcd4e7
* Mon Mar  2 2020 palcantara@suse.de
- smb3: pass mode bits into create calls (bsc#1164565).
- commit 9e90af4
* Mon Mar  2 2020 palcantara@suse.de
- smb3: Add missing reparse tags (bsc#1164565).
- commit 631f1b0
* Mon Mar  2 2020 palcantara@suse.de
- fs/cifs/sess.c: Remove set but not used variable 'capabilities'
  (bsc#1164565).
- commit e4f316a
* Mon Mar  2 2020 palcantara@suse.de
- fs/cifs/smb2pdu.c: Make SMB2_notify_init static (bsc#1164565).
- commit 1781460
* Mon Mar  2 2020 palcantara@suse.de
- smb3: allow decryption keys to be dumped by admin for debugging
  (bsc#1164565).
- commit 449f80c
* Mon Mar  2 2020 palcantara@suse.de
- cifs: modefromsid: write mode ACE first (bsc#1164565).
- commit 6f29db0
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add missing worker function for SMB3 change notify
  (bsc#1164565).
- commit c88cd2a
* Mon Mar  2 2020 palcantara@suse.de
- cifs: modefromsid: make room for 4 ACE (bsc#1164565).
- commit 41e2c7e
* Mon Mar  2 2020 palcantara@suse.de
- smb3: fix potential null dereference in decrypt offload
  (bsc#1164565).
- commit cc2bebe
* Mon Mar  2 2020 palcantara@suse.de
- smb3: display max smb3 requests in flight at any one time
  (bsc#1164565).
- commit 2b340ea
* Mon Mar  2 2020 palcantara@suse.de
- smb3: only offload decryption of read responses if multiple
  requests (bsc#1164565).
- Refresh
  patches.suse/cifs-move-cifsFileInfo_put-logic-into-a-work-queue.patch.
- commit 8d8b9e0
* Mon Mar  2 2020 palcantara@suse.de
- smb3: enable offload of decryption of large reads via mount
  option (bsc#1164565).
- commit c0c0dd0
* Mon Mar  2 2020 palcantara@suse.de
- smb3: allow parallelizing decryption of reads (bsc#1164565).
- Refresh
  patches.suse/cifs-move-cifsFileInfo_put-logic-into-a-work-queue.patch.
- commit dbfeff1
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add a debug macro that prints \\server\share for errors
  (bsc#1164565).
- commit fd241c6
* Mon Mar  2 2020 palcantara@suse.de
- smb3: allow skipping signature verification for perf sensitive
  configurations (bsc#1164565).
- commit dd9ca23
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add dynamic tracepoints for flush and close (bsc#1164565).
- commit b3d48ee
* Mon Mar  2 2020 palcantara@suse.de
- smb3: log warning if CSC policy conflicts with cache mount
  option (bsc#1164565).
- commit 633ceea
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add mount option to allow RW caching of share accessed
  by only 1 client (bsc#1164565).
- commit 79b4f8c
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add some more descriptive messages about share when
  mounting cache=ro (bsc#1164565).
- commit fc6a23b
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add mount option to allow forced caching of read only
  share (bsc#1164565).
- commit 30b7183
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix dereference on ses before it is null checked
  (bsc#1164565).
- commit 30243d5
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add new debugging macro cifs_server_dbg (bsc#1164565).
- Refresh
  patches.suse/CIFS-Fix-retry-mid-list-corruption-on-reconnects.patch.
- commit 894b13c
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove set but not used variables (bsc#1164565).
- commit 147b525
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove unused variable (bsc#1164565).
- commit b38b168
* Mon Mar  2 2020 palcantara@suse.de
- cifs: remove redundant assignment to variable rc (bsc#1164565).
- commit a3fa732
* Mon Mar  2 2020 palcantara@suse.de
- smb3: add missing flag definitions (bsc#1164565).
- commit 344e8bd
* Mon Mar  2 2020 palcantara@suse.de
- cifs: add passthrough for smb2 setinfo (bsc#1164565).
- commit 046be6b
* Mon Mar  2 2020 palcantara@suse.de
- cifs: allow chmod to set mode bits using special sid
  (bsc#1164565).
- commit fc541ed
* Mon Mar  2 2020 palcantara@suse.de
- cifs: get mode bits from special sid on stat (bsc#1164565).
- commit 5c3507b
* Mon Mar  2 2020 palcantara@suse.de
- fs: cifs: cifsssmb: remove redundant assignment to variable ret
  (bsc#1164565).
- commit 79247fd
* Mon Mar  2 2020 palcantara@suse.de
- cifs: fix a comment for the timeouts when sending echos
  (bsc#1164565).
- commit d69504d
* Sat Feb 29 2020 msuchanek@suse.de
- scsi: ibmvfc: Avoid loss of all paths during SVC node reboot
  (bsc#1161951 ltc#183551).
- commit fd62623
* Fri Feb 28 2020 nsaenzjulienne@suse.de
- pinctrl: bcm2835: Add support for all GPIOs on BCM2711
  (bsc#1164722).
- commit ac59893
* Fri Feb 28 2020 nsaenzjulienne@suse.de
- pinctrl: bcm2835: Refactor platform data (bsc#1164722).
- pinctrl: bcm2835: Drop unused define (bsc#1164722).
- commit 1089640
* Fri Feb 28 2020 nsaenzjulienne@suse.de
- Refresh: patches.suse/thermal-add-bcm2711-thermal-driver.patch
- commit 15ec939
* Fri Feb 28 2020 mkubecek@suse.cz
- supported.conf: sort
  Fix order of entries.
- commit b92122c
* Fri Feb 28 2020 tbogendoerfer@suse.de
- supported.conf: mark GVE supported (jsc#SLE10540, bsc#1165245)
- commit 87b5d1a
* Fri Feb 28 2020 yousaf.kaukab@suse.com
- dmaengine: make mux_configure32 static (jsc#SLE-9263).
- commit b01a9f4
* Fri Feb 28 2020 yousaf.kaukab@suse.com
- net: dsa: felix: use dsa_switch_alloc() (jsc#SLE-9263).
- commit 1190849
* Thu Feb 27 2020 bp@suse.de
- x86/mce/amd: Fix kobject lifetime (bsc#1152489).
- x86/mce/amd: Publish the bank pointer only after setup has
  succeeded (bsc#1152489).
- commit 218de4e
* Thu Feb 27 2020 bp@suse.de
- x86/cpu/amd: Enable the fixed Instructions Retired counter
  IRPERF (bsc#1152489).
- commit a161705
* Thu Feb 27 2020 dwagner@suse.de
- scsi: qla2xxx: Update driver version to 10.01.00.24-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use QLA_FW_STOPPED macro to propagate flag
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add fixes for mailbox command (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix control flags for login/logout IOCB
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Save rscn_gen for new fcport (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use correct ISP28xx active FW region
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Print portname for logging in
  qla24xx_logio_entry() (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Fix qla2x00_echo_test() based on ISP type
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Correction to selection of loopback/echo test
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use endian macros to assign static fields in
  fwdump header (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix RDP response size (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Handle cases for limiting RDP response payload
  length (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add deferred queue for processing ABTS and RDP
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Cleanup ELS/PUREX iocb fields (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Show correct port speed capabilities for RDP
  command (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Display message for FCE enabled (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add vendor extended FDMI commands (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add ql2xrdpenable module parameter for RDP
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add vendor extended RDP additions and amendments
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add changes in preparation for vendor extended
  FDMI/RDP (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add endianizer macro calls to fc host stats
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add sysfs node for D-Port Diagnostics AEN data
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Move free of fcport out of interrupt context
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add beacon LED config sysfs interface
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Check locking assumptions at runtime in
  qla2x00_abort_srb() (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- commit d0cdedd
* Thu Feb 27 2020 dwagner@suse.de
- Refresh series.conf
- commit b45c83a
* Thu Feb 27 2020 yousaf.kaukab@suse.com
- gpio: mpc8xxx: ls1088a/ls1028a edge detection mode bug fixs
  (jsc#SLE-9263).
- dmaengine: fsl-edma: Add eDMA support for QorIQ LS1028A platform
  (jsc#SLE-9263).
- dmaengine: fsl-edma: add i.mx7ulp edma2 version support
  (jsc#SLE-9263).
- commit 2aac33b
* Thu Feb 27 2020 jslaby@suse.cz
- net: stmmac: Fixed link does not need MDIO Bus (git-fixes).
- commit c15f5f6
* Thu Feb 27 2020 yousaf.kaukab@suse.com
- clk: ls1028a: fix a dereference of pointer 'parent' before a
  null check (jsc#SLE-9263).
- clk: ls1028a: Fix warning on clamp() usage (jsc#SLE-9263).
- clk: ls1028a: Add clock driver for Display output interface
  (jsc#SLE-9263).
- commit b49745f
* Thu Feb 27 2020 jslaby@suse.cz
- net: stmmac: dwmac-sun8i: Allow all RGMII modes
  (networking-stable-20_01_11).
- net: stmmac: dwmac-sunxi: Allow all RGMII modes
  (networking-stable-20_01_11).
- net: dsa: mv88e6xxx: Preserve priority when setting CPU port
  (networking-stable-20_01_11).
- net: freescale: fec: Fix ethtool -d runtime PM
  (networking-stable-20_01_11).
- commit 292d79c
* Thu Feb 27 2020 mhocko@suse.com
- Update config files.
  turn {arm64,x86_64}/preempt to diff config against default flavor.
- commit 79606c0
* Thu Feb 27 2020 yousaf.kaukab@suse.com
- net: dsa: felix: Use PHY_INTERFACE_MODE_INTERNAL instead of GMII
  (jsc#SLE-9263).
- commit 6cfa413
* Thu Feb 27 2020 jslaby@suse.cz
- net: dsa: sja1105: Reconcile the meaning of TPID and TPID2
  for E/T and P/Q/R/S (networking-stable-20_01_01).
- net: stmmac: dwmac-meson8b: Fix the RGMII TX delay on
  Meson8b/8m2 SoCs (networking-stable-20_01_01).
- net/dst: do not confirm neighbor for vxlan and geneve pmtu
  update (networking-stable-20_01_01).
- sit: do not confirm neighbor when do pmtu update
  (networking-stable-20_01_01).
- vti: do not confirm neighbor when do pmtu update
  (networking-stable-20_01_01).
- tunnel: do not confirm neighbor when do pmtu update
  (networking-stable-20_01_01).
- net/dst: add new function skb_dst_update_pmtu_no_confirm
  (networking-stable-20_01_01).
- gtp: do not confirm neighbor when do pmtu update
  (networking-stable-20_01_01).
- ip6_gre: do not confirm neighbor when do pmtu update
  (networking-stable-20_01_01).
- net: add bool confirm_neigh parameter for dst_ops.update_pmtu
  (networking-stable-20_01_01).
- net: dsa: bcm_sf2: Fix IP fragment location and behavior
  (networking-stable-20_01_01).
- gtp: avoid zero size hashtable (networking-stable-20_01_01).
- gtp: fix an use-after-free in ipv4_pdp_find()
  (networking-stable-20_01_01).
- gtp: fix wrong condition in gtp_genl_dump_pdp()
  (networking-stable-20_01_01).
- gtp: do not allow adding duplicate tid and ms_addr pdp context
  (networking-stable-20_01_01).
- vhost/vsock: accept only packets with the right dst_cid
  (networking-stable-20_01_01).
- commit f17afc0
* Thu Feb 27 2020 jslaby@suse.cz
- net: stmmac: platform: Fix MDIO init for platforms without PHY
  (networking-stable-19_12_28).
- selftests: forwarding: Delete IPv6 address at the end
  (networking-stable-19_12_28).
- sctp: fully initialize v4 addr in some functions
  (networking-stable-19_12_28).
- commit 6abcdbd
* Wed Feb 26 2020 yousaf.kaukab@suse.com
- net: dsa: felix: fix link error (jsc#SLE-9263).
- enetc: Fix inconsistent IS_ERR and PTR_ERR (jsc#SLE-9263).
- commit 77d3fbd
* Wed Feb 26 2020 duwe@suse.de
- enable CRYPTO_TEST on arm64, as it is on all other architectures.
  (bsc#1164254)
- commit a8c6955
* Wed Feb 26 2020 msuchanek@suse.de
- rpm/package-descriptions: garbege collection
  remove old ARM and Xen flavors.
- commit bda0360
* Wed Feb 26 2020 mkubecek@suse.cz
- Revert "sign also s390x kernel images (bsc#1163524)"
  This reverts commit b38b61155f0a2c3ebca06d4bb0c2e11a19a87f1f.
  As further discussion revealed, this change depends on changes in
  pesign-obs-integration package which are not ready yet so that it breaks
  s390x binary builds at the moment.
- commit 6326fe1
* Wed Feb 26 2020 mhocko@suse.com
- Created new preempt kernel flavor (jsc#SLE-11309)
  Configs are cloned from the respective $arch/default configs. All
  changed configs appart from CONFIG_PREEMPT->y are a result of
  dependencies, namely many lock/unlock primitives are no longer
  inlined in the preempt kernel. TREE_RCU has been also changed to
  PREEMPT_RCU which is the default implementation for PREEMPT kernel.
- commit f994874
* Wed Feb 26 2020 bp@suse.de
- EDAC/mc: Fix use-after-free and memleaks during device removal
  (jsc#SLE-9482).
- EDAC/sysfs: Remove csrow objects on errors (jsc#SLE-9482).
- commit 9698f66
* Tue Feb 25 2020 tbogendoerfer@suse.de
- net/mlx5: DR, Handle reformat capability over sw-steering tables
  (jsc#SLE-8464).
- net/mlx5e: Don't clear the whole vf config when switching modes
  (jsc#SLE-8464).
- net/mlx5: DR, Fix matching on vport gvmi (jsc#SLE-8464).
- net/mlx5e: Fix crash in recovery flow without devlink reporter
  (jsc#SLE-8464).
- net/mlx5e: Reset RQ doorbell counter before moving RQ state
  from RST to RDY (jsc#SLE-8464 bsc#1163335).
- bonding: fix lockdep warning in bond_get_stats() (bsc#1154353
  bnc#1151927).
- bonding: add missing netdev_update_lockdep_key() (bsc#1154353).
- net: add strict checks in netdev_name_node_alt_destroy()
  (bsc#1154353).
- net: rtnetlink: fix bugs in rtnl_alt_ifname() (bsc#1154353).
- commit 1a3940e
* Tue Feb 25 2020 yousaf.kaukab@suse.com
- net: mscc: fix in frame extraction (jsc#SLE-9263).
- net: dsa: felix: Allow PHY to AN 10/100/1000 with 2500 serdes link (jsc#SLE-9263).
- net: dsa: felix: Handle PAUSE RX regardless of AN result (jsc#SLE-9263).
- net: dsa: felix: Don't error out on disabled ports with no phy-mode (jsc#SLE-9263).
- net: dsa: felix: Don't restart PCS SGMII AN if not needed (jsc#SLE-9263).
- net: dsa: felix: Set USXGMII link based on BMSR, not LPA (jsc#SLE-9263).
- net: dsa: felix: Add PCS operations for PHYLINK (jsc#SLE-9263).
- net: mscc: ocelot: export ANA, DEV and QSYS registers to include/soc/mscc (jsc#SLE-9263).
- net: mscc: ocelot: make phy_mode a member of the common struct ocelot_port (jsc#SLE-9263).
- enetc: Set MDIO_CFG_HOLD to the recommended value of 2 (jsc#SLE-9263).
- enetc: Make MDIO accessors more generic and export to include/linux/fsl (jsc#SLE-9263).
- net: dsa: Pass pcs_poll flag from driver to PHYLINK (jsc#SLE-9263).
- net: phylink: add support for polling MAC PCS (jsc#SLE-9263).
- net: phylink: make QSGMII a valid PHY mode for in-band AN (jsc#SLE-9263).
- mii: Add helpers for parsing SGMII auto-negotiation (jsc#SLE-9263).
- net: dsa: ocelot: add NET_VENDOR_MICROSEMI dependency (jsc#SLE-9263).
- net: mscc: ocelot: unregister the PTP clock on deinit (jsc#SLE-9263).
- net: mscc: ocelot: use skb queue instead of skbs list (jsc#SLE-9263).
- net: mscc: ocelot: avoid incorrect consuming in skbs list (jsc#SLE-9263).
- net: dsa: ocelot: fix "should it be static?" warnings (jsc#SLE-9263).
- net: dsa: ocelot: add hardware timestamping support for Felix (jsc#SLE-9263).
- net: dsa: ocelot: define PTP registers for felix_vsc9959 (jsc#SLE-9263).
- net: mscc: ocelot: convert to use ocelot_port_add_txtstamp_skb() (jsc#SLE-9263).
- net: mscc: ocelot: convert to use ocelot_get_txtstamp() (jsc#SLE-9263).
- net: mscc: ocelot: export ocelot_hwstamp_get/set functions (jsc#SLE-9263).
- net: dsa: felix: Fix CPU port assignment when not last port (jsc#SLE-9263).
- net: dsa: ocelot: add driver for Felix switch family (jsc#SLE-9263).
- net: dsa: ocelot: add tagger for Ocelot/Felix switches (jsc#SLE-9263).
- net: mscc: ocelot: publish ocelot_sys.h to include/soc/mscc (jsc#SLE-9263).
- net: mscc: ocelot: publish structure definitions to include/soc/mscc/ocelot.h (jsc#SLE-9263).
- net: mscc: ocelot: separate the implementation of switch reset (jsc#SLE-9263).
- net: mscc: ocelot: adjust MTU on the CPU port in NPI mode (jsc#SLE-9263).
- net: mscc: ocelot: export a constant for the tag length in bytes (jsc#SLE-9263).
- net: mscc: ocelot: create a helper for changing the port MTU (jsc#SLE-9263).
- net: mscc: ocelot: move invariant configs out of adjust_link (jsc#SLE-9263).
- net: mscc: ocelot: filter out ocelot SoC specific PCS config from common path (jsc#SLE-9263).
- net: mscc: ocelot: move resource ioremap and regmap init to common code (jsc#SLE-9263).
- net: mscc: ocelot: don't hardcode the number of the CPU port (jsc#SLE-9263).
- net: mscc: ocelot: split assignment of the cpu port into a separate function (jsc#SLE-9263).
- net: mscc: ocelot: refactor adjust_link into a netdev-independent function (jsc#SLE-9263).
- net: mscc: ocelot: initialize list of multicast addresses in common code (jsc#SLE-9263).
- net: mscc: ocelot: separate the common implementation of ndo_open and ndo_stop (jsc#SLE-9263).
- net: mscc: ocelot: move port initialization into separate function (jsc#SLE-9263).
- net: mscc: ocelot: limit vlan ingress filtering to actual number of ports (jsc#SLE-9263).
- net: mscc: ocelot: refactor ethtool callbacks (jsc#SLE-9263).
- net: mscc: ocelot: separate net_device related items out of ocelot_port (jsc#SLE-9263).
- net: mscc: ocelot: refactor struct ocelot_port out of function prototypes (jsc#SLE-9263).
- net: mscc: ocelot: change prototypes of switchdev port attribute handlers (jsc#SLE-9263).
- net: mscc: ocelot: change prototypes of hwtstamping ioctls (jsc#SLE-9263).
- net: mscc: ocelot: break out fdb operations into abstract implementations (jsc#SLE-9263).
- net: mscc: ocelot: break apart vlan operations into ocelot_vlan_{add, del} (jsc#SLE-9263).
- net: mscc: ocelot: break apart ocelot_vlan_port_apply (jsc#SLE-9263).
- net: mscc: PTP Hardware Clock (PHC) support (jsc#SLE-9263).
- net: mscc: remove the frame_info cpuq member (jsc#SLE-9263).
- net: mscc: improve the frame header parsing readability (jsc#SLE-9263).
- net: mscc: describe the PTP register range (jsc#SLE-9263).
- commit 79f7160
* Tue Feb 25 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Take-into-account-runnable_avg-to-classify-group.patch.
- Refresh
  patches.suse/sched-fair-reorder-enqueue-dequeue_task_fair-path.patch.
- Refresh
  patches.suse/sched-numa-Bias-swapping-tasks-based-on-their-preferred-node.patch.
- Refresh
  patches.suse/sched-numa-Distinguish-between-the-different-task_numa_migrate-failure-cases.patch.
- Refresh
  patches.suse/sched-numa-Find-an-alternative-idle-CPU-if-the-CPU-is-part-of-an-active-NUMA-balance.patch.
- sched/numa: Prefer using an idle CPU as a migration target
  instead of comparing tasks (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- Refresh
  patches.suse/sched-numa-Stop-an-exhastive-search-if-a-reasonable-swap-candidate-or-idle-CPU-is-found.patch.
- Refresh
  patches.suse/sched-numa-Trace-when-no-candidate-CPU-was-found-on-the-preferred-node.patch.
- Refresh
  patches.suse/sched-numa-Use-similar-logic-to-the-load-balancer-for-moving-between-domains-with-spare-capacity.patch.
- Refresh
  patches.suse/sched-numa-replace-runnable_load_avg-by-load_avg.patch.
- Refresh
  patches.suse/sched-pelt-Add-a-new-runnable-average-signal.patch.
- Refresh
  patches.suse/sched-pelt-Remove-unused-runnable-load-average.patch.
- commit de86223
* Tue Feb 25 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-reorder-enqueue-dequeue_task_fair-path.patch.
- commit a0aa0f8
* Tue Feb 25 2020 mgorman@suse.de
- sched/numa: Distinguish between the different
  task_numa_migrate() failure cases (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- commit 408baa5
* Tue Feb 25 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-numa-Trace-when-no-candidate-CPU-was-found-on-the-preferred-node.patch.
- commit 7d03e16
* Tue Feb 25 2020 mgorman@suse.de
- sched/fair: Optimize select_idle_core() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit f749d53
* Tue Feb 25 2020 mgorman@suse.de
- sched/fair: Allow a per-CPU kthread waking a task to stack on
  the same CPU, to fix XFS performance regression (bsc#1154329).
- sched/fair: Allow a small load imbalance between low utilisation
  SD_NUMA domains (bnc#1160896).
- commit 2ab2039
* Tue Feb 25 2020 meissner@suse.de
- sign also s390x kernel images (bsc#1163524)
- commit b38b611
* Tue Feb 25 2020 vbabka@suse.cz
- mm, hotplug: fix page online with DEBUG_PAGEALLOC compiled
  but not enabled (VM Functionality, bsc#1164436).
- commit 05a4d19
* Tue Feb 25 2020 jslaby@suse.cz
- blacklist.conf: add CONFIG_PROC_FS=n entry
- commit cc29a90
* Tue Feb 25 2020 jslaby@suse.cz
- nbd: add a flush_workqueue in nbd_start_device (git-fixes).
- perf c2c: Fix return type for histogram sorting comparision
  functions (git-fixes).
- x86/cpu: Update cached HLE state on write to
  TSX_CTRL_CPUID_CLEAR (git-fixes).
- commit 6880922
* Tue Feb 25 2020 jroedel@suse.de
- KVM: nVMX: Check IO instruction VM-exit conditions
  (CVE-2020-2732 bsc#1163971).
- KVM: nVMX: Refactor IO bitmap checks into helper function
  (CVE-2020-2732 bsc#1163971).
- KVM: nVMX: Don't emulate instructions in guest mode
  (CVE-2020-2732 bsc#1163971).
- commit f91f45f
* Tue Feb 25 2020 mkubecek@suse.cz
- config: enable BLK_DEV_SR_VENDOR on armv7hl (bsc#1164632)
  This option was recently enabled in all SLE15-SP2 configs, enable it also
  in armv7hl which is built only in openSUSE-15.2.
- commit b8ee3fe
* Tue Feb 25 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/vt-selection-close-sel_buffer-race.patch
  patches.suse/vt-selection-handle-pending-signals-in-paste_selecti.patch
- commit 0c9df1b
* Tue Feb 25 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/powerpc-tm-Fix-clearing-MSR-TS-in-current-when-recla.patch
- commit 220f81e
* Mon Feb 24 2020 bp@suse.de
- x86/boot: Handle malformed SRAT tables during early ACPI parsing
  (bsc#1152489).
- commit ce68bc1
* Mon Feb 24 2020 jroedel@suse.de
- iommu/vt-d: Unnecessary to handle default identity domain
  (bsc#1162414).
- iommu/vt-d: Allow devices with RMRRs to use identity domain
  (bsc#1162414).
- commit 048a6f9
* Mon Feb 24 2020 nborisov@suse.com
- btrfs: rename btrfs_space_info_add_old_bytes (bsc#1141456).
- btrfs: remove orig_bytes from reserve_ticket (bsc#1141456).
- btrfs: fix may_commit_transaction to deal with no partial
  filling (bsc#1141456).
- btrfs: rework wake_all_tickets (bsc#1141456).
- btrfs: refactor the ticket wakeup code (bsc#1141456).
- btrfs: stop partially refilling tickets when releasing space
  (bsc#1141456).
- btrfs: add space reservation tracepoint for reserved bytes
  (bsc#1141456).
- btrfs: roll tracepoint into btrfs_space_info_update helper
  (bsc#1141456).
- btrfs: do not allow reservations if we have pending tickets
  (bsc#1141456).
- commit 18cd200
* Mon Feb 24 2020 yousaf.kaukab@suse.com
- Refresh patches.suse/mmc-sdhci-fix-up-CMD12-sending.patch.
- commit b36db25
* Mon Feb 24 2020 oneukum@suse.com
- tools lib traceevent: Remove unneeded qsort and uses memmove
  instead (git-fixes).
- commit 37953f8
* Mon Feb 24 2020 yousaf.kaukab@suse.com
- rtc: fsl-ftm-alarm: move patch to sorted section
- commit 80b90f8
* Mon Feb 24 2020 oneukum@suse.com
- kvm: Reintroduce nopvspin kernel parameter (bsc#1056427).
- commit dcec1fa
* Mon Feb 24 2020 yousaf.kaukab@suse.com
- thermal: qoriq: refresh patches
- Refresh patches.suse/thermal-qoriq-Add-hwmon-support.patch.
- Refresh
  patches.suse/thermal-qoriq-Add-local-struct-device-pointer.patch.
- Refresh
  patches.suse/thermal-qoriq-Add-local-struct-qoriq_sensor-pointer.patch.
- Refresh
  patches.suse/thermal-qoriq-Convert-driver-to-use-regmap-API.patch.
- Refresh
  patches.suse/thermal-qoriq-Do-not-report-invalid-temperature-read.patch.
- Refresh
  patches.suse/thermal-qoriq-Don-t-store-struct-thermal_zone_device.patch.
- Refresh
  patches.suse/thermal-qoriq-Drop-unnecessary-drvdata-cleanup.patch.
- Refresh
  patches.suse/thermal-qoriq-Embed-per-sensor-data-into-struct-qori.patch.
- Refresh
  patches.suse/thermal-qoriq-Enable-all-sensors-before-registering-.patch.
- Refresh
  patches.suse/thermal-qoriq-Pass-data-to-qoriq_tmu_calibration-dir.patch.
- Refresh
  patches.suse/thermal-qoriq-Pass-data-to-qoriq_tmu_register_tmu_zo.patch.
- Refresh
  patches.suse/thermal_hwmon-Add-devres-wrapper-for-thermal_add_hwm.patch.
- commit bd644db
* Mon Feb 24 2020 jslaby@suse.cz
- ttyprintk: fix a potential deadlock in interrupt context issue
  (git-fixes).
- commit dc7ade5
* Mon Feb 24 2020 pmladek@suse.com
- blacklist.conf: bug: cosmetic change; related to a larger code clean up
- commit 43ce447
* Mon Feb 24 2020 ykaukab@suse.de
- dpaa_eth: support all modes with rate adapting PHYs
  (bsc#1159662).
- commit a5b2d56
* Mon Feb 24 2020 pmladek@suse.com
- printk: fix exclusive_console replaying (bsc#1164711).
- commit 466e4dc
* Mon Feb 24 2020 msuchanek@suse.de
- sr_vendor: support Beurer GL50 evo CD-on-a-chip devices
  (boo#1164632).
- commit a186914
* Mon Feb 24 2020 msuchanek@suse.de
- Enable CONFIG_BLK_DEV_SR_VENDOR (boo#1164632).
- commit 1c8f90b
* Mon Feb 24 2020 jack@suse.cz
- patches.suse/ext4-Fix-mount-failure-with-quota-configured-as-modu.patch:
  Update tags.
- commit 713f734
* Mon Feb 24 2020 oneukum@suse.com
- Delete
  patches.suse/0001-kvm-Introduce-nopvspin-kernel-parameter.patch.
  Remove guarded patch as it has been rendered unnecessary by
  9043442b43b1fddf202591b84702863286700c1a
  ("locking/paravirt: Use new static key for controlling call of
  virt_spin_lock()")
  and b2798ba0b876 ("KVM: X86: Choose qspinlock when dedicated physical
  CPUs are available")
- commit 583da5e
* Mon Feb 24 2020 jgross@suse.com
- xen: Enable interrupts when calling _cond_resched()
  (bsc#1065600).
- commit 4f2ecad
* Mon Feb 24 2020 lyan@suse.com
- KVM: arm64: Treat emulated TVAL TimerValue as a signed 32-bit
  integer (bsc#1133021).
- KVM: arm64: pmu: Fix chained SW_INCR counters (bsc#1133021).
- KVM: arm64: pmu: Don't increment SW_INCR if PMCR.E is unset
  (bsc#1133021).
- KVM: arm: Make inject_abt32() inject an external abort instead
  (bsc#1133021).
- KVM: arm: Fix DFSR setting for non-LPAE aarch32 guests
  (bsc#1133021).
- KVM: arm/arm64: Fix young bit from mmu notifier (bsc#1133021).
- KVM: arm/arm64: vgic-its: Fix restoration of unmapped
  collections (bsc#1133021).
- KVM: Clean up __kvm_gfn_to_hva_cache_init() and its callers
  (bsc#1133021).
- KVM: Check for a bad hva before dropping into the ghc slow path
  (bsc#1133021).
- KVM: arm/arm64: Properly handle faulting of device mappings
  (bsc#1133021).
- KVM: arm64: Ensure 'params' is initialised when looking up
  sys register (bsc#1133021).
- KVM: arm/arm64: Get rid of unused arg in cpu_init_hyp_mode()
  (bsc#1133021).
- KVM: fix placement of refcount initialization (bsc#1133021).
- KVM: Fix NULL-ptr deref after kvm_create_vm fails (bsc#1133021).
- kvm: call kvm_arch_destroy_vm if vm creation fails
  (bsc#1133021).
- commit 51a3eef
* Mon Feb 24 2020 lyan@suse.com
- kvm: Allocate memslots and buses before calling kvm_arch_init_vm
  (bsc#1133021).
- Refresh
  patches.suse/kvm-x86-mmu-Recovery-of-shattered-NX-large-pages.patch.
- commit fc34308
* Mon Feb 24 2020 nborisov@suse.com
- btrfs: only reserve metadata_size for inodes (bsc#1141456).
- btrfs: rename the btrfs_calc_*_metadata_size helpers
  (bsc#1141456).
- commit d6be9ae
* Mon Feb 24 2020 nborisov@suse.com
- btrfs: introduce an evict flushing state (bsc#1141456).
- btrfs: refactor priority_reclaim_metadata_space (bsc#1141456).
- btrfs: factor out the ticket flush handling (bsc#1141456).
- btrfs: unify error handling for ticket flushing (bsc#1141456).
- btrfs: add a flush step for delayed iputs (bsc#1141456).
- commit 21300d0
* Sun Feb 23 2020 colyli@suse.de
- md/raid0: Fix buffer overflow at debug print (bsc#1164051).
- commit c36de2b
* Fri Feb 21 2020 mkubecek@suse.cz
- series.conf: cleanup
  Reorganize the "Storage" section a bit.
  No effect on expanded tree.
- commit 0a80524
* Fri Feb 21 2020 duwe@suse.de
- crypto: allow self-test for ansi_cprng (bsc#1164254).
- commit e75c9ce
* Fri Feb 21 2020 mkubecek@suse.cz
- series.conf: cleanup
  Keep the number of top level sections reasonable.
- commit ff097d4
* Fri Feb 21 2020 duwe@suse.de
- s390 crypto: explicitly memzero stack key material in aes_s390.c
  (bsc#1163459).
- random: move FIPS continuous test to output functions
  (bsc#1163458).
- commit b896cb7
* Fri Feb 21 2020 nstange@suse.de
- kABI: restore debugfs_remove_recursive() (bsc#1159198).
- commit 102712e
* Fri Feb 21 2020 mkubecek@suse.cz
- hwmon: (k10temp) Display up to eight sets of CCD temperatures
  (bsc#1163206).
- hwmon: (k10temp) Don't show temperature limits on Ryzen (Zen)
  CPUs (bsc#1163206).
- hwmon: (k10temp) Show core and SoC current and voltages on
  Ryzen CPUs (bsc#1163206).
- hwmon: (k10temp) Report temperatures per CPU die (bsc#1163206).
- hmon: (k10temp) Convert to use
  devm_hwmon_device_register_with_info (bsc#1163206).
- hwmon: (k10temp) Use bitops (bsc#1163206).
- commit 82bbfc1
* Fri Feb 21 2020 dwagner@suse.de
- arm64: KVM: Invoke compute_layout() before alternatives are
  applied (bsc#1162702).
- percpu-refcount: Use normal instead of RCU-sched" (bsc#1162702).
- drm/i915: Don't disable interrupts independently of the lock
  (bsc#1162702).
- x86/ioapic: Rename misnamed functions (bsc#1162702).
- block: Don't disable interrupts in trigger_softirq()
  (bsc#1162702).
- commit 227d21b
* Fri Feb 21 2020 ailiopoulos@suse.com
- xfs: Fix deadlock between AGI and AGF with RENAME_WHITEOUT
  (bsc#1164482).
- commit 96d108c
* Fri Feb 21 2020 jack@suse.cz
- ext4: Fix mount failure with quota configured as module
  (bsc#1164471).
  Refresh patches.suse/ext4-unsupported-features.patch
- commit 4ccdd26
* Fri Feb 21 2020 hare@suse.de
- Refresh
  patches.suse/sd-always-retry-READ-CAPACITY-for-ALUA-state-transit.patch.
- commit 6221d57
* Fri Feb 21 2020 hare@suse.de
- Delete
  patches.suse/sd-always-scan-VPD-pages-if-thin-provisioning-is-ena.patch.
- commit 7919fbe
* Fri Feb 21 2020 hare@suse.de
- Delete patches.suse/scsi-disable-VPD-page-check-on-error.patch.
- commit e6dd2e4
* Fri Feb 21 2020 hare@suse.de
- ch: review and re-enable refcounting patches
- ch: remove ch_mutex() (bsc#1124235).
- ch: synchronize ch_probe() and ch_open() (bsc#1124235).
- Refresh
  patches.suse/ch-fixup-refcounting-imbalance-for-SCSI-devices.patch.
- Delete
  patches.suse/ch-add-missing-mutex_lock-mutex_unlock-in-ch_release.patch.
- commit 9a39484
* Fri Feb 21 2020 hare@suse.de
- scsi: mpt3sas: Update drive version to 33.100.00.00
  (jsc#SLE-10717).
- scsi: mpt3sas: Remove usage of device_busy counter
  (jsc#SLE-10717).
- scsi: mpt3sas: Print function name in which cmd timed out
  (jsc#SLE-10717).
- scsi: mpt3sas: Optimize mpt3sas driver logging (jsc#SLE-10717).
- scsi: mpt3sas: print in which path firmware fault occurred
  (jsc#SLE-10717).
- scsi: mpt3sas: Handle CoreDump state from watchdog thread
  (jsc#SLE-10717).
- scsi: mpt3sas: Add support IOCs new state named COREDUMP
  (jsc#SLE-10717).
- scsi: mpt3sas: renamed _base_after_reset_handler function
  (jsc#SLE-10717).
- scsi: mpt3sas: Add support for NVMe shutdown (jsc#SLE-10717).
- scsi: mpt3sas: Update MPI Headers to v02.00.57 (jsc#SLE-10717).
- scsi: mpt3sas: Fix double free in attach error handling
  (jsc#SLE-10717).
- scsi: mpt3sas: change allocation option (jsc#SLE-10717).
- scsi: mpt3sas: Clean up some indenting (jsc#SLE-10717).
- commit 916674e
* Fri Feb 21 2020 hare@suse.de
- megaraid_sas-fixup-MSIx-interrupt-setup-during-resume.patch: replace with upstream version
- commit 56ba2a9
* Fri Feb 21 2020 hare@suse.de
- scsi: megaraid_sas: Update driver version to 07.713.01.00-rc1
  (jsc#SLE-10720).
- scsi: megaraid_sas: Use Block layer API to check SCSI device
  in-flight IO requests (jsc#SLE-10720).
- scsi: megaraid_sas: Limit the number of retries for the IOCTLs
  causing firmware fault (jsc#SLE-10720).
- scsi: megaraid_sas: Do not initiate OCR if controller is not
  in ready state (jsc#SLE-10720).
- scsi: megaraid_sas: Re-Define enum DCMD_RETURN_STATUS
  (jsc#SLE-10720).
- scsi: megaraid_sas: Do not set HBA Operational if FW is not
  in operational state (jsc#SLE-10720).
- scsi: megaraid_sas: Do not kill HBA if JBOD Seqence map or
  RAID map is disabled (jsc#SLE-10720).
- scsi: megaraid_sas: Do not kill host bus adapter, if adapter
  is already dead (jsc#SLE-10720).
- scsi: megaraid_sas: Update optimal queue depth for SAS and
  NVMe devices (jsc#SLE-10720).
- scsi: megaraid_sas: Set no_write_same only for Virtual Disk
  (jsc#SLE-10720).
- scsi: megaraid_sas: Reset adapter if FW is not in READY state
  after device resume (jsc#SLE-10720).
- commit 65e16b2
* Fri Feb 21 2020 hare@suse.de
- Disable 'megaraid_sas-fixup-MSIx-interrupt-setup-during-resume'
- commit e492554
* Fri Feb 21 2020 mkubecek@suse.cz
- series.conf: cleanup
  Move patches.suse/suse-hv-kabi.patch into kABI padding section.
- commit fc6dc14
* Fri Feb 21 2020 rgoldwyn@suse.com
- fix up iter on short count in fuse_direct_io() (git-fixes).
- ovl: fix lseek overflow on 32bit (git-fixes).
- ovl: fix wrong WARN_ON() in ovl_cache_update_ino() (git-fixes).
- commit 508fa98
* Fri Feb 21 2020 rgoldwyn@suse.com
- Refresh patches.suse/new-helper-lookup_positive_unlocked.patch.
  Remove compiler warnings because of unused goto label.
- commit 71e012e
* Thu Feb 20 2020 ohering@suse.de
- hyper-v: Untangle stimers and timesync from clocksources (jsc#SLE-8133).
- commit a1b2308
* Thu Feb 20 2020 ohering@suse.de
- hv: kabi placeholders (jsc#SLE-8133).
- commit c3e96e8
* Thu Feb 20 2020 jroedel@suse.de
- KVM: x86/mmu: Add explicit access mask for MMIO SPTEs
  (bsc#1164354).
- Refresh patches.suse/kvm-mmu-ITLB_MULTIHIT-mitigation.patch.
- Refresh
  patches.suse/kvm-svm-override-default-mmio-mask-if-memory-encryption-is-enabled.
- commit 8a15fbd
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: push the grant head when the log head moves forward
  (bsc#1164095).
- commit d1770d3
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: push iclog state cleaning into xlog_state_clean_log
  (bsc#1164095).
- commit d1535a4
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: factor iclog state processing out of
  xlog_state_do_callback() (bsc#1164095).
- commit 3094c67
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: factor callbacks out of xlog_state_do_callback()
  (bsc#1164095).
- commit 901e51d
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: factor debug code out of xlog_state_do_callback()
  (bsc#1164095).
- commit 860c5ae
* Thu Feb 20 2020 jroedel@suse.de
- KVM: x86/mmu: Revert "KVM: x86/mmu: Remove is_obsolete() call"
  (bsc#1164357).
- Refresh
  patches.suse/kvm-x86-mmu-Recovery-of-shattered-NX-large-pages.patch.
- commit c9e37dc
* Thu Feb 20 2020 jroedel@suse.de
- KVM: x86/mmu: Revert "Revert "KVM: MMU: reclaim the
  zapped-obsolete page first"" (bsc#1164361).
- Refresh
  patches.suse/kvm-x86-mmu-Recovery-of-shattered-NX-large-pages.patch.
- commit 3193cde
* Thu Feb 20 2020 jroedel@suse.de
- KVM: x86: Unconditionally call x86 ops that are always
  implemented (bsc#1164382).
- Refresh
  patches.suse/kvm-x86-mmu-Recovery-of-shattered-NX-large-pages.patch.
- commit 3095ae2
* Thu Feb 20 2020 mbrugger@suse.com
- ARM: dts: stm32: add missing vdda-supply to adc on
  stm32429i-eval (bsc#1164461).
- commit da5a397
* Thu Feb 20 2020 mbrugger@suse.com
- blacklist.conf: add duplicated commit ID
- commit a626162
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: prevent CIL push holdoff in log recovery (bsc#1164095).
- commit d2cfffa
* Thu Feb 20 2020 mbrugger@suse.com
- blacklist.conf: ignore fix for not supported arch
- commit ca8ddc1
* Thu Feb 20 2020 jroedel@suse.de
- iommu/qcom: Fix bogus detach logic (bsc#1164445).
- iommu/vt-d: Simplify check in identity_mapping() (bsc#1159594).
- iommu/vt-d: Remove deferred_attach_domain() (bsc#1159594).
- iommu/vt-d: Do deferred attachment in iommu_need_mapping()
  (bsc#1159594).
- iommu/vt-d: Move deferred device attachment into helper function
  (bsc#1159594).
- iommu/vt-d: Add attach_deferred() helper (bsc#1159594).
- iommu/vt-d: Fix compile warning from intel-svm.h (bsc#1164446).
- KVM: x86/mmu: Fix struct guest_walker arrays for 5-level paging
  (bsc#1164356).
- KVM: nVMX: Use correct root level for nested EPT shadow page
  tables (bsc#1164330).
- KVM: x86: Mask off reserved bit from #DB exception payload
  (bsc#1164353).
- KVM: Use vcpu-specific gva->hva translation when querying host
  page size (bsc#1164337).
- KVM: x86: Revert "KVM: X86: Fix fpu state crash in kvm guest"
  (bsc#1164381).
- KVM: x86: Ensure guest's FPU state is loaded when accessing
  for emulation (bsc#1164344).
- KVM: x86: Handle TIF_NEED_FPU_LOAD in kvm_{load,put}_guest_fpu()
  (bsc#1164349).
- KVM: x86: Protect pmu_intel.c from Spectre-v1/L1TF attacks
  (bsc#1164374).
- KVM: x86: Protect DR-based index computations from
  Spectre-v1/L1TF attacks (bsc#1164365).
- KVM: x86: Protect exit_reason from being used in Spectre-v1/L1TF
  attacks (bsc#1164366).
- KVM: x86: Protect MSR-based index computations from
  Spectre-v1/L1TF attacks in x86.c (bsc#1164371).
- KVM: x86: Protect MSR-based index computations in pmu.h from
  Spectre-v1/L1TF attacks (bsc#1164373).
- KVM: x86: Protect MSR-based index computations in
  fixed_msr_to_seg_unit() from Spectre-v1/L1TF attacks
  (bsc#1164372).
- KVM: x86: Protect kvm_lapic_reg_write() from Spectre-v1/L1TF
  attacks (bsc#1164370).
- KVM: x86: Protect ioapic_write_indirect() from Spectre-v1/L1TF
  attacks (bsc#1164368).
- KVM: x86: Protect ioapic_read_indirect() from Spectre-v1/L1TF
  attacks (bsc#1164367).
- KVM: x86: Refactor picdev_write() to prevent Spectre-v1/L1TF
  attacks (bsc#1164376).
- KVM: x86: Protect kvm_hv_msr_[get|set]_crash_data() from
  Spectre-v1/L1TF attacks (bsc#1164369).
- KVM: x86: Protect x86_decode_insn from Spectre-v1/L1TF attacks
  (bsc#1164375).
- kvm/svm: PKU not currently supported (bsc#1164335).
- KVM: x86: Remove spurious clearing of async #PF MSR
  (bsc#1164378).
- KVM: x86: Remove spurious kvm_mmu_unload() from vcpu destruction
  path (bsc#1164379).
- KVM: x86: Free wbinvd_dirty_mask if vCPU creation fails
  (bsc#1164348).
- KVM: x86/mmu: Apply max PA check for MMIO sptes to 32-bit KVM
  (bsc#1164355).
- KVM: x86: Fix potential put_fpu() w/o load_fpu() on MPX platform
  (bsc#1164346).
- kvm: nVMX: VMWRITE checks unsupported field before read-only
  field (bsc#1164331).
- kvm: nVMX: VMWRITE checks VMCS-link pointer before VMCS field
  (bsc#1164332).
- kvm: nVMX: Relax guest IA32_FEATURE_CONTROL constraints
  (bsc#1164329).
- KVM: retpolines: x86: eliminate retpoline from vmx.c exit
  handlers (bsc#1164333).
- KVM: VMX: Fix conditions for guest IA32_XSS support
  (bsc#1164340).
- KVM: x86: Introduce vcpu->arch.xsaves_enabled (bsc#1164351).
- KVM: SVM: Guard against DEACTIVATE when performing
  WBINVD/DF_FLUSH (bsc#1164334).
- KVM: SVM: Serialize access to the SEV ASID bitmap (bsc#1164336).
- KVM: VMX: Do not change PID.NDST when loading a blocked vCPU
  (bsc#1164339).
- KVM: VMX: Consider PID.PIR to determine if vCPU has pending
  interrupts (bsc#1164338).
- KVM: nVMX: Don't leak L1 MMIO regions to L2 (bsc#1164328).
- kvm: vmx: Limit guest PMCs to those supported on the host
  (bsc#1164342).
- kvm: x86: Use AMD CPUID semantics for AMD vCPUs (bsc#1164383).
- kvm: x86: Improve emulation of CPUID leaves 0BH and 1FH
  (bsc#1164350).
- kvm: x86: Fix a spurious -E2BIG in __do_cpuid_func
  (bsc#1164345).
- KVM: x86/mmu: Revert "Revert "KVM: MMU: collapse TLB flushes
  when zap all pages"" (bsc#1164360).
- KVM: x86/mmu: Revert "Revert "KVM: MMU: zap pages in batch""
  (bsc#1164363).
- KVM: x86/mmu: Revert "Revert "KVM: MMU: add tracepoint for
  kvm_mmu_invalidate_all_pages"" (bsc#1164359).
- KVM: x86/mmu: Revert "Revert "KVM: MMU: show mmu_valid_gen in
  shadow page related tracepoints"" (bsc#1164362).
- KVM: x86/mmu: Treat invalid shadow pages as obsolete
  (bsc#1164364).
- KVM: x86: Manually flush collapsible SPTEs only when toggling
  flags (bsc#1164352).
- KVM: x86: Return to userspace with internal error on unexpected
  exit reason (bsc#1164380).
- KVM: x86: Add kvm_emulate_{rd,wr}msr() to consolidate VXM/SVM
  code (bsc#1164343).
- KVM: x86: Refactor up kvm_{g,s}et_msr() to simplify callers
  (bsc#1164377).
- KVM: x86: Fix x86_decode_insn() return when fetching insn
  bytes fails (bsc#1164347).
- commit d065de5
* Thu Feb 20 2020 ailiopoulos@suse.com
- xfs: push the AIL in xlog_grant_head_wake (bsc#1164095).
- commit 1bce18c
* Thu Feb 20 2020 mkubecek@suse.cz
- enable patches.suse/lan78xx-Enable-LEDs-and-auto-negotiation.patch
  This is one of inherited SLE15-SP1 non-upstream patches. It doesn't really
  match the bug it references and there has not been any apparent attempt to
  get it into mainline since it was added to SLE15. To avoid regressions,
  keep it in SLE15-SP2 for now but drop with SLE16 unless it gets upstreamed
  or there is at least some serious attempt to upstream it.
  Rename patches.suse/bsc1084332-0003-lan78xx-Enable-LEDs-and-auto-negotiation.patch
  to patches.suse/lan78xx-Enable-LEDs-and-auto-negotiation.patch, refresh it,
  enable and move into NIC driver section.
- commit 627e945
* Thu Feb 20 2020 ohering@suse.de
- hv_balloon: Balloon up according to request page number
  (git-fixes).
- scsi: storvsc: Correctly set number of hardware queues for
  IDE disk (git-fixes).
- hv_netvsc: Fix unwanted rx_table reset (git-fixes).
- hv_netvsc: Fix tx_table init in rndis_set_subchannel()
  (git-fixes).
- Drivers: hv: balloon: Remove dependencies on guest page size
  (git-fixes).
- hv_netvsc: flag software created hash value (git-fixes).
- hv_netvsc: Fix send_table offset in case of a host bug
  (git-fixes).
- hv_netvsc: Fix offset usage in netvsc_send_table() (git-fixes).
- commit 9bdb4de
* Wed Feb 19 2020 msuchanek@suse.de
- powerpc/tm: Fix clearing MSR[TS] in current when reclaiming
  on signal delivery (bsc#1118338 ltc#173734).
- commit 2e0d5f0
* Wed Feb 19 2020 tiwai@suse.de
- ASoC: sun8i-codec: Fix setting DAI data format (git-fixes).
- ASoC: fsl_sai: Fix exiting path on probing failure (git-fixes).
- ALSA: hda: Use scnprintf() for printing texts for sysfs/procfs
  (git-fixes).
- ALSA: hda/realtek - Apply quirk for yet another MSI laptop
  (git-fixes).
- ALSA: hda/realtek - Apply quirk for MSI GP63, too (git-fixes).
- ALSA: rawmidi: Avoid bit fields for state flags (git-fixes).
- ALSA: seq: Fix concurrent access to queue current tick/time
  (git-fixes).
- ALSA: seq: Avoid concurrent access to queue flags (git-fixes).
- commit a23ff90
* Wed Feb 19 2020 mbrugger@suse.com
- ata: ahci: Add shutdown to freeze hardware resources of ahci
  (bsc#1164388).
- commit ce5f6e5
* Wed Feb 19 2020 jroedel@suse.de
- iommu/arm-smmu-v3: Populate VMID field for CMDQ_OP_TLBI_NH_VA (bsc#1164308).
- commit d6eceea
* Wed Feb 19 2020 jroedel@suse.de
- blacklist.conf: Add b06c076ea962 Revert "iommu/arm-smmu: Make arm-smmu explicitly non-modular"
- commit 08f1fd5
* Wed Feb 19 2020 jroedel@suse.de
- blacklist.conf: Add 6e8fa7404c13 Revert "iommu/arm-smmu: Make arm-smmu-v3 explicitly non-modular"
- commit 4c1b45c
* Wed Feb 19 2020 jroedel@suse.de
- perf/x86/intel: Fix inaccurate period in context switch for
  auto-reload (bsc#1164307).
- iommu/vt-d: Avoid sending invalid page response (bsc#1164304).
- iommu/vt-d: Fix off-by-one in PASID allocation (bsc#1164305).
- iommu/vt-d: Match CPU and IOMMU paging mode (bsc#1164306).
- iommu/amd: Only support x2APIC with IVHD type 11h/40h
  (bsc#1164303).
- iommu/amd: Check feature support bit before accessing MSI
  capability registers (bsc#1164302).
- commit ead9f32
* Wed Feb 19 2020 mbenes@suse.cz
- tracing: Fix now invalid var_ref_vals assumption in trace action
  (git-fixes).
- commit 9385a9b
* Wed Feb 19 2020 jack@suse.cz
- block: fix get_max_segment_size() overflow on 32bit arch
  (bsc#1164285).
- commit 88517df
* Wed Feb 19 2020 jack@suse.cz
- ext4: fix support for inode sizes > 1024 bytes (bsc#1164284).
- commit 05b8b1c
* Wed Feb 19 2020 jack@suse.cz
- memcg: fix a crash in wb_workfn when a device disappears
  (bsc#1164276).
- commit b25cbaa
* Wed Feb 19 2020 mbrugger@suse.com
- arm64: dts: agilex/stratix10: fix pmu interrupt numbers
  (bsc#1164272).
- commit 0c677d5
* Wed Feb 19 2020 mbrugger@suse.com
- arm64: KVM: Device mappings should be execute-never
  (bsc#1164268).
- Refresh
  patches.suse/arm64-Ensure-VM_WRITE-VM_SHARED-ptes-are-clean-by-de.patch.
- commit b79bc51
* Wed Feb 19 2020 mkubecek@suse.cz
- fix upstream references
- fix Patch-mainline:
  patches.suse/fix-autofs-regression-caused-by-follow_managed-changes.patch
  patches.suse/fix-dget_parent-fastpath-race.patch
  patches.suse/fsnamei.c-fix-missing-barriers-when-checking-positivity.patch
  patches.suse/fsnamei.c-pull-positivity-check-into-follow_managed.patch
  patches.suse/new-helper-lookup_positive_unlocked.patch
- commit d37656d
* Wed Feb 19 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and resort:
  patches.suse/dma-contiguous-cma-give-precedence-to-cmdline.patch
- commit 1b96e18
* Wed Feb 19 2020 lyan@suse.com
- Replace
  Replace patches.suse/kvm-aarch64-avoid-guest-access-host-pmu-register.patch
  with patches.suse/KVM-arm64-Write-arch.mdcr_el2-changes-since-last-vcp.patch
  upstream id is 4942dec6638b0 (bsc#1161692).
- commit 6264601
* Wed Feb 19 2020 tbogendoerfer@suse.de
- netdevsim: fix ptr_ret.cocci warnings (bsc#1154353).
- commit acfaee7
* Tue Feb 18 2020 rgoldwyn@suse.com
- fix autofs regression caused by follow_managed() changes
  (git-fixes, bsc#1159271).
- commit a954cfa
* Tue Feb 18 2020 rgoldwyn@suse.com
- fs/namei.c: fix missing barriers when checking positivity
  (bsc#1159271).
- fix dget_parent() fastpath race  (bsc#1159271).
- new helper: lookup_positive_unlocked()  (bsc#1159271).
- fs/namei.c: pull positivity check into follow_managed()
  (bsc#1159271).
- commit 15f64cd
* Tue Feb 18 2020 mgorman@suse.de
- sched/fair: fix statistics for find_idlest_group() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit 2db86c8
* Tue Feb 18 2020 mgorman@suse.de
- sched/fair: Fix kernel-doc warning in attach_entity_load_avg()
  (git fixes (sched)).
- commit 366accc
* Tue Feb 18 2020 msuchanek@suse.de
- powerpc/kexec: Move kexec files into a dedicated subdir
  (bsc#1140025 ltc#176086).
  Refresh
  patches.suse/powerpc-Avoid-clang-warnings-around-setjmp-and-longj.patch.
- powerpc/32: Split kexec low level code out of misc_32.S
  (bsc#1140025 ltc#176086).
- commit ea45911
* Tue Feb 18 2020 mbrugger@suse.com
- arm64: dts: fast models: Fix FVP PCI interrupt-map property
  (bsc#1164201).
- arm64: ssbs: Fix context-switch when SSBS is present on all CPUs
  (bsc#1164221).
- arm64: dts: marvell: clearfog-gt-8k: fix switch cpu port node
  (bsc#1164211).
- arm64: acpi: fix DAIF manipulation with pNMI (bsc#1164197).
- arm64: nofpsmid: Handle TIF_FOREIGN_FPSTATE flag cleanly
  (bsc#1164219).
- arm64: ptrace: nofpsimd: Fail FP/SIMD regset operations
  (bsc#1164220).
- arm64: cpufeature: Set the FP/SIMD compat HWCAP bits properly
  (bsc#1164199).
- arm64: cpufeature: Fix the type of no FP/SIMD capability
  (bsc#1164198).
- arm64: kbuild: remove compressed images on 'make ARCH=arm64
  (dist)clean' (bsc#1164218).
- arm64: dts: allwinner: a64: olinuxino: Fix SDIO supply regulator
  (bsc#1164200).
- arm64: dts: imx8mq-librem5-devkit: use correct interrupt for
  the magnetometer (bsc#1164205).
- arm64: dts: imx8mm: Change SDMA1 ahb clock for imx8mm
  (bsc#1164202).
- arm64: dts: ls1028a: fix endian setting for dcfg (bsc#1164208).
- arm64: Implement copy_thread_tls (bsc#1164195).
- update arm64 config files (add HAVE_COPY_THREAD_TLS=y)
- arm64: Move __ARCH_WANT_SYS_CLONE3 definition to uapi headers
  (bsc#1164196).
- arm64: dts: ls1028a: fix reboot node (bsc#1164209).
- Revert "arm64: dts: juno: add dma-ranges property"
  (bsc#1164194).
- arm64: dts: juno: Fix UART frequency (bsc#1164206).
- arm64: dts: meson-gxm-khadas-vim2: fix uart_A bluetooth node
  (bsc#1164216).
- arm64: dts: meson-gxl-s905x-khadas-vim: fix uart_A bluetooth
  node (bsc#1164215).
- arm64: dts: meson-gxl-s905x-khadas-vim: fix gpio-keys-polled
  node (bsc#1164214).
- arm64: dts: meson: odroid-c2: Disable usb_otg bus to avoid
  power failed warning (bsc#1164217).
- arm64: dts: meson: axg: fix audio fifo reg size (bsc#1164212).
- arm64: dts: marvell: Fix CP110 NAND controller node multi-line
  comment alignment (bsc#1164210).
- arm64: dts: imx8mm: Correct OPP table according to latest
  datasheet (bsc#1164203).
- commit 8ffc54a
* Tue Feb 18 2020 msuchanek@suse.de
- powerpc: avoid adjusting memory_limit for capture kernel memory
  reservation (bsc#1140025).
- powerpc: reserve memory for capture kernel after hugepages init
  (bsc#1140025).
- commit 3e6df66
* Tue Feb 18 2020 dwagner@suse.de
- nvme: fix the parameter order for nvme_get_log in
  nvme_get_fw_slot_info (bsc#1163774).
- commit f4930bf
* Tue Feb 18 2020 mbrugger@suse.com
- ARM: npcm: Bring back GPIOLIB support (bsc#1164185).
- commit 3c9a346
* Tue Feb 18 2020 mbrugger@suse.com
- blacklist.conf: blacklist commits with wrong fixes ID
- commit b51d31a
* Tue Feb 18 2020 mbrugger@suse.com
- ARM: dts: am43xx: add support for clkout1 clock (bsc#1164150).
- ARM: dts: meson8b: use the actual frequency for the GPU's
  364MHz OPP (bsc#1164174).
- ARM: dts: meson8: use the actual frequency for the GPU's
  182.1MHz OPP (bsc#1164172).
- ARM: dts: meson8b: fix the clock controller compatible string
  (bsc#1164173).
- ARM: dts: at91: sama5d3: define clock rate range for tcb1
  (bsc#1164156).
- ARM: dts: at91: sama5d3: fix maximum peripheral clock rates
  (bsc#1164157).
- ARM: dts: at91: Reenable UART TX pull-ups (bsc#1164155).
- ARM: dts: stm32: Add power-supply for DSI panel on
  stm32f469-disco (bsc#1164177).
- ARM: dts: imx7: Fix Toradex Colibri iMX7S 256MB NAND flash
  support (bsc#1164167).
- ARM: dts: imx6sll-evk: Remove incorrect power supply assignment
  (bsc#1164164).
- ARM: dts: imx6sl-evk: Remove incorrect power supply assignment
  (bsc#1164163).
- ARM: dts: imx6sx-sdb: Remove incorrect power supply assignment
  (bsc#1164165).
- ARM: dts: imx6qdl-sabresd: Remove incorrect power supply
  assignment (bsc#1164162).
- ARM: dts: imx6q-icore-mipi: Use 1.5 version of i.Core MX6DL
  (bsc#1164161).
- ARM: dts: imx6q-dhcom: Fix SGTL5000 VDDIO regulator connection
  (bsc#1164159).
- ARM: dts: imx7ulp: fix reg of cpu node (bsc#1164168).
- ARM: dts: imx6q-dhcom: fix rtc compatible (bsc#1164160).
- ARM: dts: meson8: fix the size of the PMU registers
  (bsc#1164171).
- ARM: dts: am571x-idk: Fix gpios property to have the correct
  gpio number (bsc#1164151).
- ARM: OMAP2+: Fix ti_sysc_find_one_clockdomain to check for
  to_clk_hw_omap (bsc#1164146).
- ARM: dts: imx6ul: imx6ul-14x14-evk.dtsi: Fix SPI NOR probing
  (bsc#1164166).
- ARM: dts: bcm283x: Fix critical trip point (bsc#1164158).
- ARM: dts: Cygnus: Fix MDIO node address/size cells
  (bsc#1164148).
- ARM: dts: BCM5301X: Fix MDIO node address/size cells
  (bsc#1164147).
- ARM: dts: Fix sgx sysconfig register for omap4 (bsc#1164149).
- ARM: dts: logicpd-torpedo-37xx-devkit-28: Reference new DRM
  panel (bsc#1164170).
- ARM: dts: s3c64xx: Fix init order of clock providers
  (bsc#1164176).
- ARM: dts: stm32: relax qspi pins slew-rate for stm32mp157
  (bsc#1164182).
- ARM: dts: sunxi: Revert phy-names removal for ECHI and OHCI
  (bsc#1164184).
- ARM: omap2plus_defconfig: Enable DRM_TI_TFP410 (bsc#1164186).
- ARM: dts: logicpd-som-lv: Fix i2c2 and i2c3 Pin mux
  (bsc#1164169).
- ARM: dts: aspeed-g5: Fixe gpio-ranges upper limit (bsc#1164152).
- ARM: dts: aspeed: swift: Change power supplies to version 2
  (bsc#1164153).
- ARM: dts: aspeed: swift: Fix FSI GPIOs (bsc#1164154).
- ARM: dts: r8a7779: Use SYSC "always-on" PM Domain for HSCIF
  (bsc#1164175).
- ARM: dts: stm32: add pwm cells to stm32f746 (bsc#1164180).
- ARM: dts: stm32: add pwm cells to stm32f429 (bsc#1164179).
- ARM: dts: stm32: add pwm cells to stm32mp157c (bsc#1164181).
- ARM: dts: stm32: add missing vdda-supply to adc on
  stm32h743i-eval (bsc#1164178).
- ARM: dts: stm32: remove fixed regulator unit address on
  stm32429i-eval (bsc#1164183).
- commit 303d59d
* Tue Feb 18 2020 msuchanek@suse.de
- asm-generic/tlb: avoid potential double flush (bsc#1163776
  ltc#183929).
- commit 3b90a7e
* Tue Feb 18 2020 mbrugger@suse.com
- lib/vdso: Make __arch_update_vdso_data() logic understandable
  (bsc#1164141).
- commit 0a18ce1
* Tue Feb 18 2020 lhenriques@suse.com
- ceph: noacl mount option is effectively ignored (jsc#SES-1134).
- ceph: canonicalize server path in place (jsc#SES-1134).
- ceph: do not execute direct write in parallel if O_APPEND is
  specified (jsc#SES-1134).
- rbd: set the 'device' link in sysfs (jsc#SES-1134).
- ceph: move net/ceph/ceph_fs.c to fs/ceph/util.c (jsc#SES-1134).
- ceph: print name of xattr in __ceph_{get,set}xattr() douts
  (jsc#SES-1134).
- ceph: print r_direct_hash in hex in __choose_mds() dout
  (jsc#SES-1134).
- ceph: use copy-from2 op in copy_file_range (jsc#SES-1134).
- ceph: close holes in structs ceph_mds_session and
  ceph_mds_request (jsc#SES-1134).
- ceph: allocate the correct amount of extra bytes for the
  session features (jsc#SES-1134).
- ceph: rename get_session and switch to use ceph_get_mds_session
  (jsc#SES-1134).
- ceph: remove the extra slashes in the server path
  (jsc#SES-1134).
- ceph: add possible_max_rank and make the code more readable
  (jsc#SES-1134).
- ceph: print dentry offset in hex and fix xattr_version type
  (jsc#SES-1134).
- ceph: only touch the caps which have the subset mask requested
  (jsc#SES-1134).
- ceph: don't clear I_NEW until inode metadata is fully populated
  (jsc#SES-1134).
- ceph: retry the same mds later after the new session is opened
  (jsc#SES-1134).
- ceph: check availability of mds cluster on mount after wait
  timeout (jsc#SES-1134).
- ceph: keep the session state until it is released
  (jsc#SES-1134).
- ceph: add __send_request helper (jsc#SES-1134).
- ceph: ensure we have a new cap before continuing in fill_inode
  (jsc#SES-1134).
- ceph: drop unused ttl_from parameter from fill_inode
  (jsc#SES-1134).
- ceph: fix possible long time wait during umount (jsc#SES-1134).
- ceph: only choose one MDS who is in up:active state without
  laggy (jsc#SES-1134).
- ceph: fix mdsmap cluster available check based on laggy number
  (jsc#SES-1134).
- ceph: remove unnecessary assignment in ceph_pre_init_acls()
  (jsc#SES-1134).
- ceph: delete redundant douts in con_get/put() (jsc#SES-1134).
- commit 7a69ca8
* Tue Feb 18 2020 tbogendoerfer@suse.de
- IB/mlx5: Use div64_u64 for num_var_hw_entries calculation
  (jsc#SLE-8446).
- RDMA/core: Fix protection fault in get_pkey_idx_qp_list
  (jsc#SLE-8449).
- RDMA/rxe: Fix soft lockup problem due to using tasklets in
  softirq (jsc#SLE-8449).
- RDMA/mlx5: Prevent overflow in mmap offset calculations
  (jsc#SLE-8446).
- IB/umad: Fix kernel crash while unloading ib_umad
  (jsc#SLE-8449).
- RDMA/mlx5: Fix async events cleanup flows (jsc#SLE-8446).
- RDMA/core: Add missing list deletion on freeing event queue
  (jsc#SLE-8449).
- RDMA/siw: Remove unwanted WARN_ON in siw_cm_llp_data_ready()
  (jsc#SLE-8381).
- RDMA/iw_cxgb4: initiate CLOSE when entering TERM (jsc#SLE-8392).
- IB/mlx5: Return failure when rts2rts_qp_counters_set_id is
  not supported (jsc#SLE-8446).
- RDMA/core: Fix invalid memory access in spec_filter_size
  (jsc#SLE-8449).
- IB/rdmavt: Reset all QPs when the device is shut down
  (jsc#SLE-8449).
- IB/hfi1: Close window for pq and request coliding
  (jsc#SLE-8449).
- IB/hfi1: Acquire lock to release TID entries when user file
  is closed (jsc#SLE-8449).
- RDMA/hfi1: Fix memory leak in _dev_comp_vect_mappings_create
  (jsc#SLE-8449).
- net: hns3: fix a copying IPv6 address error in
  hclge_fd_get_flow_tuples() (bsc#1154353).
- net: hns3: fix VF bandwidth does not take effect in some case
  (bsc#1154353).
- net: hns3: add management table after IMP reset (bsc#1154353).
- page_pool: refill page when alloc.count of pool is zero
  (bsc#1154353).
- ice: Trivial fixes (jsc#SLE-7926).
- ice: Use correct netif error function (jsc#SLE-7926).
- ice: Cleanup ice_vsi_alloc_q_vectors (jsc#SLE-7926).
- ice: Make print statements more compact (jsc#SLE-7926).
- ice: Use ice_pf_to_dev (jsc#SLE-7926).
- ice: Remove possible null dereference (jsc#SLE-7926).
- ice: update Unit Load Status bitmask to check after reset
  (jsc#SLE-7926).
- ice: fix and consolidate logging of NVM/firmware version
  information (jsc#SLE-7926).
- ice: Modify link message logging (jsc#SLE-7926).
- ice: Remove CONFIG_PCI_IOV wrap in ice_set_pf_caps
  (jsc#SLE-7926).
- ice: Remove ice_dev_onetime_setup() (jsc#SLE-7926).
- ice: Don't allow same value for Rx tail to be written twice
  (jsc#SLE-7926).
- ice: display supported and advertised link modes (jsc#SLE-7926).
- ice: Fix switch between FW and SW LLDP (jsc#SLE-7926).
- ice: Fix DCB rebuild after reset (jsc#SLE-7926).
- net: ena: ena-com.c: prevent NULL pointer dereference
  (bsc#1154492).
- net: ena: ethtool: use correct value for crc32 hash
  (bsc#1154492).
- net: ena: make ena rxfh support ETH_RSS_HASH_NO_CHANGE
  (bsc#1154492).
- net: ena: fix corruption of dev_idx_to_host_tbl (bsc#1154492).
- net: ena: fix incorrectly saving queue numbers when setting
  RSS indirection table (bsc#1154492).
- net: ena: rss: store hash function as values and not bits
  (bsc#1154492).
- net: ena: rss: fix failure to get indirection table
  (bsc#1154492).
- net: ena: rss: do not allocate key when not supported
  (bsc#1154492).
- net: ena: fix incorrect default RSS key (bsc#1154492).
- net: ena: add missing ethtool TX timestamping indication
  (bsc#1154492).
- net: ena: fix uses of round_jiffies() (bsc#1154492).
- net: ena: fix potential crash when rxfh key is NULL
  (bsc#1154492).
- i40e: Fix the conditional for i40e_vc_validate_vqs_bitmaps
  (bsc#1163036).
- bpf: Improve bucket_log calculation logic (bsc#1154353).
- i40e: Relax i40e_xsk_wakeup's return value when PF is busy
  (jsc#SLE-8025).
- mlxsw: spectrum_dpipe: Add missing error path (bsc#1154488).
- mlxsw: core: Add validation of hardware device types for MGPIR
  register (bsc#1154488).
- ipv6/addrconf: fix potential NULL deref in inet6_set_link_af()
  (bsc#1154353).
- taprio: Fix dropping packets when using taprio + ETF offloading
  (bsc#1154353).
- taprio: Use taprio_reset_tc() to reset Traffic Classes
  configuration (bsc#1154353).
- taprio: Add missing policy validation for flags (bsc#1154353).
- taprio: Fix still allowing changing the flags during runtime
  (bsc#1154353).
- taprio: Fix enabling offload with wrong number of traffic
  classes (bsc#1154353).
- net/mlx5: Deprecate usage of generic TLS HW capability bit
  (jsc#SLE-8464).
- net/mlx5e: TX, Error completion is for last WQE in batch
  (jsc#SLE-8464).
- net/mlx5: IPsec, fix memory leak at
  mlx5_fpga_ipsec_delete_sa_ctx (jsc#SLE-8464).
- net/mlx5: IPsec, Fix esp modify function attribute
  (jsc#SLE-8464).
- net/mlx5: Fix deadlock in fs_core (jsc#SLE-8464).
- skbuff: fix a data race in skb_queue_len() (bsc#1154353).
- cxgb4: Added tls stats prints (jsc#SLE-8389).
- net_sched: fix an OOB access in cls_tcindex (bsc#1154353).
- netdevsim: remove unused sdev code (bsc#1154353).
- netdevsim: use __GFP_NOWARN to avoid memalloc warning
  (bsc#1154353).
- netdevsim: use IS_ERR instead of IS_ERR_OR_NULL for debugfs
  (bsc#1154353).
- netdevsim: fix stack-out-of-bounds in nsim_dev_debugfs_init()
  (bsc#1154353).
- netdevsim: fix panic in nsim_dev_take_snapshot_write()
  (bsc#1154353).
- netdevsim: disable devlink reload when resources are being used
  (bsc#1154353).
- netdevsim: fix using uninitialized resources (bsc#1154353).
- bnxt_en: Fix TC queue mapping (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix logic that disables Bus Master during firmware
  reset (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix RDMA driver failure with SRIOV after firmware reset
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor logic to re-enable SRIOV after firmware
  reset detected (jsc#SLE-8371 bsc#1153274).
- cls_rsvp: fix rsvp_policy (bsc#1154353).
- RDMA/core: Make the entire API tree static (jsc#SLE-8449).
- RDMA/efa: Mask access flags with the correct optional range
  (jsc#SLE-5640).
- RDMA/cma: Fix unbalanced cm_id reference count during address
  resolve (jsc#SLE-8449).
- RDMA/umem: Fix ib_umem_find_best_pgsz() (jsc#SLE-8449).
- IB/mlx4: Fix leak in id_map_find_del (jsc#SLE-8461).
- IB/opa_vnic: Spelling correction of 'erorr' to 'error'
  (jsc#SLE-8449).
- IB/hfi1: Fix logical condition in msix_request_irq
  (jsc#SLE-8449).
- RDMA/cm: Use IBA functions for complex structure members
  (jsc#SLE-8449).
- RDMA/cm: Use IBA functions for simple structure members
  (jsc#SLE-8449).
- RDMA/cm: Use IBA functions for swapping get/set acessors
  (jsc#SLE-8449).
- RDMA/cm: Use IBA functions for simple get/set acessors
  (jsc#SLE-8449).
- RDMA/cm: Add SET/GET implementations to hide IBA wire format
  (jsc#SLE-8449).
- RDMA/cm: Add accessors for CM_REQ transport_type (jsc#SLE-8449).
- IB/mlx5: Return the administrative GUID if exists
  (jsc#SLE-8446).
- RDMA/core: Ensure that rdma_user_mmap_entry_remove() is a fence
  (jsc#SLE-8449).
- IB/mlx4: Fix memory leak in add_gid error flow (jsc#SLE-8461).
- IB/mlx5: Expose RoCE accelerator counters (jsc#SLE-8446).
- RDMA/mlx5: Set relaxed ordering when requested (jsc#SLE-8446).
- RDMA/uverbs: Add new relaxed ordering memory region access flag
  (jsc#SLE-8446).
- RDMA/efa: Allow passing of optional access flags for MR
  registration (jsc#SLE-5640).
- RDMA/core: Add optional access flags range (jsc#SLE-8449).
- RDMA/uverbs: Verify MR access flags (jsc#SLE-8449).
- RDMA/uverbs: Add ioctl command to get a device context
  (jsc#SLE-8449).
- RDMA/core: Remove ucontext_lock from the
  uverbs_destry_ufile_hw() path (jsc#SLE-8449).
- RDMA/core: Add UVERBS_METHOD_ASYNC_EVENT_ALLOC (jsc#SLE-8449).
- net/mlx5: Expose relaxed ordering bits (jsc#SLE-8464).
- net/mlx5: Add RoCE accelerator counters (jsc#SLE-8464).
- IB/srp: Never use immediate data if it is disabled by a user
  (jsc#SLE-8449).
- RDMA/rxe: Compute the maximum sges and inline size based on
  the WQE size (jsc#SLE-8449).
- Introduce maximum WQE size to check limits (jsc#SLE-8449).
- RDMA/efa: Remove unused ucontext parameter from
  efa_qp_user_mmap_entries_remove (jsc#SLE-5640).
- RDMA/efa: Remove {} brackets from single statement if
  (jsc#SLE-5640).
- RDMA/efa: Device definitions documentation updates
  (jsc#SLE-5640).
- RDMA/hns: Add support for extended atomic in userspace
  (jsc#SLE-8449).
- RDMA/hns: Get pf capabilities from firmware (jsc#SLE-8449).
- RDMA/hns: Add interfaces to get pf capabilities from firmware
  (jsc#SLE-8449).
- RDMA/hns: Remove some redundant variables related to
  capabilities (jsc#SLE-8449).
- RDMA/core: Use READ_ONCE for ib_ufile.async_file (jsc#SLE-8449).
- RDMA/core: Make ib_uverbs_async_event_file into a uobject
  (jsc#SLE-8449).
- RDMA/core: Remove the ufile arg from rdma_alloc_begin_uobject
  (jsc#SLE-8449).
- RDMA/core: Simplify type usage for ib_uverbs_async_handler()
  (jsc#SLE-8449).
- RDMA/core: Do not erase the type of ib_wq.uobject
  (jsc#SLE-8449).
- RDMA/core: Do not erase the type of ib_srq.uobject
  (jsc#SLE-8449).
- RDMA/core: Do not erase the type of ib_qp.uobject
  (jsc#SLE-8449).
- RDMA/core: Do not erase the type of ib_cq.uobject
  (jsc#SLE-8449).
- RDMA/core: Make ib_ucq_object use ib_uevent_object
  (jsc#SLE-8449).
- RDMA/core: Do not allow alloc_commit to fail (jsc#SLE-8449).
- RDMA/mlx5: Simplify devx async commands (jsc#SLE-8446).
- RDMA/core: Simplify destruction of FD uobjects (jsc#SLE-8449).
- RDMA/mlx5: Use RCU and direct refcounts to keep memory alive
  (jsc#SLE-8446).
- RDMA/uverbs: Remove needs_kfree_rcu from uverbs_obj_type_class
  (jsc#SLE-8449).
- IB/mlx5: Add mmap support for VAR (jsc#SLE-8446).
- IB/mlx5: Introduce VAR object and its alloc/destroy methods
  (jsc#SLE-8446).
- IB/mlx5: Extend caps stage to handle VAR capabilities
  (jsc#SLE-8446).
- RDMA/core: Remove err in iw_query_port (jsc#SLE-8449).
- RDMA/hns: Add support for reporting wc as software mode
  (jsc#SLE-8449).
- RDMA/hns: Bugfix for posting a wqe with sge (jsc#SLE-8449).
- IB/hfi1: Add RcvShortLengthErrCnt to hfi1stats (jsc#SLE-8449).
- IB/hfi1: Add software counter for ctxt0 seq drop (jsc#SLE-8449).
- IB/hfi1: Return void in packet receiving functions
  (jsc#SLE-8449).
- IB/hfi1: Decouple IRQ name from type (jsc#SLE-8449).
- IB/hfi1: Create API for auto activate (jsc#SLE-8449).
- IB/hfi1: IB/hfi1: Add an API to handle special case drop
  (jsc#SLE-8449).
- IB/hfi1: Move common receive IRQ code to function
  (jsc#SLE-8449).
- IB/hfi1: Add fast and slow handlers for receive context
  (jsc#SLE-8449).
- IB/hfi1: Move chip specific functions to chip.c (jsc#SLE-8449).
- RDMA/core: Fix locking in ib_uverbs_event_read (jsc#SLE-8449).
- IB/core: Fix build failure without hugepages (jsc#SLE-8449).
- IB/core: Rename event_handler_lock to qp_open_list_lock
  (jsc#SLE-8449).
- IB/core: Cut down single member ib_cache structure
  (jsc#SLE-8449).
- IB/core: Let IB core distribute cache update events
  (jsc#SLE-8449).
- IB/mlx5: Do reverse sequence during device removal
  (jsc#SLE-8446).
- RDMA/hns: Fix coding style issues (jsc#SLE-8449).
- RDMA/hns: Replace custom macros HNS_ROCE_ALIGN_UP
  (jsc#SLE-8449).
- RDMA/hns: Remove redundant print information (jsc#SLE-8449).
- RDMA/hns: Delete unnessary parameters in hns_roce_v2_qp_modify()
  (jsc#SLE-8449).
- RDMA/hns: Update the value of qp type (jsc#SLE-8449).
- RDMA/hns: Remove unused function hns_roce_init_eq_table()
  (jsc#SLE-8449).
- RDMA/hns: Avoid printing address of mtt page (jsc#SLE-8449).
- RDMA/core: Add trace points to follow MR allocation
  (jsc#SLE-8449).
- RDMA/core: Trace points for diagnosing completion queue issues
  (jsc#SLE-8449).
- RDMA/cma: Add trace points in RDMA Connection Manager
  (jsc#SLE-8449).
- RDMA/cm: Delete unused CM ARP functions (jsc#SLE-8449).
- RDMA/cm: Delete unused CM LAP functions (jsc#SLE-8449).
- RDMA/i40iw: fix a potential NULL pointer dereference
  (jsc#SLE-8449).
- RDMA/rxe: Fix error type of mmap_offset (jsc#SLE-8449).
- RDMA/mlx5: use true,false for bool variable (jsc#SLE-8446).
- RDMA/mlx4: use true,false for bool variable (jsc#SLE-8461).
- IB/iser: use true,false for bool variable (jsc#SLE-8449).
- IB/hfi1: use true,false for bool variable (jsc#SLE-8449).
- RDMA/siw: use true,false for bool variable (jsc#SLE-8381).
- IB/core: Fix ODP with IB_ACCESS_HUGETLB handling (jsc#SLE-8449).
- IB/core: Fix ODP get user pages flow (jsc#SLE-8449).
- IB/mlx5: Unify ODP MR code paths to allow extra flexibility
  (jsc#SLE-8446).
- IB/rdmavt: Correct comments in rdmavt_qp.h header
  (jsc#SLE-8449).
- IB/hfi1: List all receive contexts from debugfs (jsc#SLE-8449).
- IB/hfi1: Add accessor API routines to access context members
  (jsc#SLE-8449).
- RDMA/mlx4: Redo TX checksum offload in line with docs
  (jsc#SLE-8461).
- RDMA/cm: Use RCU synchronization mechanism to protect
  cm_id_private xa_load() (jsc#SLE-8449).
- RDMA/srpt: Remove unnecessary assertion in srpt_queue_response
  (jsc#SLE-8449).
- RDMA/netlink: Do not always generate an ACK for some netlink
  operations (jsc#SLE-8449).
- IB/mlx5: Fix outstanding_pi index for GSI qps (jsc#SLE-8446).
- RDMA/siw: Simplify QP representation (jsc#SLE-8381).
- RDMA/hns: Simplify the calculation and usage of wqe idx for
  post verbs (jsc#SLE-8449).
- RDMA/bnxt_re: Report more number of completion vectors
  (jsc#SLE-8372 bsc#1153275).
- RDMA/qedr: Add kernel capability flags for dpm enabled mode
  (jsc#SLE-8215).
- net/core: Do not clear VF index for node/port GUIDs query
  (bsc#1154353).
- flow_dissector: Fix to use new variables for port ranges in
  bpf hook (bsc#1154353).
- libbpf: Fix realloc usage in bpf_core_find_cands (bsc#1154353).
- sfc: move mcdi filtering code (jsc#SLE-8314).
- sfc: create header for mcdi filtering code (jsc#SLE-8314).
- sfc: rename mcdi filtering functions/structs (jsc#SLE-8314).
- bnxt_en: Add support for devlink info command (jsc#SLE-8371
  bsc#1153274).
- devlink: add macro for "fw.roce" (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Rename switch_id to dsn (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add support to update progress of flash update
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Move devlink_register before registering netdev
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Register devlink irrespective of firmware spec version
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor bnxt_dl_register() (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Disable workaround for lost interrupts on 575XX B0
  and newer chips (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Periodically check and remove aged-out ntuple filters
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Do not accept fragments for aRFS flow steering
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Support UDP RSS hashing on 575XX chips (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Remove the setting of dev_port (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Improve bnxt_probe_phy() (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Improve link up detection (jsc#SLE-8371 bsc#1153274).
- mlxsw: minimal: Fix an error handling path in
  'mlxsw_m_port_create()' (bsc#1154488).
- ice: Bump version (jsc#SLE-7926).
- ice: Implement ethtool get/set rx-flow-hash (jsc#SLE-7926).
- ice: Initilialize VF RSS tables (jsc#SLE-7926).
- ice: Optimize table usage (jsc#SLE-7926).
- ice: Enable writing filtering tables (jsc#SLE-7926).
- ice: Populate TCAM filter software structures (jsc#SLE-7926).
- ice: Allocate flow profile (jsc#SLE-7926).
- ice: Enable writing hardware filtering tables (jsc#SLE-7926).
- net: sched: sch_tbf: Don't overwrite backlog before dumping
  (bsc#1154353).
- devlink: Add health recover notifications on devlink flows
  (bsc#1154353).
- net/mlx5e: Enable all available stats for uplink reps
  (jsc#SLE-8464).
- net/mlx5e: Create q counters on uplink representors
  (jsc#SLE-8464).
- net/mlx5e: Convert rep stats to mlx5e_stats_grp-based infra
  (jsc#SLE-8464).
- net/mlx5e: IPoIB, use separate stats groups (jsc#SLE-8464).
- net/mlx5e: Convert stats groups array to array of group pointers
  (jsc#SLE-8464).
- net/mlx5e: Declare stats groups via macro (jsc#SLE-8464).
- net/mlx5e: Profile specific stats groups (jsc#SLE-8464).
- net/mlx5e: Move uplink rep init/cleanup code into own functions
  (jsc#SLE-8464).
- net/mlx5: DR, Allow connecting flow table to a lower/same
  level table (jsc#SLE-8464).
- net/mlx5: DR, Modify header copy support (jsc#SLE-8464).
- net/mlx5: DR, Modify set action limitation extension
  (jsc#SLE-8464).
- net/mlx5e: Add mlx5e_flower_parse_meta support (jsc#SLE-8464).
- net/mlx5e: allow TSO on VXLAN over VLAN topologies
  (jsc#SLE-8464).
- net/mlx5e: Fix printk format warning (jsc#SLE-8464).
- bpf: Fix trampoline usage in preempt (bsc#1154353).
- net: hns3: cleanup some coding style issue (bsc#1154353).
- net: hns3: remove redundant print on ENOMEM (bsc#1154353).
- net: hns3: delete unnecessary blank line and space for cleanup
  (bsc#1154353).
- net: hns3: rewrite a log in hclge_put_vector() (bsc#1154353).
- net: hns3: refine the input parameter 'size' for snprintf()
  (bsc#1154353).
- net: hns3: move duplicated macro definition into header
  (bsc#1154353).
- net: hns3: set VF's default reset_type to HNAE3_NONE_RESET
  (bsc#1154353).
- net: hns3: do not reuse pfmemalloc pages (bsc#1154353).
- net: hns3: limit the error logging in the hns3_clean_tx_ring()
  (bsc#1154353).
- net: hns3: replace snprintf with scnprintf in
  hns3_update_strings (bsc#1154353).
- net: hns3: replace snprintf with scnprintf in hns3_dbg_cmd_read
  (bsc#1154353).
- RDMA/mlx5: Fix handling of IOVA != user_va in ODP paths
  (jsc#SLE-8446).
- IB/mlx5: Mask out unsupported ODP capabilities for kernel QPs
  (jsc#SLE-8446).
- RDMA/mlx5: Don't fake udata for kernel path (jsc#SLE-8446).
- IB/mlx5: Add ODP WQE handlers for kernel QPs (jsc#SLE-8446).
- IB/core: Add interface to advise_mr for kernel users
  (jsc#SLE-8449).
- IB/core: Introduce ib_reg_user_mr (jsc#SLE-8449).
- net/mlx5: Allow creating autogroups with reserved entries
  (jsc#SLE-8464).
- net/mlx5: Add ignore level support fwd to table rules
  (jsc#SLE-8464).
- net/mlx5: fs_core: Introduce unmanaged flow tables
  (jsc#SLE-8464).
- net/mlx5: Refactor mlx5_create_auto_grouped_flow_table
  (jsc#SLE-8464).
- net/mlx5e: Add discard counters per priority (jsc#SLE-8464).
- net/mlx5e: Expose FEC feilds and related capability bit
  (jsc#SLE-8464).
- net/mlx5: Add mlx5_ifc definitions for connection tracking
  support (jsc#SLE-8464).
- net/mlx5: Add copy header action struct layout (jsc#SLE-8464).
- net/mlx5: Expose resource dump register mapping (jsc#SLE-8464).
- net/mlx5: Add structures and defines for MIRC register
  (jsc#SLE-8464).
- net/mlx5: Read MCAM register groups 1 and 2 (jsc#SLE-8464).
- net/mlx5: Add structures layout for new MCAM access reg groups
  (jsc#SLE-8464).
- net/mlx5: Expose vDPA emulation device capabilities
  (jsc#SLE-8464).
- net/mlx5: Add Virtio Emulation related device capabilities
  (jsc#SLE-8464).
- sfc: remove duplicated include from efx.c (jsc#SLE-8314).
- sfc/ethtool_common: Make some function to static (jsc#SLE-8314).
- net: hns3: refactor the notification scheme of PF reset
  (bsc#1154353).
- net: hns3: modify hclge_func_reset_sync_vf()'s return type to
  void (bsc#1154353).
- net: hns3: enlarge HCLGE_RESET_WAIT_CNT (bsc#1154353).
- net: hns3: refactor the procedure of VF FLR (bsc#1154353).
- net: hns3: refactor the precedure of PF FLR (bsc#1154353).
- net: hns3: split hclgevf_reset() into preparing and rebuilding
  part (bsc#1154353).
- net: hns3: split hclge_reset() into preparing and rebuilding
  part (bsc#1154353).
- sfc: remove set but not used variable 'nic_data' (jsc#SLE-8314).
- sfc: remove duplicated include from ef10.c (jsc#SLE-8314).
- bnxt: Detach page from page pool before sending up the stack
  (jsc#SLE-8371 bsc#1153274).
- devlink: add macro for "fw.psid" (bsc#1154353).
- sfc: move RPS code (jsc#SLE-8314).
- sfc: move yet more functions (jsc#SLE-8314).
- sfc: move RSS code (jsc#SLE-8314).
- sfc: move a couple more functions (jsc#SLE-8314).
- sfc: move some ethtool code (jsc#SLE-8314).
- sfc: move various functions (jsc#SLE-8314).
- sfc: move more rx code (jsc#SLE-8314).
- sfc: move more tx code (jsc#SLE-8314).
- sfc: refactor selftest work init code (jsc#SLE-8314).
- sfc: move MCDI logging device attribute (jsc#SLE-8314).
- sfc: conditioned some functionality (jsc#SLE-8314).
- sfc: move MCDI receive queue management code (jsc#SLE-8314).
- sfc: move MCDI transmit queue management code (jsc#SLE-8314).
- sfc: move MCDI event queue management code (jsc#SLE-8314).
- sfc: move MCDI VI alloc/free code (jsc#SLE-8314).
- sfc: move more MCDI port code (jsc#SLE-8314).
- sfc: move some MCDI port utility functions (jsc#SLE-8314).
- sfc: move some port link state/caps code (jsc#SLE-8314).
- vmxnet3: Remove always false conditional statement
  (bsc#1154353).
- bnxt_en: Call recovery done after reset is successfully done
  (jsc#SLE-8371 bsc#1153274).
- devlink: add devink notification when reporter update health
  state (bsc#1154353).
- devlink: add support for reporter recovery completion
  (bsc#1154353).
- sfc: move common tx code (jsc#SLE-8314).
- sfc: move common rx code (jsc#SLE-8314).
- sfc: move event queue management code (jsc#SLE-8314).
- sfc: move channel interrupt management code (jsc#SLE-8314).
- sfc: move channel alloc/removal code (jsc#SLE-8314).
- sfc: move channel start/stop code (jsc#SLE-8314).
- sfc: move some channel-related code (jsc#SLE-8314).
- sfc: move struct init and fini code (jsc#SLE-8314).
- sfc: move some device reset code (jsc#SLE-8314).
- sfc: move datapath management code (jsc#SLE-8314).
- sfc: move mac configuration and status functions (jsc#SLE-8314).
- sfc: move reset workqueue code (jsc#SLE-8314).
- sfc: further preparation for code split (jsc#SLE-8314).
- sfc: add new headers in preparation for code split
  (jsc#SLE-8314).
- net/mlx5: DR, Create multiple destination action from
  dr_create_fte (jsc#SLE-8464).
- net/mlx5: DR, Add support for multiple destination table action
  (jsc#SLE-8464).
- net/mlx5: DR, Align dest FT action creation to API
  (jsc#SLE-8464).
- net/mlx5: DR, Pass table flags at creation to lower layer
  (jsc#SLE-8464).
- net/mlx5: DR, Create multi-destination table for SW-steering
  use (jsc#SLE-8464).
- net/mlx5: DR, Create FTE entry in the FW from SW-steering
  (jsc#SLE-8464).
- net/mlx5: DR, Use attributes struct for FW flow table creation
  (jsc#SLE-8464).
- net/mlx5: Use async EQ setup cleanup helpers for multiple EQs
  (jsc#SLE-8464).
- net/mlx5: Reduce No CQ found log level from warn to debug
  (jsc#SLE-8464).
- net/mlx5: Increase the max number of channels to 128
  (jsc#SLE-8464).
- net/mlx5e: Support accept action on nic table (jsc#SLE-8464).
- mlx5: work around high stack usage with gcc (jsc#SLE-8464).
- net/mlx5: limit the function in local scope (jsc#SLE-8464).
- mlxsw: spectrum: Disable DIP_LINK_LOCAL check in hardware
  pipeline (bsc#1154488).
- mlxsw: spectrum: Disable SIP_DIP check in hardware pipeline
  (bsc#1154488).
- mlxsw: spectrum: Disable MC_DMAC check in hardware pipeline
  (bsc#1154488).
- mlxsw: spectrum: Disable SIP_CLASS_E check in hardware pipeline
  (bsc#1154488).
- net: hns3: modify an unsuitable reset level for hardware error
  (bsc#1154353).
- net: hns3: replace an unsuitable variable type in
  hclge_inform_reset_assert_to_vf() (bsc#1154353).
- net: hns3: add protection when get SFP speed as 0 (bsc#1154353).
- net: hns3: modify the IRQ name of misc vectors (bsc#1154353).
- net: hns3: modify an unsuitable log in
  hclge_map_ring_to_vector() (bsc#1154353).
- net: hns3: modify the IRQ name of TQP vector (bsc#1154353).
- net: hns3: re-organize vector handle (bsc#1154353).
- net: hns3: add trace event support for HNS3 driver
  (bsc#1154353).
- ice: Suppress Coverity warnings for xdp_rxq_info_reg
  (jsc#SLE-7926).
- ice: Add a boundary check in ice_xsk_umem() (jsc#SLE-7926).
- ice: add extra check for null Rx descriptor (jsc#SLE-7926).
- ice: suppress checked_return error (jsc#SLE-7926).
- ice: Demote MTU change print to debug (jsc#SLE-7926).
- ice: Enable ip link show on the PF to display VF unicast MAC(s)
  (jsc#SLE-7926).
- ice: Fix VF link state when it's IFLA_VF_LINK_STATE_AUTO
  (jsc#SLE-7926).
- ice: Remove Rx flex descriptor programming (jsc#SLE-7926).
- ice: Return error on not supported ethtool -C parameters
  (jsc#SLE-7926).
- ice: Restore interrupt throttle settings after VSI rebuild
  (jsc#SLE-7926).
- ice: Set default value for ITR in alloc function (jsc#SLE-7926).
- ice: Add ice_for_each_vf() macro (jsc#SLE-7926).
- ice: Add code to keep track of current dflt_vsi (jsc#SLE-7926).
- ice: Fix VF spoofchk (jsc#SLE-7926).
- ice: Support UDP segmentation offload (jsc#SLE-7926).
- sfc: Remove unnecessary dependencies on I2C (jsc#SLE-8314).
- mlxsw: spectrum_dcb: Allow setting default port priority
  (bsc#1154488).
- mlxsw: reg: Add QoS Port DSCP to Priority Mapping Register
  (bsc#1154488).
- page_pool: help compiler remove code in case CONFIG_NUMA=n
  (bsc#1154353).
- page_pool: handle page recycle for NUMA_NO_NODE condition
  (bsc#1154353).
- e1000e: Use netdev_info instead of pr_info for link messages
  (jsc#SLE-8100).
- igb: dont drop packets if rx flow control is enabled
  (jsc#SLE-7967 jsc#SLE-8010).
- sfc: avoid duplicate error handling code in
  'efx_ef10_sriov_set_vf_mac()' (jsc#SLE-8314).
- net: ena: remove set but not used variable 'rx_ring'
  (bsc#1154492).
- mlxsw: spectrum_router: Make route creation and destruction
  symmetric (bsc#1154488).
- mlxsw: spectrum_router: Eliminate dead code (bsc#1154488).
- mlxsw: spectrum_router: Remove unnecessary checks (bsc#1154488).
- net: hns3: only print misc interrupt status when handling fails
  (bsc#1154353).
- net: hns3: add a log for getting chain failure in
  hns3_nic_uninit_vector_data() (bsc#1154353).
- net: hns3: add some VF VLAN information for command "ip link
  show" (bsc#1154353).
- net: hns3: implement ndo_features_check ops for hns3 driver
  (bsc#1154353).
- net: hns3: get FD rules location before dump in debugfs
  (bsc#1154353).
- net: hns3: optimization for CMDQ uninitialization (bsc#1154353).
- net: hns3: remove useless mutex vport_cfg_mutex in the struct
  hclge_dev (bsc#1154353).
- net: hns3: check FE bit before calling hns3_add_frag()
  (bsc#1154353).
- mlxsw: spectrum: Rename MLXSW_REG_QEEC_HIERARCY_* enumerators
  (bsc#1154488).
- mlxsw: spectrum_qdisc: Clarify a comment (bsc#1154488).
- net: pkt_cls: Clarify a comment (bsc#1154353).
- sch_cake: drop unused variable tin_quantum_prio (bsc#1154353).
- cxgb4/chtls: fix ULD connection failures due to wrong TID base
  (jsc#SLE-8389).
- cxgb4: fix missed high priority region calculation
  (jsc#SLE-8389).
- net: hns3: do not schedule the periodic task when reset fail
  (bsc#1154353).
- net: hns3: allocate WQ with WQ_MEM_RECLAIM flag (bsc#1154353).
- net: hns3: remove unnecessary work in hclgevf_main
  (bsc#1154353).
- net: hns3: remove mailbox and reset work in hclge_main
  (bsc#1154353).
- net: hns3: schedule hclgevf_service by using delayed workqueue
  (bsc#1154353).
- tcp: Set rcv zerocopy hint correctly if skb last frag is <
  PAGE_SIZE (bsc#1154353).
- Revert "nfp: abm: fix memory leak in nfp_abm_u32_knode_replace"
  (bsc#1154353).
- net: ena: Add first_interrupt field to napi struct
  (bsc#1154492).
- net: ena: Implement XDP_TX action (bsc#1154492).
- net: ena: implement XDP drop support (bsc#1154492).
- rtnetlink: provide permanent hardware address in RTM_NEWLINK
  (bsc#1154353).
- cxgb4: add support for high priority filters (jsc#SLE-8389).
- nfp: add support for TLV device stats (bsc#1154353).
- tcp: Cleanup duplicate initialization of sk->sk_state
  (bsc#1154353).
- qed: remove redundant assignments to rc (jsc#SLE-8401).
- Documentation: nfp: add nfp driver specific notes (bsc#1154353).
- commit 00df886
* Tue Feb 18 2020 mbenes@suse.cz
- ftrace: Protect ftrace_graph_hash with ftrace_sync (git-fixes).
- commit 18b606e
* Tue Feb 18 2020 mbenes@suse.cz
- ftrace: Add comment to why rcu_dereference_sched() is open coded
  (git-fixes).
- commit 3920d17
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Annotate ftrace_graph_notrace_hash pointer with __rcu
  (git-fixes).
- commit dca30ea
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Annotate ftrace_graph_hash pointer with __rcu
  (git-fixes).
- commit 0478306
* Tue Feb 18 2020 jgross@suse.com
- xen/balloon: Support xend-based toolstack take two
  (bsc#1065600).
- commit 97502bd
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Fix sched switch start/stop refcount racy updates
  (git-fixes).
- commit cccfa7b
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Simplify assignment parsing for hist triggers
  (git-fixes).
- commit 4ec91e7
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Fix tracing_stat return values in error handling paths
  (git-fixes).
- commit f3d8551
* Tue Feb 18 2020 mbenes@suse.cz
- tracing: Fix very unlikely race of registering two stat tracers
  (git-fixes).
- commit f65b168
* Tue Feb 18 2020 mbrugger@suse.com
- serial: 8250_dw: Avoid double error messaging when IRQ absent
  (bsc#1164118).
- commit f336e59
* Tue Feb 18 2020 mbrugger@suse.com
- blacklist.conf: ignore duplicated commit ID
- commit 720d999
* Tue Feb 18 2020 mkoutny@suse.com
- powerpc: convert to copy_thread_tls (bsc#1163988).
- Update config files: Add CONFIG_HAVE_COPY_THREAD_TLS=y
- commit f351204
* Tue Feb 18 2020 petr.pavlu@suse.com
- cifs: fix mount option display for sec=krb5i (bsc#1161907).
- commit c56405f
* Tue Feb 18 2020 msuchanek@suse.de
- Delete patches.rpmify/powerpc-boot-Fix-missing-crc32poly.h-when-building-w.patch.
- commit 18a7f4d
* Tue Feb 18 2020 mbrugger@suse.com
- arm64: Revert support for execute-only user mappings
  (bsc#1160218).
- commit 373929f
* Tue Feb 18 2020 mkoutny@suse.com
- memcg: account security cred as well to kmemcg (bsc#1164094).
- commit 28f2006
* Tue Feb 18 2020 jack@suse.cz
- ext4: add cond_resched() to ext4_protect_reserved_inode
  (bsc#1164069 CVE-2020-8992).
- commit e44be93
* Tue Feb 18 2020 nborisov@suse.com
- btrfs: Fix split-brain handling when changing FSID to metadata
  uuid (git-fixes).
- btrfs: Handle another split brain scenario with metadata uuid
  feature (git-fixes).
- btrfs: Factor out metadata_uuid code from find_fsid (git-fixes).
- btrfs: Call find_fsid from find_fsid_inprogress (git-fixes).
- commit d6dd57b
* Tue Feb 18 2020 nborisov@suse.com
- btrfs: Correctly handle empty trees in find_first_clear_extent_bit (git-fixes).
- commit 35b5ead
* Tue Feb 18 2020 colyli@suse.de
- bcache: remove macro nr_to_fifo_front() (bsc#1163762).
- bcache: Revert "bcache: shrink btree node cache after
  bch_btree_check()" (bsc#1163762, bsc#1112504).
- bcache: ignore pending signals when creating gc and allocator
  thread (bsc#1163762, bsc#1112504).
- bcache: check return value of prio_read() (bsc#1163762).
- bcache: fix incorrect data type usage in btree_flush_write()
  (bsc#1163762).
- bcache: add readahead cache policy options via sysfs interface
  (bsc#1163762).
- bcache: explicity type cast in bset_bkey_last() (bsc#1163762).
- bcache: fix memory corruption in bch_cache_accounting_clear()
  (bsc#1163762).
- bcache: reap from tail of c->btree_cache in bch_mca_scan()
  (bsc#1163762).
- bcache: reap c->btree_cache_freeable from the tail in
  bch_mca_scan() (bsc#1163762).
- bcache: remove member accessed from struct btree (bsc#1163762).
- bcache: print written and keys in trace_bcache_btree_write
  (bsc#1163762).
- bcache: avoid unnecessary btree nodes flushing in
  btree_flush_write() (bsc#1163762).
- bcache: add code comments for state->pool in __btree_sort()
  (bsc#1163762).
- lib: crc64: include <linux/crc64.h> for 'crc64_be'
  (bsc#1163762).
- bcache: don't export symbols (bsc#1163762).
- bcache: remove the extra cflags for request.o (bsc#1163762).
- bcache: at least try to shrink 1 node in bch_mca_scan()
  (bsc#1163762).
- bcache: add idle_max_writeback_rate sysfs interface
  (bsc#1163762).
- bcache: add code comments in bch_btree_leaf_dirty()
  (bsc#1163762).
- bcache: fix deadlock in bcache_allocator (bsc#1163762).
- bcache: add code comment bch_keylist_pop() and
  bch_keylist_pop_front() (bsc#1163762).
- bcache: deleted code comments for dead code in
  bch_data_insert_keys() (bsc#1163762).
- bcache: add more accurate error messages in read_super()
  (bsc#1163762).
- bcache: fix static checker warning in bcache_device_free()
  (bsc#1163762).
- bcache: fix a lost wake-up problem caused by
  mca_cannibalize_lock (bsc#1163762).
- bcache: Fix an error code in bch_dump_read() (bsc#1163762).
- bcache: add cond_resched() in __bch_cache_cmp() (bsc#1163762).
- commit fdeab1e
* Mon Feb 17 2020 mkoutny@suse.com
- clone3: ensure copy_thread_tls is implemented (bsc#1163988).
- commit 480a977
* Mon Feb 17 2020 mkoutny@suse.com
- cgroup: Prevent double killing of css when enabling threaded
  cgroup (bsc#1153013).
- commit c46884c
* Mon Feb 17 2020 jack@suse.cz
- ext4: fix kernel oops caused by spurious casefold flag
  (bsc#1163984).
- commit 91a9b4c
* Mon Feb 17 2020 jack@suse.cz
- blacklist.conf: Blacklist 44d282796f81
- commit 13cd15a
* Mon Feb 17 2020 jack@suse.cz
- blacklist.conf: Blacklist 311ae9e159d8
- commit 72fb7d5
* Mon Feb 17 2020 msuchanek@suse.de
- Update
  patches.suse/powerpc-pseries-vio-Fix-iommu_table-use-after-free-r.patch
  (bsc#1065729 bsc#1163838 ltc#183850).
- commit 7b4b6e2
* Mon Feb 17 2020 lyan@suse.com
- KVM: s390: do not clobber registers during guest reset/store
  status (bsc#1133021).
- KVM: s390: ENOTSUPP -> EOPNOTSUPP fixups (bsc#1133021).
- commit 25937f8
* Mon Feb 17 2020 jack@suse.cz
- bdev: Refresh bdev size for disks without partitioning
  (bsc#1163921).
- commit 6da307d
* Mon Feb 17 2020 jack@suse.cz
- bdev: Factor out bdev revalidation into a common helper
  (bsc#1163920).
- commit 7d363e5
* Mon Feb 17 2020 jack@suse.cz
- udf: Allow writing to 'Rewritable' partitions (bsc#1163919).
- commit ae441d0
* Mon Feb 17 2020 jack@suse.cz
- blacklist.conf: Blacklist d9e9866803f7
- commit 53fef3b
* Mon Feb 17 2020 jack@suse.cz
- reiserfs: Fix memory leak of journal device string
  (bsc#1163867).
- commit 56254a8
* Mon Feb 17 2020 jack@suse.cz
- reiserfs: Fix spurious unlock in reiserfs_fill_super() error
  handling (bsc#1163869).
- commit f560b4f
* Mon Feb 17 2020 jack@suse.cz
- aio: prevent potential eventfd recursion on poll (bsc#1163918).
- commit d377261
* Mon Feb 17 2020 jack@suse.cz
- eventfd: track eventfd_signal() recursion depth (bsc#1163917).
- commit 29a8cc7
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fix memory leak from c->sup_node (bsc#1163916).
- commit fe0e8a1
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fix ino_t format warnings in orphan_delete()
  (bsc#1163915).
- commit 9d44fec
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fix deadlock in concurrent bulk-read and writepage
  (bsc#1163856).
- commit d4691a3
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fix wrong memory allocation (bsc#1163913).
- commit 08cc8d9
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fix FS_IOC_SETFLAGS unexpectedly clearing encrypt flag
  (bsc#1163855).
- commit 3341be7
* Mon Feb 17 2020 jack@suse.cz
- jbd2: make sure ESHUTDOWN to be recorded in the journal
  superblock (bsc#1163912).
- commit d51c1c8
* Mon Feb 17 2020 jack@suse.cz
- ext4, jbd2: ensure panic when aborting with zero errno
  (bsc#1163853).
- commit f604866
* Mon Feb 17 2020 jack@suse.cz
- jbd2: switch to use jbd2_journal_abort() when failed to submit
  the commit record (bsc#1163852).
- commit c3599a5
* Mon Feb 17 2020 jack@suse.cz
- jbd2_seq_info_next should increase position index (bsc#1163911).
- commit d64397e
* Mon Feb 17 2020 jack@suse.cz
- jbd2: clear JBD2_ABORT flag before journal_reset to update
  log tail info when load journal (bsc#1163910).
- commit 78b7063
* Mon Feb 17 2020 jack@suse.cz
- erofs: fix out-of-bound read for shifted uncompressed block
  (bsc#1163909).
- commit a97e621
* Mon Feb 17 2020 jack@suse.cz
- ubifs: don't trigger assertion on invalid no-key filename
  (bsc#1163850).
- commit 64c82f1
* Mon Feb 17 2020 jack@suse.cz
- readdir: be more conservative with directory entry names
  (bsc#1163907).
- commit 879663d
* Mon Feb 17 2020 jack@suse.cz
- locks: print unsigned ino in /proc/locks (bsc#1163905).
- blacklist.conf: blacklist e39e773ad100
- commit 611e661
* Mon Feb 17 2020 jack@suse.cz
- iomap: fix sub-page uptodate handling (bsc#1163904).
- commit f83b374
* Mon Feb 17 2020 jack@suse.cz
- ubifs: do_kill_orphans: Fix a memory leak bug (bsc#1163902).
- commit 37ace01
* Mon Feb 17 2020 jack@suse.cz
- ubifs: Fixed missed le64_to_cpu() in journal (bsc#1163901).
- commit cc34990
* Mon Feb 17 2020 jack@suse.cz
- fcntl: fix typo in RWH_WRITE_LIFE_NOT_SET r/w hint name
  (bsc#1163843).
- commit bc0e099
* Mon Feb 17 2020 jack@suse.cz
- ext4: improve explanation of a mount failure caused by a
  misconfigured kernel (bsc#1163843).
- commit 900aad6
* Mon Feb 17 2020 jack@suse.cz
- ext4: fix race conditions in ->d_compare() and ->d_hash()
  (bsc#1163899).
- commit cfc289b
* Mon Feb 17 2020 jack@suse.cz
- ext4: fix deadlock allocating crypto bounce page from mempool
  (bsc#1163898).
- commit 21b72aa
* Mon Feb 17 2020 jack@suse.cz
- ext4: validate the debug_want_extra_isize mount option at
  parse time (bsc#1163897).
- commit b0ee42b
* Mon Feb 17 2020 jack@suse.cz
- ext4: unlock on error in ext4_expand_extra_isize()
  (bsc#1163896).
- commit cd7a6d4
* Mon Feb 17 2020 jack@suse.cz
- block, bfq: do not plug I/O for bfq_queues with no proc refs
  (bsc#1163894).
- commit 3c9b27c
* Mon Feb 17 2020 jack@suse.cz
- block: fix splitting segments on boundary masks (bsc#1163893).
- commit 8b3de45
* Mon Feb 17 2020 jack@suse.cz
- compat_ioctl: block: handle BLKGETZONESZ/BLKGETNRZONES
  (bsc#1163892).
- commit c3d2ac2
* Mon Feb 17 2020 jack@suse.cz
- compat_ioctl: block: handle BLKREPORTZONE/BLKRESETZONE
  (bsc#1163891).
- commit bbed8ba
* Mon Feb 17 2020 jack@suse.cz
- jbd2: do not clear the BH_Mapped flag when forgetting a metadata
  buffer (bsc#1163836).
- commit 17af302
* Mon Feb 17 2020 jack@suse.cz
- jbd2: move the clearing of b_modified flag to the
  journal_unmap_buffer() (bsc#1163880).
- commit 2f2419e
* Mon Feb 17 2020 jack@suse.cz
- ext4: fix checksum errors with indexed dirs (bsc#1160979).
- commit b490dab
* Mon Feb 17 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/0001-crypto-sun4i-ss-fix-big-endian-issues.patch
  patches.suse/0001-perf-imx_ddr-Add-MODULE_DEVICE_TABLE.patch
- commit 9d8931e
* Mon Feb 17 2020 mkubecek@suse.cz
- blaklist.conf: improve comments
- "already gone in" is rather cryptic, change the d51224b73d18 entry to
  "duplicate of ac479b51f3f4"
- change the 1340cc631bd0 entry to "duplicate of d79749f7716d"
- commit 580e740
* Mon Feb 17 2020 msuchanek@suse.de
- powerpc/mmu_gather: enable RCU_TABLE_FREE even for !SMP case
  (bsc#1163776 ltc#183929).
- Refresh
  patches.suse/mm-mmu_gather-invalidate-TLB-correctly-on-batch-allo.patch.
- commit b99c448
* Mon Feb 17 2020 mkubecek@suse.cz
- fix patches metadata
- fix Patch-mainline:
  patches.suse/fmc-remove-left-over-ipmi-fru.h-after-fmc-deletion.patch
  patches.suse/mm-thp-don-t-need-care-deferred-split-queue-in-memcg-charge-move-path.patch
  patches.suse/mm-vmscan-protect-shrinker-idr-replace-with-CONFIG_MEMCG.patch
  patches.suse/ptr_ring-add-include-of-linux-mm.h.patch
  patches.suse/taskstats-fix-data-race.patch
- commit b311938
* Mon Feb 17 2020 oneukum@suse.com
- crypto: atmel - Fix build error of CRYPTO_AUTHENC (git-fixes).
- commit 96a9a36
* Mon Feb 17 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-lpfc-Fix-Fabric-hostname-registration-if-system.patch
  patches.suse/scsi-lpfc-Fix-MDS-Latency-Diagnostics-Err-drop-rates.patch
  patches.suse/scsi-lpfc-Fix-Rework-setting-of-fdmi-symbolic-node-n.patch
  patches.suse/scsi-lpfc-Fix-disablement-of-FC-AL-on-lpe35000-model.patch
  patches.suse/scsi-lpfc-Fix-improper-flag-check-for-IO-type.patch
  patches.suse/scsi-lpfc-Fix-missing-check-for-CSF-in-Write-Object-.patch
  patches.suse/scsi-lpfc-Fix-ras_log-via-debugfs.patch
  patches.suse/scsi-lpfc-Fix-unmap-of-dpp-bars-affecting-next-drive.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.6.0.3.patch
  No effect on expanded tree.
- commit b74bc8d
* Mon Feb 17 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/panfrost: Handle resetting on timeout better'
- commit c1cf6b0
* Mon Feb 17 2020 tzimmermann@suse.de
- drm/mipi_dbi: Fix off-by-one bugs in mipi_dbi_blank() (bsc#1152489)
- commit 5f73109
* Mon Feb 17 2020 mkubecek@suse.cz
- series.conf: cleanup
  Keep ACPI patches in one place.
  No effect on expanded tree.
- commit daba698
* Mon Feb 17 2020 tzimmermann@suse.de
- drm/etnaviv: fix dumping of iommuv2 (bsc#1152472)
- commit f714fd7
* Mon Feb 17 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/ehl: Define EHL powerwells independently of ICL'
- commit 2edb74e
* Mon Feb 17 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Copy across scheduler behaviour flags across submit fences'
- commit fe75061
* Mon Feb 17 2020 tiwai@suse.de
- hwmon: (pmbus/ltc2978) Fix PMBus polling of MFR_COMMON
  definitions (git-fixes).
- commit f1c1df9
* Mon Feb 17 2020 tiwai@suse.de
- drivers: ipmi: fix off-by-one bounds check that leads to a
  out-of-bounds write (git-fixes).
- commit 901290b
* Mon Feb 17 2020 jslaby@suse.cz
- vt: selection, close sel_buffer race (bnc#1162928
  CVE-2020-8648).
- vt: selection, handle pending signals in paste_selection
  (bnc#1162928 CVE-2020-8648).
- commit c7af915
* Mon Feb 17 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/drivers-ipmi-Modify-max-length-of-IPMB-packet.patch
  patches.suse/drivers-ipmi-Support-raw-i2c-packet-in-IPMB.patch
  No effect on expanded tree.
- commit cb3f6eb
* Mon Feb 17 2020 glin@suse.com
- bpf, sockmap: Don't sleep while holding RCU lock on tear-down
  (bsc#1155518).
- bpftool: Don't crash on missing xlated program instructions
  (bsc#1155518).
- samples: bpf: Allow for -ENETDOWN in xdpsock (bsc#1155518).
- bpf: Fix modifier skipping logic (bsc#1155518).
- commit c617a95
* Mon Feb 17 2020 firo.yang@suse.com
- enic: prevent waking up stopped tx queues over watchdog reset
  (bsc#1133147).
- commit b9b83d8
* Sat Feb 15 2020 mgorman@suse.de
- sched/fair: Take into account runnable_avg to classify group
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 60b875c
* Sat Feb 15 2020 mgorman@suse.de
- sched/pelt: Add a new runnable average signal (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit eb2bc08
* Sat Feb 15 2020 mgorman@suse.de
- sched/pelt: Remove unused runnable load average (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit 99634f9
* Sat Feb 15 2020 tiwai@suse.de
- mwifiex: Fix possible buffer overflows in
  mwifiex_cmd_append_vsie_tlv() (git-fixes).
- mwifiex: Fix possible buffer overflows in
  mwifiex_ret_wmm_get_status() (git-fixes).
- commit 0a55d21
* Sat Feb 15 2020 tiwai@suse.de
- mac80211: fix quiet mode activation in action frames
  (git-fixes).
- qmi_wwan: re-add DW5821e pre-production variant (git-fixes).
- drm/i915/gvt: more locking for ppgtt mm LRU list (git-fixes).
- Revert "drm/sun4i: drv: Allow framebuffer modifiers in mode
  config" (git-fixes).
- commit 8c7a45f
* Sat Feb 15 2020 tiwai@suse.de
- ALSA: usb-audio: Apply sample rate quirk for Audioengine D1
  (git-fixes).
- ALSA: usb-audio: Apply 48kHz fixed rate playback for Jabra
  Evolve 65 headset (git-fixes).
- commit 36550e5
* Sat Feb 15 2020 tiwai@suse.de
- ALSA: pcm: Fix double hw_free calls (git-fixes).
- ALSA: usb-audio: Add clock validity quirk for Denon
  MC7000/MCX8000 (git-fixes).
- ALSA: hda/realtek - Fix silent output on MSI-GL73 (git-fixes).
- ALSA: hda/realtek - Add more codec supported Headset Button
  (git-fixes).
- ALSA: usb-audio: Fix UAC2/3 effect unit parsing (git-fixes).
- ALSA: usb-audio: add quirks for Line6 Helix devices fw>=2.82
  (git-fixes).
- ALSA: usb-audio: add implicit fb quirk for MOTU M Series
  (git-fixes).
- ALSA: usb-audio: unlock on error in probe (git-fixes).
- ALSA: usb-audio: Add boot quirk for MOTU M Series (git-fixes).
- ALSA: usb-audio: Use lower hex numbers for IDs (git-fixes).
- commit 70d0fd1
* Fri Feb 14 2020 mgorman@suse.de
- sched/numa: Stop an exhastive search if a reasonable swap
  candidate or idle CPU is found (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- commit a207d84
* Fri Feb 14 2020 tiwai@suse.de
- Move ipmi_si fix to subsystem sorted section (bsc#1161943)
- commit 53fab48
* Fri Feb 14 2020 mgorman@suse.de
- sched/numa: Bias swapping tasks based on their preferred
  node (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/numa: Find an alternative idle CPU if the CPU is part of
  an active NUMA balance (bnc#1155798 (CPU scheduler functional
  and performance backports)).
- sched/numa: Prefer using an idle cpu as a migration target
  instead of comparing tasks (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/numa: Use similar logic to the load balancer for moving
  between domains with spare capacity (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/numa: replace runnable_load_avg by load_avg (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: reorder enqueue/dequeue_task_fair path (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/numa: Distinguish between the different task_numa_migrate
  failure cases (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/numa: Trace when no candidate CPU was found on the
  preferred node (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- mm: thp: don't need care deferred split queue in memcg charge
  move path (git fixes (mm/memcg)).
- fmc: remove left-over ipmi-fru.h after fmc deletion (git fixes
  (FRU removal)).
- ptr_ring: add include of linux/mm.h (git fixes (mm/includes)).
- taskstats: fix data-race (git fixes (taskstats)).
- mm: vmscan: protect shrinker idr replace with CONFIG_MEMCG
  (git fixes (mm/vmscan)).
- commit a00a8d0
* Fri Feb 14 2020 mgorman@suse.de
- Refresh patches.suse/sched-fair-Optimize-select_idle_core.patch.
- commit 59efedb
* Thu Feb 13 2020 tiwai@suse.de
- Update config files: enable CONFIG_FW_CFG_SYSFS for arm64 (bsc#1163521)
- commit 3795961
* Thu Feb 13 2020 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Allow-a-small-load-imbalance-between-low-utilisation-SD_NUMA-domains.patch.
- commit d461156
* Wed Feb 12 2020 jdelvare@suse.de
- ACPI / watchdog: Set default timeout in probe (bsc#1162557).
- ACPI: watchdog: Allow disabling WDAT at boot (bsc#1162557).
- commit 54f65f7
* Wed Feb 12 2020 mcgrof@suse.com
- patches.suse/simple_recursive_removal-kernel-side-rm-rf-for-ramfs.patch: (bsc#1159198,CVE-2019-19770).
- commit ae16628
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: use first valid target residency as poll time
  (jsc#SLE-11312).
- commit 4e4e473
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: haltpoll: Take 'idle=' override into account
  (jsc#SLE-11312).
- commit b7ea903
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: Enable kvm guest polling when dedicated
  physical CPUs are available (jsc#SLE-11312).
- commit c957ec1
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: do not set an owner to allow modunload
  (jsc#SLE-11312).
- commit dc19dcc
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: return -ENODEV on modinit failure
  (jsc#SLE-11312).
- commit 5f4abc5
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: set haltpoll as preferred governor
  (jsc#SLE-11312).
- commit f056412
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: allow governor switch on cpuidle_register_driver()
  (jsc#SLE-11312).
- commit a8f3113
* Wed Feb 12 2020 hare@suse.de
- scsi: lpfc: Update lpfc version to 12.6.0.4
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Clean up hba max_lun_queue_depth checks
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Remove handler for obsolete ELS - Read Port
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix coverity errors in fmdi attribute handling
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix compiler warning on frame size
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix release of hwq to clear the eq relationship
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix registration of ELS type support in fdmi
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix broken Credit Recovery after driver load
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix lpfc_io_buf resource leak in
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix RQ buffer leakage when no IOCBs available
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.6.0.3
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix improper flag check for IO type
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix MDS Latency Diagnostics Err-drop rates
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix unmap of dpp bars affecting next driver load
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix disablement of FC-AL on lpe35000 models
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix ras_log via debugfs (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix Fabric hostname registration if system
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix missing check for CSF in Write Object Mbox
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix: Rework setting of fdmi symbolic node name
  registration (bsc#1156632,jsc#SLE-8654).
- commit ad7b473
* Wed Feb 12 2020 tiwai@suse.de
- tools/kvm_stat: Fix kvm_exit filter name (git-fixes).
- tools lib: Fix builds when glibc contains strlcpy() (git-fixes).
- tools/power/acpi: fix compilation error (git-fixes).
- sh_eth: check sh_eth_cpu_data::dual_port when dumping registers
  (git-fixes).
- commit a1660a4
* Wed Feb 12 2020 tiwai@suse.de
- enetc: Don't print from enetc_sched_speed_set when link goes
  down (git-fixes).
- PM / devfreq: Add new name attribute for sysfs (git-fixes).
- PM / devfreq: Don't fail devfreq_dev_release if not in list
  (git-fixes).
- PM / devfreq: Set scaling_max_freq to max on OPP notifier error
  (git-fixes).
- PM / devfreq: Fix devfreq_notifier_call returning errno
  (git-fixes).
- commit 280c62f
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: vcpu hotplug support (jsc#SLE-11312).
- commit be83569
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: header file stubs must be "static inline"
  (jsc#SLE-11312).
- commit 72c5ab4
* Wed Feb 12 2020 tiwai@suse.de
- blacklist.conf: Add already cherry-picked i915 commits
- commit e79e886
* Wed Feb 12 2020 trenn@suse.com
- cpuidle-haltpoll: disable host side polling when kvm virtualized
  (jsc#SLE-11312).
- Update config files.
- commit 7a92459
* Wed Feb 12 2020 tiwai@suse.de
- alarmtimer: Unregister wakeup source when module get fails
  (git-fixes).
- afs: Fix characters allowed into cell names (git-fixes).
- afs: Fix afs_lookup() to not clobber the version on a new dentry
  (git-fixes).
- afs: Fix use-after-loss-of-ref (git-fixes).
- atm: eni: fix uninitialized variable warning (git-fixes).
- staging: axis-fifo: add unspecified HAS_IOMEM dependency
  (git-fixes).
- afs: Fix missing cell comparison in afs_test_super()
  (git-fixes).
- afs: Fix creation calls in the dynamic root to fail with
  EOPNOTSUPP (git-fixes).
- afs: Fix mountpoint parsing (git-fixes).
- afs: Fix SELinux setting security label on /afs (git-fixes).
- afs: Fix afs_find_server lookups for ipv4 peers (git-fixes).
- afs: Remove set but not used variables 'before', 'after'
  (git-fixes).
- affs: fix a memory leak in affs_remount (git-fixes).
- afs: Fix large file support (git-fixes).
- afs: Fix possible assert with callbacks from yfs servers
  (git-fixes).
- afs: Fix missing timeout reset (git-fixes).
- commit 70f7941
* Wed Feb 12 2020 fdmanana@suse.com
- Btrfs: make deduplication with range including the last block
  work (bsc#1163496).
- commit 177be09
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: add haltpoll governor (jsc#SLE-11312).
- Update config files.
- commit 3395a31
* Wed Feb 12 2020 fdmanana@suse.com
- fs: allow deduplication of eof block into the end of the
  destination file (bsc#1163496).
- commit a6f621e
* Wed Feb 12 2020 fdmanana@suse.com
- Btrfs: send, fix emission of invalid clone operations within
  the same file (bsc#1163493).
- commit e5b1bf0
* Wed Feb 12 2020 trenn@suse.com
- governors: unify last_state_idx (jsc#SLE-11312).
- Refresh
  patches.suse/cpuidle-teo-Allow-tick-to-be-stopped-if-PM-QoS-is-us.patch.
- Refresh
  patches.suse/cpuidle-teo-Avoid-using-early-hits-incorrectly.patch.
- commit 5219109
* Wed Feb 12 2020 trenn@suse.com
- cpuidle: add poll_limit_ns to cpuidle_device structure
  (jsc#SLE-11312).
- commit 39e79ea
* Wed Feb 12 2020 fdmanana@suse.com
- Btrfs: fix race between adding and putting tree mod seq elements
  and nodes (bsc#1163384).
- commit 20ba722
* Wed Feb 12 2020 fdmanana@suse.com
- Btrfs: fix infinite loop during fsync after rename operations
  (bsc#1163383).
- commit d4b4993
* Wed Feb 12 2020 fdmanana@suse.com
- Btrfs: fix missing hole after hole punching and fsync when
  using NO_HOLES (bsc#1158749).
- commit 1e49dd1
* Wed Feb 12 2020 trenn@suse.com
- add cpuidle-haltpoll driver (jsc#SLE-11312).
- Update config files.
- supported.conf: add cpuidle-haltpoll as supported
  supported.conf:
  Add newly introduced cpuidle-haltpoll driver
- commit ba1edb5
* Wed Feb 12 2020 mkubecek@suse.cz
- drop obsolete btrfs patches inherited from SLE15-SP1
- drop
  patches.suse/btrfs-prevent-ioctls-from-interfering-with-a-swap-file.patch
    (mainline commit eede2bf34f4f, v5.0-rc1)
  patches.suse/btrfs-rename-and-export-get_chunk_map.patch
    (mainline commit 60ca842e3457, v5.0-rc1)
  patches.suse/btrfs-support-swap-files.patch
    (mainline commit ed46ff3d4237, v5.0-rc1)
- commit 7f19d4b
* Wed Feb 12 2020 tiwai@suse.de
- ASoC: sgtl5000: Fix VDDA and VDDIO comparison (git-fixes).
- commit 75f282a
* Wed Feb 12 2020 tiwai@suse.de
- crypto: ccree - fix pm wrongful error reporting (git-fixes).
- Refresh patches.suse/crypto-ccree-fix-PM-race-condition.patch.
- commit dbcb926
* Wed Feb 12 2020 tiwai@suse.de
- iwlwifi: don't throw error when trying to remove IGTK
  (git-fixes).
- ARM: tegra: Enable PLLP bypass during Tegra124 LP1 (git-fixes).
- drm/amd/dm/mst: Ignore payload update failures (git-fixes).
- clk: tegra: Mark fuse clock as critical (git-fixes).
- mfd: dln2: More sanity checking for endpoints (git-fixes).
- media: rc: ensure lirc is initialized before registering input
  device (git-fixes).
- media: v4l2-core: compat: ignore native command codes
  (git-fixes).
- PM: core: Fix handling of devices deleted during system-wide
  resume (git-fixes).
- media/v4l2-core: set pages dirty upon releasing DMA buffers
  (git-fixes).
- power: supply: ltc2941-battery-gauge: fix use-after-free
  (git-fixes).
- usb: gadget: legacy: set max_speed to super-speed (git-fixes).
- crypto: ccree - fix FDE descriptor sequence (git-fixes).
- crypto: ccree - fix backlog memory leak (git-fixes).
- ACPI: video: Do not export a non working backlight interface
  on MSI MS-7721 boards (git-fixes).
- regulator fix for "regulator: core: Add regulator_is_equal()
  helper" (git-fixes).
- regulator: core: Add regulator_is_equal() helper (git-fixes).
- platform/x86: intel_scu_ipc: Fix interrupt support (git-fixes).
- mmc: spi: Toggle SPI polarity, do not hardcode it (git-fixes).
- mmc: sdhci-pci: Make function amd_sdhci_reset static
  (git-fixes).
- commit 798d10c
* Wed Feb 12 2020 mkubecek@suse.cz
- fix mainline references
- fix Patch-mainline:
  patches.suse/apparmor-Switch-to-GFP_KERNEL-where-possible.patch
  patches.suse/apparmor-Use-a-memory-pool-instead-per-CPU-caches.patch
  patches.suse/apparmor-fix-aa_xattrs_match-may-sleep-while-holding-a-RCU-lock.patch
  patches.suse/apparmor-fix-bind-mounts-aborting-with-ENOMEM.patch
  patches.suse/apparmor-fix-wrong-buffer-allocation-in-aa_new_mount.patch
  patches.suse/apparmor-increase-left-match-history-buffer-size.patch
  patches.suse/apparmor-make-it-so-work-buffers-can-be-allocated-from-atomic-context.patch
  patches.suse/apparmor-only-get-a-label-reference-if-the-fast-path-check-fails.patch
  patches.suse/apparmor-reduce-rcu_read_lock-scope-for-aa_file_perm-mediation.patch
- commit 04ce0c4
* Wed Feb 12 2020 mkubecek@suse.cz
- update patch metadata
- update Git-commit after (likely) maintainer tree rebase:
  patches.suse/scsi-tcm_qla2xxx-Make-qlt_alloc_qfull_cmd-set-cmd-se.patch
- commit 1747315
* Tue Feb 11 2020 dbueso@suse.de
- ipc/msg.c: consolidate all xxxctl_down() functions
  (bsc#1159886).
- ipc/sem.c: document and update memory barriers (bsc#1159886).
- ipc/msg.c: update and document memory barriers (bsc#1159886).
- ipc/mqueue.c: update/document memory barriers (bsc#1159886).
- ipc/mqueue.c: remove duplicated code (bsc#1159886).
- locking/osq: Use optimized spinning loop for arm64
  (bsc#1149032).
- cgroup: Optimize single thread migration (bsc#1163388).
- cgroup/cpuset: Convert cpuset_mutex to percpu_rwsem
  (bsc#1163388).
- commit 95157e6
* Tue Feb 11 2020 tiwai@suse.de
- vfio/spapr/nvlink2: Skip unpinning pages on error exit
  (git-fixes).
- commit 97b7cca
* Tue Feb 11 2020 tiwai@suse.de
- smp_mb__{before,after}_atomic(): update Documentation
  (git-fixes).
- tomoyo: Use atomic_t for statistics counter (git-fixes).
- irqdomain: Fix a memory leak in irq_domain_push_irq()
  (git-fixes).
- commit ab7e36c
* Tue Feb 11 2020 tiwai@suse.de
- irqchip/gic-v3-its: Reference to its_invall_cmd descriptor
  when building INVALL (git-fixes).
- hrtimer: Annotate lockless access to timer->state (git-fixes).
- commit 18567f5
* Tue Feb 11 2020 tiwai@suse.de
- dma-mapping: fix handling of dma-ranges for reserved memory
  (again) (git-fixes).
- commit 854b530
* Tue Feb 11 2020 tiwai@suse.de
- kconfig: fix broken dependency in randconfig-generated .config
  (git-fixes).
- clocksource: Prevent double add_timer_on() for watchdog_timer
  (git-fixes).
- iwlwifi: mvm: avoid use after free for pmsr request (git-fixes).
- drop_monitor: Do not cancel uninitialized work item (git-fixes).
- soc: qcom: rpmhpd: Set 'active_only' for active only power
  domains (git-fixes).
- soc/tegra: fuse: Correct straps' address for older Tegra124
  device trees (git-fixes).
- bus: tegra-aconnect: Remove PM_CLK dependency (git-fixes).
- ARM: at91: pm: use of_device_id array to find the proper shdwc
  node (git-fixes).
- ARM: at91: pm: use SAM9X60 PMC's compatible (git-fixes).
- ARM: dma-api: fix max_pfn off-by-one error in __dma_supported()
  (git-fixes).
- commit 80930f7
* Mon Feb 10 2020 msuchanek@suse.de
- powerpc/kuap: Fix set direction in allow/prevent_user_access()
  (bsc#1156395).
- powerpc/32s: Fix bad_kuap_fault() (bsc#1156395).
- commit ecc6175
* Mon Feb 10 2020 tiwai@suse.de
- ipmi_si: Avoid spurious errors for optional IRQs (bsc#1161943).
- commit 807bbff
* Mon Feb 10 2020 tiwai@suse.de
- media: go7007: Fix URB type for interrupt handling
  (bsc#1162583).
- commit 658c146
* Mon Feb 10 2020 msuchanek@suse.de
- powerpc/futex: Fix incorrect user access blocking (bsc#1156395).
- powerpc/ptdump: Only enable PPC_CHECK_WX with STRICT_KERNEL_RWX
  (bsc#1156395).
- powerpc/ptdump: Fix W+X verification (bsc#1156395).
- powerpc: Define arch_is_kernel_initmem_freed() for lockdep
  (bsc#1156395).
- powerpc/ptdump: get out of note_prot_wx() when
  CONFIG_PPC_DEBUG_WX is not selected (bsc#1156395).
- commit f8eff5c
* Mon Feb 10 2020 mhocko@suse.com
- mm/sparse.c: reset section's mem_map when fully deactivated
  (bnc#1162503).
- commit f068a8c
* Mon Feb 10 2020 msuchanek@suse.de
- powerpc/papr_scm: Fix leaking 'bus_desc.provider_name' in some
  paths (FATE#327775 bsc#1142685 ltc#179509).
- commit 1c49eb1
* Mon Feb 10 2020 mgorman@suse.de
- apparmor: fix aa_xattrs_match() may sleep while holding a RCU
  lock (bnc#1158765).
- apparmor: only get a label reference if the fast path check
  fails (bnc#1158765).
- apparmor: fix bind mounts aborting with -ENOMEM (bnc#1158765).
- apparmor: make it so work buffers can be allocated from atomic
  context (bnc#1158765).
- apparmor: reduce rcu_read_lock scope for aa_file_perm mediation
  (bnc#1158765).
- apparmor: fix wrong buffer allocation in aa_new_mount
  (bnc#1158765).
- apparmor: increase left match history buffer size (bnc#1158765).
- apparmor: Switch to GFP_KERNEL where possible (bnc#1158765).
- apparmor: Use a memory pool instead per-CPU caches
  (bnc#1158765).
- commit db8094b
* Mon Feb 10 2020 tiwai@suse.de
- Move upstreamed wireless fixes into sorted section
  Refreshed:
  patches.suse/libertas-dont-exit-from-lbs_ibss_join_existing-with.patch
  patches.suse/libertas-make-lbs_ibss_join_existing-return-error.patch
  patches.suse/mwifiex-fix-unbalanced-locking-in-mwifiex_process_co.patch
- commit 8dbbd1d
* Mon Feb 10 2020 msuchanek@suse.de
- powerpc/pseries/vio: Fix iommu_table use-after-free refcount
  warning (bsc#1065729).
- powerpc/pseries: Advance pfn if section is not present in
  lmb_is_removable() (bsc#1065729).
- powerpc/pseries: Allow not having ibm,
  hypertas-functions::hcall-multi-tce for DDW (bsc#1065729).
- powerpc/pseries/hotplug-memory: Change rc variable to bool
  (bsc#1065729).
- commit fe5c033
* Mon Feb 10 2020 mkubecek@suse.cz
- tomoyo: Don't use nifty names on sockets (git-fixes).
  Bring the patch again as bsc#1162590 turned out to be bogus.
- commit e6918af
* Mon Feb 10 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-qla2xxx-Fix-unbound-NVME-response-length.patch
- commit f9847d8
* Sat Feb  8 2020 tiwai@suse.de
- drm/amd/display: Retrain dongles when SINK_COUNT becomes
  non-zero (git-fixes).
- clk: qcom: rcg2: Don't crash if our parent can't be found;
  return an error (git-fixes).
- clk: qcom: Don't overwrite 'cfg' in clk_rcg2_dfs_populate_freq()
  (git-fixes).
- watchdog: fix UAF in reboot notifier handling in watchdog core
  code (git-fixes).
- drivers: watchdog: stm32_iwdg: set WDOG_HW_RUNNING at probe
  (git-fixes).
- virtio_balloon: Fix memory leaks on errors in
  virtballoon_probe() (git-fixes).
- virtio-balloon: Fix memory leak when unloading while hinting
  is in progress (git-fixes).
- virtio-pci: check name when counting MSI-X vectors (git-fixes).
- virtio-balloon: initialize all vq callbacks (git-fixes).
- commit 56decc0
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic/x2apic: Implement IPI shorthands support (bsc#1162702).
- commit af57cfd
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic/flat64: Remove the IPI shorthand decision logic (bsc#1162702).
- commit 309c2e1
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Share common IPI helpers (bsc#1162702).
- commit e29e384
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Remove the shorthand decision logic (bsc#1162702).
- commit b931a9c
* Fri Feb  7 2020 dwagner@suse.de
- x86/smp: Enhance native_send_call_func_ipi() (bsc#1162702).
- commit f0857f7
* Fri Feb  7 2020 dwagner@suse.de
- x86/smp: Move smp_function_call implementations into IPI code (bsc#1162702).
- commit 10bcbc5
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Provide and use helper for send_IPI_allbutself() (bsc#1162702).
- commit ee9e660
* Fri Feb  7 2020 mbenes@suse.cz
- livepatch/samples/selftest: Use klp_shadow_alloc() API correctly
  (bsc#1071995).
- commit 00eed06
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Add static key to Control IPI shorthands (bsc#1162702).
- commit 6d35b8a
* Fri Feb  7 2020 mbenes@suse.cz
- livepatch/selftest: Clean up shadow variable names and type
  (bsc#1071995).
- commit e95b82b
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Move no_ipi_broadcast() out of 32bit (bsc#1162702).
- commit 9c72d3f
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Add NMI_VECTOR wait to IPI shorthand (bsc#1162702).
- commit 11f617e
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Remove dest argument from __default_send_IPI_shortcut() (bsc#1162702).
- commit 6e1b483
* Fri Feb  7 2020 dwagner@suse.de
- x86/hotplug: Silence APIC and NMI when CPU is dead (bsc#1162702).
- commit c8f6f01
* Fri Feb  7 2020 dwagner@suse.de
- x86/cpu: Move arch_smt_update() to a neutral place (bsc#1162702).
- Refresh patches.suse/x86-speculation-taa-Add-mitigation-for-TSX-Async-Abo.patch.
- Refresh patches.suse/x86-speculation-taa-Fix-printing-of-TAA_MSG_SMT-on-I.patch.
- commit 1c4fec9
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic/uv: Make x2apic_extra_bits static (bsc#1162702).
- Refresh patches.suse/x86-platform-uv-Add-UV-Hubbed-Hubless-Proc-FS-Files.patch.
- Refresh patches.suse/x86-platform-uv-Return-UV-Hubless-System-Type.patch.
- commit c91a792
* Fri Feb  7 2020 nborisov@suse.com
- btrfs: drop log root for dropped roots (bsc#1166772).
- btrfs: do not delete mismatched root refs (bsc#1166772).
- btrfs: fix invalid removal of root ref (bsc#1166772).
- btrfs: rework arguments of btrfs_unlink_subvol (bsc#1166772).
- btrfs: do not leak reloc root if we fail to read the fs root (bsc#1166772).
- commit 9f44227
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Consolidate the apic local headers (bsc#1162702).
- commit c920fec
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Move apic_flat_64 header into apic directory (bsc#1162702).
- commit 73a08d5
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Move ipi header into apic directory (bsc#1162702).
- commit 06589f2
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Cleanup the include maze (bsc#1162702).
- Refresh patches.suse/x86-platform-uv-Check-EFI-Boot-to-set-reboot-type.patch.
- Refresh patches.suse/x86-platform-uv-Return-UV-Hubless-System-Type.patch.
- Refresh patches.suse/x86-platform-uv-Save-OEM_ID-from-ACPI-MADT-probe.patch.
- commit 327f5f6
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Move IPI inlines into ipi.c (bsc#1162702).
- commit 81a4d6d
* Fri Feb  7 2020 dwagner@suse.de
- x86/apic: Invoke perf_events_lapic_init() after enabling APIC (bsc#1162702).
- Refresh patches.suse/x86-apic-32-Avoid-bogus-LDR-warnings.patch.
- commit b5224ec
* Fri Feb  7 2020 tiwai@suse.de
- uaccess: disallow > INT_MAX copy sizes (git-fixes).
- commit 59e5f9a
* Fri Feb  7 2020 tiwai@suse.de
- thermal: brcmstb_thermal: Do not use DT coefficients
  (git-fixes).
- soc: ti: wkup_m3_ipc: Fix race condition with rproc_boot
  (git-fixes).
- serdev: Don't claim unsupported ACPI serial devices (git-fixes).
- commit ea25f56
* Fri Feb  7 2020 tiwai@suse.de
- rtc: cmos: Stop using shared IRQ (git-fixes).
- rtc: hym8563: Return -EINVAL if the time is known to be invalid
  (git-fixes).
- commit 15ca52d
* Fri Feb  7 2020 tiwai@suse.de
- pxa168fb: Fix the function used to release some memory in an
  error handling path (git-fixes).
- qmi_wwan: Add support for Quectel RM500Q (git-fixes).
- commit b92716e
* Fri Feb  7 2020 tiwai@suse.de
- power: supply: core: Update sysfs-class-power ABI document
  (git-fixes).
- power: supply: sbs-battery: Fix a signedness bug in
  sbs_get_battery_capacity() (git-fixes).
- power: supply: axp20x_ac_power: Fix reporting online status
  (git-fixes).
- power/supply: ingenic-battery: Don't change scale if there's
  only one (git-fixes).
- commit cfd3f61
* Fri Feb  7 2020 tiwai@suse.de
- blacklist.conf: Add already cherry-picked platform drivers
- commit 57ff8bd
* Fri Feb  7 2020 tiwai@suse.de
- mtd: sharpslpart: Fix unsigned comparison to zero (git-fixes).
- mtd: onenand_base: Adjust indentation in onenand_read_ops_nolock
  (git-fixes).
- net: phy: dp83867: Set FORCE_LINK_GOOD to default after reset
  (git-fixes).
- commit 9763e59
* Fri Feb  7 2020 tiwai@suse.de
- mfd: rn5t618: Mark ADC control register volatile (git-fixes).
- mfd: da9062: Fix watchdog compatible string (git-fixes).
- mfd: max77650: Select REGMAP_IRQ in Kconfig (git-fixes).
- mfd: axp20x: Mark AXP20X_VBUS_IPSOUT_MGMT as volatile
  (git-fixes).
- mfd: bd70528: Fix hour register mask (git-fixes).
- leds: pca963x: Fix open-drain initialization (git-fixes).
- lib/scatterlist.c: adjust indentation in __sg_alloc_table
  (git-fixes).
- ide: remove set but not used variable 'hwif' (git-fixes).
- ima: ima/lsm policy rule loading logic bug fixes (git-fixes).
- hwmon: (pmbus/ibm-cffps) Fix LED blink behavior (git-fixes).
- commit e4dc7c5
* Fri Feb  7 2020 tiwai@suse.de
- fbdev: fix numbering of fbcon options (git-fixes).
- habanalabs: remove variable 'val' set but not used (git-fixes).
- habanalabs: rate limit error msg on waiting for CS (git-fixes).
- habanalabs: skip VA block list update in reset flow (git-fixes).
- commit afb5fba
* Fri Feb  7 2020 tiwai@suse.de
- clk: qcom: Add missing msm8998 gcc_bimc_gfx_clk (git-fixes).
- clk: qcom: smd: Add missing bimc clock (git-fixes).
- clk: ti: dra7: fix parent for gmac_clkctrl (git-fixes).
- clk: sunxi-ng: add mux and pll notifiers for A64 CPU clock
  (git-fixes).
- clk: meson: meson8b: make the CCF use the glitch-free mali mux
  (git-fixes).
- clk: meson: pll: Fix by 0 division in __pll_params_to_rate()
  (git-fixes).
- clk: meson: g12a: fix missing uart2 in regmap table (git-fixes).
- clk: renesas: rcar-gen3: Allow changing the RPC[D2] clocks
  (git-fixes).
- clk: imx: imx8mq: fix sys3_pll_out_sels (git-fixes).
- commit edbbc8e
* Fri Feb  7 2020 tiwai@suse.de
- Bluetooth: hci_bcm: Drive RTS only for BCM43438 (git-fixes).
- Bluetooth: hci_bcm: Add device-tree compatible for BCM4329
  (git-fixes).
- Bluetooth: hci_bcm: Disallow set_baudrate for BCM4354
  (git-fixes).
- Bluetooth: btbcm: Add entry for BCM4335A0 UART bluetooth
  (git-fixes).
- Bluetooth: hci_bcm: Add compatible string for BCM43540
  (git-fixes).
- commit f42c6a9
* Fri Feb  7 2020 dwagner@suse.de
- cpumask: Implement cpumask_or_equal() (bsc#1162702).
- commit a130302
* Fri Feb  7 2020 jeyu@suse.de
- Refresh and re-enable
  patches.suse/0005-modsign-print-module-name-along-with-error-message.patch.
- commit e9c76fb
* Fri Feb  7 2020 tiwai@suse.de
- clk: at91: sam9x60: fix programmable clock prescaler
  (git-fixes).
- clk: uniphier: Add SCSSI clock gate for each channel
  (git-fixes).
- clk: actually call the clock init before any other callback
  of the clock (git-fixes).
- media: vp7045: do not read uninitialized values if usb transfer
  fails (git-fixes).
- media: af9005: uninitialized variable printked (git-fixes).
- media: digitv: don't continue if remote control state can't
  be read (git-fixes).
- media: dvb-usb/dvb-usb-urb.c: initialize actlen to 0
  (git-fixes).
- media: gspca: zero usb_buf (git-fixes).
- Bluetooth: Fix race condition in hci_release_sock() (git-fixes).
- r8152: disable DelayPhyPwrChg (git-fixes).
- r8152: avoid the MCU to clear the lanwake (git-fixes).
- r8152: disable test IO for RTL8153B (git-fixes).
- r8152: get default setting of WOL before initializing
  (git-fixes).
- Input: max77650-onkey - add of_match table (git-fixes).
- Input: evdev - convert kzalloc()/vzalloc() to kvzalloc()
  (git-fixes).
- led: max77650: add of_match table (git-fixes).
- wireless: wext: avoid gcc -O3 warning (git-fixes).
- mac80211: Fix TKIP replay protection immediately after key setup
  (git-fixes).
- cfg80211: Fix radar event during another phy CAC (git-fixes).
- wireless: fix enabling channel 12 for custom regulatory domain
  (git-fixes).
- mac80211: mesh: restrict airtime metric to peered established
  plinks (git-fixes).
- clk: mmp2: Fix the order of timer mux parents (git-fixes).
- clk: sunxi-ng: h6-r: Fix AR100/R_APB2 parent order (git-fixes).
- clk: sunxi-ng: sun8i-r: Fix divider on APB0 clock (git-fixes).
- platform/x86: intel_pmc_core: update Comet Lake platform driver
  (git-fixes).
- platform/x86: GPD pocket fan: Allow somewhat lower/higher
  temperature limits (git-fixes).
- commit eff0f28
* Thu Feb  6 2020 tiwai@suse.de
- ALSA: hda: Clear RIRB status before reading WP (git-fixes).
- ALSA: hda/realtek - Fixed one of HP ALC671 platform Headset
  Mic supported (git-fixes).
- ASoC: SOF: trace: fix unconditional free in trace release
  (git-fixes).
- ALSA: hda - Fix DP-MST support for NVIDIA codecs (git-fixes).
- ALSA: dummy: Fix PCM format loop in proc output (git-fixes).
- ALSA: usb-audio: Annotate endianess in Scarlett gen2 quirk
  (git-fixes).
- ALSA: usb-audio: Fix endianess in descriptor validation
  (git-fixes).
- ALSA: hda: Add JasperLake PCI ID and codec vid (git-fixes).
- ALSA: pcm: Fix memory leak at closing a stream without hw_free
  (git-fixes).
- ALSA: hda: Reset stream if DMA RUN bit not cleared (git-fixes).
- ASoC: Intel: Skylake: Explicitly include linux/io.h for
  virt_to_phys() (git-fixes).
- commit 90e1eab
* Thu Feb  6 2020 chrubis@suse.cz
- rpm/kernel-binary.spec.in: Replace Novell with SUSE
- commit 8719d69
* Thu Feb  6 2020 ykaukab@suse.de
- kabi: arm64: reserve space in cpu_hwcaps and cpu_hwcap_keys
  arrays (bsc#1089086).
  Enable and refresh cpu_hwcaps kabi reservation patch.
- commit a2cfe97
* Thu Feb  6 2020 nborisov@suse.com
- btrfs: don't double lock the subvol_sem for rename exchange (bsc#1162943).
- commit 6492de6
* Thu Feb  6 2020 oneukum@suse.com
- blacklist.conf: different IDs in stable and mainline
- commit a8a637a
* Thu Feb  6 2020 wqu@suse.com
- Update
  patches.suse/btrfs-qgroups-fix-rescan-worker-running-races.patch
  (bsc#1091101, bsc#1156919).
  Since the problem is still here and not solved, re-enable it and rebase
  the code.
- commit 5647b0a
* Wed Feb  5 2020 tiwai@suse.de
- pwm: Remove set but not set variable 'pwm' (git-fixes).
- pwm: omap-dmtimer: put_device() after of_find_device_by_node()
  (git-fixes).
- pwm: omap-dmtimer: Simplify error handling (git-fixes).
- pwm: omap-dmtimer: Remove PWM chip in .remove before making
  it unfunctional (git-fixes).
- commit f1507d7
* Wed Feb  5 2020 msuchanek@suse.de
- Refresh patches.suse/powerpc-drmem-avoid-NULL-pointer-dereference-when-dr.patch.
- commit 3c1c79f
* Wed Feb  5 2020 tiwai@suse.de
- PCI: Add DMA alias quirk for Intel VCA NTB (git-fixes).
- Refresh
  patches.suse/0001-PCI-Vulcan-AHCI-PCI-bar-fix-for-Broadcom-Vulcan-earl.patch.
- commit 55d6c4b
* Wed Feb  5 2020 tiwai@suse.de
- mei: me: add comet point (lake) H device ids (git-fixes).
- mei: hdcp: bind only with i915 on the same PCH (git-fixes).
- staging: most: net: fix buffer overflow (git-fixes).
- staging: vt6656: Fix false Tx excessive retries reporting
  (git-fixes).
- staging: vt6656: use NULLFUCTION stack on mac80211 (git-fixes).
- staging: vt6656: correct packet types for CTS protect, mode
  (git-fixes).
- serial: imx: fix a race condition in receive path (git-fixes).
- usb: dwc3: pci: add ID for the Intel Comet Lake -V variant
  (git-fixes).
- ARM: 8955/1: virt: Relax arch timer version check during early
  boot (git-fixes).
- phy: cpcap-usb: Prevent USB line glitches from waking up modem
  (git-fixes).
- phy: qcom-qmp: Increase PHY ready timeout (git-fixes).
- usb: musb: jz4740: Silence error if code is -EPROBE_DEFER
  (git-fixes).
- drm/amd/display: Reduce HDMI pixel encoding if max clock is
  exceeded (git-fixes).
- gpio: max77620: Add missing dependency on GPIOLIB_IRQCHIP
  (git-fixes).
- HID: steam: Fix input device disappearing (git-fixes).
- HID: intel-ish-hid: ipc: Add Tiger Lake PCI device ID
  (git-fixes).
- drivers/hid/hid-multitouch.c: fix a possible null pointer access
  (git-fixes).
- HID: wacom: Recognize new MobileStudio Pro PID (git-fixes).
- HID: intel-ish-hid: ipc: add CMP device id (git-fixes).
- HID: Add quirk for incorrect input length on Lenovo Y720
  (git-fixes).
- HID: asus: Ignore Asus vendor-page usage-code 0xff events
  (git-fixes).
- HID: ite: Add USB id match for Acer SW5-012 keyboard dock
  (git-fixes).
- HID: Add quirk for Xin-Mo Dual Controller (git-fixes).
- HID: multitouch: Add LG MELF0410 I2C touchscreen support
  (git-fixes).
- watchdog: rn5t618_wdt: fix module aliases (git-fixes).
- watchdog: max77620_wdt: fix potential build errors (git-fixes).
- spi: spi-dw: Add lock protect dw_spi rx/tx to prevent concurrent
  calls (git-fixes).
- platform/x86: dell-laptop: disable kbd backlight on Inspiron
  10xx (git-fixes).
- staging: mt7621-pci: add quirks for 'E2' revision using
  'soc_device_attribute' (git-fixes).
- extcon-intel-cht-wc: Don't reset USB data connection at probe
  (git-fixes).
- usb-storage: Disable UAS on JMicron SATA enclosure (git-fixes).
- mmc: sdhci-pci: Add support for Intel JSL (git-fixes).
- mmc: sdhci-pci: Quirk for AMD SDHC Device 0x7906 (git-fixes).
- ASoC: Intel: cht_bsw_rt5645: Add quirk for boards using
  pmc_plt_clk_0 (git-fixes).
- ARM: OMAP2+: SmartReflex: add omap_sr_pdata definition
  (git-fixes).
- Bluetooth: btbcm: Use the BDADDR_PROPERTY quirk (git-fixes).
- Bluetooth: Allow combination of BDADDR_PROPERTY and
  INVALID_BDADDR quirks (git-fixes).
- HID: wacom: add new MobileStudio Pro 13 support (git-fixes).
- commit 2f59d11
* Wed Feb  5 2020 lhenriques@suse.com
- ceph: fix compat_ioctl for ceph_dir_operations (jsc#SES-1134).
- compat_ioctl: add compat_ptr_ioctl() (jsc#SES-1134).
- commit e540507
* Wed Feb  5 2020 oneukum@suse.com
- crypto: sun4i-ss - fix big endian issues (git-fixes).
- commit 0bfb337
* Wed Feb  5 2020 oneukum@suse.com
- blacklist.conf: not needed in our config
- commit a23b2d7
* Wed Feb  5 2020 oneukum@suse.com
- blacklist.conf: upstream has a wrong Fixes
- commit 3b66050
* Wed Feb  5 2020 oneukum@suse.com
- perf/imx_ddr: Add MODULE_DEVICE_TABLE (git-fixes).
- commit f0f1d6b
* Wed Feb  5 2020 dwagner@suse.de
- bitmap.h: fix kernel-doc warning and typo (bsc#1162702).
- commit be235a4
* Wed Feb  5 2020 oneukum@suse.com
- blacklist.conf: duplication
- commit 0224176
* Wed Feb  5 2020 oneukum@suse.com
- iwlwifi: fw: make pos static in iwl_sar_get_ewrd_table() loop
  (git-fixes).
- commit fa51eb6
* Wed Feb  5 2020 oneukum@suse.com
- iwlwifi: mvm: don't send the IWL_MVM_RXQ_NSSN_SYNC notif to
  Rx queues (git-fixes).
- commit 861212e
* Wed Feb  5 2020 jroedel@suse.de
- iommu/vt-d: Refactor find_domain() helper (bsc#1159594).
- commit e9b12d5
* Wed Feb  5 2020 oneukum@suse.com
- blacklist.conf: only cosmetics
- commit 1870278
* Wed Feb  5 2020 oneukum@suse.com
- blacklist.conf: patch is wrong, later reverted
- commit ed8aa8a
* Wed Feb  5 2020 bp@suse.de
- x86/resctrl: Fix a deadlock due to inaccurate reference
  (bsc#1152489).
- x86/resctrl: Fix use-after-free due to inaccurate refcount of
  rdtgroup (bsc#1152489).
- x86/resctrl: Fix use-after-free when deleting resource groups
  (bsc#1152489).
- commit 1107939
* Wed Feb  5 2020 ykaukab@suse.de
- coresight: etm4x: Fix unused function warning (jsc#SLE-9326).
- coresight: replicator: Fix missing spin_lock_init()
  (jsc#SLE-9326).
- coresight: funnel: Fix missing spin_lock_init() (jsc#SLE-9326).
- coresight: etm4x: Fix BMVAL misuse (jsc#SLE-9326).
- coresight: Add explicit architecture dependency (jsc#SLE-9326).
- coresight: etm4x: Add missing single-shot control API to sysfs
  (jsc#SLE-9326).
- coresight: etm4x: Add view comparator settings API to sysfs
  (jsc#SLE-9326).
- coresight: etm4x: Improve usability of sysfs - CID and VMID
  masks (jsc#SLE-9326).
- coresight: etm4x: Improve usability of sysfs - include/exclude
  addr (jsc#SLE-9326).
- coresight: etm4x: Fix issues with start-stop logic
  (jsc#SLE-9326).
- coresight: etm4x: Add missing API to set EL match on address
  filters (jsc#SLE-9326).
- coresight: etm4x: Fixes for ETM v4.4 architecture updates
  (jsc#SLE-9326).
- coresight: etm4x: Add support for ThunderX2 (jsc#SLE-9326).
- coresight: etm4x: Save/restore state across CPU low power states
  (jsc#SLE-9326).
- coresight: tmc-etr: Add barrier packets when moving offset
  forward (jsc#SLE-9326).
- coresight: tmc-etr: Decouple buffer sync and barrier packet
  insertion (jsc#SLE-9326).
- coresight: tmc: Make memory width mask computation into a
  function (jsc#SLE-9326).
- coresight: tmc-etr: Fix updating buffer in not-snapshot mode
  (jsc#SLE-9326).
- coresight: etm4x: improve clarity of etm4_os_unlock comment
  (jsc#SLE-9326).
- coresight: etm4x: use module_param instead of module_param_named
  (jsc#SLE-9326).
- coresight: etm4x: Remove superfluous setting of os_unlock
  (jsc#SLE-9326).
- coresight: acpi: Static funnel support (jsc#SLE-9326).
- coresight: Convert pr_warn to dev_warn for obsolete bindings
  (jsc#SLE-9326).
- coresight: tmc-etr: Check if non-secure access is enabled
  (jsc#SLE-9326).
- coresight: tmc-etr: Handle memory errors (jsc#SLE-9326).
- coresight: etr_buf: Consolidate refcount initialization
  (jsc#SLE-9326).
- coresight: cpu-debug: Add support for Qualcomm Kryo
  (jsc#SLE-9326).
- coresight: etm4x: Add ETM PIDs for SDM845 and MSM8996
  (jsc#SLE-9326).
- coresight: etm4x: Two function calls less (jsc#SLE-9326).
- commit 42abd9d
* Wed Feb  5 2020 mkubecek@suse.cz
- config: refresh
- drop no longer available option
- commit df9bfb1
* Wed Feb  5 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/mm-mmu_gather-invalidate-TLB-correctly-on-batch-allo.patch
- commit 11779f3
* Wed Feb  5 2020 mkubecek@suse.cz
- update patch metadata
- update Git-commit (maintainer repository rebased?):
  patches.suse/scsi-qla2xxx-Fix-unbound-NVME-response-length.patch
- commit 6a6f7db
* Wed Feb  5 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/powerpc-mm-Remove-kvm-radix-prefetch-workaround-for-.patch
  patches.suse/powerpc-papr_scm-Don-t-enable-direct-map-for-a-regio.patch
  patches.suse/powerpc-pseries-lparcfg-Fix-display-of-Maximum-Memor.patch
  patches.suse/powerpc-xmon-don-t-access-ASDR-in-VMs.patch
- commit b278cb1
* Wed Feb  5 2020 mkubecek@suse.cz
- fix patch metadata
- fix Patch-mainline:
  patches.suse/vfs-fix-do_last-regression.patch
- commit d2a495c
* Wed Feb  5 2020 glin@suse.com
- libbpf: Add missing newline in opts validation macro
  (bsc#1155518).
- libbpf: Fix printf compilation warnings on ppc64le arch
  (bsc#1155518).
- commit 413fb24
* Tue Feb  4 2020 msuchanek@suse.de
- powerpc: Do not consider weak unresolved symbol relocations
  as bad (bsc#1148868).
- powerpc: Provide initial documentation for PAPR hcalls
  (bsc#1156395).
- gen_initramfs_list.sh: fix 'bad variable name' error
  (bsc#1148868).
- mkcompile_h: use printf for LINUX_COMPILE_BY (bsc#1148868).
- mkcompile_h: git rid of UTS_TRUNCATE from
  LINUX_COMPILE_{BY,HOST} (bsc#1148868).
- scripts/setlocalversion: clear local variable to make it work
  for sh (bsc#1148868).
- kbuild: add $(BASH) to run scripts with bash-extension
  (bsc#1148868).
- commit 200c822
* Tue Feb  4 2020 dwagner@suse.de
- jbd2: Free journal head outside of locked region (bsc#1162702).
- jbd2: Make state lock a spinlock (bsc#1162702).
- jbd2: Don't call __bforget() unnecessarily (bsc#1162702).
- jbd2: Drop unnecessary branch from jbd2_journal_forget()
  (bsc#1162702).
- jbd2: Move dropping of jh reference out of un/re-filing
  functions (bsc#1162702).
- jbd2: Remove jbd_trylock_bh_state() (bsc#1162702).
- jbd2: Simplify journal_unmap_buffer() (bsc#1162702).
- commit 64d9c8c
* Tue Feb  4 2020 jroedel@suse.de
- KVM: SVM: Override default MMIO mask if memory encryption is
  enabled (bsc#1162684).
- commit 6f8451a
* Tue Feb  4 2020 bp@suse.de
- x86/fpu: Deactivate FPU state after failure during state load
  (bsc#1152489).
- commit fb7702a
* Tue Feb  4 2020 bp@suse.de
- x86/resctrl: Check monitoring static key in the MBM overflow
  handler (bsc#1152489).
- commit 8f4ba2c
* Tue Feb  4 2020 tiwai@suse.de
- Delete patches.suse/tomoyo-Don-t-use-nifty-names-on-sockets.patch (bsc#1162590)
  We've hit mysterious regression and the git bisection points this one.
  As this is no serious fix backport, let's try to revert it at first.
- commit 0ecd623
* Tue Feb  4 2020 ghe@suse.com
- ocfs2: fix oops when writing cloned file (bsc#1160831).
- commit dd0a42c
* Tue Feb  4 2020 nsaenzjulienne@suse.de
- dma-contiguous: CMA: give precedence to cmdline (bsc#1160609).
- commit d7a3b9d
* Tue Feb  4 2020 msuchanek@suse.de
- mm/mmu_gather: invalidate TLB correctly on batch allocation
  failure and flush (bsc#1055186).
- commit c9dade1
* Tue Feb  4 2020 duwe@suse.de
- rpm/modules.fips: add keywrap (bsc#1160561)
- commit 68cc4b8
* Tue Feb  4 2020 lhenriques@suse.com
- ceph: hold extra reference to r_parent over life of request
  (jsc#SES-1134).
- ceph: add more debug info when decoding mdsmap (jsc#SES-1134).
- ceph: switch to global cap helper (jsc#SES-1134).
- ceph: trigger the reclaim work once there has enough pending
  caps (jsc#SES-1134).
- ceph: show tasks waiting on caps in debugfs caps file
  (jsc#SES-1134).
- ceph: convert int fields in ceph_mount_options to unsigned int
  (jsc#SES-1134).
- commit 5bcfbba
* Tue Feb  4 2020 bp@suse.de
- blacklist.conf: 6cd18453b689 EDAC/sifive: Fix return value check in ecc_register()
- commit 267e9ae
* Tue Feb  4 2020 lhenriques@suse.com
- libceph, rbd, ceph: convert to use the new mount API
  (jsc#SES-1134).
- Refresh
  patches.suse/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit dd179b3
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: ask for a weaker incompat mask for read-only mappings
  (jsc#SES-1134).
- commit 1660de5
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: don't query snapshot features (jsc#SES-1134).
- Refresh
  patches.suse/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit 578ddcb
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: remove snapshot existence validation code (jsc#SES-1134).
- Refresh
  patches.suse/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit 15f7151
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: don't establish watch for read-only mappings
  (jsc#SES-1134).
- rbd: don't acquire exclusive lock for read-only mappings
  (jsc#SES-1134).
- rbd: disallow read-write partitions on images mapped read-only
  (jsc#SES-1134).
- rbd: treat images mapped read-only seriously (jsc#SES-1134).
- commit 3b44169
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: introduce RBD_DEV_FLAG_READONLY (jsc#SES-1134).
- Refresh
  patches.suse/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit 8848484
* Tue Feb  4 2020 lhenriques@suse.com
- rbd: introduce rbd_is_snap() (jsc#SES-1134).
- ceph: don't leave ino field in ceph_mds_request_head
  uninitialized (jsc#SES-1134).
- ceph: tone down loglevel on ceph_mdsc_build_path warning
  (jsc#SES-1134).
- ceph: fix geting random mds from mdsmap (jsc#SES-1134).
- rbd: fix spelling mistake "requeueing" -> "requeuing"
  (jsc#SES-1134).
- ceph: make several helper accessors take const pointers
  (jsc#SES-1134).
- libceph: drop unnecessary check from dispatch() in mon_client.c
  (jsc#SES-1134).
- commit ea0e3ab
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86/intel_pstate: Handle runtime turbo disablement/enablement
  in frequency invariance (bsc#1155798).
- commit d2ecce1
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86, sched: Add support for frequency invariance on ATOM
  (bsc#1155798).
- commit 5a622ef
* Tue Feb  4 2020 lpechacek@suse.cz
- net: aquantia: add an error handling in
  aq_nic_set_multicast_list (jsc#SLE-10218).
- commit d467792
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86, sched: Add support for frequency invariance on
  ATOM_GOLDMONT* (bsc#1155798).
- commit 6550e7c
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86, sched: Add support for frequency invariance on
  XEON_PHI_KNL/KNM (bsc#1155798).
- commit 708e8cb
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86, sched: Add support for frequency invariance on SKYLAKE_X
  (bsc#1155798).
- commit 0ae5deb
* Tue Feb  4 2020 ggherdovich@suse.cz
- x86, sched: Add support for frequency invariance (bsc#1155798).
- commit 54365d2
* Mon Feb  3 2020 dwagner@suse.de
- scsi: qla2xxx: Fix unbound NVME response length (bsc#1157966
  bsc#1158013 bsc#1157424).
- scsi: tcm_qla2xxx: Make qlt_alloc_qfull_cmd() set
  cmd->se_cmd.map_tag (bsc#1157966 bsc#1158013 bsc#1157424).
- scsi: qla2xxx: Fix a NULL pointer dereference in an error path
  (bsc#1157966 bsc#1158013 bsc#1157424).
- commit 586fcc6
* Mon Feb  3 2020 rgoldwyn@suse.com
- vfs: fix do_last() regression  (bsc#1162109,CVE-2020-8428).
- Update
  patches.suse/do_last-fetch-directory--i_mode-and--i_uid-before-its-too-late.patch
  (bsc#1162109,CVE-2020-8428).
- commit 7adeb03
* Mon Feb  3 2020 msuchanek@suse.de
- KVM: PPC: Book3S PR: Fix -Werror=return-type build failure
  (bsc#1061840).
- KVM: PPC: Book3S PR: Free shared page if mmu initialization
  fails (bsc#1061840).
- KVM: PPC: Book3S HV: Uninit vCPU if vcore creation fails
  (bsc#1061840).
- commit 45012b1
* Mon Feb  3 2020 tzimmermann@suse.de
- Update "drm/amdkfd: fix a potential NULL pointer dereference (v2)"
  We have a bug report and a CVE for this patch. Point references tag there.
- commit db7a4f2
* Mon Feb  3 2020 mbenes@suse.cz
- tracing/kprobes: Have uname use __get_str() in print_fmt
  (git-fixes).
- commit 1cc7e66
* Mon Feb  3 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/0001-x86-kvm-Be-careful-not-to-clear-KVM_VCPU_FLUSH_TLB-b.patch
  patches.suse/0002-x86-kvm-Introduce-kvm_-un-map_gfn.patch
  patches.suse/0003-x86-kvm-Cache-gfn-to-pfn-translation.patch
  patches.suse/0004-x86-KVM-Make-sure-KVM_VCPU_FLUSH_TLB-flag-is-not-mis.patch
  patches.suse/0005-x86-KVM-Clean-up-host-s-steal-time-structure.patch
- commit 488b94c
* Mon Feb  3 2020 mkubecek@suse.cz
- patch whitespace cleanup
- delete whitespace on line separating rfc2822 header and body:
  patches.suse/ocfs2-make-local-header-paths-relative-to-C-files.patch
- commit bbd1cb9
* Sun Feb  2 2020 ghe@suse.com
- ocfs2: make local header paths relative to C files
  (bsc#1159889).
- commit fafd040
* Sat Feb  1 2020 tiwai@suse.de
- PCI: tegra: Fix afi_pex2_ctrl reg offset for Tegra30
  (git-fixes).
- PCI: tegra: Fix return value check of pm_runtime_get_sync()
  (git-fixes).
- PCI: keystone: Fix error handling when "num-viewport" DT
  property is not populated (git-fixes).
- PCI: keystone: Fix outbound region mapping (git-fixes).
- PCI: keystone: Fix link training retries initiation (git-fixes).
- PCI/IOV: Fix memory leak in pci_iov_add_virtfn() (git-fixes).
- PCI/switchtec: Fix vep_vector_number ioread width (git-fixes).
- PCI/switchtec: Use dma_set_mask_and_coherent() (git-fixes).
- PCI: Don't disable bridge BARs when assigning bus resources
  (git-fixes).
- PCI/AER: Initialize aer_fifo (git-fixes).
- media: uvcvideo: Avoid cyclic entity chains due to malformed
  USB descriptors (git-fixes).
- media: iguanair: fix endpoint sanity check (git-fixes).
- media: v4l2-rect.h: fix v4l2_rect_map_inside() top/left
  adjustments (git-fixes).
- media: ov5640: Fix check for PLL1 exceeding max allowed rate
  (git-fixes).
- media: imx7-mipi-csis: remove subdev_notifier (git-fixes).
- media: meson: add missing allocation failure check on new_buf
  (git-fixes).
- media: i2c: adv748x: Fix unsafe macros (git-fixes).
- commit 0778c54
* Sat Feb  1 2020 mbrugger@suse.com
- EDAC/mc: Fix use-after-free and memleaks during device removal
  (jsc#SLE-9482).
- Refresh
  patches.suse/EDAC-mc-Reorder-functions-edac_mc_alloc.patch.
- commit 7999d28
* Fri Jan 31 2020 duwe@suse.de
- Refresh and reenable patches.suse/prepare-arm64-kgraft.
- Delete patches.suse/pstore-backend-autoaction.
  (see commit 62c0377bb94742def)
- commit 2e37144
* Fri Jan 31 2020 hare@suse.de
- s390/dasd: disable ese support due to possible data corruption
  (bsc#1161428).
- commit daa742e
* Fri Jan 31 2020 jroedel@suse.de
- iommu/amd: Fix IOMMU perf counter clobbering during init
  (bsc#1162393).
- iommu/vt-d: Call __dmar_remove_one_dev_info with valid pointer
  (bsc#1159594).
- commit 3146a75
* Fri Jan 31 2020 tiwai@suse.de
- airo: Add missing CAP_NET_ADMIN check in
  AIROOLDIOCTL/SIOCDEVPRIVATE (git-fixes).
- airo: Fix possible info leak in AIROOLDIOCTL/SIOCDEVPRIVATE
  (git-fixes).
- commit 21afd27
* Fri Jan 31 2020 tiwai@suse.de
- crypto: vmx - Avoid weird build failures (git-fixes).
- commit 5668910
* Fri Jan 31 2020 tiwai@suse.de
- drm/vmwgfx: prevent memory leak in vmw_cmdbuf_res_add
  (git-fixes).
- drm: msm: mdp4: Adjust indentation in mdp4_dsi_encoder_enable
  (git-fixes).
- drm/msm/adreno: fix zap vs no-zap handling (git-fixes).
- drm/nouveau: Fix copy-paste error in
  nouveau_fence_wait_uevent_handler (git-fixes).
- drm/nouveau/secboot/gm20b: initialize pointer in
  gm20b_secboot_new() (git-fixes).
- drm/mediatek: Add gamma property according to hardware
  capability (git-fixes).
- drm: atmel-hlcdc: prefer a lower pixel-clock than requested
  (git-fixes).
- drm: atmel-hlcdc: enable clock before configuring timing engine
  (git-fixes).
- drm: atmel-hlcdc: use double rate for pixel clock only if
  supported (git-fixes).
- drm: bridge: dw-hdmi: constify copied structure (git-fixes).
- drm/rockchip: lvds: Fix indentation of a #define (git-fixes).
- drm/amdkfd: remove set but not used variable 'top_dev'
  (git-fixes).
- drm/amd/powerplay: remove set but not used variable 'us_mvdd'
  (git-fixes).
- drm/amdgpu: remove set but not used variable 'invalid'
  (git-fixes).
- drm/amdgpu: remove set but not used variable 'count'
  (git-fixes).
- drm/amdgpu: remove set but not used variable 'amdgpu_connector'
  (git-fixes).
- drm/amdgpu: remove set but not used variable 'mc_shared_chmap'
  from 'gfx_v6_0.c' and 'gfx_v7_0.c' (git-fixes).
- drm/amdgpu: remove set but not used variable 'mc_shared_chmap'
  (git-fixes).
- drm/amdgpu: remove always false comparison in
  'amdgpu_atombios_i2c_process_i2c_ch' (git-fixes).
- drm/amdgpu: remove set but not used variable 'dig' (git-fixes).
- drm/amdgpu: remove set but not used variable 'dig_connector'
  (git-fixes).
- drm/amdgpu: add function parameter description in
  'amdgpu_gart_bind' (git-fixes).
- drm/amdgpu: add function parameter description in
  'amdgpu_device_set_cg_state' (git-fixes).
- drm/amdgpu: remove 4 set but not used variable in
  amdgpu_atombios_get_connector_info_from_object_table
  (git-fixes).
- drm/panel: simple: Add Logic PD Type 28 display support
  (git-fixes).
- drm/qxl: Complete exception handling in qxl_device_init()
  (git-fixes).
- drm/rect: update kerneldoc for drm_rect_clip_scaled()
  (git-fixes).
- drm/rect: Avoid division by zero (git-fixes).
- drm/fourcc: Fill out all block sizes for P210 (git-fixes).
- drm/fourcc: Fill out all block sizes for P10/12/16 (git-fixes).
- drm/ttm: ttm_tt_init_fields() can be static (git-fixes).
- commit 93987eb
* Fri Jan 31 2020 tiwai@suse.de
- PM: hibernate: fix crashes with init_on_free=1 (git-fixes).
- commit 748603f
* Fri Jan 31 2020 tiwai@suse.de
- Add the already cherry-picked id to pinctrl fix patch
- commit fdc0f64
* Fri Jan 31 2020 jroedel@suse.de
- x86/KVM: Clean up host's steal time structure (bsc#1161154,
  CVE-2019-3016).
- x86/KVM: Make sure KVM_VCPU_FLUSH_TLB flag is not missed
  (bsc#1161154, CVE-2019-3016).
- x86/kvm: Cache gfn to pfn translation (bsc#1161154,
  CVE-2019-3016).
- x86/kvm: Introduce kvm_(un)map_gfn() (bsc#1161154,
  CVE-2019-3016).
- x86/kvm: Be careful not to clear KVM_VCPU_FLUSH_TLB bit
  (bsc#1161154, CVE-2019-3016).
- commit b5111ca
* Fri Jan 31 2020 mkubecek@suse.cz
- supported.conf: mark ufshcd_core and ufshcd_pltfrm as supported (bsc#1158776)
  kernel-source commit ba2a8909aec7 marked modules ufs_hisi, ufs_medatek and
  ufs_qcom as supported (with reference to comment 14 here); these depend on
  ufshcd_core and ufshcd_pltfrm which are unsupported so that IBS build
  (aarch64/default) now fails one of the late checks.
  Mark ufshcd_core and ufshcd_pltfrm as supported to avoid unfulfilled
  dependencies in arm64 kernel-default.
- commit e66a364
* Fri Jan 31 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and resort:
  patches.suse/scsi-qla2xxx-Add-D-Port-Diagnostic-reason-explanatio.patch
  patches.suse/scsi-qla2xxx-Add-a-shadow-variable-to-hold-disc_stat.patch
  patches.suse/scsi-qla2xxx-Cleanup-unused-async_logout_done.patch
  patches.suse/scsi-qla2xxx-Consolidate-fabric-scan.patch
  patches.suse/scsi-qla2xxx-Correct-fcport-flags-handling.patch
  patches.suse/scsi-qla2xxx-Fix-RIDA-Format-2.patch
  patches.suse/scsi-qla2xxx-Fix-fabric-scan-hang.patch
  patches.suse/scsi-qla2xxx-Fix-mtcp-dump-collection-failure.patch
  patches.suse/scsi-qla2xxx-Fix-stuck-login-session-using-prli_pend.patch
  patches.suse/scsi-qla2xxx-Fix-stuck-session-in-GNL.patch
  patches.suse/scsi-qla2xxx-Fix-the-endianness-of-the-qla82xx_get_f.patch
  patches.suse/scsi-qla2xxx-Fix-update_fcport-for-current_topology.patch
  patches.suse/scsi-qla2xxx-Improve-readability-of-the-code-that-ha.patch
  patches.suse/scsi-qla2xxx-Remove-defer-flag-to-indicate-immeadiat.patch
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.22-k.patch
  patches.suse/scsi-qla2xxx-Use-common-routine-to-free-fcport-struc.patch
  patches.suse/scsi-qla2xxx-Use-get_unaligned_-instead-of-open-codi.patch
  No effect on expanded tree.
- commit 35cf494
* Thu Jan 30 2020 mbenes@suse.cz
- s390/ftrace: generate traced function stack frame
  (jsc#SLE-11050).
- commit 8abd203
* Thu Jan 30 2020 tiwai@suse.de
- scripts/find-unused-docs: Fix massive false positives
  (git-fixes).
- selftests: settings: tests can be in subsubdirs (git-fixes).
- visorbus: fix uninitialized variable access (git-fixes).
- debugfs: Return -EPERM when locked down (git-fixes).
- driver core: Fix test_async_driver_probe if NUMA is disabled
  (git-fixes).
- component: do not dereference opaque pointer in debugfs
  (git-fixes).
- iio: adc: stm32-dfsdm: fix single conversion (git-fixes).
- iio: st_gyro: Correct data for LSM9DS0 gyro (git-fixes).
- staging: wlan-ng: ensure error return is actually returned
  (git-fixes).
- serial: 8250_bcm2835aux: Fix line mismatch on driver unbind
  (git-fixes).
- USB: serial: ir-usb: fix IrLAP framing (git-fixes).
- USB: serial: ir-usb: fix link-speed handling (git-fixes).
- USB: serial: ir-usb: add missing endpoint sanity check
  (git-fixes).
- usb: typec: wcove: fix "op-sink-microwatt" default that was
  in mW (git-fixes).
- usb: typec: tcpci: mask event interrupts when remove driver
  (git-fixes).
- usb: host: xhci-tegra: set MODULE_FIRMWARE for tegra186
  (git-fixes).
- phy: qualcomm: Adjust indentation in read_poll_timeout
  (git-fixes).
- usb: gadget: f_ecm: Use atomic_t to track in-flight request
  (git-fixes).
- usb: gadget: f_ncm: Use atomic_t to track in-flight request
  (git-fixes).
- usb: dwc3: gadget: Delay starting transfer (git-fixes).
- usb: dwc3: gadget: Check END_TRANSFER completion (git-fixes).
- usb: dwc3: turn off VBUS when leaving host mode (git-fixes).
- usb: gadget: f_fs: set req->num_sgs as 0 for non-sg transfer
  (git-fixes).
- pinctrl: sh-pfc: r8a7778: Fix duplicate SDSELF_B and SD1_CLK_B
  (git-fixes).
- pinctrl: sh-pfc: r8a77965: Fix DU_DOTCLKIN3 drive/bias control
  (git-fixes).
- gpiolib: Set lockdep class for hierarchical irq domains
  (git-fixes).
- commit 28a738b
* Wed Jan 29 2020 rgoldwyn@suse.com
- do_last(): fetch directory ->i_mode and ->i_uid before it's
  too late  (bsc#1152109,CVE-2020-8428).
- commit 6a0a735
* Wed Jan 29 2020 bp@suse.de
- crypto: ccp - Verify access to device registers before
  initializing (bsc#1161073).
- crypto: ccp - Change a message to reflect status instead of
  failure (bsc#1161073).
- commit 9d00d4d
* Wed Jan 29 2020 tiwai@suse.de
- firestream: fix memory leaks (git-fixes).
- net: usb: lan78xx: Add .ndo_features_check (git-fixes).
- PCI: Mark AMD Navi14 GPU rev 0xc5 ATS as broken (git-fixes).
- hwmon: (adt7475) Make volt2reg return same reg as reg2volt input
  (git-fixes).
- media: v4l2-ioctl.c: zero reserved fields for S/TRY_FMT
  (git-fixes).
- commit 0f48df8
* Wed Jan 29 2020 mbrugger@suse.com
- EDAC/mc: Remove per layer counters (jsc#SLE-9482).
- EDAC/mc: Remove detail[] string and cleanup error string
  generation (jsc#SLE-9482).
- EDAC/mc: Pass the error descriptor to error reporting functions
  (jsc#SLE-9482).
- EDAC/mc: Remove enable_per_layer_report function arguments
  (jsc#SLE-9482).
- EDAC/mc: Report "unknown memory" on too many DIMM labels found
  (jsc#SLE-9482).
- EDAC/mc: Create new function edac_inc_csrow() (jsc#SLE-9482).
- EDAC/mc: Determine mci pointer from the error descriptor
  (jsc#SLE-9482).
- EDAC: Store error type in struct edac_raw_error_desc
  (jsc#SLE-9482).
- EDAC/mc: Reorder functions edac_mc_alloc*() (jsc#SLE-9482).
- EDAC/mc: Split edac_mc_alloc() into smaller functions
  (jsc#SLE-9482).
- commit d500698
* Wed Jan 29 2020 vbabka@suse.cz
- mm/hmm: hmm_range_fault() infinite loop (HMM Functionality,
  jsc#SLE-8176).
- commit f666122
* Wed Jan 29 2020 vbabka@suse.cz
- mm/hmm: hmm_range_fault() NULL pointer bug (HMM Functionality,
  jsc#SLE-8176).
- commit 27fd79f
* Wed Jan 29 2020 tiwai@suse.de
- Fix applying via rapidquilt again
  Refresh
  patches.suse/sched-topology-Assert-non-NUMA-topology-masks-don-t-partially-overlap.patch.
  A patch in a patch description is confusing.
- commit 82f83e9
* Wed Jan 29 2020 mkubecek@suse.cz
- update upstream references
- update Patch-mainline:
  patches.suse/sched-Use-fair-prio_changed-instead-of-ad-hoc-implementation.patch
  patches.suse/sched-core-Remove-unused-variable-from-set_user_nice.patch
  patches.suse/sched-fair-Define-sched_idle_cpu-only-for-SMP-configurations.patch
  patches.suse/sched-fair-Fix-sgc-min-max-_capacity-calculation-for-SD_OVERLAP.patch
  patches.suse/sched-topology-Assert-non-NUMA-topology-masks-don-t-partially-overlap.patch
  patches.suse/sched-wait-fix-___wait_var_event-exclusive.patch
  patches.suse/schied-fair-Skip-calculating-contrib-without-load.patch
- commit 1c0fc31
* Wed Jan 29 2020 ptesarik@suse.cz
- config: enable CONFIG_DRM_ETNAVIV on arm64 (jsc#SLE-9263).
- supported.conf: mark etnaviv as supported (jsc#SLE-9263).
- commit ff1abc4
* Wed Jan 29 2020 ptesarik@suse.cz
- supported.conf: Support lima and panfrost (jsc#SLE-8203).
- commit aa64aa2
* Wed Jan 29 2020 msuchanek@suse.de
- powerpc/mm: Remove kvm radix prefetch workaround for Power9
  DD2.2 (bsc#1061840).
- commit 8d2d7a2
* Wed Jan 29 2020 nsaenzjulienne@suse.de
- mmc: host: sdhci-pci: Add Genesys Logic GL975x support
  (bsc#1144168).
- Update config files
- mmc: sdhci: Export sdhci_abort_tuning function symbol
  (bsc#1144168).
- PCI: Add Genesys Logic, Inc. Vendor ID (bsc#1144168).
- mmc: sdhci: Add PLL Enable support to internal clock setup
  (bsc#1144168).
- commit 418d5df
* Wed Jan 29 2020 msuchanek@suse.de
- powerpc/xmon: don't access ASDR in VMs (bsc#1065729).
- commit cc778b6
* Wed Jan 29 2020 msuchanek@suse.de
- powerpc/papr_scm: Don't enable direct map for a region by
  default (bsc#1129551).
- commit 5d46d16
* Wed Jan 29 2020 tiwai@suse.de
- Add already cherry-picked id for mdio_bus fix
- commit e3cd812
* Wed Jan 29 2020 tiwai@suse.de
- opp: Free static OPPs on errors while adding them (git-fixes).
- ptp: free ptp device pin descriptors properly (git-fixes).
- clk: samsung: exynos5420: Keep top G3D clocks enabled
  (git-fixes).
- commit 003f497
* Wed Jan 29 2020 mgorman@suse.de
- sched/fair: Define sched_idle_cpu() only for SMP configurations
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit c8faafc
* Wed Jan 29 2020 mgorman@suse.de
- sched/topology: Assert non-NUMA topology masks don't (partially)
  overlap (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit ffd4102
* Wed Jan 29 2020 mgorman@suse.de
- sched/fair: Fix sgc->{min,max}_capacity calculation for
  SD_OVERLAP (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- commit d5c0168
* Wed Jan 29 2020 mgorman@suse.de
- sched/core: Remove unused variable from set_user_nice()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit d56a5d4
* Wed Jan 29 2020 mgorman@suse.de
- schied/fair: Skip calculating @contrib without load (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit e039f48
* Wed Jan 29 2020 mgorman@suse.de
- sched/wait: fix ___wait_var_event(exclusive) (bnc#1155798
  (CPU scheduler functional and performance backports)).
- commit a75fdb5
* Wed Jan 29 2020 mgorman@suse.de
- sched: Use fair:prio_changed() instead of ad-hoc implementation
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit d945568
* Wed Jan 29 2020 mkubecek@suse.cz
- supported.conf: cleanup
  Drop entries which no longer match any module built.
- commit c5f35cc
* Wed Jan 29 2020 tzimmermann@suse.de
- drm/mgag200: Flag all G200 SE A machines as broken wrt <startadd> (bsc#1152489)
- commit 9c74a8c
* Wed Jan 29 2020 mkubecek@suse.cz
- series.conf: cleanup
- update upstream references and move into sorted section:
  patches.suse/ASoC-fsl_sai-add-IRQF_SHARED.patch
  patches.suse/USB-Fix-Don-t-skip-endpoint-descriptors-with-maxpack.patch
  patches.suse/enetc-add-software-timestamping.patch
  patches.suse/enetc-remove-variable-tc_max_sized_frame-set-but-not.patch
  patches.suse/gpio-mpc8xxx-Add-platform-device-to-gpiochip-parent.patch
  patches.suse/libertas-Fix-two-buffer-overflows-at-parsing-bss-des.patch
  patches.suse/sched-Spare-resched-IPI-when-prio-changes-on-a-single-fair-task.patch
  patches.suse/sched-clock-Use-static_branch_likely-with-sched_clock_running.patch
  patches.suse/sched-fair-Improve-update_sd_pick_busiest-for-spare-capacity-case.patch
  patches.suse/sched-fair-Load-balance-aggressively-for-SCHED_IDLE-CPUs.patch
  patches.suse/sched-fair-Make-sched-idle-CPU-selection-consistent-throughout.patch
  patches.suse/sched-fair-Optimize-select_idle_cpu.patch
  patches.suse/sched-fair-Remove-redundant-call-to-cpufreq_update_util.patch
  patches.suse/sched-fair-calculate-delta-runnable-load-only-when-it-s-needed.patch
  No effect on expanded tree.
- commit 06db07c
* Wed Jan 29 2020 tzimmermann@suse.de
- drm/mgag200: Add workaround for HW that does not support 'startadd' (bsc#1152489)
- commit 8ad9863
* Wed Jan 29 2020 mkubecek@suse.cz
- series.conf: refresh
- update upstream references (mainline now) and resort:
  patches.suse/hwrng-iproc-rng200-add-support-for-bcm2711.patch
  patches.suse/ice-Add-device-ids-for-E822-devices.patch
  patches.suse/igc-Add-64-bit-DMA-access-support.patch
  patches.suse/igc-Add-PHY-power-management-control.patch
  patches.suse/igc-Add-SKU-for-i225-device.patch
  patches.suse/igc-Add-basic-skeleton-for-PTP.patch
  patches.suse/igc-Add-legacy-power-management-support.patch
  patches.suse/igc-Add-scatter-gather-support.patch
  patches.suse/igc-Add-support-for-RX-timestamping.patch
  patches.suse/igc-Add-support-for-TSO.patch
  patches.suse/igc-Add-support-for-TX-timestamping.patch
  patches.suse/igc-Add-support-for-ethtool-GET_TS_INFO-command.patch
  patches.suse/igc-Fix-parameter-descriptions-for-a-several-functio.patch
  patches.suse/igc-Fix-the-parameter-description-for-igc_alloc_rx_b.patch
  patches.suse/igc-Fix-typo-in-a-comment.patch
  patches.suse/igc-Improve-the-DMA-mapping-flow.patch
  patches.suse/igc-Prefer-to-use-the-pci_release_mem_regions-method.patch
  patches.suse/igc-Remove-excess-parameter-description-from-igc_is_.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_alloc_mapp.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_assign_vec.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_clean_tx_r.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_configure.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_configure_.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_free_q_vec-f7bcca5d.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_free_q_vec.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_irq_disabl.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_irq_enable.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_power_down.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_set_defaul.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_set_interr.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_set_rx_mod.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_sw_init.patch
  patches.suse/igc-Remove-no-need-declaration-of-the-igc_write_itr.patch
  patches.suse/igc-Remove-serdes-comments-from-a-description-of-met.patch
  patches.suse/igc-Remove-unused-definition.patch
  patches.suse/igc-Use-Start-of-Packet-signal-from-PHY-for-timestam.patch
- commit a2cb839
* Wed Jan 29 2020 tiwai@suse.de
- crypto: ccree - fix PM race condition (git-fixes).
- crypto: caam/qi2 - fix typo in algorithm's driver name
  (git-fixes).
- crypto: atmel-sha - fix error handling when setting hmac key
  (git-fixes).
- crypto: artpec6 - return correct error code for failed setkey()
  (git-fixes).
- crypto: chelsio - fix writing tfm flags to wrong place
  (git-fixes).
- crypto: api - fix unexpectedly getting generic implementation
  (git-fixes).
- crypto: picoxcell - adjust the position of tasklet_init and
  fix missed tasklet_kill (git-fixes).
- crypto: api - Fix race condition in crypto_spawn_alg
  (git-fixes).
- crypto: api - Check spawn->alg under lock in crypto_drop_spawn
  (git-fixes).
- crypto: af_alg - Use bh_lock_sock in sk_destruct (git-fixes).
- crypto: testmgr - don't try to decrypt uninitialized buffers
  (git-fixes).
- crypto: pcrypt - Do not clear MAY_SLEEP flag in original request
  (git-fixes).
- crypto: arm64/ghash-neon - bump priority to 150 (git-fixes).
- crypto: ccp - set max RSA modulus size for v3 platform devices
  as well (git-fixes).
- commit 57ecf54
* Wed Jan 29 2020 tiwai@suse.de
- ASoC: topology: fix soc_tplg_fe_link_create() - link->dobj
  initialization order (git-fixes).
- ASoC: Intel: skl_hda_dsp_common: Fix global-out-of-bounds bug
  (git-fixes).
- ALSA: hda: Add Clevo W65_67SB the power_save blacklist
  (git-fixes).
- ALSA: hda - Add docking station support for Lenovo Thinkpad
  T420s (git-fixes).
- ALSA: hda/hdmi - add retry logic to parse_intel_hdmi()
  (git-fixes).
- ALSA: hda/realtek - Add Headset Mic supported for HP cPC
  (git-fixes).
- ALSA: hda/analog - Minor optimization for SPDIF mux connections
  (git-fixes).
- ALSA: hda: patch_hdmi: remove warnings with empty body
  (git-fixes).
- ALSA: hda: correct kernel-doc parameter descriptions
  (git-fixes).
- ALSA: hda: Manage concurrent reg access more properly
  (git-fixes).
- ALSA: hda: patch_realtek: fix empty macro usage in if block
  (git-fixes).
- ALSA: hda: Fix a typo in comments (git-fixes).
- ALSA: sh: Fix compile warning wrt const (git-fixes).
- ALSA: hda: More constifications (git-fixes).
- ALSA: hda/realtek - More constifications (git-fixes).
- ALSA: hda/realtek - Apply mic mute LED quirk for Dell E7xx
  laptops, too (git-fixes).
- ALSA: sh: Fix unused variable warnings (git-fixes).
- ALSA: hda - constify and cleanup static NodeID tables
  (git-fixes).
- ALSA: hda: Constify snd_pci_quirk tables (git-fixes).
- ALSA: hda: Constify snd_kcontrol_new items (git-fixes).
- ALSA: hda: constify copied structure (git-fixes).
- ALSA: hda: Comment about snd_hdac_bus_update_rirb() and spinlock
  (git-fixes).
- ALSA: control: remove useless assignment in .info callback of
  PCM chmap element (git-fixes).
- ALSA: hda: Unify get_response handling (git-fixes).
- ALSA: hda: Use waitqueue for RIRB in HDA-core helper, too
  (git-fixes).
- ALSA: hda: Use standard waitqueue for RIRB wakeup (git-fixes).
- ath10k: Correct the DMA direction for management tx buffers
  (git-fixes).
- Revert "ath10k: fix DMA related firmware crashes on multiple
  devices" (git-fixes).
- ath10k: pci: Fix comment on ath10k_pci_dump_memory_sram
  (git-fixes).
- ath10k: pci: Only dump ATH10K_MEM_REGION_TYPE_IOREG when safe
  (git-fixes).
- iwlegacy: ensure loop counter addr does not wrap and cause an
  infinite loop (git-fixes).
- rtw88: fix potential NULL skb access in TX ISR (git-fixes).
- brcmfmac: sdio: Fix OOB interrupt initialization on brcm43362
  (git-fixes).
- mwifiex: drop most magic numbers from
  mwifiex_process_tdls_action_frame() (git-fixes).
- net: socionext: fix xdp_result initialization in
  netsec_process_rx (git-fixes).
- net: socionext: fix possible user-after-free in
  netsec_process_rx (git-fixes).
- ath9k: fix storage endpoint lookup (git-fixes).
- brcmfmac: Fix memory leak in brcmf_usbdev_qinit (git-fixes).
- zd1211rw: fix storage endpoint lookup (git-fixes).
- rsi_91x_usb: fix interface sanity check (git-fixes).
- rtl8xxxu: fix interface sanity check (git-fixes).
- orinoco_usb: fix interface sanity check (git-fixes).
- brcmfmac: fix interface sanity check (git-fixes).
- mwifiex: delete unused mwifiex_get_intf_num() (git-fixes).
- brcmfmac: Fix use after free in brcmf_sdio_readframes()
  (git-fixes).
- rsi: fix non-atomic allocation in completion handler
  (git-fixes).
- rsi: fix memory leak on failed URB submission (git-fixes).
- rsi: fix use-after-free on probe errors (git-fixes).
- rsi: fix use-after-free on failed probe and unbind (git-fixes).
- bcma: remove set but not used variable 'sizel' (git-fixes).
- brcmfmac: Fix memory leak in brcmf_p2p_create_p2pdev()
  (git-fixes).
- wil6210: fix break that is never reached because of zero'ing
  of a retry counter (git-fixes).
- ath10k: Fix qmi init error handling (git-fixes).
- ath10k: correct the tlv len of
  ath10k_wmi_tlv_op_gen_config_pno_start (git-fixes).
- NFC: pn544: Adjust indentation in pn544_hci_check_presence
  (git-fixes).
- ppp: Adjust indentation into ppp_async_input (git-fixes).
- Bluetooth: btusb: fix memory leak on fw (git-fixes).
- Bluetooth: btusb: fix non-atomic allocation in completion
  handler (git-fixes).
- commit b16c1ef
* Wed Jan 29 2020 tiwai@suse.de
- regulator: core: Fix exported symbols to the exported GPL
  version (git-fixes).
- commit b623820
* Wed Jan 29 2020 wqu@suse.com
- btrfs: dev-replace: remove warning for unknown return codes
  when finished (dependency for bsc#1162067).
- commit c6cf4b1
* Wed Jan 29 2020 wqu@suse.com
- btrfs: scrub: Require mandatory block group RO for  dev-replace
  (bsc#1162067).
- commit 1eeede9
* Wed Jan 29 2020 jlee@suse.com
- Update config files. (bsc#1160067)
  The 8379bb84be be backported by Takashi from v5.5-rc7 to SLE15-SP2
  kernel. This patch fixed bsc#1160067. After long run testing, we
  confirmed that the issue be fixed on SLE15-SP2 and also v5.5 mainline
  kernel. So I enable CONFIG_KEYS_REQUEST_CACHE again.
  commit 8379bb84be757d5df2d818509faec5d66adb861d
  Author: David Howells <dhowells@redhat.com>
  Date:   Tue Jan 14 16:06:14 2020 +0000
    keys: Fix request_key() cache
- commit 8e290bd
* Wed Jan 29 2020 mgorman@suse.de
- sched, fair: Allow a per-cpu kthread waking a task to stack
  on the same CPU (bsc#1154329).
- commit 8765a0f
* Wed Jan 29 2020 ptesarik@suse.cz
- config: enable arm-specific UFS modules (bsc#1158776 comment 14).
- supported.conf: mark arm-specific UFS modules as supported.
- commit ba2a890
* Tue Jan 28 2020 ptesarik@suse.cz
- config: enable CONFIG_SCSI_SNIC_DEBUG_FS (bsc#1158776 comment 19).
- commit 1120a0c
* Tue Jan 28 2020 lyan@suse.com
- kvm: aarch64: Avoid guest access host debug/PMU registers
  (bnc#1161692).
- commit 392760e
* Tue Jan 28 2020 ptesarik@suse.cz
- config: enable CONFIG_NVM_PBLK on arm64 (bsc#1158776 comment 18).
- commit 1f58f3e
* Tue Jan 28 2020 ptesarik@suse.cz
- config: disable CONFIG_VIRTIO_BLK_SCSI (bsc#1158776 comment 17).
- commit a547bc2
* Tue Jan 28 2020 msuchanek@suse.de
- powerpc/pseries/lparcfg: Fix display of Maximum Memory
  (bsc#1162028 ltc#181740).
- commit c2573b2
* Tue Jan 28 2020 ptesarik@suse.cz
- config: enable BLK_SED_OPAL on arm64 (bsc#1158776 comment 16).
- commit 5c8c73b
* Tue Jan 28 2020 ptesarik@suse.cz
- config: disable CONFIG_RD_LZ4 in arm64/default and s390x/zfcpdump
  (bsc#1158776 comment 15).
- commit 6466f6e
* Tue Jan 28 2020 ptesarik@suse.cz
- config: adjust block device options on arm64 to match x86_64
  (bsc#1158776 comment 14).
- commit 6b66509
* Tue Jan 28 2020 ptesarik@suse.cz
- config: disable MANDATORY_FILE_LOCKING on arm64. To the best of my
  knowledge this is dead code that no one cares about. (bsc#1158776
  comment 12).
- commit 6b4bc5e
* Tue Jan 28 2020 ptesarik@suse.cz
- config: Disable 842 compression on arm64 (bsc#1158776 comment 11).
- commit 998bea1
* Tue Jan 28 2020 ptesarik@suse.cz
- config: file system options on arm64 (bsc#1158776 comment 10).
- commit b603b82
* Tue Jan 28 2020 ptesarik@suse.cz
- config: USB options on arm64 (bsc#1158776 comment 9).
- commit f06de5d
* Tue Jan 28 2020 ptesarik@suse.cz
- config: update non-x86_64 header (gcc 7.5.0)
- commit a033e88
* Tue Jan 28 2020 mbenes@suse.cz
- blacklist.conf: aeed8aa3874d ("tracing: trigger: Replace unneeded RCU-list traversals")
  Needs 28875945ba98 ("rcu: Add support for consolidated-RCU reader
  checking"), which seems to be too invasive for the potential gain.
- commit d3073ab
* Tue Jan 28 2020 ohering@suse.de
- Update patches.suse/target-add-lio-rbd-to-makefile-Kconfig.patch.
  TCM_RBD depends on BLK_DEV_RBD (rbd_img_request_put)
- commit 804b592
* Tue Jan 28 2020 mkubecek@suse.cz
- config: refresh
- update x86_64/default header (gcc 7.5.0)
- clean up x86_64/kvmsmall
- commit 88fb509
* Tue Jan 28 2020 mkubecek@suse.cz
- patch metadata cleanup
- fix Patch-mainline:
  patches.suse/sched-cfs-fix-spurious-active-migration.patch
  patches.suse/sched-fair-Fix-find_idlest_group-to-handle-CPU-affinity.patch
  patches.suse/sched-fair-Optimize-select_idle_core.patch
- commit 2dd79f3
* Tue Jan 28 2020 ptesarik@suse.cz
- Consistent network-related options (bsc#1158776 comment 7).
- commit 8954e4c
* Tue Jan 28 2020 tiwai@suse.de
- clocksource/drivers/bcm2835_timer: Fix memory leak of timer
  (git-fixes).
- ACPI / battery: Deal better with neither design nor full
  capacity not being reported (git-fixes).
- ACPI / battery: Use design-cap for capacity calculations if
  full-cap is not available (git-fixes).
- ACPI / battery: Deal with design or full capacity being reported
  as -1 (git-fixes).
- regulator: rk808: Lower log level on optional GPIOs being not
  available (git-fixes).
- regulator: vctrl-regulator: Avoid deadlock getting and setting
  the voltage (git-fixes).
- spi: fsl-lpspi: fix only one cs-gpio working (git-fixes).
- spi: spi-fsl-qspi: Ensure width is respected in spi-mem
  operations (git-fixes).
- regmap: fix writes to non incrementing registers (git-fixes).
- dmaengine: fsl-qdma: fix duplicated argument to && (git-fixes).
- dmaengine: axi-dmac: add a check for devm_regmap_init_mmio
  (git-fixes).
- platform/x86: intel_mid_powerbtn: Take a copy of ddata
  (git-fixes).
- commit 9a9e8fa
* Mon Jan 27 2020 fdmanana@suse.com
- Btrfs: always copy scrub arguments back to user space
  (bsc#1161948).
- commit 08b80dc
* Mon Jan 27 2020 fdmanana@suse.com
- btrfs: skip log replay on orphaned roots (bsc#1161935).
- commit eeeba1a
* Mon Jan 27 2020 fdmanana@suse.com
- btrfs: handle ENOENT in btrfs_uuid_tree_iterate (bsc#1161937).
- commit 2acecda
* Mon Jan 27 2020 fdmanana@suse.com
- btrfs: abort transaction after failed inode updates in
  create_subvol (bsc#1161936).
- commit 78f55a1
* Mon Jan 27 2020 fdmanana@suse.com
- btrfs: do not call synchronize_srcu() in inode_tree_del
  (bsc#1161934).
- commit 433b7cb
* Mon Jan 27 2020 fdmanana@suse.com
- Btrfs: make tree checker detect checksum items with overlapping
  ranges (bsc#1161931).
- commit 1bcc04b
* Mon Jan 27 2020 fdmanana@suse.com
- Btrfs: fix missing data checksums after replaying a log tree
  (bsc#1161931).
- commit fe9925a
* Mon Jan 27 2020 mbenes@suse.cz
- tracing: Fix histogram code when expression has same var as
  value (git-fixes).
- commit 70a4335
* Mon Jan 27 2020 mbenes@suse.cz
- tracing: xen: Ordered comparison of function pointers
  (git-fixes).
- commit 1c35b4a
* Mon Jan 27 2020 tiwai@suse.de
- mwifiex: fix unbalanced locking in mwifiex_process_country_ie()
  (CVE-2019-14895 bsc#1157158).
- commit b2eb35f
* Mon Jan 27 2020 tiwai@suse.de
- iwlwifi: mvm: fix SKB leak on invalid queue (git-fixes).
- can, slip: Protect tty->disc_data in write_wakeup and close
  with RCU (git-fixes).
- Input: pm8xxx-vib - fix handling of separate enable register
  (git-fixes).
- Input: keyspan-remote - fix control-message timeouts
  (git-fixes).
- Input: sur40 - fix interface sanity checks (git-fixes).
- Input: gtco - fix endpoint sanity check (git-fixes).
- Input: aiptek - fix endpoint sanity check (git-fixes).
- Input: pegasus_notetaker - fix endpoint sanity check
  (git-fixes).
- Input: sun4i-ts - add a check for
  devm_thermal_zone_of_sensor_register (git-fixes).
- drm/i915: Align engine->uabi_class/instance with i915_drm.h
  (git-fixes).
- drm/i915/userptr: fix size calculation (git-fixes).
- mmc: sdhci: fix minimum clock rate for v3 controller
  (git-fixes).
- mmc: tegra: fix SDR50 tuning override (git-fixes).
- mmc: sdhci_am654: Reset Command and Data line after tuning
  (git-fixes).
- mmc: sdhci_am654: Remove Inverted Write Protect flag
  (git-fixes).
- hwmon: (core) Do not use device managed functions for memory
  allocations (git-fixes).
- hwmon: (nct7802) Fix non-working alarm on voltages (git-fixes).
- hwmon: (nct7802) Fix voltage limits to wrong registers
  (git-fixes).
- batman-adv: Fix DAT candidate selection on little endian systems
  (git-fixes).
- cfg80211: check for set_wiphy_params (git-fixes).
- iio: adc: ad7124: Fix DT channel configuration (git-fixes).
- USB: serial: option: add support for Quectel RM500Q in QDL mode
  (git-fixes).
- USB: serial: option: Add support for Quectel RM500Q (git-fixes).
- USB: serial: simple: Add Motorola Solutions TETRA MTP3xxx and
  MTP85xx (git-fixes).
- usb: core: hub: Improved device recognition on remote wakeup
  (git-fixes).
- macb: Don't unregister clks unconditionally (git-fixes).
- drm/arm/mali: make malidp_mw_connector_helper_funcs static
  (git-fixes).
- tomoyo: Don't use nifty names on sockets (git-fixes).
- drm/i915/gvt: set guest display buffer as readonly (git-fixes).
- rtc: bd70528: fix module alias to autoload module (git-fixes).
- drm/amdgpu: allow direct upload save restore list for raven2
  (git-fixes).
- mt76: fix possible out-of-bound access in
  mt7615_fill_txs/mt7603_fill_txs (git-fixes).
- commit daca0f5
* Mon Jan 27 2020 tbogendoerfer@suse.de
- Update patches.suse/ipv6-fix-a-typo-in-fib6_rule_lookup.patch
  (bnc#1151927 5.3.4 CVE-2019-20422).
  Added CVE reference.
- commit afdb381
* Mon Jan 27 2020 tbogendoerfer@suse.de
- net: Fix skb->csum update in inet_proto_csum_replace16()
  (bsc#1154353).
- netfilter: nf_tables: autoload modules from the abort path
  (bsc#1154353).
- netfilter: nf_tables: add __nft_chain_type_get() (bsc#1154353).
- netfilter: conntrack: sctp: use distinct states for new SCTP
  connections (bsc#1154353).
- netfilter: ipset: use bitmap infrastructure completely
  (bsc#1154353).
- netfilter: nft_osf: add missing check for DREG attribute
  (bsc#1154353).
- net/mlx5e: kTLS, Do not send decrypted-marked SKBs via non-accel
  path (jsc#SLE-8464).
- net/mlx5e: kTLS, Remove redundant posts in TX resync flow
  (jsc#SLE-8464).
- net/mlx5e: kTLS, Fix corner-case checks in TX resync flow
  (jsc#SLE-8464).
- net/mlx5e: Clear VF config when switching modes (jsc#SLE-8464).
- net/mlx5: DR, use non preemptible call to get the current cpu
  number (jsc#SLE-8464).
- net/mlx5: E-Switch, Prevent ingress rate configuration of
  uplink rep (jsc#SLE-8464).
- net/mlx5: DR, Enable counter on non-fwd-dest objects
  (jsc#SLE-8464).
- net/mlx5: Update the list of the PCI supported devices
  (jsc#SLE-8464).
- net/mlx5: Fix lowest FDB pool size (jsc#SLE-8464).
- net: cxgb3_main: Add CAP_NET_ADMIN check to CHELSIO_GET_MEM
  (bsc#1154353).
- ipv6_route_seq_next should increase position index
  (bsc#1154353).
- rt_cpu_seq_next should increase position index (bsc#1154353).
- neigh_stat_seq_next() should increase position index
  (bsc#1154353).
- vcc_seq_next should increase position index (bsc#1154353).
- l2t_seq_next should increase position index (bsc#1154353).
- seq_tab_next() should increase position index (bsc#1154353).
- tcp: do not leave dangling pointers in tp->highest_sack
  (bsc#1154353).
- net/rose: fix spelling mistake "to" -> "too" (bsc#1154353).
- caif_usb: fix spelling mistake "to" -> "too" (bsc#1154353).
- ipvs: fix spelling mistake "to" -> "too" (bsc#1154353).
- i40e: fix spelling mistake "to" -> "too" (jsc#SLE-8025).
- net_sched: fix datalen for ematch (bsc#1154353).
- qlcnic: Fix CPU soft lockup while collecting firmware dump
  (bsc#1154353).
- fou: Fix IPv6 netlink policy (bsc#1154353).
- tun: add mutex_unlock() call and napi.skb clearing in
  tun_get_user() (bsc#1154353).
- mlxsw: spectrum_acl: Fix use-after-free during reload
  (bsc#1154488).
- gtp: make sure only SOCK_DGRAM UDP sockets are accepted
  (bsc#1154353).
- net: rtnetlink: validate IFLA_MTU attribute in
  rtnl_create_link() (bsc#1154353).
- net, ip6_tunnel: fix namespaces move (bsc#1154353).
- net_sched: use validated TCA_KIND attribute in tc_new_tfilter()
  (bsc#1154353).
- Revert "udp: do rmem bulk free even if the rx sk queue is empty"
  (bsc#1154353).
- net: Fix packet reordering caused by GRO and listified RX
  cooperation (bsc#1154353).
- net, sk_msg: Don't check if sock is locked when tearing down
  psock (bsc#1154353).
- net, ip_tunnel: fix namespaces move (bsc#1154353).
- tcp: remove redundant assigment to snd_cwnd (bsc#1154353).
- tcp_bbr: improve arithmetic division in bbr_update_bw()
  (bsc#1154353).
- net-sysfs: Fix reference count leak (bsc#1154353).
- ipv6: sr: remove SKB_GSO_IPXIP6 on End.D* actions (bsc#1154353).
- xfrm: support output_mark for offload ESP packets (bsc#1154353).
- xfrm interface: fix packet tx through bpf_redirect()
  (bsc#1154353).
- vti: fix packet tx through bpf_redirect() (bsc#1154353).
- net: ip6_gre: fix moving ip6gre between namespaces
  (bsc#1154353).
- commit 3508aa7
* Mon Jan 27 2020 bp@suse.de
- x86/MCE/AMD: Do not use rdmsr_safe_on_cpu() in smca_configure()
  (bsc#1152489).
- Refresh
  patches.suse/x86-mce-amd-allow-reserved-types-to-be-overwritten-in-smca_banks.patch.
- commit 0c7e16a
* Mon Jan 27 2020 jslaby@suse.cz
- Input: rmi_f54 - read from FIFO in 32 byte blocks (git-fixes).
- Input: synaptics-rmi4 - simplify data read in rmi_f54_work
  (git-fixes).
- Delete
  patches.suse/Input-synaptics-rmi4-don-t-increment-rmiaddr-for-SMB.patch.
  a284e11c371e was reverted in 8ff771f8c8d5. c15f8ba6dc1f is a proper fix.
- commit 396ae25
* Mon Jan 27 2020 jslaby@suse.cz
- net_sched: use validated TCA_KIND attribute in tc_new_tfilter()
  (git-fixes).
- readdir: make user_access_begin() use the real access range
  (git-fixes).
- commit 4c11de1
* Mon Jan 27 2020 tiwai@suse.de
- Fix off-by-one error in the previous i915 fix (bsc#1161720 bsc#1161785)
- commit 079d24f
* Mon Jan 27 2020 jeyu@suse.de
- rpm/kabi.pl: support new (>=5.4) Module.symvers format (new symbol namespace field)
- commit eecbd97
* Mon Jan 27 2020 msuchanek@suse.de
- powerpc/mm/hash: Fix sharing context ids between kernel &
  userspace (bsc#1156395).
- commit c178acd
* Mon Jan 27 2020 msuchanek@suse.de
- powerpc/xive: Discard ESB load value when interrupt is invalid
  (fate#322438 bsc#1085030).
- commit ee23543
* Mon Jan 27 2020 msuchanek@suse.de
- Update
  patches.suse/powerpc-xive-Implement-get_irqchip_state-method-for-.patch
  (fate#322438 bsc#1085030).
- commit 9781d7d
* Mon Jan 27 2020 jack@suse.cz
- libnvdimm/namespace: Differentiate between probe mapping and
  runtime mapping (bsc#1153535).
- commit 515c670
* Fri Jan 24 2020 tiwai@suse.de
- drm/i915/gt: Detect if we miss WaIdleLiteRestore (bsc#1161720).
  Remove the corresponding blacklist entry, too
- commit 480b94e
* Fri Jan 24 2020 mgorman@suse.de
- sched/fair: Load balance aggressively for SCHED_IDLE CPUs
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Make sched-idle CPU selection consistent throughout
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/clock: Use static_branch_likely() with sched_clock_running
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Remove redundant call to cpufreq_update_util()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: calculate delta runnable load only when it's
  needed (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair : Improve update_sd_pick_busiest for spare capacity
  case (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched: Spare resched IPI when prio changes on a single fair
  task (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Optimize select_idle_core (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/fair: Optimize select_idle_cpu (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/fair: Fix find_idlest_group() to handle CPU affinity
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit aa673a4
* Fri Jan 24 2020 bp@suse.de
- x86/CPU/AMD: Ensure clearing of SME/SEV features is maintained
  (bsc#1161731).
- commit 4ba75bd
* Fri Jan 24 2020 ptesarik@suse.cz
- net/smc: unregister ib devices in reboot_event (jsc#SLE-7395).
- net/smc: remove unused constant (jsc#SLE-7395).
- net/smc: use rcu_barrier() on module unload (jsc#SLE-7395).
- net/smc: guarantee removal of link groups in reboot
  (jsc#SLE-7395).
- net/smc: introduce bookkeeping of SMCR link groups
  (jsc#SLE-7395).
- net/smc: immediate termination for SMCR link groups
  (jsc#SLE-7395).
- net/smc: wait for tx completions before link freeing
  (jsc#SLE-7395).
- net/smc: abnormal termination without orderly flag
  (jsc#SLE-7395).
- net/smc: no WR buffer wait for terminating link group
  (jsc#SLE-7395).
- net/smc: introduce bookkeeping of SMCD link groups
  (jsc#SLE-7395).
- net/smc: abnormal termination of SMCD link groups
  (jsc#SLE-7395).
- net/smc: immediate termination for SMCD link groups
  (jsc#SLE-7395).
- net/smc: fix final cleanup sequence for SMCD devices
  (jsc#SLE-7395).
- net/smc: remove close abort worker (jsc#SLE-7395).
- net/smc: introduce link group termination worker (jsc#SLE-7395).
- net/smc: improve abnormal termination of link groups
  (jsc#SLE-7395).
- net/smc: tell peers about abnormal link group termination
  (jsc#SLE-7395).
- net/smc: improve link group freeing (jsc#SLE-7395).
- net/smc: improve abnormal termination locking (jsc#SLE-7395).
- net/smc: terminate link group without holding lgr lock
  (jsc#SLE-7395).
- net/smc: cancel send and receive for terminated socket
  (jsc#SLE-7395).
- net/smc: improve close of terminated socket (jsc#SLE-7395).
- net/smc: no new connections on disappearing devices
  (jsc#SLE-7395).
- net/smc: increase device refcount for added link group
  (jsc#SLE-7395).
- net/smc: separate locks for SMCD and SMCR link group lists
  (jsc#SLE-7395).
- net/smc: separate SMCD and SMCR link group lists (jsc#SLE-7395).
- commit 57bf8aa
* Thu Jan 23 2020 mbrugger@suse.com
- EDAC: Remove misleading comment in struct edac_raw_error_desc
  (jsc#SLE-9482).
- commit f2fb341
* Thu Jan 23 2020 ailiopoulos@suse.com
- xfs: fix mount failure crash on invalid iclog memory access
  (bsc#1161726).
- commit fbaeaa1
* Thu Jan 23 2020 bp@suse.de
- blacklist.conf:
  df1a7524741b ("x86/entry/32: Remove unused resume_userspace label")
- commit 175a9c1
* Thu Jan 23 2020 bp@suse.de
- x86/ioapic: Prevent inconsistent state when moving an interrupt
  (bsc#1152489).
- commit a9854ec
* Thu Jan 23 2020 mbrugger@suse.com
- EDAC: Unify the mc_event tracepoint call (jsc#SLE-9482).
- EDAC/ghes: Remove intermediate buffer pvt->detail_location
  (jsc#SLE-9482).
- EDAC/ghes: Fix grain calculation (jsc#SLE-9482).
- EDAC/ghes: Use standard kernel macros for page calculations
  (jsc#SLE-9482).
- EDAC/mc: Reduce indentation level in edac_mc_handle_error()
  (jsc#SLE-9482).
- EDAC/mc: Remove needless zero string termination (jsc#SLE-9482).
- EDAC/mc: Do not BUG_ON() in edac_mc_alloc() (jsc#SLE-9482).
- EDAC: Introduce an mci_for_each_dimm() iterator (jsc#SLE-9482).
- EDAC: Remove EDAC_DIMM_OFF() macro (jsc#SLE-9482).
- EDAC: Replace EDAC_DIMM_PTR() macro with edac_get_dimm()
  function (jsc#SLE-9482).
- commit 242a2b2
* Thu Jan 23 2020 mbrugger@suse.com
- EDAC/mc_sysfs: Make debug messages consistent (jsc#SLE-9482).
- EDAC/mc_sysfs: Remove pointless gotos (jsc#SLE-9482).
- EDAC: Prefer 'unsigned int' to bare use of 'unsigned'
  (jsc#SLE-9482).
- commit 919516b
* Thu Jan 23 2020 mbrugger@suse.com
- EDAC/mc: Cleanup _edac_mc_free() code (jsc#SLE-9482).
- commit 0c79b9b
* Thu Jan 23 2020 ptesarik@suse.cz
- s390/qeth: vnicc Fix init to default (jsc#SLE-7474).
- s390/qeth: Fix vnicc_is_in_use if rx_bcast not set
  (jsc#SLE-7474).
- s390/qeth: fix false reporting of VNIC CHAR config failure
  (jsc#SLE-7474).
- s390/qeth: lock the card while changing its hsuid
  (jsc#SLE-7474).
- s390/qeth: fix qdio teardown after early init error
  (jsc#SLE-7474).
- s390/qeth: don't return -ENOTSUPP to userspace (jsc#SLE-7474).
- s390/qeth: fix promiscuous mode after reset (jsc#SLE-7474).
- s390/qeth: handle error due to unsupported transport mode
  (jsc#SLE-7474).
- s390/qeth: ensure linear access to packet headers
  (jsc#SLE-7474).
- s390/qeth: guard against runt packets (jsc#SLE-7474).
- s390/qeth: don't check drvdata in sysfs code (jsc#SLE-7474).
- s390/qeth: replace qeth_l3_get_addr_buffer() (jsc#SLE-7474).
- s390/qeth: remove VLAN tracking for L3 devices (jsc#SLE-7474).
- s390/qeth: consolidate L3 mcast registration code
  (jsc#SLE-7474).
- s390/qeth: remove gratuitious RX modeset (jsc#SLE-7474).
- s390/qeth: fine-tune L3 mcast locking (jsc#SLE-7474).
- s390/qeth: clean up error path in qeth_core_probe_device()
  (jsc#SLE-7474).
- s390/qeth: handle skb allocation error gracefully
  (jsc#SLE-7474).
- s390/qeth: drop unwanted packets earlier in RX path
  (jsc#SLE-7474).
- s390/qeth: support per-frame invalidation (jsc#SLE-7474).
- s390/qeth: gather more detailed RX dropped/error statistics
  (jsc#SLE-7474).
- s390/qeth: don't cache MAC addresses for multicast IPs
  (jsc#SLE-7474).
- s390/qeth: use helpers for IP address hashing (jsc#SLE-7474).
- s390/qeth: don't set card state in qeth_qdio_clear_card()
  (jsc#SLE-7474).
- commit 97e2cae
* Thu Jan 23 2020 ptesarik@suse.cz
- s390/qeth: keep IRQ disabled until NAPI is really done
  (jsc#SLE-7474).
- s390/qeth: use QDIO_BUFNR() (jsc#SLE-7474).
- s390/qdio: move SSQD Sniffer mask definition (jsc#SLE-7474).
- commit 0fcd468
* Thu Jan 23 2020 tbogendoerfer@suse.de
- Update
  patches.suse/net-mlx5-prevent-memory-leak-in-mlx5_fpga_conn_creat.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11 CVE-2019-19045).
  Added CVE reference
- commit 9835bdc
* Thu Jan 23 2020 wqu@suse.com
- btrfs: relocation: fix reloc_root lifespan and access
  (bsc#1159588).
- commit fc30409
* Wed Jan 22 2020 bp@suse.de
- x86/kgbd: Use NMI_VECTOR not APIC_DM_NMI (bsc#1152489).
- commit d1023df
* Wed Jan 22 2020 bp@suse.de
- blacklist.conf:
  7720804a2ae4 ("x86, perf: Fix the dependency of the x86 insn decoder selftest")
- commit b934c08
* Wed Jan 22 2020 msuchanek@suse.de
- Update
  patches.suse/mm-memory_hotplug-don-t-free-usage-map-when-removing-a-re-added-early-section.patch
  (bsc#1160366 ltc#183002 git fixes (mm/hotplug)).
- commit 4057d37
* Wed Jan 22 2020 tiwai@suse.de
- blacklist.conf: Add iwlwifi revert entry that isn't suitable
- commit 8b00a89
* Wed Jan 22 2020 tiwai@suse.de
- bus: ti-sysc: Fix iterating over clocks (git-fixes).
- clk: Don't try to enable critical clocks if prepare failed
  (git-fixes).
- clk: tegra: Fix double-free in tegra_clk_init() (git-fixes).
- commit 7747d41
* Wed Jan 22 2020 tiwai@suse.de
- blacklist.conf: Add drm/virtio entries, insufficent for SLE15-SP2
- commit c1ea031
* Wed Jan 22 2020 bp@suse.de
- x86/resctrl: Fix potential memory leak (bsc#1152489).
- x86/resctrl: Fix an imbalance in domain_remove_cpu()
  (bsc#1152489).
- commit b6bd4fe
* Wed Jan 22 2020 ykaukab@suse.de
- PCI: dwc: Add validation that PCIe core is set to correct mode
  (jsc#SLE-10562).
- commit a4552c1
* Wed Jan 22 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: register gpu instance before fan boost feature enablment'
- commit 6fe4000
* Wed Jan 22 2020 mgorman@suse.de
- sched/cfs: fix spurious active migration (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- commit 8b16f2e
* Wed Jan 22 2020 tzimmermann@suse.de
- drm/amdgpu: fix license on Kconfig and Makefiles (bsc#1152472)
- commit af71d3c
* Wed Jan 22 2020 tzimmermann@suse.de
- drm/amdgpu: Call find_vma under mmap_sem (bsc#1152489)
- commit 45b9c9d
* Wed Jan 22 2020 tzimmermann@suse.de
- drm/amd/powerplay: Fix error handling in smu_init_fb_allocations() (bsc#1152489)
- commit ac2af40
* Wed Jan 22 2020 mkoutny@suse.com
- exit: panic before exit_mm() on global init exit (bsc#1161549).
- commit e6e6d28
* Wed Jan 22 2020 tiwai@suse.de
- rpmsg: char: release allocated memory (CVE-2019-19053
  bsc#1161520).
- commit bdab989
* Wed Jan 22 2020 tiwai@suse.de
- media: rc: prevent memory leak in cx23888_ir_probe
  (CVE-2019-19054 bsc#1161518).
- commit 91d7fee
* Wed Jan 22 2020 tiwai@suse.de
- libertas: make lbs_ibss_join_existing() return error code
  on rates overflow (CVE-2019-14896 bsc#1157157 CVE-2019-14897
  bsc#1157155).
- libertas: don't exit from lbs_ibss_join_existing() with RCU
  read lock held (CVE-2019-14896 bsc#1157157 CVE-2019-14897
  bsc#1157155).
- commit a649646
* Wed Jan 22 2020 jack@suse.cz
- libnvdimm/region: Enable MAP_SYNC for volatile regions
  (bsc#1161291).
- commit 8ecd112
* Tue Jan 21 2020 lpechacek@suse.cz
- powerpc: drmem: avoid NULL pointer dereference when drmem is
  unavailable (bsc#1160659).
- commit 1775954
* Tue Jan 21 2020 tbogendoerfer@suse.de
- igc: Add PHY power management control (bsc#1160632).
- igc: Add support for TSO (bsc#1160634).
- igc: Add SKU for i225 device (bsc#1160634).
- igc: Remove unused definition (bsc#1160634).
- igc: Fix typo in a comment (bsc#1160634).
- igc: Use Start of Packet signal from PHY for timestamping
  (bsc#1160634).
- igc: Add support for ethtool GET_TS_INFO command (bsc#1160634).
- igc: Add support for TX timestamping (bsc#1160634).
- igc: Add support for RX timestamping (bsc#1160634).
- igc: Add basic skeleton for PTP (bsc#1160634).
- igc: Remove no need declaration of the igc_sw_init
  (bsc#1160634).
- igc: Remove no need declaration of the igc_write_itr
  (bsc#1160634).
- igc: Remove no need declaration of the igc_assign_vector
  (bsc#1160634).
- igc: Remove no need declaration of the igc_free_q_vector
  (bsc#1160634).
- igc: Remove no need declaration of the igc_free_q_vectors
  (bsc#1160634).
- igc: Remove no need declaration of the igc_irq_disable
  (bsc#1160634).
- igc: Remove no need declaration of the igc_irq_enable
  (bsc#1160634).
- igc: Remove no need declaration of the igc_configure_msix
  (bsc#1160634).
- igc: Remove no need declaration of the igc_set_rx_mode
  (bsc#1160634).
- igc: Remove no need declaration of the
  igc_set_interrupt_capability (bsc#1160634).
- igc: Remove no need declaration of the igc_alloc_mapped_page
  (bsc#1160634).
- igc: Remove no need declaration of the igc_configure
  (bsc#1160634).
- igc: Remove no need declaration of the
  igc_set_default_mac_filter (bsc#1160634).
- igc: Remove no need declaration of the igc_power_down_link
  (bsc#1160634).
- igc: Remove no need declaration of the igc_clean_tx_ring
  (bsc#1160634).
- igc: Remove serdes comments from a description of methods
  (bsc#1160634).
- igc: Add legacy power management support (bsc#1160634).
- igc: Add 64 bit DMA access support (bsc#1160634).
- igc: Fix parameter descriptions for a several functions
  (bsc#1160634).
- igc: Fix the parameter description for igc_alloc_rx_buffers
  (bsc#1160634).
- igc: Remove excess parameter description from igc_is_non_eop
  (bsc#1160634).
- igc: Prefer to use the pci_release_mem_regions method
  (bsc#1160634).
- igc: Improve the DMA mapping flow (bsc#1160634).
- igc: Add scatter gather support (bsc#1160634).
- cxgb4: reject overlapped queues in TC-MQPRIO offload
  (jsc#SLE-8389).
- cxgb4: fix Tx multi channel port rate limit (jsc#SLE-8389).
- net: sched: act_ctinfo: fix memory leak (bsc#1154353).
- bnxt_en: Do not treat DSN (Digital Serial Number) read failure
  as fatal (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix ipv6 RFS filter matching logic (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Fix NTUPLE firmware command failures (jsc#SLE-8371
  bsc#1153274).
- net: hns: fix soft lockup when there is not enough memory
  (bsc#1154353).
- net: avoid updating qdisc_xmit_lock_key in
  netdev_update_lockdep_key() (bsc#1154353).
- net/sched: act_ife: initalize ife->metalist earlier
  (bsc#1154353).
- netfilter: nat: fix ICMP header corruption on ICMP errors
  (bsc#1154353).
- netfilter: nf_tables: fix flowtable list del corruption
  (bsc#1154353).
- netfilter: nf_tables: remove WARN and add NLA_STRING upper
  limits (bsc#1154353).
- netfilter: nft_tunnel: ERSPAN_VERSION must not be null
  (bsc#1154353).
- netfilter: nft_tunnel: fix null-attribute check (bsc#1154353).
- netfilter: nf_tables: store transaction list locally while
  requesting module (bsc#1154353).
- netfilter: arp_tables: init netns pointer in xt_tgdtor_param
  struct (bsc#1154353).
- netfilter: fix a use-after-free in mtype_destroy()
  (bsc#1154353).
- net: hns3: pad the short frame before sending to the hardware
  (bsc#1154353).
- macvlan: use skb_reset_mac_header() in macvlan_queue_xmit()
  (bsc#1154353).
- tcp: fix marked lost packets not being retransmitted
  (bsc#1154353).
- mlxsw: spectrum_qdisc: Include MC TCs in Qdisc counters
  (bsc#1154488).
- mlxsw: spectrum: Wipe xstats.backlog of down ports
  (bsc#1154488).
- mlxsw: switchx2: Do not modify cloned SKBs during xmit
  (bsc#1154488).
- mlxsw: spectrum: Do not modify cloned SKBs during xmit
  (bsc#1154488).
- mlxsw: spectrum: Do not enforce same firmware version for
  multiple ASICs (bsc#1154488).
- devlink: correct misspelling of snapshot (bsc#1154353).
- devlink: Wait longer before warning about unset port type
  (bsc#1154353).
- ipv4: Detect rollover in specific fib table dump (bsc#1154353).
- net/tls: fix async operation (bsc#1154353).
- net/tls: avoid spurious decryption error with HW resync
  (bsc#1154353).
- e1000e: Revert "e1000e: Make watchdog use delayed work"
  (jsc#SLE-8100).
- i40e: Set PHY Access flag on X722 (jsc#SLE-8025).
- iavf: remove current MAC address filter on VF reset
  (jsc#SLE-7940).
- igb: Fix SGMII SFP module discovery for 100FX/LX (jsc#SLE-7967
  jsc#SLE-8010).
- ixgbe: Fix calculation of queue with VFs and flow director on
  interface flap (jsc#SLE-7979 jsc#SLE-7981).
- ixgbevf: Remove limit of 10 entries for unicast filter list
  (jsc#SLE-7979 jsc#SLE-7981).
- i40e: Fix virtchnl_queue_select bitmap validation
  (jsc#SLE-8025).
- xprtrdma: Fix oops in Receive handler after device removal
  (jsc#SLE-8449).
- xprtrdma: Fix completion wait during device removal
  (jsc#SLE-8449).
- xprtrdma: Fix create_qp crash on device unload (jsc#SLE-8449).
- commit 42c7e2a
* Tue Jan 21 2020 jgross@suse.com
- blacklist.conf: added 1a8211c7d8717b19c1e9fa41d19fe6a55409765e
- commit 302e64e
* Tue Jan 21 2020 jgross@suse.com
- KVM: vmx: Introduce handle_unexpected_vmexit and handle WAITPKG
  vmexit (jsc#SLE-11070).
- commit f99f84d
* Tue Jan 21 2020 jgross@suse.com
- KVM: vmx: Emulate MSR IA32_UMWAIT_CONTROL (jsc#SLE-11070).
- Refresh
  patches.suse/kvm-vmx-implement-msr_ia32_tsx_ctrl-disable-rtm-functionality.
- commit e194189
* Tue Jan 21 2020 jgross@suse.com
- KVM: x86: Add support for user wait instructions
  (jsc#SLE-11070).
- commit dd3d6b5
* Tue Jan 21 2020 mbenes@suse.cz
- perf/x86/cstate: Add Comet Lake CPU support (jsc#SLE-10621).
- commit 344f793
* Tue Jan 21 2020 mbenes@suse.cz
- perf/x86/msr: Add Comet Lake CPU support (jsc#SLE-10621).
- commit ed2c0f6
* Tue Jan 21 2020 mbenes@suse.cz
- perf/x86/intel: Add Comet Lake CPU support (jsc#SLE-10621).
- commit 03d1cee
* Tue Jan 21 2020 ykaukab@suse.de
- PCI: mobiveil: ls_pcie_g4: fix SError when accessing config space (bsc#1161495).
- PCI: mobiveil: ls_pcie_g4: add Workaround for A-011451 (bsc#1161495).
- PCI: mobiveil: ls_pcie_g4: add Workaround for A-011577 (bsc#1161495).
- commit 2049c57
* Tue Jan 21 2020 tiwai@suse.de
- Revert "rsi: fix potential null dereference in rsi_probe()"
  (git-fixes).
- commit 2ef75f1
* Mon Jan 20 2020 msuchanek@suse.de
- blacklist.conf: Add ppc booke fixes.
  3a0990ca1a00 powerpc/booke: Spelling s/date/data/
  71eb40fc5337 powerpc/kasan: Fix boot failure with RELOCATABLE &&
  FSL_BOOKE
- commit 8f24d42
* Mon Jan 20 2020 tiwai@suse.de
- cfg80211: fix page refcount issue in A-MSDU decap (git-fixes).
- cfg80211: fix memory leak in cfg80211_cqm_rssi_update
  (git-fixes).
- cfg80211: fix memory leak in nl80211_probe_mesh_link
  (git-fixes).
- cfg80211: fix deadlocks in autodisconnect work (git-fixes).
- r8152: add missing endpoint sanity check (git-fixes).
- net: usb: lan78xx: limit size of local TSO packets (git-fixes).
- i2c: iop3xx: Fix memory leak in probe error path (git-fixes).
- i2c: tegra: Properly disable runtime PM on driver's probe error
  (git-fixes).
- i2c: tegra: Fix suspending in active runtime PM state
  (git-fixes).
- mtd: rawnand: gpmi: Restore nfc timing setup after
  suspend/resume (git-fixes).
- mtd: rawnand: gpmi: Fix suspend/resume problem (git-fixes).
- drm/i915: Add missing include file <linux/math64.h> (git-fixes).
- efi/earlycon: Fix write-combine mapping on x86 (git-fixes).
- staging: comedi: ni_routes: allow partial routing information
  (git-fixes).
- staging: comedi: ni_routes: fix null dereference in
  ni_find_route_source() (git-fixes).
- iio: light: vcnl4000: Fix scale for vcnl4040 (git-fixes).
- iio: buffer: align the size of scan bytes to size of the
  largest element (git-fixes).
- iio: chemical: pms7003: fix unmet triggered buffer dependency
  (git-fixes).
- iio: imu: st_lsm6dsx: Fix selection of ST_LSM6DS3_ID
  (git-fixes).
- clk: sunxi-ng: r40: Allow setting parent rate for external
  clock outputs (git-fixes).
- clk: qcom: gcc-sdm845: Add missing flag to votable GDSCs
  (git-fixes).
- dmaengine: k3dma: Avoid null pointer traversal (git-fixes).
- drm/amdgpu: enable gfxoff for raven1 refresh (git-fixes).
- net: nfc: nci: fix a possible sleep-in-atomic-context bug in
  nci_uart_tty_receive() (git-fixes).
- net: gemini: Fix memory leak in gmac_setup_txqs (git-fixes).
- rsi: fix potential null dereference in rsi_probe() (git-fixes).
- commit 4cb2bed
* Mon Jan 20 2020 msuchanek@suse.de
- kernel-binary.spec.in: do not recommend firmware for kvmsmall and azure
  flavor (boo#1161360).
- commit dbe7b27
* Mon Jan 20 2020 msuchanek@suse.de
- torture: Remove exporting of internal functions (bsc#1156395).
- commit 3c30cc1
* Mon Jan 20 2020 msuchanek@suse.de
- config/x86_64/kvmsmall: Enable UINPUT (boo#1161305).
- commit 61a4f71
* Mon Jan 20 2020 tiwai@suse.de
- ASoC: msm8916-wcd-digital: Reset RX interpolation path after
  use (git-fixes).
- ASoC: msm8916-wcd-analog: Fix MIC BIAS Internal1 (git-fixes).
- ASoC: sti: fix possible sleep-in-atomic (git-fixes).
- ASoC: msm8916-wcd-analog: Fix selected events for MIC BIAS
  External1 (git-fixes).
- ASoC: hdac_hda: Fix error in driver removal after failed probe
  (git-fixes).
- ASoC: SOF: Intel: fix HDA codec driver probe with multiple
  controllers (git-fixes).
- ASoC: SOF: Intel: lower print level to dbg if we will reinit
  DSP (git-fixes).
- ASoC: stm32: dfsdm: fix 16 bits record (git-fixes).
- ASoC: Intel: bytcht_es8316: Fix Irbis NB41 netbook quirk
  (git-fixes).
- ASoC: rt5640: Fix NULL dereference on module unload (git-fixes).
- ALSA: seq: Fix racy access for queue timer in proc read
  (git-fixes).
- ALSA: usb-audio: fix sync-ep altsetting sanity check
  (git-fixes).
- ALSA: dice: fix fallback from protocol extension into limited
  functionality (git-fixes).
- ALSA: firewire-tascam: fix corruption due to spin lock without
  restoration in SoftIRQ context (git-fixes).
- commit 5af0dd5
* Mon Jan 20 2020 oneukum@suse.com
- NFC: pn533: fix bulk-message timeout (git-fixes).
- commit 442eed3
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: quatech2: handle unbound ports (git-fixes).
- commit d0020c8
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: keyspan: handle unbound ports (git-fixes).
- commit 32ba490
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: io_edgeport: add missing active-port sanity check
  (git-fixes).
- commit 1494e56
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: io_edgeport: handle unbound ports on URB completion
  (git-fixes).
- commit 6182181
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: ch341: handle unbound port at reset_resume
  (git-fixes).
- commit 2b59c4a
* Mon Jan 20 2020 oneukum@suse.com
- blacklist.conf: it removes an attribute from sysfs
- commit 3748cd2
* Mon Jan 20 2020 oneukum@suse.com
- USB: serial: opticon: fix control-message timeouts (git-fixes).
- commit 6bc0895
* Mon Jan 20 2020 mgorman@suse.de
- mm: memcg/slab: call flush_memcg_workqueue() only if memcg
  workqueue is valid (git fixes (mm/slab)).
- mm: memcg/slab: fix percpu slab vmstats flushing (git fixes
  (mm/memcg)).
- mm/shmem.c: thp, shmem: fix conflict of above-47bit hint
  address and PMD alignment (git fixes (mm/pgtable)).
- mm/huge_memory.c: thp: fix conflict of above-47bit hint address
  and PMD alignment (git fixes (mm/pgtable)).
- mm/memory_hotplug: don't free usage map when removing a re-added
  early section (git fixes (mm/hotplug)).
- commit 1508be3
* Mon Jan 20 2020 glin@suse.com
- bpf: Sockmap/tls, fix pop data with SK_DROP return code
  (bsc#1155518).
- bpf: Sockmap/tls, skmsg can have wrapped skmsg that needs
  extra chaining (bsc#1155518).
- bpf: Sockmap/tls, tls_sw can create a plaintext buf > encrypt
  buf (bsc#1155518).
- bpf: Sockmap/tls, msg_push_data may leave end mark in place
  (bsc#1155518).
- bpf: Sockmap, skmsg helper overestimates push, pull, and pop
  bounds (bsc#1155518).
- bpf: Sockmap/tls, push write_space updates through ulp updates
  (bsc#1155518).
- bpf: Sockmap, ensure sock lock held during tear down
  (bsc#1155518).
- net: bpf: Don't leak time wait and request sockets
  (bsc#1155518).
- bpf/sockmap: Read psock ingress_msg before sk_receive_queue
  (bsc#1155518).
- commit 8d7a4ba
* Mon Jan 20 2020 glin@suse.com
- bpf: Sockmap/tls, during free we may call tcp_bpf_unhash()
  in loop (bsc#1155518).
- bpf: Fix incorrect verifier simulation of ARSH under ALU32
  (bsc#1155518).
- bpftool: Fix printing incorrect pointer in btf_dump_ptr
  (bsc#1155518).
- commit 67424a0
* Fri Jan 17 2020 ptesarik@suse.cz
- s390/qeth: consolidate some duplicated HW cmd code
  (jsc#SLE-7474).
- Refresh patches.suse/s390-qeth-fix-initialization-on-old-hw.
- commit 00d9aa3
* Fri Jan 17 2020 ptesarik@suse.cz
- s390/qeth: merge qeth_reply struct into qeth_cmd_buffer
  (jsc#SLE-7542).
- Refresh
  patches.suse/s390-qeth-fix-dangling-io-buffers-after-halt-clear.
- commit 9542e64
* Fri Jan 17 2020 ptesarik@suse.cz
- s390/qeth: return proper errno on IO error (jsc#SLE-7542).
- s390/qeth: fix potential deadlock on workqueue flush
  (jsc#SLE-7542).
- s390/qeth: Fix initialization of vnicc cmd masks during set
  online (jsc#SLE-7542).
- s390/qeth: Fix error handling during VNICC initialization
  (jsc#SLE-7542).
- s390/qdio: clarify size of the QIB parm area (jsc#SLE-7542).
- s390/ctcm: Delete unnecessary checks before the macro call
  "dev_kfree_skb" (jsc#SLE-7542).
- s390/lcs: don't use intparm for channel IO (jsc#SLE-7542).
- s390/ctcm: don't use intparm for channel IO (jsc#SLE-7542).
- s390/qeth: streamline control code for promisc mode
  (jsc#SLE-7542).
- s390/qeth: get vnicc sub-cmd type from reply data
  (jsc#SLE-7542).
- s390/qeth: keep cmd alive after IO completion (jsc#SLE-7542).
- s390/qeth: use correct length field in SNMP cmd callback
  (jsc#SLE-7542).
- s390/qeth: propagate length of processed cmd IO data to callback
  (jsc#SLE-7542).
- s390/qeth: use node_descriptor struct (jsc#SLE-7542).
- commit 8223e8d
* Fri Jan 17 2020 jgross@suse.com
- xen/blkfront: Adjust indentation in xlvbd_alloc_gendisk
  (bsc#1065600).
- commit 5b346da
* Fri Jan 17 2020 ddiss@suse.de
- Refresh patches.suse/target-add-lio-rbd-to-makefile-Kconfig.patch:
  (fate#318836).
- supported.conf: relist target_core_rbd (fate#318836)
- re-enable CONFIG_TCM_RBD=m
- Refresh patches.suse/target-add-rbd-backend.patch:
  (fate#318836).
  + use upstream RBD bvecs API and split out compare&write and
    write-same request support
- Refresh patches.suse/rbd-add-lio-specific-data-area.patch:
  (fate#318836).
  + rebased, with lio_cmd_data moved into union with rq/copyup state
- Add patches.suse/rbd-add-img_request-done-callback.patch:
  (fate#318836).
  + this is needed for target_core_rbd SCSI cmd completion following
    7114edac357b ("rbd: new request completion code")
- Refresh
  patches.suse/rbd-move-structs-used-by-lio-rbd-to-new-header.patch:
  (fate#318836).
  + rebase and expose bvecs instead of sgl API for data payload
- Refresh
  patches.suse/rbd-export-some-functions-used-by-lio-rbd-backend.patch:
  (fate#318836).
  + export bvecs API for data payload
- commit d3df489
* Fri Jan 17 2020 ddiss@suse.de
- Deletions for target_core_rbd refactoring
- Drop upstreamed patches
  patches.suse/target-configfs-add-device-vendor_id-attribute.patch
  patches.suse/target-remove-hardcoded-T10-Vendor-ID-in-INQUIRY-res.patch
- Merge with target-add-rbd-backend.patch
  patches.suse/0001-target_core_rbd-use-RCU-in-free_device.patch
  patches.suse/0002-target_core_rbd-break-up-free_device-callback.patch
  patches.suse/target-rbd-don-t-put-snap_context-twice.patch
  patches.suse/target-rbd-handle-zero-length-UNMAP-requests-early.patch
  patches.suse/target-rbd-use-target_configure_unmap_from_queue-hel.patch
- Remove rbd sgl patches following target_core_rbd bvec conversion
  patches.suse/libceph-add-scatterlist-messenger-data-type.patch
  patches.suse/libceph-fix-scatterlist-last_piece-calculation.patch
  patches.suse/rbd-add-support-for-scatterlist-obj_request_type.patch
  patches.suse/rbd-handle-OBJ_REQUEST_SG-types-for-copyup.patch
- Drop compare-and-write support pending bvecs conversion
  patches.suse/0001-rbd-drop-extra-rbd_img_request_get.patch
  patches.suse/libceph-add-support-for-CMPEXT-compare-extent-reques.patch
  patches.suse/rbd-add-num-ops-calculator-helper.patch
  patches.suse/rbd-add-support-for-COMPARE_AND_WRITE-CMPEXT.patch
  patches.suse/rbd-copy-compare-and-write-osd-requests-before-resub.patch
  patches.suse/rbd-don-t-log-miscompare-as-an-error.patch
  patches.suse/rbd-helper-to-copy-compare-and-write-osd-requests.patch
  patches.suse/rbd-truncate-objects-on-cmpext-short-reads.patch
  patches.suse/target-add-COMPARE_AND_WRITE-sg-creation-helper.patch
  patches.suse/target-add-compare-and-write-callback.patch
  patches.suse/target-compare-and-write-backend-driver-sense-handli.patch
  patches.suse/target-rbd-remove-caw_mutex-usage.patch
  patches.suse/rbd-add-write-test-helper.patch
- Drop SCSI Reservation support pending upstream discussion
  patches.suse/0002-rbd-make-sure-pages-are-freed-by-libceph.patch
  patches.suse/ceph-osd_client-add-support-for-CEPH_OSD_OP_GETXATTR.patch
  patches.suse/libceph-fix-pr_fmt-compile-issues.patch
  patches.suse/rbd-add-cmpsetattr-device-attribute-for-debugging.patch
  patches.suse/rbd-add-getxattr-device-attribute-for-debugging.patch
  patches.suse/rbd-add-rbd_dev_cmpsetxattr-helper.patch
  patches.suse/rbd-add-rbd_dev_getxattr-helper.patch
  patches.suse/rbd-add-rbd_dev_setxattr-helper.patch
  patches.suse/rbd-add-setxattr-device-attribute-for-debugging.patch
  patches.suse/rbd-do-away-with-obj_request-in-cmpsetxattr.patch
  patches.suse/rbd-do-away-with-obj_request-in-getxattr.patch
  patches.suse/rbd-do-away-with-obj_request-in-setxattr.patch
  patches.suse/target-fix-tcm_rbd_gen_it_nexus-for-emulated-XCOPY-s.patch
  patches.suse/target-pr-add-backend-API-for-reservation-handling.patch
  patches.suse/target-pr-fix-core_scsi3_pr_seq_non-caller.patch
  patches.suse/target-pr-split-out-and-export-core_scsi3_pr_seq_non.patch
  patches.suse/target-rbd-SCSI3-check-conflict-support.patch
  patches.suse/target-rbd-add-SCSI2-reservation-entry-to-PR-info.patch
  patches.suse/target-rbd-add-pr_clear-support.patch
  patches.suse/target-rbd-add-pr_preempt-support.patch
  patches.suse/target-rbd-add-pr_read_reservation-support.patch
  patches.suse/target-rbd-add-pr_release-support.patch
  patches.suse/target-rbd-add-pr_report_capabilities-support.patch
  patches.suse/target-rbd-add-pr_reserve-support.patch
  patches.suse/target-rbd-add-stubbed-out-pr_read_full_status.patch
  patches.suse/target-rbd-add-stubbed-out-pr_register_and_move.patch
  patches.suse/target-rbd-add-support-for-PR-register-read-keys.patch
  patches.suse/target-rbd-fix-PR-info-memory-leaks.patch
  patches.suse/target-rbd-handle-SCSI2-reservation-release-on-reset.patch
  patches.suse/target-rbd-implement-SCSI2-reservation-handling.patch
- Remove write-same support pending bvecs conversion
  patches.suse/libceph-add-support-for-write-same-requests.patch
  patches.suse/libceph-use-upstream-write-same-opcode.patch
  patches.suse/rbd-add-support-for-writesame-requests.patch
- commit 1277a52
* Thu Jan 16 2020 tiwai@suse.de
- Documentation/ABI: Add missed attribute for mlxreg-io sysfs
  interfaces (git-fixes).
- Documentation/ABI: Fix documentation inconsistency for mlxreg-io
  sysfs interfaces (git-fixes).
- commit 4873021
* Thu Jan 16 2020 tiwai@suse.de
- platform/x86: asus-wmi: Fix keyboard brightness cannot be set
  to 0 (git-fixes).
- platform/x86: GPD pocket fan: Use default values when wrong
  modparams are given (git-fixes).
- platform/mellanox: fix potential deadlock in the tmfifo driver
  (git-fixes).
- commit 0bb7471
* Thu Jan 16 2020 jeyu@suse.de
- Delete patches.suse/x86-cpu_entry_area-Map-also-trace_idt_table.patch.
  The real fixes have been upstream since v4.14.
- commit 46e9a10
* Thu Jan 16 2020 tbogendoerfer@suse.de
- i40iw: Remove setting of VMA private data and use
  rdma_user_mmap_io (jsc#SLE-8449).
- IB/hfi1: Adjust flow PSN with the correct resync_psn
  (jsc#SLE-8449).
- IB/hfi1: Don't cancel unused work item (jsc#SLE-8449).
- RDMA/bnxt_re: Fix Send Work Entry state check while polling
  completions (jsc#SLE-8372 bsc#1153275).
- RDMA/bnxt_re: Avoid freeing MR resources if dereg fails
  (jsc#SLE-8372 bsc#1153275).
- netfilter: conntrack: dccp, sctp: handle null timeout argument
  (bsc#1154353).
- netfilter: arp_tables: init netns pointer in xt_tgchk_param
  struct (bsc#1154353).
- macvlan: do not assume mac_header is set in macvlan_broadcast()
  (bsc#1154353).
- net: sch_prio: When ungrafting, replace with FIFO (bsc#1154353).
- mlxsw: spectrum_qdisc: Ignore grafting of invisible FIFO
  (bsc#1154488).
- gtp: fix bad unlock balance in gtp_encap_enable_socket
  (bsc#1154353).
- pkt_sched: fq: do not accept silly TCA_FQ_QUANTUM (bsc#1154353).
- net/mlx5: DR, Init lists that are used in rule's member
  (jsc#SLE-8464).
- net/mlx5e: Fix hairpin RSS table size (jsc#SLE-8464).
- net/mlx5: DR, No need for atomic refcount for internal SW
  steering resources (jsc#SLE-8464).
- Revert "net/mlx5: Support lockless FTE read lookups"
  (jsc#SLE-8464).
- net/mlx5: Move devlink registration before interfaces load
  (jsc#SLE-8464).
- net/mlx5e: Always print health reporter message to dmesg
  (jsc#SLE-8464).
- net/mlx5e: Avoid duplicating rule destinations (jsc#SLE-8464).
- sctp: free cmd->obj.chunk for the unprocessed SCTP_CMD_REPLY
  (bsc#1154353).
- net: Google gve: Remove dma_wmb() before ringing doorbell
  (bsc#1154353).
- sch_cake: avoid possible divide by zero in cake_enqueue()
  (bsc#1154353).
- tcp: fix "old stuff" D-SACK causing SACK to be treated as D-SACK
  (bsc#1154353).
- commit b1356f9
* Thu Jan 16 2020 wqu@suse.com
- Delete
  patches.suse/btrfs-suspend-qgroups-during-relocation-recovery.patch.
  This patch is no longer needed for v5.3. Since v5.1 we have proper
  qgroup + balance optimization to avoid unnecessary rescan.
- commit b92eedd
* Thu Jan 16 2020 wqu@suse.com
- Delete
  patches.suse/0001-btrfs-qgroup-Make-qgroup-async-transaction-commit-mo.patch.
  This patch is already upstreamed in v5.1, thus already included.
- commit 5b34f2a
* Thu Jan 16 2020 rgoldwyn@suse.com
- overlayfs: pseudo dev obviates treating btrfs as different
  Delete patches.suse/ovl-treat-btrfs-as-different-mount.patch.
- commit e1e67d4
* Wed Jan 15 2020 rgoldwyn@suse.com
- apparmor: Delete apparmor patches not required for v5.3
- Delete
  patches.suse/0001-apparmor-fix-unnecessary-creation-of-net-compat.patch.
- Delete
  patches.suse/0001-apparmor-patch-to-provide-compatibility-with-v2.x-ne.patch.
- Delete
  patches.suse/0003-apparmor-fix-use-after-free-in-sk_peer_label.patch.
- Delete patches.suse/apparmor-compatibility-with-v2.x-net.patch.
- commit faddc27
* Wed Jan 15 2020 mbrugger@suse.com
- supported.conf: mark gpio-mlxbf as supported
- commit 987e308
* Wed Jan 15 2020 tiwai@suse.de
- arm: Implement copy_thread_tls (git-fixes).
- drm/i915: Hold reference to intel_frontbuffer as we track
  activity (git-fixes).
- drm/i915/tgl: Drop Wa#1178 (git-fixes).
- ARM: vexpress: Set-up shared OPP table instead of individual
  for each CPU (git-fixes).
- commit 5a1c660
* Wed Jan 15 2020 tiwai@suse.de
- blacklist.conf: Add cosmetic entry for drivers/reset/Kconfig
- commit 9ca8239
* Wed Jan 15 2020 hare@suse.de
- acpi: disable deprecated warnings (bsc#1160977).
- commit 509dee8
* Wed Jan 15 2020 bp@suse.de
- Delete patches.suse/ras-cec-disable-cec.patch.
  Now we're behaving the same way as upstream.
- commit 9e8f6dc
* Wed Jan 15 2020 mbrugger@suse.com
- drivers: ipmi: Modify max length of IPMB packet (jsc#SLE-10262).
- drivers: ipmi: Support raw i2c packet in IPMB (jsc#SLE-10262).
- commit 856cc09
* Wed Jan 15 2020 mbrugger@suse.com
- supported.conf: mark ipmb_dev_int as supported (jsc#SLE-10262)
  Also mentioned in  bsc#1119861
- commit 995fffc
* Wed Jan 15 2020 mbrugger@suse.com
- ipmi: fix ipmb_poll()'s return type (jsc#SLE-10262).
- commit 96db5f2
* Wed Jan 15 2020 oneukum@suse.com
- Update
  patches.suse/USB-Fix-Don-t-skip-endpoint-descriptors-with-maxpack.patch
  (bsc#1159811 bsc#1152932).
  Added further bug this fixes
- commit 698a1af
* Wed Jan 15 2020 vbabka@suse.cz
- Refresh
  patches.suse/mm-debug_pagealloc-don-t-rely-on-static-keys-too-ear.patch.
- Update to final upstream version and move to sorted section.
- commit 0b6c359
* Wed Jan 15 2020 tiwai@suse.de
- keys: Fix request_key() cache (git-fixes).
- i2c: fix bus recovery stop mode timing (git-fixes).
- usb: musb: Disable pullup at init (git-fixes).
- USB-PD tcpm: bad warning+size, PPS adapters (git-fixes).
- USB: serial: option: add ZLP support for 0x1bc7/0x9010
  (git-fixes).
- phy/rockchip: inno-hdmi: round clock rate down to closest 1000
  Hz (git-fixes).
- phy: mapphone-mdm6600: Fix uninitialized status value regression
  (git-fixes).
- chardev: Avoid potential use-after-free in 'chrdev_open()'
  (git-fixes).
- staging: rtl8188eu: Add device code for TP-Link TL-WN727N v5.21
  (git-fixes).
- staging: vt6656: set usb_set_intfdata on driver fail
  (git-fixes).
- staging: vt6656: remove bool from vnt_radio_power_on ret
  (git-fixes).
- staging: vt6656: limit reg output to block size (git-fixes).
- staging: vt6656: correct return of vnt_init_registers
  (git-fixes).
- staging: vt6656: Fix non zero logical return of, usb_control_msg
  (git-fixes).
- tty: always relink the port (git-fixes).
- drm/i915: Add Wa_1407352427:icl,ehl (git-fixes).
- drm/i915: Add Wa_1408615072 and Wa_1407596294 to icl,ehl
  (git-fixes).
- gpiolib: acpi: Add honor_wakeup module-option + quirk mechanism
  (git-fixes).
- gpiolib: acpi: Turn dmi_system_id table into a generic quirk
  table (git-fixes).
- Input: add safety guards to input_set_keycode() (git-fixes).
- HID: hid-input: clear unmapped usages (git-fixes).
- HID: Fix slab-out-of-bounds read in hid_field_extract
  (git-fixes).
- tty: link tty and port before configuring it as console
  (git-fixes).
- commit cc6ecc7
* Tue Jan 14 2020 tiwai@suse.de
- drm/i915/gen9: Clear residual context state on context switch
  (CVE-2019-14615 bsc#1160195).
- commit d10cf58
* Tue Jan 14 2020 mbrugger@suse.com
- drivers: ipmi: Support for both IPMB Req and Resp
  (jsc#SLE-10262).
- commit a109ac6
* Tue Jan 14 2020 mbrugger@suse.com
- EDAC, mellanox: Add ECC support for BlueField DDR4
  (jsc#SLE-10262).
- Update config files. Build EDAC_BLUEFIELD as module
- supported.conf: Mark bluefield_edac as supported
- commit bda0819
* Tue Jan 14 2020 mbrugger@suse.com
- platform/mellanox: fix the mlx-bootctl sysfs (jsc#SLE-10262).
- commit c5d7bab
* Tue Jan 14 2020 mbrugger@suse.com
- platform/mellanox: Fix Kconfig indentation (jsc#SLE-10262).
- platform/mellanox: Add bootctl driver for Mellanox BlueField
  Soc (jsc#SLE-10262).
- Update config files: build MLXBF_BOOTCTL as module
- supported.conf: add mlxbf-bootctl
- driver core: add dev_groups to all drivers (jsc#SLE-10262).
- commit 619e678
* Tue Jan 14 2020 mgorman@suse.de
- sched, fair: Allow a small load imbalance between low
  utilisation SD_NUMA domains (bnc#1160896).
- commit fef7d8c
* Tue Jan 14 2020 jeyu@suse.de
- blacklist.conf: Blacklist a11391b6f506 ("scripts: package: mkdebian: add missing rsync dependency")
- commit 4a86d94
* Tue Jan 14 2020 nsaenzjulienne@suse.de
- thermal: Add BCM2711 thermal driver (bsc#1160311).
- Update config files.
- supported.conf: Add bcm2711-thermal
- commit 8743e23
* Tue Jan 14 2020 nsaenzjulienne@suse.de
- scripts/git_sort/git_sort.py: Add thermal tree
- commit b511c78
* Tue Jan 14 2020 trenn@suse.com
- Refresh patches.suse/pstore-backend-autoaction.
- commit 62c0377
* Mon Jan 13 2020 msuchanek@suse.de
- powerpc/pmem: Fix kernel crash due to wrong range value usage
  in flush_dcache_range (bsc#1156395).
- commit 252a29d
* Mon Jan 13 2020 mkubecek@suse.cz
- Update references:
  patches.suse/x86-fpu-Don-t-cache-access-to-fpu_fpregs_owner_ctx.patch
  (add bsc#1158887).
- commit b4c1446
* Mon Jan 13 2020 msuchanek@suse.de
- powerpc/mm: Mark get_slice_psize() & slice_addr_is_low()
  as notrace (bsc#1156395).
- powerpc: Fix __clear_user() with KUAP enabled (bsc#1156395).
- powerpc/fixmap: Use __fix_to_virt() instead of fix_to_virt()
  (bsc#1156395).
- powerpc: Chunk calls to flush_dcache_range in arch_*_memory
  (bsc#1156395).
- commit bb8bcdd
* Mon Jan 13 2020 fdmanana@suse.com
- Btrfs: fix infinite loop during nocow writeback due to race
  (bsc#1160804).
- commit ef1dd9a
* Mon Jan 13 2020 fdmanana@suse.com
- Btrfs: fix removal logic of the tree mod log that leads to
  use-after-free issues (bsc#1160803).
- commit d3f68f5
* Mon Jan 13 2020 mbenes@suse.cz
- tracing: Change offset type to s32 in preempt/irq tracepoints
  (bsc#1160794).
- commit 3de9401
* Mon Jan 13 2020 mbenes@suse.cz
- kernel/trace: Fix do not unregister tracepoints when register
  sched_migrate_task fail (bsc#1160787).
- commit 11f6e8d
* Mon Jan 13 2020 mbenes@suse.cz
- ftrace: Avoid potential division by zero in function profiler
  (bsc#1160784).
- commit 55123bf
* Mon Jan 13 2020 mbenes@suse.cz
- blacklist.conf: b8299d362d08 ("tracing: Have stack tracer compile when MCOUNT_INSN_SIZE is not defined")
  We cannot run into the scenario with our codebase and configs.
- commit 1491d6e
* Mon Jan 13 2020 bp@suse.de
- Update
  patches.suse/x86-fpu-Don-t-cache-access-to-fpu_fpregs_owner_ctx.patch
  (bnc#1151927 5.3.15 CVE-2019-19602).
  Add CVE number.
- commit c2d738c
* Mon Jan 13 2020 tiwai@suse.de
- Move upstreamed qlde patches into sorted section
- commit 8ed9cca
* Mon Jan 13 2020 dkirjanov@suse.com
- patches.suse/0010-netfilter-ipset-avoid-null-deref-when-IPSET_ATTR_LIN.patch:
  (git-fixes).
- patches.suse/0011-netfilter-nft_flow_offload-fix-underflow-in-flowtabl.patch:
  (git-fixes).
- patches.suse/0012-netfilter-bridge-make-sure-to-pull-arp-header-in-br_.patch:
  (git-fixes).
- patches.suse/0009-net-phy-broadcom-Fix-RGMII-delays-configuration-for-.patch:
  (git-fixes).
- patches.suse/0008-net-stmmac-Fix-TSO-descriptor-with-Enhanced-Addressi.patch:
  (git-fixes).
- patches.suse/0007-net-stmmac-selftests-Prevent-false-positives-in-filt.patch:
  (git-fixes).
- patches.suse/0006-net-stmmac-selftests-Fix-L2-Hash-Filter-test.patch:
  (git-fixes).
- patches.suse/0005-net-stmmac-gmac4-Not-all-Unicast-addresses-may-be-av.patch:
  (git-fixes).
- patches.suse/0004-net-stmmac-selftests-Check-if-filtering-is-available.patch:
  (git-fixes).
- patches.suse/0003-net-stmmac-xgmac-Disable-the-Timestamp-interrupt-by-.patch:
  (git-fixes).
- net: stmmac: dwmac-meson8b: Fix signedness bug in probe
  (git-fixes).
- patches.suse/0001-netfilter-nf_tables_offload-avoid-excessive-stack-us.patch:
  (git-fixes).
- commit aa9a965
* Mon Jan 13 2020 palcantara@suse.de
- Delete patches.suse/cifs-fix-set-info.patch.
  Applied to v4.12+, not needed anymore.
- commit b070525
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: hide another #warning'
- commit b0c0990
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: revert "disable bulk moves for now"'
- commit 8d0546c
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: Fix KFD-related kernel oops on Hawaii'
- commit c48f714
* Mon Jan 13 2020 tzimmermann@suse.de
- drm/meson: vclk: use the correct G12A frac max value (bsc#1152489)
- commit 7b38ed0
* Mon Jan 13 2020 tzimmermann@suse.de
- drm/mipi-dbi: fix a loop in debugfs code (bsc#1152489)
- commit d510e3b
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix g4x sprite scaling stride check with GTT remapping'
- commit cf03598
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/dp: Fix dsc bpp calculations, v5.'
- commit 44b95e2
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Mark contents as dirty on a write fault'
- commit fa91ba4
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Bump skl+ max plane width to 5k for linear/x-tiled'
- commit 9d6eb9a
* Mon Jan 13 2020 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Don't mix srcu tag and negative error codes'
- commit e879648
* Mon Jan 13 2020 msuchanek@suse.de
- powerpc/irq: fix stack overflow verification (bsc#1065729).
- commit 3c46adb
* Mon Jan 13 2020 nsaenzjulienne@suse.de
- Delete patches.suse/firmware-arm_sdei-fix-wrong-of_node_put-in-init-function.patch.
  Applied to v5.0, not needed anymore.
- commit a8b4a26
* Mon Jan 13 2020 msuchanek@suse.de
- powerpc/mm: drop #ifdef CONFIG_MMU in is_ioremap_addr()
  (bsc#1065729).
- powerpc/security: Fix debugfs data leak on 32-bit (bsc#1065729).
- powerpc/pkeys: remove unused pkey_allows_readwrite
  (bsc#1065729).
- powerpc/64s/radix: Fix build failure with RADIX_MMU=n
  (bsc#1065729).
- commit 710230e
* Mon Jan 13 2020 tiwai@suse.de
- HID: hidraw, uhid: Always report EPOLLOUT (git-fixes).
- HID: hidraw: Fix returning EPOLLOUT from hidraw_poll
  (git-fixes).
- hidraw: Return EPOLLOUT from hidraw_poll (git-fixes).
- commit be1efe9
* Mon Jan 13 2020 hare@suse.de
- Enable SCSI patches after review
- Refresh patches.suse/fcoe-reduce-max_sectors.
- commit cdd6e89
* Mon Jan 13 2020 hare@suse.de
- Remove disabled NVMe patches after review
- Delete
  patches.suse/nvme-Do-not-remove-namespaces-during-reset.patch.
- Delete
  patches.suse/nvme-flush-scan_work-when-resetting-controller.patch.
- Delete
  patches.suse/nvme-schedule-requeue-whenever-a-LIVE-state-is-enter.patch.
- Delete
  patches.suse/nvme-skip-nvme_update_disk_info-if-the-controller-is.patch.
- commit 0f8d58e
* Mon Jan 13 2020 tiwai@suse.de
- vlan: vlan_changelink() should propagate errors (git-fixes).
- vlan: fix memory leak in vlan_dev_set_egress_priority
  (git-fixes).
- vxlan: fix tos value before xmit (git-fixes).
- commit cb7ad7e
* Mon Jan 13 2020 tiwai@suse.de
- usb: missing parentheses in USE_NEW_SCHEME (git-fixes).
- usb: ohci-da8xx: ensure error return on variable error is set
  (git-fixes).
- usb: musb: fix idling for suspend after disconnect interrupt
  (git-fixes).
- USB: serial: option: add Telit ME910G1 0x110a composition
  (git-fixes).
- usb: chipidea: host: Disable port power only if previously
  enabled (git-fixes).
- usb: dwc3: gadget: Fix request complete check (git-fixes).
- usb: musb: dma: Correct parameter passed to IRQ handler
  (git-fixes).
- USB: core: fix check for duplicate endpoints (git-fixes).
- sbitmap: only queue kyber's wait callback if not already active
  (git-fixes).
- rfkill: Fix incorrect check to avoid NULL pointer dereference
  (git-fixes).
- usb: typec: fusb302: Fix an undefined reference to
  'extcon_get_state' (git-fixes).
- regulator: fix use after free issue (git-fixes).
- spi: spi-ti-qspi: Fix a bug when accessing non default CS
  (git-fixes).
- spi: spi-cavium-thunderx: Add missing pci_release_regions()
  (git-fixes).
- spi: pxa2xx: Add support for Intel Jasper Lake (git-fixes).
- reset: Do not register resource data for missing resets
  (git-fixes).
- USB: dummy-hcd: use usb_urb_dir_in instead of usb_pipein
  (git-fixes).
- commit fb98c64
* Mon Jan 13 2020 tiwai@suse.de
- phy: cpcap-usb: Fix flakey host idling and enumerating of
  devices (git-fixes).
- phy: cpcap-usb: Fix error path when no host driver is loaded
  (git-fixes).
- powercap: intel_rapl: add NULL pointer check to
  rapl_mmio_cpu_online() (git-fixes).
- pstore/ram: Regularize prz label allocation lifetime
  (git-fixes).
- pinctrl: meson: Fix wrong shift value when get drive-strength
  (git-fixes).
- pinctrl: lochnagar: select GPIOLIB (git-fixes).
- net: ethernet: ti: davinci_cpdma: fix warning "device driver
  frees DMA memory with different size" (git-fixes).
- psi: Fix a division error in psi poll() (git-fixes).
- net: ethernet: ti: ale: clean ale tbl on init and intf restart
  (git-fixes).
- net: ethernet: ti: Add dependency for TI_DAVINCI_EMAC
  (git-fixes).
- commit f56a8be
* Mon Jan 13 2020 tiwai@suse.de
- net: usb: lan78xx: fix possible skb leak (git-fixes).
- net: phylink: fix failure to register on x86 systems
  (git-fixes).
- commit dfe6464
* Mon Jan 13 2020 tiwai@suse.de
- i2c: bcm2835: Store pointer to bus clock (git-fixes).
- mtd: onenand: omap2: Pass correct flags for prep_dma_memcpy
  (git-fixes).
- mtd: rawnand: stm32_fmc2: avoid to lock the CPU bus (git-fixes).
- Input: input_event - fix struct padding on sparc64 (git-fixes).
- commit 016c9c2
* Mon Jan 13 2020 tiwai@suse.de
- gpio: zynq: Fix for bug in zynq_gpio_restore_context API
  (git-fixes).
- HID: hiddev: fix mess in hiddev_open() (git-fixes).
- HID: uhid: Fix returning EPOLLOUT from uhid_char_poll
  (git-fixes).
- efi/gop: Fix memory leak in __gop_query32/64() (git-fixes).
- efi/gop: Return EFI_SUCCESS if a usable GOP was found
  (git-fixes).
- efi/gop: Return EFI_NOT_FOUND if there are no usable GOPs
  (git-fixes).
- commit 07644ef
* Mon Jan 13 2020 ptesarik@suse.cz
- Delete patches.suse/s390-sles15-05-01-gmb.patch (unused code).
- commit 396bd69
* Mon Jan 13 2020 tiwai@suse.de
- staging: comedi: adv_pci1710: fix AI channels 16-31 for PCI-1713
  (git-fixes).
- drm/i915/gt: Mark up virtual engine uabi_instance (git-fixes).
- drm/fb-helper: Round up bits_per_pixel if possible (git-fixes).
- drm/sun4i: tcon: Set RGB DCLK min. divider based on hardware
  model (git-fixes).
- drm/dp_mst: correct the shifting in DP_REMOTE_I2C_READ
  (git-fixes).
- cfg80211: fix double-free after changing network namespace
  (git-fixes).
- drm/exynos: gsc: add missed component_del (git-fixes).
- commit 9472262
* Mon Jan 13 2020 tiwai@suse.de
- can: mscan: mscan_rx_poll(): fix rx path lockup when returning
  from polling to irq mode (git-fixes).
- can: gs_usb: gs_usb_probe(): use descriptors of current
  altsetting (git-fixes).
- can: kvaser_usb: fix interface sanity check (git-fixes).
- can: can_dropped_invalid_skb(): ensure an initialized headroom
  in outgoing CAN sk_buffs (git-fixes).
- commit d7cc7b3
* Mon Jan 13 2020 ptesarik@suse.cz
- Delete patches.suse/s390-sles15-bpf-indirect-call.patch (code removed).
- commit 5611b27
* Mon Jan 13 2020 tiwai@suse.de
- ALSA: hda: enable regmap internal locking (git-fixes).
- ALSA: hda/realtek - Add quirk for the bass speaker on Lenovo
  Yoga X1 7th gen (git-fixes).
- ALSA: hda/realtek - Set EAPD control to default for ALC222
  (git-fixes).
- ASoC: topology: Prevent use-after-free in
  snd_soc_get_pcm_runtime() (git-fixes).
- ASoC: fsl_audmix: add missed pm_runtime_disable (git-fixes).
- ASoC: stm32: spdifrx: fix input pin state management
  (git-fixes).
- ASoC: stm32: spdifrx: fix race condition in irq handler
  (git-fixes).
- ASoC: stm32: spdifrx: fix inconsistent lock state (git-fixes).
- ASoC: soc-core: Set dpcm_playback / dpcm_capture (git-fixes).
- ASoC: SOF: fix fault at driver unload after failed probe
  (git-fixes).
- ALSA: usb-audio: Apply the sample rate quirk for Bose Companion
  5 (git-fixes).
- ALSA: hda/realtek - Add new codec supported for ALCS1200A
  (git-fixes).
- commit 2b19b57
* Mon Jan 13 2020 ptesarik@suse.cz
- Delete outdated kmsg patches:
  - patches.suse/s390-sles15sp1-kmsg-update-2019-01-10.patch
  - patches.suse/s390-sles15sp1-kmsg-update-2019-03-08.patch
  - patches.suse/s390-sles15-00-04-04-kmsg-add-VNIC-Characteristics-msg-documentation.patch
- commit 687aa24
* Mon Jan 13 2020 jroedel@suse.de
- iommu/vt-d: Unlink device if failed to add to group
  (bsc#1160752).
- iommu: Remove device link to group on failure (bsc#1160750).
- iommu/vt-d: Fix adding non-PCI devices to Intel IOMMU
  (bsc#1160751).
- commit 0ea0858
* Mon Jan 13 2020 glin@suse.com
- bpf: Fix passing modified ctx to ld/abs/ind instruction
  (bsc#1155518).
- bpf: cgroup: prevent out-of-order release of cgroup bpf
  (bsc#1155518).
- commit 0a9f272
* Mon Jan 13 2020 hare@suse.de
- megaraid_sas: fixup MSIx interrupt setup during resume
  (bsc#1160647).
- commit c59143f
* Mon Jan 13 2020 clin@suse.com
- devpts_pty_kill(): don't bother with d_delete() (jsc#SLE-9943).
- commit 7312898
* Fri Jan 10 2020 ptesarik@suse.cz
- Update config options that were missing on arm64 in commit
  7dd255172f6798f5ec3ab63db55384fbd980125e (bsc#1158776).
- commit 597cc24
* Fri Jan 10 2020 ptesarik@suse.cz
- Set CONFIG_LOG_CPU_MAX_BUF_SHIFT=12 on arm64 (bsc#1158776).
- commit 855731d
* Fri Jan 10 2020 ptesarik@suse.cz
- Enable CONFIG_VMAP_STACK on arm64 (bsc#1158776).
- commit 51f78da
* Fri Jan 10 2020 ptesarik@suse.cz
- Disable CONFIG_PCCARD on arm64 (bsc#1158776).
- commit 04bc6eb
* Fri Jan 10 2020 nsaenzjulienne@suse.de
- supported.conf: Enable mdio-bcm-unimac (bsc#1160310)
  Needed in order for Raspberry Pi 4's ethernet port to work.
- commit 8c2fc6c
* Fri Jan 10 2020 jeyu@suse.de
- export: avoid code duplication in include/linux/export.h
  (jsc#SLE-10158).
- modpost: remove unneeded local variable in contains_namespace()
  (jsc#SLE-10158).
- scripts/nsdeps: support nsdeps for external module builds
  (jsc#SLE-10158).
  Refresh	patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
- modpost: dump missing namespaces into a single modules.nsdeps
  file (jsc#SLE-10158).
  Refresh	patches.suse/supported-flag
- modpost: free ns_deps_buf.p after writing ns_deps files
  (jsc#SLE-10158).
- modpost: do not invoke extra modpost for nsdeps (jsc#SLE-10158).
  Refresh
  patches.suse/supported-flag
  patches.suse/supported-flag-external
- scripts/nsdeps: make sure to pass all module source files to
  spatch (jsc#SLE-10158).
- scripts/nsdeps: use alternative sed delimiter (jsc#SLE-10158).
- symbol namespaces: revert to previous __ksymtab name scheme
  (jsc#SLE-10158).
- modpost: make updating the symbol namespace explicit
  (jsc#SLE-10158).
- modpost: delegate updating namespaces to separate function
  (jsc#SLE-10158).
- doc: move namespaces.rst from kbuild/ to core-api/
  (jsc#SLE-10158).
- nsdeps: make generated patches independent of locale
  (jsc#SLE-10158).
- nsdeps: fix hashbang of scripts/nsdeps (jsc#SLE-10158).
- kbuild: fix build error of 'make nsdeps' in clean tree
  (jsc#SLE-10158).
- module: rename __kstrtab_ns_* to __kstrtabns_* to avoid symbol
  conflict (jsc#SLE-10158).
- modpost: fix broken sym->namespace for external module builds
  (jsc#SLE-10158).
- module: swap the order of symbol.namespace (jsc#SLE-10158).
- scripts: add_namespace: Fix coccicheck failed (jsc#SLE-10158).
- module: Fix link failure due to invalid relocation on namespace
  offset (jsc#SLE-10158).
- usb-storage: export symbols in USB_STORAGE namespace
  (jsc#SLE-10158).
- usb-storage: remove single-use define for debugging
  (jsc#SLE-10158).
- docs: Add documentation for Symbol Namespaces (jsc#SLE-10158).
- scripts: Coccinelle script for namespace dependencies
  (jsc#SLE-10158).
  Refresh
  patches.suse/supported-flag
  patches.suse/supported-flag-external
- modpost: add support for generating namespace dependencies
  (jsc#SLE-10158).
  Refresh	patches.suse/supported-flag
- export: allow definition default namespaces in Makefiles or
  sources (jsc#SLE-10158).
- module: add config option MODULE_ALLOW_MISSING_NAMESPACE_IMPORTS
  (jsc#SLE-10158).
  Refresh configs (add MODULE_ALLOW_MISSING_NAMESPACE_IMPORTS=n).
- modpost: add support for symbol namespaces (jsc#SLE-10158).
  Refresh	patches.suse/livepatch-modpost-ignore-unresolved-symbols.patch
- module: add support for symbol namespaces (jsc#SLE-10158).
- export: explicitly align struct kernel_symbol (jsc#SLE-10158).
- module: support reading multiple values per modinfo tag
  (jsc#SLE-10158).
- commit 4ff553d
* Fri Jan 10 2020 ptesarik@suse.cz
- Enable CONFIG_SECURITY_DMESG_RESTRICT on arm64 (bsc#1158776).
- commit 08863e8
* Fri Jan 10 2020 mkubecek@suse.cz
- supported.conf: fix order of the entries
- commit 8e2c146
* Fri Jan 10 2020 hare@suse.de
- scsi: add 'disable_async_probing' module argument
  (jsc#SLE-11117,bsc#1156954).
- drivers/base: implement dev_enable_async_probe()
  (jsc#SLE-11117,bsc#1156954).
- commit cbc6624
* Fri Jan 10 2020 jlee@suse.com
- Update config files. (bsc#1160067)
  Disable CONFIG_KEYS_REQUEST_CACHE.
  The CONFIG_KEYS_REQUEST_CACHE adds a cache in task_struct for the result
  of request_key(). But it causes kernel NULL pointer dereference problem
  when we run the long-run testing by the request_key03 test case in LTP.
  The issue can be reproduced on v5.3 mainline kernel and later, even on
  v5.5-rc kernel. The CONFIG_KEYS_REQUEST_CACHE be introduced by
  7743c48e54ee9be9c patch since v5.3 kernel:
  commit 7743c48e54ee9be9c799cbf3b8e3e9f2b8d19e72
  Author: David Howells <dhowells@redhat.com>
  Date:   Wed Jun 19 16:10:15 2019 +0100
    keys: Cache result of request_key*() temporarily in task_struct
  Before this issue be fixed on kernel upstream, Let's disable the
  CONFIG_KEYS_REQUEST_CACHE function on SLE15-SP2 on all architecture.
- commit f6f29a6
* Thu Jan  9 2020 lduncan@suse.com
- scsi: libsas: stop discovering if oob mode is disconnected
  (CVE-2019-19965 bsc#1159911).
- commit 0bb4d37
* Thu Jan  9 2020 tiwai@suse.de
- serial: sprd: Add clearing break interrupt operation
  (git-fixes).
- staging/wlan-ng: add CRC32 dependency in Kconfig (git-fixes).
- usb: gadget: fix wrong endpoint desc (git-fixes).
- selftests: breakpoints: Fix a typo of function name (git-fixes).
- commit 1096b35
* Thu Jan  9 2020 tiwai@suse.de
- samples/seccomp: Zero out members based on seccomp_notif_sizes
  (git-fixes).
- rseq/selftests: Fix: Namespace gettid() for compatibility with
  glibc 2.30 (git-fixes).
- samples/trace_printk: Wait for IRQ work to finish (git-fixes).
- samples: pktgen: fix proc_cmd command result check logic
  (git-fixes).
- commit 168e639
* Thu Jan  9 2020 tiwai@suse.de
- rpmsg: glink: Free pending deferred work on remove (git-fixes).
- rpmsg: glink: Don't send pending rx_done during remove
  (git-fixes).
- rpmsg: glink: Fix rpmsg_register_device err handling
  (git-fixes).
- rpmsg: glink: Put an extra reference during cleanup (git-fixes).
- rpmsg: glink: Fix use after free in open_ack TIMEOUT case
  (git-fixes).
- rpmsg: glink: Fix reuse intents memory leak issue (git-fixes).
- rpmsg: glink: Set tail pointer to 0 at end of FIFO (git-fixes).
- commit eefcc8c
* Thu Jan  9 2020 tiwai@suse.de
- ptp: fix the race between the release of ptp_clock and cdev
  (git-fixes).
- phy: renesas: phy-rcar-gen2: Fix the array off by one warning
  (git-fixes).
- PM / hibernate: memory_bm_find_bit(): Tighten node optimisation
  (git-fixes).
- commit 8fdacf8
* Thu Jan  9 2020 ptesarik@suse.cz
- s390/qeth: fix initialization on old HW (bsc#1160228
  LTC#183076).
- commit 4565d24
* Thu Jan  9 2020 tiwai@suse.de
- media: pulse8-cec: fix lost cec_transmit_attempt_done() call
  (git-fixes).
- media: cec: avoid decrementing transmit_queue_sz if it is 0
  (git-fixes).
- media: cec: CEC 2.0-only bcast messages were ignored
  (git-fixes).
- net: phy: aquantia: add suspend / resume ops for AQR105
  (git-fixes).
- gpiolib: fix up emulated open drain outputs (git-fixes).
- net: usb: lan78xx: Fix error message format specifier
  (git-fixes).
- net: usb: lan78xx: Fix suspend/resume PHY register access error
  (git-fixes).
- iio: st_accel: Fix unused variable warning (git-fixes).
- net: phy: dp83867: enable robust auto-mdix (git-fixes).
- commit 9ace80b
* Thu Jan  9 2020 ptesarik@suse.cz
- s390/qeth: fix dangling IO buffers after halt/clear (bsc#1160227
  LTC#183077).
- commit 889634e
* Thu Jan  9 2020 tiwai@suse.de
- drm/amdgpu/smu: add metrics table lock for vega20 (v2)
  (git-fixes).
- drm/amdgpu/smu: add metrics table lock for navi (v2)
  (git-fixes).
- drm/amdgpu/smu: add metrics table lock (git-fixes).
- commit c292740
* Thu Jan  9 2020 tiwai@suse.de
- drm/amd/display: Reset steer fifo before unblanking the stream
  (git-fixes).
- drm/amd/display: Change the delay time before enabling FEC
  (git-fixes).
- drm/amd/display: Fixed kernel panic when booting with DP-to-HDMI
  dongle (git-fixes).
- drm/amdgpu: add cache flush workaround to gfx8 emit_fence
  (git-fixes).
- drm/amdgpu: add check before enabling/disabling broadcast mode
  (git-fixes).
- drm/nouveau/kms/nv50-: fix panel scaling (git-fixes).
- drm/nouveau: Fix drm-core using atomic code-paths on pre-nv50
  hardware (git-fixes).
- drm/nouveau: Move the declaration of struct nouveau_conn_atom
  up a bit (git-fixes).
- drm/i915/execlists: Fix annotation for decoupling virtual
  request (git-fixes).
- ath9k_htc: Discard undersized packets (git-fixes).
- ath9k_htc: Modify byte order for an error message (git-fixes).
- commit bd77fbc
* Thu Jan  9 2020 tiwai@suse.de
- ata: ahci_brcm: Add missing clock management during recovery
  (git-fixes).
- ata: ahci_brcm: BCM7425 AHCI requires AHCI_HFLAG_DELAY_ENGINE
  (git-fixes).
- ata: ahci_brcm: Fix AHCI resources management (git-fixes).
- ata: libahci_platform: Export again
  ahci_platform_<en/dis>able_phys() (git-fixes).
- commit 02d31e9
* Thu Jan  9 2020 mbenes@suse.cz
- s390/ftrace: save traced function caller (jsc#SLE-11050).
- commit df15586
* Thu Jan  9 2020 mbenes@suse.cz
- s390/unwind: stop gracefully at user mode pt_regs in irq stack
  (jsc#SLE-11050).
- commit cb8ad0f
* Thu Jan  9 2020 msuchanek@suse.de
- drivers/base/memory.c: cache blocks in radix tree to accelerate
  lookup (bsc#1159955 ltc#182993).
- commit a6f9349
* Wed Jan  8 2020 ailiopoulos@suse.com
- xfs: fix missed wakeup on l_flush_wait (git-fixes).
- commit b398e15
* Wed Jan  8 2020 ailiopoulos@suse.com
- iomap: iomap that extends beyond EOF should be marked dirty
  (git-fixes).
- commit 1ec5fb2
* Wed Jan  8 2020 ailiopoulos@suse.com
- xfs: use bitops interface for buf log item AIL flag check
  (git-fixes).
- commit 245f9d1
* Wed Jan  8 2020 ailiopoulos@suse.com
- xfs: change the seconds fields in xfs_bulkstat to signed
  (git-fixes).
- commit 225e4fb
* Wed Jan  8 2020 tiwai@suse.de
- tpm: Handle negative priv->response_len in tpm_common_read()
  (git-fixes).
- commit f84106a
* Wed Jan  8 2020 nsaenzjulienne@suse.de
- supported.conf: enable Raspberry Pi cpufreq driver (bsc#1160461).
  These drivers are required in order to enable CPU frequency scaling on
  the Raspberry Pi family of boards.
- commit 248458d
* Wed Jan  8 2020 tiwai@suse.de
- libertas: Fix two buffer overflows at parsing bss descriptor
  (CVE-2019-14896 bsc#1157157 CVE-2019-14897 bsc#1157155).
- commit 7117d1b
* Wed Jan  8 2020 yousaf.kaukab@suse.com
- PCI: mobiveil: Add PCIe Gen4 RC driver for NXP Layerscape SoCs (bsc#1161495).
- dt-bindings: PCI: Add NXP Layerscape SoCs PCIe Gen4 controller (bsc#1161495).
- PCI: mobiveil: Add 8-bit and 16-bit CSR register accessors (bsc#1161495).
- PCI: mobiveil: Make mobiveil_host_init() can be used to re-init host (bsc#1161495).
- PCI: mobiveil: Add callback function for link up check (bsc#1161495).
- PCI: mobiveil: Add callback function for interrupt initialization (bsc#1161495).
- PCI: mobiveil: Modularize the Mobiveil PCIe Host Bridge IP driver (bsc#1161495).
- PCI: mobiveil: Collect the interrupt related operations into a routine (bsc#1161495).
- PCI: mobiveil: Move the host initialization into a routine (bsc#1161495).
- PCI: mobiveil: Re-abstract the private structure (bsc#1161495).
- commit 3a1031d
* Wed Jan  8 2020 yousaf.kaukab@suse.com
- PCI: mobiveil: Fix csr_read()/write() build issue (bsc#1161495).
- commit 201a79d
* Wed Jan  8 2020 yousaf.kaukab@suse.com
- arm64: PCI: mobiveil: remove patchset v8
  References: bsc#1161495
  Prepare to backport patchset v9
- Delete
  patches.suse/PCI-mobiveil-Add-8-bit-and-16-bit-CSR-register-acces.patch.
- Delete
  patches.suse/PCI-mobiveil-Add-PCIe-Gen4-RC-driver-for-NXP-Layersc.patch.
- Delete
  patches.suse/PCI-mobiveil-Make-mobiveil_host_init-can-be-used-to-.patch.
- Delete
  patches.suse/PCI-mobiveil-Refactor-Mobiveil-PCIe-Host-Bridge-IP-d.patch.
- Refresh
  patches.suse/pci-brcmstb-add-broadcom-stb-pcie-host-controller-driver.patch.
- Refresh
  config/arm64/default
- commit 85f695c
* Wed Jan  8 2020 jroedel@suse.de
- iommu: Don't use sme_active() in generic code (bsc#1160320).
- commit c7574c0
* Wed Jan  8 2020 fdmanana@suse.com
- Btrfs: fix block group remaining RO forever after error during
  device replace (bsc#1160442).
- commit 3e5a343
* Wed Jan  8 2020 jroedel@suse.de
- Update patches.suse/iommu-vt-d-fix-dmar-pte-read-access-not-set-error
  (bsc#1160141, bsc#1159594, bsc#1159592).
- commit 0cb2587
* Wed Jan  8 2020 jroedel@suse.de
- Documentation: Update Documentation for iommu.passthrough
  (bsc#1160320).
- iommu: Disable passthrough mode when SME is active
  (bsc#1160320).
- iommu: Set default domain type at runtime (bsc#1160320).
- iommu: Print default domain type on boot (bsc#1160320).
- ia64: Get rid of iommu_pass_through (bsc#1160320).
- x86/dma: Get rid of iommu_pass_through (bsc#1160320).
- iommu/vt-d: Request passthrough mode from IOMMU core
  (bsc#1160320).
- iommu/amd: Request passthrough mode from IOMMU core
  (bsc#1160320).
- iommu: Use Functions to set default domain type in
  iommu_set_def_domain_type() (bsc#1160320).
- iommu: Add helpers to set/get default domain type (bsc#1160320).
- iommu: Remember when default domain type was set on kernel
  command line (bsc#1160320).
- commit fbe5ae4
* Wed Jan  8 2020 mkubecek@suse.cz
- Disable patches.suse/Documentation-ABI-mark-sys-kernel-fadump_-sysfs-file.patch
  For some reason, these changes result in "make htmldocs" stuck indefinitely
  so that kernel-docs fails to build. Whether it's a sphinx bug or some ReST
  formatting problem (or combination of both), more time will be needed to
  find a proper solution. As the offending patch touches only documentation,
  disable it for now so that we do not block Beta2 submission.
- commit ab61608
* Wed Jan  8 2020 tiwai@suse.de
- drm/sun4i: hdmi: Remove duplicate cleanup calls (git-fixes).
- drm/i915/gvt: Pin vgpu dma address before using (git-fixes).
- drm/i915/gvt: use vgpu lock for active state setting
  (git-fixes).
- drm/i915: Fix pid leak with banned clients (git-fixes).
- drm/i915/gem: Keep request alive while attaching fences
  (git-fixes).
- drm/i915: Fix WARN_ON condition for cursor plane ddb allocation
  (git-fixes).
- drm/i915: Set fence_work.ops before dma_fence_init (git-fixes).
- drm/i915/fbc: Disable fbc by default on all glk+ (git-fixes).
- drm/radeon: fix r1xx/r2xx register checker for POT textures
  (git-fixes).
- drm/amd/display: re-enable wait in pipelock, but add timeout
  (git-fixes).
- drm: limit to INT_MAX in create_blob ioctl (git-fixes).
- drm/amdgpu/gfx10: explicitly wait for cp idle after halt/unhalt
  (git-fixes).
- drm/amdgpu: Avoid accidental thread reactivation (git-fixes).
- drm/amdgpu: fix potential double drop fence reference
  (git-fixes).
- drm/amdgpu: disallow direct upload save restore list from gfx
  driver (git-fixes).
- drm/amd/display: correctly populate dpp refclk in fpga
  (git-fixes).
- drm/tegra: sor: Use correct SOR index on Tegra210 (git-fixes).
- drm/nouveau: Don't grab runtime PM refs for HPD IRQs
  (git-fixes).
- drm/gma500: fix memory disclosures due to uninitialized bytes
  (git-fixes).
- drm/bridge: dw-hdmi: Restore audio when setting a mode
  (git-fixes).
- drm/drm_vblank: Change EINVAL by the correct errno (git-fixes).
- drm/amdgpu: fix amdgpu trace event print string format error
  (git-fixes).
- drm/amd/powerplay: avoid disabling ECC if RAS is enabled for
  VEGA20 (git-fixes).
- drm/amd/display: Fix dongle_caps containing stale information
  (git-fixes).
- drm/amd/display: Program DWB watermarks from correct state
  (git-fixes).
- drm/amd/display: wait for set pipe mcp command completion
  (git-fixes).
- drm/amd/display: Properly round nominal frequency for SPD
  (git-fixes).
- drm/amdkfd: Fix MQD size calculation (git-fixes).
- drm/amdgpu: fix uninitialized variable pasid_mapping_needed
  (git-fixes).
- drm/amd/powerplay: A workaround to GPU RESET on APU (git-fixes).
- drm/amdkfd: fix a potential NULL pointer dereference (v2)
  (git-fixes).
- drm/amd/display: Set number of pipes to 1 if the second pipe
  was disabled (git-fixes).
- drm/amd/display: Handle virtual signal type in disable_link()
  (git-fixes).
- drm/amdgpu: grab the id mgr lock while accessing passid_mapping
  (git-fixes).
- drm/amdgpu/sriov: add ring_stop before ring_create in psp v11
  code (git-fixes).
- drm/amd/display: verify stream link before link test
  (git-fixes).
- drm/bridge: dw-hdmi: Refuse DDC/CI transfers on the internal
  I2C controller (git-fixes).
- drm/sun4i: dsi: Fix TCON DRQ set bits (git-fixes).
- drm/komeda: Workaround for broken FLIP_COMPLETE timestamps
  (git-fixes).
- drm/bridge: analogix-anx78xx: silence -EPROBE_DEFER warnings
  (git-fixes).
- drm: exynos: exynos_hdmi: use cec_notifier_conn_(un)register
  (git-fixes).
- drm/vc4/vc4_hdmi: fill in connector info (git-fixes).
- drm/panel: Add missing drm_panel_init() in panel drivers
  (git-fixes).
- commit a4a0b31
* Wed Jan  8 2020 tbogendoerfer@suse.de
- net/sched: add delete_empty() to filters and use it in
  cls_flower (bsc#1154353).
- tcp: Fix highest_sack and highest_sack_seq (bsc#1154353).
- cxgb4/cxgb4vf: fix flow control display for auto negotiation
  (jsc#SLE-8389).
- mlxsw: spectrum: Use dedicated policer for VRRP packets
  (bsc#1154488).
- mlxsw: spectrum_router: Skip loopback RIFs during MAC validation
  (bsc#1154488).
- net/sched: act_mirred: Pull mac prior redir to non
  mac_header_xmit device (bsc#1154353).
- net_sched: sch_fq: properly set sk->sk_pacing_status
  (bsc#1154353).
- bnx2x: Fix accounting of vlan resources among the PFs
  (bsc#1154395).
- bnx2x: Use appropriate define for vlan credit (bsc#1154395).
- net/mlxfw: Fix out-of-memory error in mfa2 flash burning
  (bsc#1154488).
- sctp: fix err handling of stream initialization (bsc#1154353).
- udp: fix integer overflow while computing available space in
  sk_rcvbuf (bsc#1154353).
- sfc: Include XDP packet headroom in buffer step size
  (jsc#SLE-8314).
- sfc: fix channel allocation with brute force (jsc#SLE-8314).
- net: dst: Force 4-byte alignment of dst_metrics (bsc#1154353).
- net: phy: ensure that phy IDs are correctly typed (bsc#1154353).
- qede: Disable hardware gro when xdp prog is installed
  (jsc#SLE-8401).
- net: ena: fix issues in setting interrupt moderation params
  in ethtool (bsc#1154492).
- net: ena: fix default tx interrupt moderation interval
  (bsc#1154492).
- net: hisilicon: Fix a BUG trigered by wrong bytes_compl
  (bsc#1154353).
- cxgb4: fix refcount init for TC-MQPRIO offload (jsc#SLE-8389).
- net/sched: cls_u32: fix refcount leak in the error path of
  u32_change() (bsc#1154353).
- net, sysctl: Fix compiler warning when only cBPF is present
  (bsc#1154353).
- net/ixgbe: Fix concurrency issues between config flow and XSK
  (jsc#SLE-7979 jsc#SLE-7981).
- net/i40e: Fix concurrency issues between config flow and XSK
  (jsc#SLE-8025).
- net/mlx5e: Fix concurrency issues between config flow and XSK
  (jsc#SLE-8464).
- xsk: Add rcu_read_lock around the XSK wakeup (bsc#1154353).
- net-sysfs: Call dev_hold always in rx_queue_add_kobject
  (bsc#1154353).
- nfp: flower: fix stats id allocation (bsc#1154353).
- net: fix kernel-doc warning in <linux/netdevice.h>
  (bsc#1154353).
- net: annotate lockless accesses to sk->sk_pacing_shift
  (bsc#1154353).
- net: qlogic: Fix error paths in ql_alloc_large_buffers()
  (bsc#1154353).
- sctp: fix memleak on err handling of stream initialization
  (bsc#1154353).
- cxgb4: Fix kernel panic while accessing sge_info (jsc#SLE-8389).
- net: phylink: fix interface passed to mac_link_up (bsc#1154353).
- bnx2x: Fix logic to get total no. of PFs per engine
  (bsc#1154395).
- bnx2x: Do not handle requests from VFs after parity
  (bsc#1154395).
- tcp: refine rule to allow EPOLLOUT generation under mem pressure
  (bsc#1154353).
- tcp: refine tcp_write_queue_empty() implementation
  (bsc#1154353).
- tcp: do not send empty skb from tcp_write_xmit() (bsc#1154353).
- tcp/dccp: fix possible race __inet_lookup_established()
  (bsc#1154353).
- ipv6/addrconf: only check invalid header values when
  NETLINK_F_STRICT_CHK is set (bsc#1154353).
- bnxt: apply computed clamp value for coalece parameter
  (jsc#SLE-8371 bsc#1153274).
- qede: Fix multicast mac configuration (jsc#SLE-8401).
- net: ena: fix napi handler misbehavior when the napi budget
  is zero (bsc#1154492).
- bnxt_en: Add missing devlink health reporters for VFs
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix the logic that creates the health reporters
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Remove unnecessary NULL checks for fw_health
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix bp->fw_health allocation and free logic
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Return error if FW returns more data than dump length
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Free context memory in the open path if firmware has
  been reset (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix MSIX request logic for RDMA driver (jsc#SLE-8371
  bsc#1153274).
- af_packet: set defaule value for tmo (bsc#1154353).
- mlxsw: spectrum_router: Remove unlikely user-triggerable warning
  (bsc#1154488).
- bonding: fix bond_neigh_init() (bsc#1154353).
- neighbour: remove neigh_cleanup() method (bsc#1154353).
- IB/mlx5: Fix device memory flows (jsc#SLE-8446).
- IB/core: Introduce rdma_user_mmap_entry_insert_range() API
  (jsc#SLE-8449).
- IB/mlx5: Fix steering rule of drop and count (jsc#SLE-8446).
- IB/mlx4: Follow mirror sequence of device add during device
  removal (jsc#SLE-8461).
- RDMA/counter: Prevent auto-binding a QP which are not tracked
  with res (jsc#SLE-8449).
- rxe: correctly calculate iCRC for unaligned payloads
  (jsc#SLE-8449).
- RDMA/cma: add missed unregister_pernet_subsys in init failure
  (jsc#SLE-8449).
- net: make socket read/write_iter() honor IOCB_NOWAIT
  (bsc#1154353).
- commit ad46b33
* Tue Jan  7 2020 dwagner@suse.de
- scsi: qla2xxx: Use get_unaligned_*() instead of open-coding
  these functions (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix the endianness of the qla82xx_get_fw_size()
  return type (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Improve readability of the code that handles
  qla_flt_header (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Update driver version to 10.01.00.22-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix mtcp dump collection failure (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix stuck session in GNL (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix RIDA Format-2 (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Consolidate fabric scan (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Correct fcport flags handling (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix stuck login session using prli_pend_timer
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use common routine to free fcport struct
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add D-Port Diagnostic reason explanation logs
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix update_fcport for current_topology
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Cleanup unused async_logout_done (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add a shadow variable to hold disc_state history
  of fcport (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix fabric scan hang (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Remove defer flag to indicate immeadiate port
  loss (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix qla2x00_request_irqs() for MSI (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: unregister ports after GPN_FT failure
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: fix rports not being mark as lost in sync fabric
  scan (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- commit c04a5b0
* Tue Jan  7 2020 msuchanek@suse.de
- Make lzo the default pstore compression method (bsc#1159986).
  Pstore has compression enabled, pstore is built-in, pstore default
  compression is deflate, deflate is modular -> pstore initialization
  fails on boot. Switch default compression to lzo which is built-in and
  the only built-in method on SLE15.
- commit f26faac
* Tue Jan  7 2020 tiwai@suse.de
- watchdog: tqmx86_wdt: Fix build error (git-fixes).
- watchdog: Fix the race between the release of watchdog_core_data
  and cdev (git-fixes).
- commit 0917c4e
* Tue Jan  7 2020 tiwai@suse.de
- tty/serial: atmel: fix out of range clock divider handling
  (git-fixes).
- tty: serial: msm_serial: Fix lockup for sysrq and oops
  (git-fixes).
- usb: xhci: Fix build warning seen with CONFIG_PM=n (git-fixes).
- usbip: Fix error path of vhci_recv_ret_submit() (git-fixes).
- USB: EHCI: Do not return -EPIPE when hub is disconnected
  (git-fixes).
- xhci-pci: Allow host runtime PM as default also for Intel Ice
  Lake xHCI (git-fixes).
- usb: usbfs: Suppress problematic bind and unbind uevents
  (git-fixes).
- usb: renesas_usbhs: add suspend event support in gadget mode
  (git-fixes).
- commit 5e7bf42
* Tue Jan  7 2020 tiwai@suse.de
- spi: st-ssc4: add missed pm_runtime_disable (git-fixes).
- spi: tegra20-slink: add missed clk_unprepare (git-fixes).
- spi: pxa2xx: Add missed security checks (git-fixes).
- spi: img-spfi: fix potential double release (git-fixes).
- spi: sprd: adi: Add missing lock protection when rebooting
  (git-fixes).
- spi: sifive: disable clk when probe fails and remove
  (git-fixes).
- spi: Add call to spi_slave_abort() function when spidev driver
  is released (git-fixes).
- commit d4280ba
* Tue Jan  7 2020 tiwai@suse.de
- soundwire: intel: fix PDI/stream mapping for Bulk (git-fixes).
- commit befdf94
* Tue Jan  7 2020 tiwai@suse.de
- staging: rtl8188eu: fix possible null dereference (git-fixes).
- staging: rtl8192u: fix multiple memory leaks on error path
  (git-fixes).
- rtlwifi: fix memory leak in rtl92c_set_fw_rsvdpagepkt()
  (git-fixes).
- rtl8xxxu: fix RTL8723BU connection failure issue after warm
  reboot (git-fixes).
- commit 70d7407
* Tue Jan  7 2020 tiwai@suse.de
- regulator: bd70528: Remove .set_ramp_delay for bd70528_ldo_ops
  (git-fixes).
- regulator: axp20x: Fix axp20x_set_ramp_delay (git-fixes).
- regulator: axp20x: Fix AXP22x ELDO2 regulator enable bitmask
  (git-fixes).
- rtc: sun6i: Add support for RTC clocks on R40 (git-fixes).
- riscv: ftrace: correct the condition logic in function graph
  tracer (git-fixes).
- regulator: max8907: Fix the usage of uninitialized variable
  in max8907_regulator_probe() (git-fixes).
- commit d2746d5
* Tue Jan  7 2020 tiwai@suse.de
- qtnfmac: fix invalid channel information output (git-fixes).
- qtnfmac: fix debugfs support for multiple cards (git-fixes).
- qtnfmac: fix using skb after free (git-fixes).
- commit 339b79a
* Tue Jan  7 2020 tiwai@suse.de
- pstore/ram: Write new dumps to start of recycled zones
  (git-fixes).
- pstore/ram: Fix error-path memory leak in persistent_ram_new()
  callers (git-fixes).
- commit a2e4095
* Tue Jan  7 2020 tiwai@suse.de
- platform/x86: pmc_atom: Add Siemens CONNECT X300 to
  critclk_systems DMI table (git-fixes).
- platform/x86: hp-wmi: Make buffer for HPWMI_FEATURE2_QUERY
  128 bytes (git-fixes).
- pinctrl: amd: fix __iomem annotation in amd_gpio_irq_handler()
  (git-fixes).
- pinctrl: sh-pfc: sh7734: Fix duplicate TCLK1_B (git-fixes).
- pinctrl: devicetree: Avoid taking direct reference to device
  name string (git-fixes).
- power: supply: cpcap-battery: Check voltage before
  orderly_poweroff (git-fixes).
- commit d3f5c31
* Tue Jan  7 2020 tiwai@suse.de
- mod_devicetable: fix PHY module format (git-fixes).
- PCI/PM: Always return devices to D0 when thawing (git-fixes).
- parport: load lowlevel driver if ports not found (git-fixes).
- commit 22bfd6f
* Tue Jan  7 2020 tiwai@suse.de
- mmc: sdhci-of-esdhc: re-implement erratum A-009204 workaround
  (git-fixes).
- mmc: sdhci: Add a quirk for broken command queuing (git-fixes).
- mmc: sdhci: Workaround broken command queuing on Intel GLK
  (git-fixes).
- mmc: sdhci-of-esdhc: fix P2020 errata handling (git-fixes).
- mmc: sdhci: Update the tuning failed messages to pr_debug level
  (git-fixes).
- mmc: sdhci-of-esdhc: Revert "mmc: sdhci-of-esdhc: add erratum
  A-009204 support" (git-fixes).
- mmc: mediatek: fix CMD_TA to 2 for MT8173 HS200/HS400 mode
  (git-fixes).
- mmc: sdhci-msm: Correct the offset and value for DDR_CONFIG
  register (git-fixes).
- misc: fastrpc: fix memory leak from miscdev->name (git-fixes).
- mmc: tmio: Add MMC_CAP_ERASE to allow erase/discard/trim
  requests (git-fixes).
- mmc: core: Drop check for mmc_card_is_removable() in
  mmc_rescan() (git-fixes).
- mmc: block: Add CMD13 polling for MMC IOCTLS with R1B response
  (git-fixes).
- mmc: block: Make card_busy_detect() a bit more generic
  (git-fixes).
- commit 028a842
* Tue Jan  7 2020 tiwai@suse.de
- media: cec: check 'transmit_in_progress', not 'transmitting'
  (git-fixes).
- media: vicodec: media_device_cleanup was called too early
  (git-fixes).
- media: vim2m: media_device_cleanup was called too early
  (git-fixes).
- media: v4l2-ctrl: Lock main_hdl on operations of requests_queued
  (git-fixes).
- media: si470x-i2c: add missed operations in remove (git-fixes).
- media: pvrusb2: Fix oops on tear-down when radio support is
  not present (git-fixes).
- media: vivid: media_device_cleanup was called too early
  (git-fixes).
- media: staging/imx: Use a shorter name for driver (git-fixes).
- commit 0e40744
* Tue Jan  7 2020 tiwai@suse.de
- media: v4l2-core: fix touch support in v4l_g_fmt (git-fixes).
- media: smiapp: Register sensor after enabling runtime PM on
  the device (git-fixes).
- media: imx7-mipi-csis: Add a check for devm_regulator_get
  (git-fixes).
- media: st-mipid02: add a check for devm_gpiod_get_optional
  (git-fixes).
- media: ad5820: Define entity function (git-fixes).
- media: ov5640: Make 2592x1944 mode only available at 15 fps
  (git-fixes).
- media: ov6650: Fix stored frame interval not in sync with
  hardware (git-fixes).
- media: aspeed: clear garbage interrupts (git-fixes).
- media: aspeed: set hsync and vsync polarities to normal before
  starting mode detection (git-fixes).
- commit c8cb4cb
* Tue Jan  7 2020 tiwai@suse.de
- media: cedrus: Fix undefined shift with a SHIFT_AND_MASK_BITS
  macro (git-fixes).
- commit 08552bc
* Tue Jan  7 2020 tiwai@suse.de
- media: ti-vpe: vpe: ensure buffers are cleaned up properly in
  abort cases (git-fixes).
- media: ti-vpe: vpe: fix a v4l2-compliance failure about frame
  sequence number (git-fixes).
- media: ti-vpe: vpe: fix a v4l2-compliance failure about invalid
  sizeimage (git-fixes).
- media: ti-vpe: vpe: Make sure YUYV is set as default format
  (git-fixes).
- media: ti-vpe: vpe: fix a v4l2-compliance warning about invalid
  pixel format (git-fixes).
- media: ti-vpe: vpe: fix a v4l2-compliance failure causing a
  kernel panic (git-fixes).
- media: cx88: Fix some error handling path in 'cx8800_initdev()'
  (git-fixes).
- commit b475671
* Tue Jan  7 2020 tiwai@suse.de
- media: cec-funcs.h: add status_req checks (git-fixes).
- media: flexcop-usb: fix NULL-ptr deref in
  flexcop_usb_transfer_init() (git-fixes).
- media: venus: Fix occasionally failures to suspend (git-fixes).
- media: venus: core: Fix msm8996 frequency table (git-fixes).
- media: i2c: ov2659: Fix missing 720p register config
  (git-fixes).
- media: i2c: ov2659: fix s_stream return value (git-fixes).
- media: cedrus: fill in bus_info for media device (git-fixes).
- media: am437x-vpfe: Setting STD to current value is not an error
  (git-fixes).
- media: vimc: Fix gpf in rmmod path when stream is active
  (git-fixes).
- commit 3bdee4e
* Tue Jan  7 2020 tiwai@suse.de
- mac80211: fix TID field in monitor mode transmit (git-fixes).
- mailbox: imx: Clear the right interrupts at shutdown
  (git-fixes).
- mailbox: imx: Fix Tx doorbell shutdown path (git-fixes).
- commit 8428c64
* Tue Jan  7 2020 tiwai@suse.de
- libata: Fix retrieving of active qcs (git-fixes).
- libata: Ensure ata_port probe has completed before detach
  (git-fixes).
- Revert "libata, freezer: avoid block device removal while
  system is frozen" (git-fixes).
- commit aa59034
* Tue Jan  7 2020 tiwai@suse.de
- leds: an30259a: add a check for devm_regmap_init_i2c
  (git-fixes).
- leds: tlc591xx: update the maximum brightness (git-fixes).
- leds: lm3692x: Handle failure to probe the regulator
  (git-fixes).
- iwlwifi: mvm: fix unaligned read of rx_pkt_status (git-fixes).
- commit 03687f9
* Tue Jan  7 2020 tiwai@suse.de
- irqchip: ingenic: Error out if IRQ domain creation failed
  (git-fixes).
- irqchip: Place CONFIG_SIFIVE_PLIC into the menu (git-fixes).
- irqchip/irq-bcm7038-l1: Enable parent IRQ if necessary
  (git-fixes).
- commit b53401c
* Tue Jan  7 2020 tiwai@suse.de
- ipmi: Don't allow device module unload when in use (git-fixes).
- commit 65e80e2
* Tue Jan  7 2020 tiwai@suse.de
- intel_th: Fix freeing IRQs (git-fixes).
- intel_th: pci: Add Elkhart Lake SOC support (git-fixes).
- intel_th: pci: Add Comet Lake PCH-V support (git-fixes).
- commit d2e079e
* Tue Jan  7 2020 tiwai@suse.de
- Input: ili210x - handle errors from input_mt_init_slots()
  (git-fixes).
- Input: st1232 - do not reset the chip too early (git-fixes).
- Input: atmel_mxt_ts - disable IRQ across suspend (git-fixes).
- commit 6ce709b
* Tue Jan  7 2020 tiwai@suse.de
- iio: dac: ad5446: Add support for new AD5600 DAC (git-fixes).
- iio: dln2-adc: fix iio_triggered_buffer_postenable() position
  (git-fixes).
- staging: iio: ad9834: add a check for devm_clk_get (git-fixes).
- iio: adc: max1027: Reset the device at probe time (git-fixes).
- iio: max31856: add missing of_node and parent references to
  iio_dev (git-fixes).
- iio: light: bh1750: Resolve compiler warning and make code
  more readable (git-fixes).
- commit 0b7fbd3
* Tue Jan  7 2020 tiwai@suse.de
- HID: i2c-hid: Send power-on command after reset (git-fixes).
- commit bc0c11b
* Tue Jan  7 2020 tiwai@suse.de
- HID: i2c-hid: Remove runtime power management (git-fixes).
- Refresh
  patches.suse/HID-i2c-hid-Reset-ALPS-touchpads-on-resume.patch.
- commit 8f8c13b
* Tue Jan  7 2020 tiwai@suse.de
- HID: logitech-hidpp: Silence intermittent get_battery_capacity
  errors (git-fixes).
- HID: Improve Windows Precision Touchpad detection (git-fixes).
- HID: rmi: Check that the RMI_STARTED bit is set before
  unregistering the RMI transport device (git-fixes).
- HID: i2c-hid: fix no irq after reset on raydium 3118
  (git-fixes).
- HID: quirks: Add quirk for HP MSU1465 PIXART OEM mouse
  (git-fixes).
- commit 6c8d52d
* Tue Jan  7 2020 tiwai@suse.de
- gpu: host1x: Allocate gather copy for host1x (git-fixes).
- commit fa0dc6d
* Tue Jan  7 2020 tiwai@suse.de
- gpio: xtensa: fix driver build (git-fixes).
- gpio: Fix error message on out-of-range GPIO in lookup table
  (git-fixes).
- gpio: mxc: Only get the second IRQ when there is more than
  one IRQ (git-fixes).
- fsi: core: Fix small accesses and unaligned offsets via sysfs
  (git-fixes).
- commit 40e8be8
* Tue Jan  7 2020 tiwai@suse.de
- fjes: fix missed check in fjes_acpi_add (git-fixes).
- firmware_loader: Fix labels with comma for builtin firmware
  (git-fixes).
- fbtft: Make sure string is NULL terminated (git-fixes).
- extcon: sm5502: Reset registers during initialization
  (git-fixes).
- commit c1f6bcd
* Tue Jan  7 2020 tiwai@suse.de
- dpaa_eth: fix DMA mapping leak (git-fixes).
- dpaa2-ptp: fix double free of the ptp_qoriq IRQ (git-fixes).
- dpaa2-eth: Fix TX FQID values (git-fixes).
- commit 7ad103e
* Tue Jan  7 2020 tiwai@suse.de
- dmaengine: virt-dma: Fix access after free in vchan_complete()
  (git-fixes).
- dmaengine: Fix access to uninitialized dma_slave_caps
  (git-fixes).
- dmaengine: xilinx_dma: Clear desc_pendingcount in
  xilinx_dma_reset (git-fixes).
- dma-debug: add a schedule point in debug_dma_dump_mappings()
  (git-fixes).
- dma-mapping: Add vmap checks to dma_map_single() (git-fixes).
- commit edbb98f
* Tue Jan  7 2020 tiwai@suse.de
- staging: comedi: gsc_hpdi: check dma_alloc_coherent() return
  value (git-fixes).
- counter: stm32-lptimer-cnt: fix a kernel-doc warning
  (git-fixes).
- counter: stm32-timer-cnt: fix a kernel-doc warning (git-fixes).
- commit 5f1dabd
* Tue Jan  7 2020 tiwai@suse.de
- clocksource: riscv: add notrace to riscv_sched_clock
  (git-fixes).
- clk: Move clk_core_reparent_orphans() under CONFIG_OF
  (git-fixes).
- clk: imx: pll14xx: fix clk_pll14xx_wait_lock (git-fixes).
- clk: imx: clk-imx7ulp: Add missing sentinel of ulp_div_table
  (git-fixes).
- clk: imx: clk-composite-8m: add lock to gate/mux (git-fixes).
- clk: walk orphan list on clock provider registration
  (git-fixes).
- clocksource/drivers/asm9260: Add a check for of_clk_get
  (git-fixes).
- clocksource/drivers/timer-of: Use unique device name instead
  of timer (git-fixes).
- clk: clk-gpio: propagate rate change to parent (git-fixes).
- clk: qcom: Allow constant ratio freq tables for rcg (git-fixes).
- commit c3af1c4
* Tue Jan  7 2020 tiwai@suse.de
- can: flexcan: poll MCR_LPM_ACK instead of GPR ACK for stop
  mode acknowledgment (git-fixes).
- can: flexcan: add low power enter/exit acknowledgment helper
  (git-fixes).
- can: flexcan: fix possible deadlock and out-of-order reception
  after wakeup (git-fixes).
- can: xilinx_can: Fix missing Rx can packets on CANFD2.0
  (git-fixes).
- cdrom: respect device capabilities during opening action
  (git-fixes).
- commit 6b25029
* Tue Jan  7 2020 tiwai@suse.de
- brcmfmac: remove monitor interface when detaching (git-fixes).
- Bluetooth: Fix advertising duplicated flags (git-fixes).
- Bluetooth: Workaround directed advertising bug in Broadcom
  controllers (git-fixes).
- Bluetooth: missed cpu_to_le16 conversion in hci_init4_req
  (git-fixes).
- commit b42e335
* Tue Jan  7 2020 tiwai@suse.de
- ath10k: Revert "ath10k: add cleanup in ath10k_sta_state()"
  (git-fixes).
- ath10k: fix get invalid tx rate for Mesh metric (git-fixes).
- ath10k: fix offchannel tx failure when no
  ath10k_mac_tx_frm_has_freq (git-fixes).
- ath10k: fix backtrace on coredump (git-fixes).
- ath10k: add cleanup in ath10k_sta_state() (git-fixes).
- commit bb2872b
* Tue Jan  7 2020 tiwai@suse.de
- ASoC: SOF: enable sync_write in hdac_bus (git-fixes).
- Refresh
  patches.suse/Revert-ASoC-SOF-Force-polling-mode-on-CFL-and-CNL.patch.
- commit 64ac0e6
* Tue Jan  7 2020 tiwai@suse.de
- ARM: tegra: Fix FLOW_CTLR_HALT register clobbering by
  tegra_resume() (git-fixes).
- ASoC: wm5100: add missed pm_runtime_disable (git-fixes).
- ASoC: wm2200: add missed operations in remove and probe failure
  (git-fixes).
- ASoC: Intel: kbl_rt5663_rt5514_max98927: Add dmic format
  constraint (git-fixes).
- ASoC: rt5677: Mark reg RT5677_PWR_ANLG2 as volatile (git-fixes).
- ASoC: Intel: bytcr_rt5640: Update quirk for Acer Switch 10
  SW5-012 2-in-1 (git-fixes).
- ASoC: wm8904: fix regcache handling (git-fixes).
- ASoC: SOF: topology: set trigger order for FE DAI link
  (git-fixes).
- commit 6a5428c
* Tue Jan  7 2020 tiwai@suse.de
- ALSA: hda/realtek - Enable the bass speaker of ASUS UX431FLC
  (git-fixes).
- ALSA: ice1724: Fix sleep-in-atomic in Infrasonic Quartet
  support code (git-fixes).
- ALSA: hda/realtek - Add Bass Speaker and fixed dac for bass
  speaker (git-fixes).
- ALSA: hda - Apply sync-write workaround to old Intel platforms,
  too (git-fixes).
- ALSA: hda/hdmi - fix atpx_present when CLASS is not VGA
  (git-fixes).
- ALSA: usb-audio: fix set_format altsetting sanity check
  (git-fixes).
- ALSA: hda/realtek - Add headset Mic no shutup for ALC283
  (git-fixes).
- ALSA: usb-audio: set the interface format after resume on Dell
  WD19 (git-fixes).
- 6pack,mkiss: fix possible deadlock (git-fixes).
- ALSA: bebob: expand sleep just after breaking connections for
  protocol version 1 (git-fixes).
- ACPI: button: Add DMI quirk for Medion Akoya E2215T (git-fixes).
- commit e88e392
* Tue Jan  7 2020 tbogendoerfer@suse.de
- ice: Add device ids for E822 devices (bsc#1157177).
- commit 0246f5b
* Tue Jan  7 2020 tbogendoerfer@suse.de
- net: marvell: mvpp2: phylink requires the link interrupt
  (bsc#1117016).
- Delete
  patches.suse/net-mvpp2-fix-condition-for-setting-up-link-interrup.patch.
- commit 8787cfd
* Tue Jan  7 2020 mbenes@suse.cz
- blacklist.conf: 1d8f65798240 ("riscv: ftrace: correct the condition logic in function graph tracer")
  RISCV architecture is not supported.
- commit 2dbbf0b
* Tue Jan  7 2020 mbenes@suse.cz
- tracing: Fix endianness bug in histogram trigger (bsc#1160231).
- commit d1849ae
* Tue Jan  7 2020 mbenes@suse.cz
- tracing: Fix lock inversion in trace_event_enable_tgid_record()
  (bsc#1160229).
- commit 4a84dfe
* Tue Jan  7 2020 tiwai@suse.de
- Move the upstreamed mwifiex fix patches into sorted section
  Refresh tags:
  patches.suse/mwifiex-Fix-heap-overflow-in-mmwifiex_process_tdls_a.patch
  patches.suse/mwifiex-fix-possible-heap-overflow-in-mwifiex_proces.patch
- commit 19bf98d
* Tue Jan  7 2020 tiwai@suse.de
- USB: Fix: Don't skip endpoint descriptors with maxpacket=0
  (bsc#1159811).
- commit 0c3dbbc
* Tue Jan  7 2020 tiwai@suse.de
- tpm: Revert "tpm_tis_core: Turn on the TPM before probing IRQ's"
  (bsc#1159152).
- tpm: Revert "tpm_tis_core: Set TPM_CHIP_FLAG_IRQ before probing
  for interrupts" (bsc#1159152).
- tpm: Revert "tpm_tis: reserve chip for duration of
  tpm_tis_core_init" (bsc#1159152).
- commit cd1e368
* Tue Jan  7 2020 mbenes@suse.cz
- tracing: Have the histogram compare functions convert to u64
  first (bsc#1160215).
- commit db2127f
* Tue Jan  7 2020 mbenes@suse.cz
- tracing: Avoid memory leak in process_system_preds()
  (bsc#1160214).
- commit d628f71
* Tue Jan  7 2020 mkubecek@suse.cz
- config: refresh armv7hl configs
  Drop EFI_RCI2_TABLE (no longer available).
- commit 056a108
* Tue Jan  7 2020 mkubecek@suse.cz
- config: refresh
  Drop EFI_RCI2_TABLE on arm64 (no longer available).
- commit 18cf2ea
* Tue Jan  7 2020 mkubecek@suse.cz
- fix mainline references
  Fix Patch-mainline:
  patches.suse/btrfs-simplify-inode-locking-for-RWF_NOWAIT.patch
  patches.suse/mm-set-S_SWAPFILE-on-blockdev-swap-devices.patch
  patches.suse/vfs-dont-allow-writes-to-swap-files.patch
- commit a590c11
* Tue Jan  7 2020 ghe@suse.com
- ocfs2: fix the crash due to call ocfs2_get_dlm_debug once less
  (bsc#1158632).
- commit 9a7b95a
* Mon Jan  6 2020 rgoldwyn@suse.com
- btrfs: simplify inode locking for RWF_NOWAIT  (git-fixes).
- commit f4e2cf3
* Mon Jan  6 2020 rgoldwyn@suse.com
- vfs: don't allow writes to swap files  (bsc#1158633).
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev.
- commit 4523846
* Mon Jan  6 2020 rgoldwyn@suse.com
- mm: set S_SWAPFILE on blockdev swap devices  (bsc#1158633).
- commit 84b8de8
* Mon Jan  6 2020 jroedel@suse.de
- blacklist.conf: Add da3cc91b8db4 iommu/mediatek: Add a new tlb_lock for tlb_flush
- commit 615be85
* Mon Jan  6 2020 jroedel@suse.de
- iommu/vt-d: Remove incorrect PSI capability check (bsc#1160142).
- iommu/vt-d: Allocate reserved region for ISA with correct
  permission (bsc#1160140).
- iommu: set group default domain before creating direct mappings
  (bsc#1160139).
- iommu/vt-d: Fix dmar pte read access not set error
  (bsc#1160141).
- iommu/vt-d: Set ISA bridge reserved region as relaxable
  (bsc#1160143).
- iommu/iova: Init the struct iova to fix the possible memleak
  (bsc#1160137).
- iommu/arm-smmu: Remove duplicate error message (bsc#1160135).
- iommu/arm-smmu-v3: Don't display an error when IRQ lines are
  missing (bsc#1160136).
- iommu/mediatek: Correct the flush_iotlb_all callback
  (bsc#1160138).
- commit 2cdf724
* Mon Jan  6 2020 msuchanek@suse.de
- powerpc/tools: Don't quote $objdump in scripts (bsc#1065729).
- commit 82d4ed4
* Mon Jan  6 2020 msuchanek@suse.de
- powerpc/pseries: Drop pointless static qualifier in
  vpa_debugfs_init() (FATE#326394 git-fixes).
- commit 2cd1f04
* Mon Jan  6 2020 msuchanek@suse.de
- powerpc/spinlocks: Include correct header for static key
  (bsc#1160010 ltc#183046).
- commit 3e6e518
* Mon Jan  6 2020 msuchanek@suse.de
- powerpc/fadump: sysfs for fadump memory reservation (bsc#1160018
  ltc#182902 jsc#SLE-9099).
- Documentation/ABI: mark /sys/kernel/fadump_* sysfs files
  deprecated (bsc#1160018 ltc#182902 jsc#SLE-9099).
- powerpc/powernv: move core and fadump_release_opalcore under
  new kobject (bsc#1160018 ltc#182902 jsc#SLE-9099).
- powerpc/fadump: reorganize /sys/kernel/fadump_* sysfs files
  (bsc#1160018 ltc#182902 jsc#SLE-9099).
- sysfs: wrap __compat_only_sysfs_link_entry_to_kobj function to
  change the symlink name (bsc#1160018 ltc#182902 jsc#SLE-9099).
- Documentation/ABI: add ABI documentation for
  /sys/kernel/fadump_* (bsc#1160018 ltc#182902 jsc#SLE-9099).
- commit 3b5b7c0
* Mon Jan  6 2020 msuchanek@suse.de
- powerpc/shared: Use static key to detect shared processor
  (bsc#1160010 ltc#183046).
- powerpc/vcpu: Assume dedicated processors as non-preempt
  (bsc#1160010 ltc#183046).
- powerpc/spinlocks: Refactor SHARED_PROCESSOR (bsc#1160010
  ltc#183046).
- commit 9083e73
* Mon Jan  6 2020 glin@suse.com
- tools: Sync if_link.h (bsc#1155518).
- commit 2837df4
* Mon Jan  6 2020 glin@suse.com
- Revert patches.suse/samples-bpf-fix-build-by-setting-HAVE_ATTR_TEST-to-z.patch (bsc#1160102)
- commit 3b6da48
* Sun Jan  5 2020 ailiopoulos@suse.com
- xfs: properly serialise fallocate against AIO+DIO (bsc#1158751).
- commit e19caef
* Sun Jan  5 2020 ailiopoulos@suse.com
- xfs: attach dquots and reserve quota blocks during unwritten
  conversion (bsc#1158753).
- commit c997f56
* Fri Jan  3 2020 jslaby@suse.cz
- Update
  patches.suse/vcs-prevent-write-access-to-vcsu-devices.patch
  (git-fixes bnc#1151927 5.3.16 bnc#1157813 CVE-2019-19252).
- commit 8980d90
* Fri Jan  3 2020 glin@suse.com
- bpf: Fix precision tracking for unbounded scalars (bsc#1155518).
- commit ab8945b
* Fri Jan  3 2020 mkubecek@suse.cz
- config: refresh
  Only headers update, reorder and diff config cleanup.
- commit c9453fd
* Fri Jan  3 2020 jslaby@suse.cz
- blacklist.conf: add one
- commit d636a45
* Fri Jan  3 2020 jslaby@suse.cz
- nbd: fix shutdown and recv work deadlock v2 (git-fixes).
- net/smc: add fallback check to connect() (git-fixes).
- selftests: net: tls: remove recv_rcvbuf test (git-fixes).
- bonding: fix active-backup transition after link failure
  (git-fixes).
- Revert "mmc: sdhci: Fix incorrect switch to HS mode"
  (git-fixes).
- usbip: Fix receive error in vhci-hcd when using scatter-gather
  (git-fixes).
- io_uring: use current task creds instead of allocating a new
  one (git-fixes).
- arm64: dts: qcom: msm8998-clamshell: Remove retention idle state
  (git-fixes).
- commit 7a4b790
* Fri Jan  3 2020 jslaby@suse.cz
- cpuidle: teo: Avoid using "early hits" incorrectly (git-fixes).
- commit bcc408a
* Fri Jan  3 2020 jslaby@suse.cz
- Linux 5.3.18 (bnc#1151927 5.3.18).
- net: ethernet: ti: cpsw: fix extra rx interrupt (bnc#1151927
  5.3.18).
- tipc: fix ordering of tipc module init and exit routine
  (bnc#1151927 5.3.18).
- openvswitch: support asymmetric conntrack (bnc#1151927 5.3.18).
- commit c9a9590
* Fri Jan  3 2020 jslaby@suse.cz
- Refresh
  patches.suse/net-thunderx-start-phy-before-starting-autonegoti.patch.
  Update upstream status.
- commit 4ab23ed
* Fri Jan  3 2020 jslaby@suse.cz
- Update
  patches.suse/Fixed-updating-of-ethertype-in-function-skb_mpls_pop.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/gre-refetch-erspan-header-from-skb-data-after-pskb_m.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/hsr-fix-a-NULL-pointer-dereference-in-hsr_dev_xmit.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/inet-protect-against-too-small-mtu-values.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/mqprio-Fix-out-of-bounds-access-in-mqprio_dump.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/net-Fixed-updating-of-ethertype-in-skb_mpls_push.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/net-bridge-deny-dev_set_mac_address-when-unregisteri.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update patches.suse/net-dsa-fix-flow-dissection-on-Tx-path.patch
  (git-fixes bnc#1151927 5.3.18).
- Update
  patches.suse/net-ipv6-add-net-argument-to-ip6_dst_lookup_flow.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/net-ipv6_stub-use-ip6_dst_lookup_flow-instead-of-ip6.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/net-mlx5e-Fix-TXQ-indices-to-be-sequential.patch
  (jsc#SLE-8464 bnc#1151927 5.3.18).
- Update
  patches.suse/net-mlx5e-Query-global-pause-state-before-setting-pr.patch
  (jsc#SLE-8464 bnc#1151927 5.3.18).
- Update
  patches.suse/net-sched-fix-dump-qlen-for-sch_mq-sch_mqprio-with-N.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/net-thunderx-start-phy-before-starting-autonegoti.patch
  (bsc#1158107 bnc#1151927 5.3.18).
- Update
  patches.suse/net-tls-Fix-return-values-to-avoid-ENOTSUPP.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/page_pool-do-not-release-pool-until-inflight-0.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/tcp-Protect-accesses-to-.ts_recent_stamp-with-READ-W.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/tcp-fix-rejected-syncookies-due-to-stale-timestamps.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/tcp-md5-fix-potential-overestimation-of-TCP-option-s.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/tcp-tighten-acceptance-of-ACKs-not-matching-a-child-.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- Update
  patches.suse/xdp-obtain-the-mem_id-mutex-before-trying-to-remove-.patch
  (bsc#1154353 bnc#1151927 5.3.18).
- commit c82b543
* Fri Jan  3 2020 jslaby@suse.cz
- Linux 5.3.17 (bnc#1151927 5.3.17).
- binder: fix incorrect calculation for num_valid (bnc#1151927
  5.3.17).
- lib: raid6: fix awk build warnings (bnc#1151927 5.3.17).
- staging: gigaset: add endpoint-type sanity check (bnc#1151927
  5.3.17).
- staging: gigaset: fix illegal free on probe errors (bnc#1151927
  5.3.17).
- staging: gigaset: fix general protection fault on probe
  (bnc#1151927 5.3.17).
- iio: humidity: hdc100x: fix IIO_HUMIDITYRELATIVE channel
  reporting (bnc#1151927 5.3.17).
- xhci: handle some XHCI_TRUST_TX_LENGTH quirks cases as default
  behaviour (bnc#1151927 5.3.17).
- usb: dwc3: ep0: Clear started flag on completion (bnc#1151927
  5.3.17).
- USB: atm: ueagle-atm: add missing endpoint check (bnc#1151927
  5.3.17).
- usb: core: urb: fix URB structure initialization function
  (bnc#1151927 5.3.17).
- ovl: relax WARN_ON() on rename to self (bnc#1151927 5.3.17).
- ovl: fix corner case of non-unique st_dev;st_ino (bnc#1151927
  5.3.17).
- ovl: fix lookup failure on multi lower squashfs (bnc#1151927
  5.3.17).
- raid5: need to set STRIPE_HANDLE for batch head (bnc#1151927
  5.3.17).
- block: fix "check bi_size overflow before merge" (bnc#1151927
  5.3.17).
- erofs: zero out when listxattr is called with no xattr
  (bnc#1151927 5.3.17).
- ARM: dts: omap3-tao3530: Fix incorrect MMC card detection GPIO
  polarity (bnc#1151927 5.3.17).
- powerpc/perf: Disable trace_imc pmu (bnc#1151927 5.3.17).
- powerpc/xive: Skip ioremap() of ESB pages for LSI interrupts
  (bnc#1151927 5.3.17).
- arm64: dts: allwinner: a64: Re-add PMU node (bnc#1151927
  5.3.17).
- mm: memcg/slab: wait for !root kmem_cache refcnt killing on
  root kmem_cache destruction (bnc#1151927 5.3.17).
- ACPI: bus: Fix NULL pointer check in acpi_bus_get_private_data()
  (bnc#1151927 5.3.17).
- s390/kaslr: store KASLR offset for early dumps (bnc#1151927
  5.3.17).
- s390/smp,vdso: fix ASCE handling (bnc#1151927 5.3.17).
- Revert "scsi: qla2xxx: Fix memory leak when sending I/O fails"
  (bnc#1151927 5.3.17).
- scsi: qla2xxx: Fix memory leak when sending I/O fails
  (bnc#1151927 5.3.17).
- scsi: zfcp: trace channel log even for FCP command responses
  (bnc#1151927 5.3.17).
- firmware: qcom: scm: Ensure 'a0' status code is treated as
  signed (bnc#1151927 5.3.17).
- mm/shmem.c: cast the type of unmap_start to u64 (bnc#1151927
  5.3.17).
- powerpc: Avoid clang warnings around setjmp and longjmp
  (bnc#1151927 5.3.17).
- powerpc: Allow 64bit VDSO __kernel_sync_dicache to work across
  ranges >4GB (bnc#1151927 5.3.17).
- powerpc: Allow flush_icache_range to work across ranges >4GB
  (bnc#1151927 5.3.17).
- ext2: check err when partial != NULL (bnc#1151927 5.3.17).
- quota: Check that quota is not dirty before release (bnc#1151927
  5.3.17).
- quota: fix livelock in dquot_writeback_dquots (bnc#1151927
  5.3.17).
- ext4: fix a bug in ext4_wait_for_tail_page_commit (bnc#1151927
  5.3.17).
- iio: imu: st_lsm6dsx: fix ODR check in st_lsm6dsx_write_raw
  (bnc#1151927 5.3.17).
- intel_th: pci: Add Tiger Lake CPU support (bnc#1151927 5.3.17).
- intel_th: pci: Add Ice Lake CPU support (bnc#1151927 5.3.17).
- USB: documentation: flags on usb-storage versus UAS (bnc#1151927
  5.3.17).
- USB: uas: heed CAPACITY_HEURISTICS (bnc#1151927 5.3.17).
- USB: uas: honor flag to avoid CAPACITY16 (bnc#1151927 5.3.17).
- usb: Allow USB device to be warm reset in suspended state
  (bnc#1151927 5.3.17).
- usb: gadget: pch_udc: fix use after free (bnc#1151927 5.3.17).
- RDMA/core: Fix ib_dma_max_seg_size() (bnc#1151927 5.3.17).
- omap: pdata-quirks: remove openpandora quirks for mmc3 and
  wl1251 (bnc#1151927 5.3.17).
- omap: pdata-quirks: revert pandora specific gpiod additions
  (bnc#1151927 5.3.17).
- ARM: dts: pandora-common: define wl1251 as child node of mmc3
  (bnc#1151927 5.3.17).
- media: cec.h: CEC_OP_REC_FLAG_ values were swapped (bnc#1151927
  5.3.17).
- ASoC: rt5645: Fixed typo for buddy jack support (bnc#1151927
  5.3.17).
- ASoC: Jack: Fix NULL pointer dereference in snd_soc_jack_report
  (bnc#1151927 5.3.17).
- ASoC: rt5645: Fixed buddy jack support (bnc#1151927 5.3.17).
- cpufreq: powernv: fix stack bloat and hard limit on number of
  CPUs (bnc#1151927 5.3.17).
- cpuidle: Do not unset the driver if it is there already
  (bnc#1151927 5.3.17).
- cpuidle: teo: Fix "early hits" handling for disabled idle states
  (bnc#1151927 5.3.17).
- cpuidle: teo: Consider hits and misses metrics of disabled
  states (bnc#1151927 5.3.17).
- cpuidle: teo: Rename local variable in teo_select() (bnc#1151927
  5.3.17).
- cpuidle: teo: Ignore disabled idle states that are too deep
  (bnc#1151927 5.3.17).
- ar5523: check NULL before memcpy() in ar5523_cmd() (bnc#1151927
  5.3.17).
- cgroup: pids: use atomic64_t for pids->limit (bnc#1151927
  5.3.17).
- workqueue: Fix pwq ref leak in rescuer_thread() (bnc#1151927
  5.3.17).
- workqueue: Fix missing kfree(rescuer) in destroy_workqueue()
  (bnc#1151927 5.3.17).
- workqueue: Fix spurious sanity check failures in
  destroy_workqueue() (bnc#1151927 5.3.17).
- s390/mm: properly clear _PAGE_NOEXEC bit when it is not
  supported (bnc#1151927 5.3.17).
- btrfs: record all roots for rename exchange on a subvol
  (bnc#1151927 5.3.17).
- Btrfs: send, skip backreference walking for extents with many
  references (bnc#1151927 5.3.17).
- btrfs: Remove btrfs_bio::flags member (bnc#1151927 5.3.17).
- btrfs: check page->mapping when loading free space cache
  (bnc#1151927 5.3.17).
- Btrfs: fix metadata space leak on fixup worker failure to set
  range as delalloc (bnc#1151927 5.3.17).
- Btrfs: fix negative subv_writers counter and data space leak
  after buffered write (bnc#1151927 5.3.17).
- btrfs: Avoid getting stuck during cyclic writebacks (bnc#1151927
  5.3.17).
- btrfs: use refcount_inc_not_zero in kill_all_nodes (bnc#1151927
  5.3.17).
- dm zoned: reduce overhead of backing device checks (bnc#1151927
  5.3.17).
- dm writecache: handle REQ_FUA (bnc#1151927 5.3.17).
- md: improve handling of bio with REQ_PREFLUSH in
  md_flush_request() (bnc#1151927 5.3.17).
- blk-mq: make sure that line break can be printed (bnc#1151927
  5.3.17).
- blk-mq: avoid sysfs buffer overflow with too many CPU cores
  (bnc#1151927 5.3.17).
- iio: imu: st_lsm6dsx: move odr_table in
  st_lsm6dsx_sensor_settings (bnc#1151927 5.3.17).
- commit 23a1f41
* Fri Jan  3 2020 jslaby@suse.cz
- Refresh
  patches.suse/reiserfs-fix-extended-attributes-on-the-root-directory.patch.
  Update upstream status.
- commit 0480375
* Thu Jan  2 2020 tiwai@suse.de
- can: kvaser_usb: kvaser_usb_leaf: Fix some info-leaks to USB
  devices (CVE-2019-19947 bsc#1159929).
- commit 507c332
* Thu Jan  2 2020 jslaby@suse.cz
- Update
  patches.suse/0001-ppdev-fix-PPGETTIME-PPSETTIME-ioctls.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/0002-video-hdmi-Fix-AVI-bar-unpack.patch
  (bsc#1152489 bnc#1151927 5.3.17).
- Update
  patches.suse/0029-pinctrl-samsung-Fix-device-node-refcount-leaks-in-S3.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-LPSS-Add-LNXVIDEO-BYT-I2C1-to-lpss_device_links.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-LPSS-Add-LNXVIDEO-BYT-I2C7-to-lpss_device_links.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-LPSS-Add-dmi-quirk-for-skipping-_DEP-check-for-.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/ACPI-OSL-only-free-map-once-in-osl.c.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-PM-Avoid-attaching-ACPI-PM-domain-to-certain-de.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-hotplug-PCI-Allocate-resources-directly-under-t.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ACPI-utils-Move-acpi_dev_get_first_match_dev-under-C.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ALSA-fireface-fix-return-value-in-error-path-of-isoc.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ALSA-oxfw-fix-return-value-in-error-path-of-isochron.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/ASoC-fsl_audmix-Add-spin-lock-to-protect-tdms.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/PM-devfreq-Lock-devfreq-in-trans_stat_show.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/Revert-nvme-Add-quirk-for-Kingston-NVME-SSD-running-.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/SUNRPC-Fix-another-issue-with-MIC-buffer-space.patch
  (bsc#1154353 bnc#1151927 5.3.17).
- Update patches.suse/USB-adutux-fix-interface-sanity-check.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/USB-idmouse-fix-interface-sanity-checks.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/USB-serial-io_edgeport-fix-epic-endpoint-lookup.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/brcmfmac-disable-PCIe-interrupts-before-bus-reset.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/coresight-Serialize-enabling-disabling-a-link-device.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/edac-altera-use-fast-register-io-for-s10-irqs.patch
  (bsc#1152489 bnc#1151927 5.3.17).
- Update
  patches.suse/edac-ghes-do-not-warn-when-incrementing-refcount-on-0.patch
  (bsc#1152489 bnc#1151927 5.3.17).
- Update
  patches.suse/ext4-Fix-credit-estimate-for-final-inode-freeing.patch
  (bsc#1158380 bnc#1151927 5.3.17).
- Update
  patches.suse/ext4-work-around-deleting-a-file-with-i_nlink-0-safe.patch
  (bsc#1158819 CVE-2019-19447 bnc#1151927 5.3.17).
- Update patches.suse/hwrng-omap-Fix-RNG-wait-loop-timeout.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/iio-ad7949-fix-channels-mixups.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iio-ad7949-kill-pointless-readback-handling-code.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iio-adc-ad7124-Enable-internal-reference.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iio-adc-ad7606-fix-reading-unnecessary-data-from-dev.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iio-adis16480-Add-debugfs_reg_access-entry.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/iio-adis16480-Fix-scales-factors.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iio-imu-inv_mpu6050-fix-temperature-reporting-using-.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/intel_th-Fix-a-double-put_device-in-error-path.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/interconnect-qcom-sdm845-Walk-the-list-safely-on-nod.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/iwlwifi-pcie-fix-support-for-transmitting-SKBs-with-.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/media-bdisp-fix-memleak-on-release.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/media-hantro-Fix-s_fmt-for-dynamic-resolution-change.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/media-radio-wl1273-fix-interrupt-masking-on-release.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/media-venus-remove-invalid-compat_ioctl32-handler.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/mfd-rk808-Fix-RK818-ID-template.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/mm-memfd-fix-COW-issue-on-MAP_PRIVATE-and-F_SEAL_FUTURE_WRITE-mappings.patch
  (bnc#1155780 (VM/FS functional and performance backports)
  bnc#1151927 5.3.17).
- Update
  patches.suse/mmc-host-omap_hsmmc-add-code-for-special-init-of-wl1.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/mtd-rawnand-Change-calculating-of-position-page-cont.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/mtd-spear_smi-Fix-Write-Burst-mode.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/net_sched-validate-TCA_KIND-attribute-in-tc_chain_tm.patch
  (bsc#1154353 bnc#1151927 5.3.17).
- Update
  patches.suse/phy-renesas-rcar-gen3-usb2-Fix-sysfs-interface-of-ro.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/pinctrl-armada-37xx-Fix-irq-mask-access-in-armada_37.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/pinctrl-rza2-Fix-gpio-name-typos.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/pinctrl-samsung-Add-of_node_put-before-return-in-err.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/pinctrl-samsung-Fix-device-node-refcount-leaks-in-Ex.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/pinctrl-samsung-Fix-device-node-refcount-leaks-in-in.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/powerpc-Fix-vDSO-clock_getres.patch
  (bsc#1065729 bnc#1151927 5.3.17).
- Update
  patches.suse/powerpc-xive-Prevent-page-fault-issues-in-the-machin.patch
  (bsc#1156882 ltc#182435 bnc#1151927 5.3.17).
- Update
  patches.suse/reiserfs-fix-extended-attributes-on-the-root-directory.patch
  (bsc#1151225 bnc#1151927 5.3.17).
- Update
  patches.suse/rtc-disable-uie-before-setting-time-and-enable-after.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/rtlwifi-rtl8192de-Fix-missing-callback-that-tests-fo.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/rtlwifi-rtl8192de-Fix-missing-code-to-retrieve-RX-bu.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/rtlwifi-rtl8192de-Fix-missing-enable-interrupt-flag.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-lpfc-Fix-bad-ndlp-ptr-in-xri-aborted-handling.patch
  (bsc#1156632,jsc#SLE-8654 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Always-check-the-qla2x00_wait_for_hba_o.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Change-discovery-state-before-PLOGI.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Check-secondary-image-if-reading-the-pr.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Do-command-completion-on-abort-timeout.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update patches.suse/scsi-qla2xxx-Fix-DMA-unmap-leak.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-NVMe-port-discovery-after-a-short-d.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-SRB-leak-on-switch-command-timeout.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update patches.suse/scsi-qla2xxx-Fix-a-dma_pool_free-call.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-a-race-condition-between-aborting-a.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-abort-timeout-race-condition.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-different-size-DMA-Alloc-Unmap.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-double-scsi_done-for-abort-path.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-driver-reload-for-ISP82xx.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update patches.suse/scsi-qla2xxx-Fix-driver-unload-hang.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-flash-read-for-Qlogic-ISPs.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-hang-in-fcport-delete-path.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-message-indicating-vectors-used-by-.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-premature-timer-expiration.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-qla24xx_process_bidir_cmd.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Fix-session-lookup-in-qlt_abort_work.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update patches.suse/scsi-qla2xxx-Fix-stale-session.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update patches.suse/scsi-qla2xxx-Fix-stuck-login-session.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Introduce-the-function-qla2xxx_init_sp.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Make-qla2x00_abort_srb-again-decrease-t.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Make-sure-that-aborted-commands-are-fre.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-Really-fix-qla2xxx_eh_abort.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/scsi-qla2xxx-qla2x00_alloc_fw_dump-set-ha-eft.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.17).
- Update
  patches.suse/seccomp-avoid-overflow-in-implicit-constant-conversi.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/splice-only-read-in-as-much-information-as-there-is-.patch
  (bsc#1158456 bnc#1151927 5.3.17).
- Update
  patches.suse/staging-rtl8188eu-fix-interface-sanity-check.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/staging-rtl8712-fix-interface-sanity-check.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/staging-vchiq-call-unregister_chrdev_region-when-dri.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/stm-class-Lose-the-protocol-driver-when-dropping-its.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/tpm-add-check-after-commands-attribs-tab-allocation.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-dwc3-gadget-Clear-started-flag-for-non-IOC.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/usb-dwc3-gadget-Fix-logical-condition.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-dwc3-pci-add-ID-for-the-Intel-Comet-Lake-H-varia.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-gadget-configfs-Fix-missing-spin_lock_init.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-host-xhci-tegra-Correct-phy-enable-sequence.patch
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608 bnc#1151927 5.3.17).
- Update
  patches.suse/usb-mon-Fix-a-deadlock-in-usbmon-between-mmap-and-re.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-roles-fix-a-potential-use-after-free.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/usb-typec-fix-use-after-free-in-typec_register_port.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/usb-xhci-only-set-D3hot-for-pci-device.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/virt_wifi-fix-use-after-free-in-virt_wifi_newlink.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/virtio-balloon-fix-managed-page-counts-when-migratin.patch
  (git-fixes bnc#1151927 5.3.17).
- Update patches.suse/wil6210-check-len-before-memcpy-calls.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/xhci-Fix-memory-leak-in-xhci_add_in_port.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/xhci-Increase-STS_HALT-timeout-in-xhci_suspend.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/xhci-fix-USB3-device-initiated-resume-race-with-root.patch
  (git-fixes bnc#1151927 5.3.17).
- Update
  patches.suse/xhci-make-sure-interrupts-are-restored-to-correct-st.patch
  (git-fixes bnc#1151927 5.3.17).
- commit eb92594
* Thu Jan  2 2020 tiwai@suse.de
- Add patch reference for sched fair fix (CVE-2019-19922 bsc#1159717)
- commit 480be0b
* Thu Jan  2 2020 jlee@suse.com
- efi: Make CONFIG_EFI_RCI2_TABLE selectable on x86 only
  (jsc#SLE-10289).
- commit 8c1a561
* Thu Jan  2 2020 jlee@suse.com
- efi: Make unexported efi_rci2_sysfs_init() static
  (jsc#SLE-10289).
- commit 0364d1d
* Thu Jan  2 2020 jlee@suse.com
- Refresh
  patches.suse/0011-PM-hibernate-require-hibernate-snapshot-image-to-be-.patch.
  (fate#316350)
- commit d4f6542
* Thu Jan  2 2020 jlee@suse.com
- Update config files. Add
  CONFIG_HIBERNATE_VERIFICATION_FORCE is not set
- Refresh
  patches.suse/0010-PM-hibernate-a-option-to-request-that-snapshot-image.patch.
  (fate#316350)
- commit 7516b3e
* Thu Jan  2 2020 jlee@suse.com
- Refresh
  patches.suse/0009-PM-hibernate-prevent-EFI-secret-key-to-be-regenerate.patch.
  (fate#316350)
- commit 3a74fdb
* Thu Jan  2 2020 jlee@suse.com
- Update config files. Add CONFIG_HIBERNATE_VERIFICATION=y
- Refresh
  patches.suse/0008-PM-hibernate-Generate-and-verify-signature-for-snaps.patch.
  (fate#316350)
- commit 04482de
* Tue Dec 31 2019 tbogendoerfer@suse.de
- r8152: avoid to call napi_disable twice (bsc#1159949).
- r8152: Re-order napi_disable in rtl8152_close (bsc#1159949).
- commit e318a2d
* Tue Dec 31 2019 jlee@suse.com
- Refresh
  patches.suse/0007-PM-hibernate-encrypt-hidden-area.patch.
  (fate#316350)
- commit 2517349
* Tue Dec 31 2019 jlee@suse.com
- Refresh
  patches.suse/0006-efi-allow-user-to-regenerate-secret-key.patch.
  (fate#316350)
- commit 15f6da6
* Tue Dec 31 2019 jlee@suse.com
- Update config files. Add:
  CONFIG_HIDDEN_AREA=y
  CONFIG_EFI_SECRET_KEY=y
- Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
  (fate#316350)
- commit 9f8bf21
* Tue Dec 31 2019 jlee@suse.com
- Refresh
  patches.suse/0003-x86-KASLR-public-the-function-for-getting-random-lon.patch.
  (fate#316350)
- commit 404b8d6
* Tue Dec 31 2019 jlee@suse.com
- Refresh
  patches.suse/0002-hibernate-avoid-the-data-in-hidden-area-to-be-snapsh.patch.
  (fate#316350)
- commit ef04a2a
* Tue Dec 31 2019 jlee@suse.com
- Update config files. Add:
  [#] CONFIG_HIDDEN_AREA is not set
- Refresh
  patches.suse/0001-security-create-hidden-area-to-keep-sensitive-data.patch.
  (fate#316350)
- commit 11a6e5f
* Mon Dec 30 2019 bp@suse.de
- x86/mce: Fix possibly incorrect severity calculation on AMD
  (bsc#1152489).
- commit f55f1be
* Mon Dec 30 2019 bp@suse.de
- x86/MCE/AMD: Allow Reserved types to be overwritten in
  smca_banks (bsc#1152489).
- commit a0ed031
* Mon Dec 30 2019 glin@suse.com
- bpf: Clear skb->tstamp in bpf_redirect when necessary
  (bsc#1155518).
- vfs: Convert bpf to use the new mount API (bsc#1155518).
- commit 7d014d2
* Mon Dec 30 2019 glin@suse.com
- Refresh patches.suse/bpf-Fix-race-in-btf_resolve_helper_id.patch.
  Refresh
  patches.suse/bpf-Compare-BTF-types-of-functions-arguments-with-ac.patch.
- commit 5dec29f
* Mon Dec 30 2019 glin@suse.com
- samples: bpf: fix syscall_tp due to unused syscall
  (bsc#1155518).
- samples: bpf: Replace symbol compare of trace_event
  (bsc#1155518).
- bpftool: Don't crash on missing jited insns or ksyms
  (bsc#1155518).
- bpf, riscv: Limit to 33 tail calls (bsc#1155518).
- libbpf: Make global data internal arrays mmap()-able, if
  possible (bsc#1155518).
- commit 479ef0d
* Sun Dec 29 2019 mkubecek@suse.cz
- config: refresh
  Clean up options which are no longer available.
- commit 64a3f68
* Sun Dec 29 2019 bp@suse.de
- supported.conf: Mark i10nm_edac as supported
  See bsc#1159522.
- commit 442c0cf
* Fri Dec 27 2019 dbueso@suse.de
- fs/epoll: remove unnecessary wakeups of nested epoll
  (bsc#1159867).
- epoll: simplify ep_poll_safewake() for CONFIG_DEBUG_LOCK_ALLOC
  (bsc#1159867).
- commit 42eb012
* Fri Dec 27 2019 dbueso@suse.de
- x86/mm/pat: Fix off-by-one bugs in interval tree search
  (bsc#1159864).
- locking/refcount: Remove unused 'refcount_error_report()'
  function (bsc#1149032).
- locking/refcount: Consolidate implementations of refcount_t
  (bsc#1149032).
- locking/refcount: Consolidate REFCOUNT_{MAX,SATURATED}
  definitions (bsc#1149032).
- locking/refcount: Move saturation warnings out of line
  (bsc#1149032).
- locking/refcount: Improve performance of generic REFCOUNT_FULL
  code (bsc#1149032).
- locking/refcount: Move the bulk of the REFCOUNT_FULL
  implementation into the <linux/refcount.h> header (bsc#1149032).
- locking/refcount: Remove unused refcount_*_checked() variants
  (bsc#1149032).
- locking/refcount: Ensure integer operands are treated as signed
  (bsc#1149032).
- locking/refcount: Define constants for saturation and max
  refcount values (bsc#1149032).
- lib/smp_processor_id: Don't use cpumask_equal() (bsc#1149032).
- x86/mm/pat: Rename pat_rbtree.c to pat_interval.c (bsc#1159864).
- x86/mm/pat: Drop the rbt_ prefix from external memtype calls
  (bsc#1159864).
- x86/mm/pat: Do not pass 'rb_root' down the memtype tree helper
  functions (bsc#1159864).
- x86/mm/pat: Convert the PAT tree to a generic interval tree
  (bsc#1159864).
- augmented rbtree: rework the RB_DECLARE_CALLBACKS macro
  definition (bsc#1159864).
- augmented rbtree: add new RB_DECLARE_CALLBACKS_MAX macro
  (bsc#1159864).
- augmented rbtree: add comments for RB_DECLARE_CALLBACKS macro
  (bsc#1159864).
- rbtree: avoid generating code twice for the cached versions
  (tools copy) (bsc#1159864).
- commit 27d4ced
* Thu Dec 26 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/net-ibmvnic-Fix-typo-in-retry-check.patch
- commit cdfb8b3
* Thu Dec 26 2019 glin@suse.com
- selftests/bpf: Add static to enable_all_controllers()
  (bsc#1155518).
- commit e1a5909
* Thu Dec 26 2019 glin@suse.com
- libbpf: Add support for field size relocations (bsc#1155518).
- libbpf: Add support for relocatable bitfields (bsc#1155518).
- selftests/bpf: Remove too strict field offset relo test cases
  (bsc#1155518).
- commit 50d1087
* Thu Dec 26 2019 glin@suse.com
- libbpf: Fix usage of u32 in userspace code (bsc#1155518).
- libbpf: Fix bpf_object name determination for
  bpf_object__open_file() (bsc#1155518).
- libbpf: Unpin auto-pinned maps if loading fails (bsc#1155518).
- selftests/bpf: Move test_section_names into test_progs and
  fix it (bsc#1155518).
- Refresh
  patches.suse/selftests-bpf-xdping-is-not-meant-to-be-run-standalo.patch.
- selftests/bpf: Fix dependency ordering for attach_probe test
  (bsc#1155518).
- commit d4cc79c
* Thu Dec 26 2019 glin@suse.com
- bpf: Fix record_func_key to perform backtracking on r3
  (bsc#1155518).
- bpf: Fix cgroup local storage prog tracking (bsc#1155518).
- bpf: Fix missing prog untrack in release_maps (bsc#1155518).
- bpf: Fix build in minimal configurations, again (bsc#1155518).
- samples/bpf: Fix broken xdp_rxq_info due to map order
  assumptions (bsc#1155518).
- libbpf: Fix up generation of bpf_helper_defs.h (bsc#1155518).
- libbpf: Fix global variable relocation (bsc#1155518).
- bpf: Introduce BPF_TRACE_x helper for the tracing tests
  (bsc#1155518).
- selftests/bpf: Add BPF trampoline performance test
  (bsc#1155518).
- selftests/bpf: Ensure core_reloc_kernel is reading test_progs's
  data only (bsc#1155518).
- libbpf: Support initialized global variables (bsc#1155518).
- libbpf: Fix various errors and warning reported by checkpatch.pl
  (bsc#1155518).
- libbpf: Refactor relocation handling (bsc#1155518).
- Refresh
  patches.suse/libbpf-fix-sym-st_value-print-on-32-bit-arches.patch.
- selftests/bpf: Integrate verbose verifier log into test_progs
  (bsc#1155518).
- selftests, bpftool: Skip the build test if not in tree
  (bsc#1155518).
- selftests, bpftool: Set EXIT trap after usage function
  (bsc#1155518).
- selftests/bpf: Add BPF_TYPE_MAP_ARRAY mmap() tests
  (bsc#1155518).
- selftests/bpf: Add a test for attaching BPF prog to another
  BPF prog and subprog (bsc#1155518).
- selftests/bpf: Extend test_pkt_access test (bsc#1155518).
- libbpf: Add support for attaching BPF programs to other BPF
  programs (bsc#1155518).
- selftests/bpf: Add stress test for maximum number of progs
  (bsc#1155518).
- selftests/bpf: Add combined fentry/fexit test (bsc#1155518).
- selftests/bpf: Add fexit tests for BPF trampoline (bsc#1155518).
- selftests/bpf: Add test for BPF trampoline (bsc#1155518).
- selftest/bpf: Simple test for fentry/fexit (bsc#1155518).
- libbpf: Add support to attach to fentry/fexit tracing progs
  (bsc#1155518).
- libbpf: Introduce btf__find_by_name_kind() (bsc#1155518).
- libbpf: Add getter for program size (bsc#1155518).
- bpf: Add cb access in kfree_skb test (bsc#1155518).
- selftests/bps: Clean up removed ints relocations negative tests
  (bsc#1155518).
- selftests/bpf: Add field size relocation tests (bsc#1155518).
- selftest/bpf: Add relocatable bitfield reading tests
  (bsc#1155518).
- selftests: Add tests for automatic map pinning (bsc#1155518).
- libbpf: Add auto-pinning of maps when loading BPF objects
  (bsc#1155518).
- libbpf: Move directory creation into _pin() functions
  (bsc#1155518).
- libbpf: Store map pin path and status in struct bpf_map
  (bsc#1155518).
- libbpf: Fix error handling in bpf_map__reuse_fd() (bsc#1155518).
- libbpf: Add support for prog_tracing (bsc#1155518).
- libbpf: Make DECLARE_LIBBPF_OPTS macro strictly a variable
  declaration (bsc#1155518).
- selftest/bpf: Get rid of a bunch of explicit BPF program type
  setting (bsc#1155518).
- selftests/bpf: Make reference_tracking test use subtests
  (bsc#1155518).
- selftests/bpf: Make a copy of subtest name (bsc#1155518).
- libbpf: Teach bpf_object__open to guess program types
  (bsc#1155518).
- libbpf: Add uprobe/uretprobe and tp/raw_tp section suffixes
  (bsc#1155518).
- libbpf: Add bpf_program__get_{type, expected_attach_type) APIs
  (bsc#1155518).
- bpf, libbpf: Add kernel version section parsing back
  (bsc#1155518).
- selftests/bpf: Make CO-RE reloc test impartial to test_progs
  flavor (bsc#1155518).
- selftests/bpf: Add field existence CO-RE relocs tests
  (bsc#1155518).
- libbpf: Add BPF-side definitions of supported field relocation
  kinds (bsc#1155518).
- libbpf: Add support for field existance CO-RE relocation
  (bsc#1155518).
- libbpf: Refactor bpf_object__open APIs to use common opts
  (bsc#1155518).
- libbpf: Update BTF reloc support to latest Clang format
  (bsc#1155518).
- selftests/bpf: Enforce libbpf build before BPF programs are
  built (bsc#1155518).
- libbpf: Generate more efficient BPF_CORE_READ code
  (bsc#1155518).
- selftests/bpf: Add read-only map values propagation tests
  (bsc#1155518).
- scripts/bpf: Fix xdp_md forward declaration typo (bsc#1155518).
- selftests/bpf: Add BPF_CORE_READ and BPF_CORE_READ_STR_INTO
  macro tests (bsc#1155518).
- libbpf: Add BPF_CORE_READ/BPF_CORE_READ_INTO helpers
  (bsc#1155518).
- libbpf: Move bpf_{helpers, helper_defs, endian, tracing}.h
  into libbpf (bsc#1155518).
- selftests/bpf: Split off tracing-only helpers into bpf_tracing.h
  (bsc#1155518).
- selftests/bpf: Adjust CO-RE reloc tests for new bpf_core_read()
  macro (bsc#1155518).
- selftests/bpf: samples/bpf: Split off legacy stuff from
  bpf_helpers.h (bsc#1155518).
- selftests/bpf: Undo GCC-specific bpf_helpers.h changes
  (bsc#1155518).
- bpftool: Fix bpftool build by switching to
  bpf_object__open_file() (bsc#1155518).
- libbpf: auto-generate list of BPF helper definitions
  (bsc#1155518).
- scripts/bpf: teach bpf_helpers_doc.py to dump BPF helper
  definitions (bsc#1155518).
- uapi/bpf: fix helper docs (bsc#1155518).
- libbpf: Add cscope and tags targets to Makefile (bsc#1155518).
- selftests/bpf: switch tests to new bpf_object__open_{file,
  mem}() APIs (bsc#1155518).
- libbpf: fix bpf_object__name() to actually return object name
  (bsc#1155518).
- libbpf: add bpf_object__open_{file, mem} w/ extensible opts
  (bsc#1155518).
- libbpf: stop enforcing kern_version, populate it for users
  (bsc#1155518).
- libbpf: Fix BTF-defined map's __type macro handling of arrays
  (bsc#1155518).
- libbpf: Bump current version to v0.0.6 (bsc#1155518).
- selftests/bpf: add bpf-gcc support (bsc#1155518).
- bpf: sync bpf.h to tools/ (bsc#1155518).
- bpf: clarify when bpf_trace_printk discards lines (bsc#1155518).
- bpf: fix 'struct pt_reg' typo in documentation (bsc#1155518).
- libbpf: relicense bpf_helpers.h and bpf_endian.h (bsc#1155518).
- tools/bpf: fix core_reloc.c compilation error (bsc#1155518).
- selftests/bpf: add CO-RE relocs misc tests (bsc#1155518).
- selftests/bpf: add CO-RE relocs ints tests (bsc#1155518).
- selftests/bpf: add CO-RE relocs ptr-as-array tests
  (bsc#1155518).
- selftests/bpf: add CO-RE relocs modifiers/typedef tests
  (bsc#1155518).
- selftests/bpf: add CO-RE relocs enum/ptr/func_proto tests
  (bsc#1155518).
- selftests/bpf: add CO-RE relocs array tests (bsc#1155518).
- selftests/bpf: add CO-RE relocs nesting tests (bsc#1155518).
- selftests/bpf: add CO-RE relocs struct flavors tests
  (bsc#1155518).
- selftests/bpf: add CO-RE relocs testing setup (bsc#1155518).
- selftests/bpf: add BPF_CORE_READ relocatable read macro
  (bsc#1155518).
- selftests/bpf: bpf_tcp_gen_syncookie->bpf_helpers (bsc#1155518).
- samples/bpf: switch trace_output sample to perf_buffer API
  (bsc#1155518).
- samples/bpf: convert xdp_sample_pkts_user to perf_buffer API
  (bsc#1155518).
- commit d828ab7
* Mon Dec 23 2019 jack@suse.cz
- ext4: check for directory entries too close to block end
  (bsc#1157717 CVE-2019-19037).
- commit 6bf11c6
* Mon Dec 23 2019 jack@suse.cz
- ext4: fix ext4_empty_dir() for directories with holes.
- commit 54aad4a
* Sun Dec 22 2019 dbueso@suse.de
- futex: Prevent exit livelock (bsc#1149032).
- futex: Provide distinct return value when owner is exiting
  (bsc#1149032).
- futex: Add mutex around futex exit (bsc#1149032).
- futex: Provide state handling for exec() as well (bsc#1149032).
- futex: Sanitize exit state handling (bsc#1149032).
- futex: Mark the begin of futex exit explicitly (bsc#1149032).
- futex: Set task::futex_state to DEAD right after handling
  futex exit (bsc#1149032).
- futex: Split futex_mm_release() for exit/exec (bsc#1149032).
- exit/exec: Seperate mm_release() (bsc#1149032).
- futex: Replace PF_EXITPIDONE with a state (bsc#1149032).
- futex: Move futex exit handling into futex code (bsc#1149032).
- commit 069097a
* Fri Dec 20 2019 vbabka@suse.cz
- mm, debug_pagealloc: don't rely on static keys too early
  (VM debuging functionality, bsc#1159455).
- commit 690a965
* Fri Dec 20 2019 jack@suse.cz
- ext4: work around deleting a file with i_nlink == 0 safely
  (bsc#1158819 CVE-2019-19447).
- commit 126e601
* Fri Dec 20 2019 tiwai@suse.de
- drm/i915/gt: Save irqstate around virtual_context_destroy
  (git-fixes).
- commit 0119c98
* Fri Dec 20 2019 tiwai@suse.de
- Mark already cherry-picked commit ids in i915 patches
  Refresh:
  patches.suse/drm-i915-Don-t-oops-in-dumb_create-ioctl-if-we-have-.patch
  patches.suse/drm-i915-userptr-Try-to-acquire-the-page-lock-around.patch
- commit 051ff5d
* Fri Dec 20 2019 tiwai@suse.de
- drm/i915: Protect context while grabbing its name for the
  request (git-fixes).
- drm/i915: Initialise breadcrumb lists on the virtual engine
  (git-fixes).
- commit 248edd0
* Fri Dec 20 2019 tiwai@suse.de
- net: dsa: fix flow dissection on Tx path (git-fixes).
- net: dsa: LAN9303: select REGMAP when LAN9303 enable
  (git-fixes).
- commit a8aec65
* Fri Dec 20 2019 tiwai@suse.de
- KEYS: asymmetric: return ENOMEM if akcipher_request_alloc()
  fails (git-fixes).
- commit 6067783
* Fri Dec 20 2019 tiwai@suse.de
- mmc: dw_mmc: Fix debugfs on 64-bit platforms (git-fixes).
- mmc: atmel-mci: Fix debugfs on 64-bit platforms (git-fixes).
- debugfs: Add debugfs_create_xul() for hexadecimal unsigned long
  (git-fixes).
- commit 3a9e8a9
* Fri Dec 20 2019 tiwai@suse.de
- tpm: fix invalid locking in NONBLOCKING mode (git-fixes).
- tpm_tis: reserve chip for duration of tpm_tis_core_init
  (git-fixes).
- nvmem: core: fix nvmem_cell_write inline function (git-fixes).
- tools/power/cpupower: Fix initializer override in
  hsw_ext_cstates (git-fixes).
- commit 1d5439f
* Fri Dec 20 2019 tiwai@suse.de
- tools/testing/nvdimm: Fix fallthrough warning (bsc#1159523).
- commit c26d308
* Fri Dec 20 2019 tiwai@suse.de
- net: wireless: intel: iwlwifi: fix GRO_NORMAL packet stalling
  (bsc#1159555).
- commit f735353
* Thu Dec 19 2019 mkubecek@suse.cz
- rpm/kernel-subpackage-spec: fix kernel-default-base build
  There were some issues with recent changes to subpackage dependencies handling:
- a typo in %%kernel_base_conflicts macro name
- copy/pasted "Recommends:" instead of "Provides:", "Obsoletes:" and
  "Conflicts:
- missing escaping of backslashes in macro expansions
  Fixes: f3b74b0ae86b ("rpm/kernel-subpackage-spec: Unify dependency handling.")
  Fixes: 3fd22e219f77 ("rpm/kernel-subpackage-spec: Fix empty Recommends tag (bsc#1143959)")
- commit 762fd66
* Thu Dec 19 2019 fdmanana@suse.com
- Btrfs: send, allow clone operations within the same file
  (bsc#1158746).
- commit 65efe90
* Thu Dec 19 2019 fdmanana@suse.com
- Btrfs: fix hole extent items with a zero size after range
  cloning (bsc#1156782).
- commit c0cfb85
* Thu Dec 19 2019 fdmanana@suse.com
- Btrfs: fix cloning range with a hole when using the NO_HOLES
  feature (bsc#1156782).
- commit 990a52a
* Thu Dec 19 2019 tiwai@suse.de
- supported.conf: Mark intel_rapl-* modules as supported (bsc#1159519)
  Those were marked as unsupported incorrectly.
- commit a95f5c6
* Thu Dec 19 2019 yousaf.kaukab@suse.com
- dpaa_eth: register a device link for the qman portal used
  (bsc#1159537).
- soc: fsl: qbman: allow registering a device link for the portal
  user (bsc#1159537).
- dpaa_eth: extend delays in ndo_stop (bsc#1159537).
- dpaa_eth: remove netdev_err() for user errors (bsc#1159537).
- dpaa_eth: add dropped frames to percpu ethtool stats
  (bsc#1159537).
- dpaa_eth: use a page to store the SGT (bsc#1159537).
- dpaa_eth: cleanup skb_to_contig_fd() (bsc#1159537).
- dpaa_eth: use fd information in dpaa_cleanup_tx_fd()
  (bsc#1159537).
- dpaa_eth: simplify variables used in dpaa_cleanup_tx_fd()
  (bsc#1159537).
- dpaa_eth: avoid timestamp read on error paths (bsc#1159537).
- dpaa_eth: perform DMA unmapping before read (bsc#1159537).
- dpaa_eth: use page backed rx buffers (bsc#1159537).
- dpaa_eth: use only one buffer pool per interface (bsc#1159537).
- dpaa_eth: add newline in dev_err() msg (bsc#1159537).
- fsl/fman: remove unused struct member (bsc#1159537).
- dpaa_eth: change DMA device (bsc#1159537).
- fsl/fman: add API to get the device behind a fman port
  (bsc#1159537).
- dpaa_eth: remove redundant code (bsc#1159537).
- dpaa_eth: defer probing after qbman (bsc#1159537).
- fsl/fman: don't touch liodn base regs reserved on non-PAMU SoCs
  (bsc#1159537).
- dpaa_eth: Use refcount_t for refcount (bsc#1159537).
- soc/fsl/qbman: Update device tree with reserved memory
  (bsc#1159535).
- soc/fsl/qbman: Fixup qman_shutdown_fq() (bsc#1159535).
- soc/fsl/qbman: Disable interrupts during portal recovery
  (bsc#1159535).
- soc/fsl/qbman: Fix drain_mr_fqni() (bsc#1159535).
- soc/fsl/qbman: Cleanup QMan queues if device was already
  initialized (bsc#1159535).
- soc/fsl/qbman: Cleanup buffer pools if BMan was initialized
  prior to bootup (bsc#1159535).
- soc/fsl/qbman: Rework QBMan private memory setup (bsc#1159535).
- commit 622fccb
* Thu Dec 19 2019 lyan@suse.com
- KVM: arm/arm64: vgic: Allow more than 256 vcpus for KVM_IRQ_LINE
  (jsc#SLE-9228).
- Refresh
  patches.suse/KVM-Hyper-V-Add-new-KVM-capability-KVM_CAP_HYPERV_DI.patch.
- commit 4054d0e
* Wed Dec 18 2019 tiwai@suse.de
- ASoC: wm8962: fix lambda value (git-fixes).
- ASoC: SOF: Intel: split cht and byt debug window sizes
  (git-fixes).
- ASoC: SOF: loader: fix snd_sof_fw_parse_ext_data (git-fixes).
- ASoC: SOF: loader: snd_sof_fw_parse_ext_data log warning on
  unknown header (git-fixes).
- ASoC: simple-card: Don't create separate link when platform
  is present (git-fixes).
- ASoC: topology: Check return value for soc_tplg_pcm_create()
  (git-fixes).
- ASoC: topology: Check return value for snd_soc_add_dai_link()
  (git-fixes).
- ASoC: Intel: bytcr_rt5640: Update quirk for Teclast X89
  (git-fixes).
- ASoC: Intel: sst: Add missing include <linux/io.h> (git-fixes).
- ASoC: max98090: fix possible race conditions (git-fixes).
- ASoC: max98090: exit workaround earlier if PLL is locked
  (git-fixes).
- ASoC: max98090: remove msleep in PLL unlocked workaround
  (git-fixes).
- ASoC: AMD: Enable clk in startup intead of hw_params
  (git-fixes).
- ASoC: rt5682: fix i2c arbitration lost issue (git-fixes).
- ALSA: hda - Downgrade error message for single-cmd fallback
  (git-fixes).
- ALSA: hda: Fix regression by strip mask fix (git-fixes).
- ALSA: hda/ca0132 - Fix work handling in delayed HP detection
  (git-fixes).
- ALSA: hda/ca0132 - Avoid endless loop (git-fixes).
- ALSA: hda/ca0132 - Keep power on during processing DSP response
  (git-fixes).
- ALSA: pcm: Avoid possible info leaks from PCM stream buffers
  (git-fixes).
- commit 5704af7
* Wed Dec 18 2019 msuchanek@suse.de
- powerpc/archrandom: fix arch_get_random_seed_int()
  (bsc#1065729).
- powerpc: Fix vDSO clock_getres() (bsc#1065729).
- powerpc/powernv: Disable native PCIe port management
  (bsc#1065729).
- commit 1064493
* Wed Dec 18 2019 msuchanek@suse.de
- ibmveth: Detect unsupported packets before sending to the
  hypervisor (bsc#1159484 ltc#182983).
- commit 258fd08
* Wed Dec 18 2019 dwagner@suse.de
- scsi: lpfc: size cpu map by last cpu id set (bsc#1157160).
- scsi: lpfc: use hdwq assigned cpu for allocation (bsc#1157160).
- commit b9fd3db
* Wed Dec 18 2019 tiwai@suse.de
- efi: Don't attempt to map RCI2 config table if it doesn't exist
  (git-fixes).
- efi/earlycon: Remap entire framebuffer after page initialization
  (git-fixes).
- libtraceevent: Fix memory leakage in copy_filter_type
  (git-fixes).
- commit 360da09
* Wed Dec 18 2019 tiwai@suse.de
- mailbox: tegra: Fix superfluous IRQ error message (git-fixes).
- Revert "pinctrl: sh-pfc: r8a77990: Fix MOD_SEL1 bit31 when
  using SIM0_D" (git-fixes).
- Revert "pinctrl: sh-pfc: r8a77990: Fix MOD_SEL1 bit30 when
  using SSI_SCK2 and SSI_WS2" (git-fixes).
- commit aaa30e6
* Wed Dec 18 2019 tiwai@suse.de
- regulator: rn5t618: fix module aliases (git-fixes).
- regulator: core: fix regulator_register() error paths to
  properly release rdev (git-fixes).
- spi: nxp-fspi: Ensure width is respected in spi-mem operations
  (git-fixes).
- spi: sprd: Fix the incorrect SPI register (git-fixes).
- spi: dw: Correct handling of native chipselect (git-fixes).
- spi: cadence: Correct handling of native chipselect (git-fixes).
- reset: Fix {of,devm}_reset_control_array_get kerneldoc return
  types (git-fixes).
- reset: brcmstb: Remove resource checks (git-fixes).
- commit 76e8bc6
* Wed Dec 18 2019 tiwai@suse.de
- Update patch references for io_uring fixes (CVE-2019-19241 bsc#1159441)
- commit a94274a
* Wed Dec 18 2019 tbogendoerfer@suse.de
- bpf: Force .BTF section start to zero when dumping from vmlinux
  (bsc#1154353).
- libbpf: Fix Makefile' libbpf symbol mismatch diagnostic
  (bsc#1154353).
- commit d383cb0
* Wed Dec 18 2019 tbogendoerfer@suse.de
- bpf: Support pre-2.25-binutils objcopy for vmlinux BTF
  (bsc#1154353).
- libbpf: handle symbol versioning properly for libbpf.a
  (bsc#1154353).
- commit 04f1f8c
* Wed Dec 18 2019 tiwai@suse.de
- usb: dwc3: pci: add ID for the Intel Comet Lake -H variant
  (git-fixes).
- xhci: fix USB3 device initiated resume race with roothub
  autosuspend (git-fixes).
- usb: dwc3: gadget: Clear started flag for non-IOC (git-fixes).
- USB: dummy-hcd: increase max number of devices to 32
  (git-fixes).
- commit b4a9fe8
* Wed Dec 18 2019 tiwai@suse.de
- wil6210: check len before memcpy() calls (git-fixes).
- commit b8cef66
* Wed Dec 18 2019 tiwai@suse.de
- iio: ad7949: fix channels mixups (git-fixes).
- iio: ad7949: kill pointless "readback"-handling code
  (git-fixes).
- commit 172e59a
* Wed Dec 18 2019 tiwai@suse.de
- drm/i915/guc: Skip suspend/resume GuC action on platforms w/o
  GuC submission (git-fixes).
- coresight: Serialize enabling/disabling a link device
  (git-fixes).
- coresight: tmc-etr: Fix perf_data check (git-fixes).
- commit ecf0694
* Wed Dec 18 2019 tiwai@suse.de
- bus: ti-sysc: Fix missing reset delay handling (git-fixes).
- blacklist.conf:
- ASoC: SOF: topology: free kcontrol memory on error (git-fixes).
- commit 4b0268c
* Wed Dec 18 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: Unify dependency handling.
- commit f3b74b0
* Wed Dec 18 2019 tiwai@suse.de
- Update patch references for reported CVEs (CVE-2019-18811 bsc#1159374 CVE-2019-19044 bsc#1159370 CVE-2019-19043 bsc#1159375)
- commit 1b9a5c8
* Wed Dec 18 2019 yousaf.kaukab@suse.com
- ASoC: fsl_sai: add IRQF_SHARED (jsc#SLE-9316).
- dmaengine: fsl-qdma: Handle invalid qdma-queue0 IRQ
  (jsc#SLE-9316).
- ASoC: fsl_sai: Fix noise when using EDMA (jsc#SLE-9316).
- dmaengine: fsl-edma: implement .device_synchronize callback
  (jsc#SLE-9316).
- ASoC: fsl_sai: Implement set_bclk_ratio (jsc#SLE-9316).
- ASoC: fsl_sai: Add support for imx8qm (jsc#SLE-9316).
- ASoC: fsl_sai: Add support for imx7ulp/imx8mq (jsc#SLE-9316).
- ASoC: fsl_sai: Add support for SAI new version (jsc#SLE-9316).
- ASoC: fsl_sai: Update Tx/Rx channel enable mask (jsc#SLE-9316).
- ASoC: fsl_sai: Add registers definition for multiple datalines
  (jsc#SLE-9316).
- ASoC: sgtl5000: add ADC mute control (jsc#SLE-9316).
- ASoC: sgtl5000: Fix definition of VAG Ramp Control
  (jsc#SLE-9316).
- ASoC: fsl_sai: mark regmap as fast_io (jsc#SLE-9316).
- ASoC: fsl_sai: derive TX FIFO watermark from FIFO depth
  (jsc#SLE-9316).
- ASoC: fsl_sai: add of_match data (jsc#SLE-9316).
- commit c78e5c0
* Wed Dec 18 2019 tiwai@suse.de
- blacklist.conf: Yet another i915 entries that are already applied
- commit 1d49d40
* Wed Dec 18 2019 mkubecek@suse.cz
- fix mainline reference
- fix Patch-mainline:
  patches.suse/efi-memreserve-Register-reservations-as-reserved-in-.patch
- commit cc91804
* Wed Dec 18 2019 clin@suse.com
- efi/memreserve: Register reservations as 'reserved' in
  /proc/iomem (jsc#SLE-9943).
- commit b90e4d7
* Wed Dec 18 2019 tiwai@suse.de
- drm/hdcp: update content protection property with uevent
  (jsc#SLE-7953).
- drm: uevent for connector status change (jsc#SLE-7953).
- commit 8809d69
* Wed Dec 18 2019 tiwai@suse.de
- blacklist.conf: Yet another couple of i915 entries
- commit 1237ce0
* Wed Dec 18 2019 tiwai@suse.de
- drm/i915/gvt: Fix cmd length check for MI_ATOMIC (jsc#SLE-7953).
- commit da0f534
* Wed Dec 18 2019 tiwai@suse.de
- drm/i915: Reduce nested prepare_remote_context() to a trylock
  (jsc#SLE-7953).
- commit 0f19c08
* Wed Dec 18 2019 tiwai@suse.de
- blacklist.conf: Add a few more i915 entries
- commit b08d57a
* Tue Dec 17 2019 tiwai@suse.de
- blacklist.conf: Add a few more bogus fixes for i915
- commit 63135e3
* Tue Dec 17 2019 tiwai@suse.de
- blacklist.conf: Remove entries that are marked already as No-Fix
- commit f8b19cf
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/query: Align flavour of engine data lookup
  (jsc#SLE-7953).
- commit 066f30e
* Tue Dec 17 2019 tiwai@suse.de
- drm: Fix kerneldoc warns in connector-related docs
  (jsc#SLE-7953).
- blacklist.conf:
- commit 78bad1b
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Fix some NULL vs IS_ERR() conditions (jsc#SLE-7953).
- commit af137f7
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Pull obj->userfault tracking under the ggtt->mutex
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Mark-contents-as-dirty-on-a-write-fault.patch.
- commit 4e3c83d
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Generalise the clflush dma-worker (jsc#SLE-7953).
- commit 6efd408
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Allow sharing the idle-barrier from other kernel
  requests (jsc#SLE-7953).
- drm/i915: Lift timeline into intel_context (jsc#SLE-7953).
- blacklist.conf:
- Refresh
  patches.suse/drm-i915-Defer-final-intel_wakeref_put-to-process-co.patch.
- commit f2b1359
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: extract i915_suspend.h from i915_drv.h (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Remove-Master-tables-from-cmdparser.patch.
- Refresh
  patches.suse/drm-i915-cmdparser-Add-support-for-backward-jumps.patch.
- commit c0ae53a
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: extract i915_perf.h from i915_drv.h (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Remove-Master-tables-from-cmdparser.patch.
- Refresh
  patches.suse/drm-i915-cmdparser-Add-support-for-backward-jumps.patch.
- commit 9d4c2ab
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Defer final intel_wakeref_put to process context
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-gen8-Add-RC6-CTX-corruption-WA.patch.
- commit dd53316
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: split out intel_pch.[ch] from i915_drv.[ch]
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-cml-Add-second-PCH-ID-for-CMP.patch.
- commit 2861115
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Isolate i915_getparam_ioctl() (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Disable-Secure-Batches-for-gen6.patch.
- commit 49cdd5f
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: rename intel_drv.h to display/intel_display_types.h
  (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-Preload-LUTs-if-the-hw-isn-t-currently-usin.patch.
- Refresh
  patches.suse/drm-i915-avoid-including-intel_drv.h-via-i915_drv.h-.patch.
- commit d61e385
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gt: Move the [class][inst] lookup for engines onto
  the GT (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Add-support-for-mandatory-cmdparsing.patch.
- commit a00ddad
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gem: Make caps.scheduler static (jsc#SLE-7953).
- commit 9158743
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Replace struct_mutex for batch pool serialisation
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Remove-Master-tables-from-cmdparser.patch.
- Refresh
  patches.suse/drm-i915-Support-ro-ppgtt-mapped-cmdparser-shadow-bu.patch.
- Refresh
  patches.suse/drm-i915-cmdparser-Add-support-for-backward-jumps.patch.
- commit 54224b5
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/tgl: Add and use new DC5 and DC6 residency counter
  registers (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Lower-RM-timeout-to-avoid-DSI-hard-hangs.patch.
- commit f24e88e
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/oa: add content to Makefile (jsc#SLE-7953).
- commit 14f0c49
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/tgl: Update north display hotplug detection to TGL
  connections (jsc#SLE-7953).
- drm/i915/tgl: Add hpd interrupt handling (jsc#SLE-7953).
- commit d733dc7
* Tue Dec 17 2019 tiwai@suse.de
- drm/hdcp: reference for srm file format (jsc#SLE-7953).
- drm/i915: update the hdcp state with uevent (jsc#SLE-7953).
- commit 5409f55
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Attach content type property (jsc#SLE-7953).
- drm: Add Content protection type property (jsc#SLE-7953).
- commit 8c5e79f
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/uc: Update drawing for firmware layout (jsc#SLE-7953).
- commit bf9ef45
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Remove set but not used variable 'src_y'
  (jsc#SLE-7953).
- Refresh
  patches.suse/0004-drm-i915-Fix-g4x-sprite-scaling-stride-check-with-GT.patch.
- commit a67f62a
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Make sure cdclk is high enough for DP audio on VLV/CHV
  (jsc#SLE-7953).
- commit 2113501
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/uc: move GuC and HuC files under gt/uc/ (jsc#SLE-7953).
- commit 75e5ecf
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gt: Use intel_gt as the primary object for handling
  resets (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-Don-t-mix-srcu-tag-and-negative-error-codes.patch.
- Refresh
  patches.suse/0001-drm-i915-Fix-and-improve-MCR-selection-logic.patch.
- Refresh
  patches.suse/drm-i915-gen8-Add-RC6-CTX-corruption-WA.patch.
- commit fc382c7
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Drop extern qualifiers from header function prototypes
  (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-Fix-and-improve-MCR-selection-logic.patch.
- Refresh
  patches.suse/drm-i915-Remove-Master-tables-from-cmdparser.patch.
- Refresh
  patches.suse/drm-i915-cmdparser-Add-support-for-backward-jumps.patch.
- commit c8d7893
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gtt: Compute the radix for gen8 page table levels
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit 55aec54
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gtt: Reorder gen8 ppgtt free/clear/alloc
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit a16779b
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gtt: Wrap page_table with page_directory
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit 71fa45e
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Add engine name to workaround debug print
  (jsc#SLE-7953).
- drm/i915: Add test for invalid flag bits in whitelist entries
  (jsc#SLE-7953).
- drm/i915: Implement read-only support in whitelist selftest
  (jsc#SLE-7953).
- drm/i915/gtt: Use shallow dma pages for scratch (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit ec55c4b
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/userptr: Don't mark readonly objects as dirty
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-userptr-Try-to-acquire-the-page-lock-around.patch.
- commit 848bfd7
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gtt: pde entry encoding is identical (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit 5787f30
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Markup potential lock for i915_active (jsc#SLE-7953).
- commit bd27d8c
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gem: Free pages before rcu-freeing the object
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Support-ro-ppgtt-mapped-cmdparser-shadow-bu.patch.
- commit b98ab90
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: whitelist PS_(DEPTH|INVOCATION)_COUNT (jsc#SLE-7953).
- commit d4fc9d3
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/execlists: Refactor CSB state machine (jsc#SLE-7953).
- Refresh
  patches.suse/0003-drm-i915-execlists-Process-interrupted-context-on-re.patch.
- commit c69c050
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Sanitize the TypeC FIA lane configuration decoding
  (jsc#SLE-7953).
- commit 7967d8b
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Factor out common parts from TypeC port handling
  functions (jsc#SLE-7953).
- commit 5386d47
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Move the TypeC port handling code to a separate file
  (jsc#SLE-7953).
- commit 5357220
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Convert most of atomic commit to take more intel state
  (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-Preload-LUTs-if-the-hw-isn-t-currently-usin.patch.
- commit 4494372
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Pass intel_crtc_state to needs_modeset()
  (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-Preload-LUTs-if-the-hw-isn-t-currently-usin.patch.
- commit 7360b01
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: make intel_uc_fw.h self-contained (jsc#SLE-7953).
- drm/i915: make intel_gvt.h self-contained (jsc#SLE-7953).
- drm/i915: make intel_guc_reg.h self-contained (jsc#SLE-7953).
- drm/i915: make intel_guc_fwif.h self-contained (jsc#SLE-7953).
- drm/i915: make intel_guc_ct.h self-contained (jsc#SLE-7953).
- drm/i915: make i915_vgpu.h self-contained (jsc#SLE-7953).
- drm/i915: make i915_pvinfo.h self-contained (jsc#SLE-7953).
- drm/i915: make i915_globals.h self-contained (jsc#SLE-7953).
- drm/i915: make i915_fixed.h self-contained (jsc#SLE-7953).
- drm/i915: add header search path to subdir Makefiles
  (jsc#SLE-7953).
- drm/i915: prefix header search path with $(srctree)/
  (jsc#SLE-7953).
- drm/i915: Move OA files to separate folder (jsc#SLE-7953).
- commit f862e29
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/icl: Add new supported CD clocks (jsc#SLE-7953).
- commit cc4a25c
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/selftests: Fixup atomic reset checking (jsc#SLE-7953).
- commit 0758444
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Rename intel_wakeref_[is]_active (jsc#SLE-7953).
- commit d288f43
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gt: Pass intel_gt to pm routines (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-Perform-GGTT-restore-much-earlier-during-re.patch.
- Refresh
  patches.suse/drm-i915-gen8-Add-RC6-CTX-corruption-WA.patch.
- commit a064bcc
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- arm64: ls1028a: enable audio support
  References: jsc#SLE-9316
- commit a7cdc29
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Prevent dereference of engine before NULL check in
  error capture (jsc#SLE-7953).
- commit e9d652e
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Rename i915_timeline to intel_timeline and move
  under gt (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-cmdparser-Add-support-for-backward-jumps.patch.
- commit be168f4
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Save trip via top-level i915 in a few more places
  (jsc#SLE-7953).
- commit 0ade10c
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Move i915_gem_chipset_flush to intel_gt
  (jsc#SLE-7953).
- commit cdfa7d6
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Stop using I915_READ/WRITE in intel_wopcm_init_hw
  (jsc#SLE-7953).
- commit 6bfe1a1
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Convert i915_gem_init_hw to intel_gt (jsc#SLE-7953).
- commit 01ae127
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Convert intel_mocs_init_l3cc_table to intel_gt
  (jsc#SLE-7953).
- commit bc875ea
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915: Move intel_gt_pm_init under intel_gt_init_early
  (jsc#SLE-7953).
- commit cd30738
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/execlists: Preempt-to-busy (jsc#SLE-7953).
- Refresh
  patches.suse/0001-drm-i915-execlists-Always-clear-pending-inflight-req.patch.
- Refresh
  patches.suse/0003-drm-i915-execlists-Process-interrupted-context-on-re.patch.
- commit 4d9e5f4
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/gvt: decouple check_vgpu() from uncore_init()
  (jsc#SLE-7953).
- Refresh
  patches.suse/drm-i915-to-make-vgpu-ppgtt-notificaiton-as-atomic-o.patch.
- commit 97898e8
* Tue Dec 17 2019 tiwai@suse.de
- drm/i915/fbdev: Restore physical addresses for fb_mmap()
  (jsc#SLE-7953).
- drm/i915: make pool objects read-only (jsc#SLE-7953).
- drm/i915: Protect request peeking with RCU (jsc#SLE-7953).
- drm/i915/tgl: MOCS table update (jsc#SLE-7953).
- drm/i915/dp: Do not switch aux to TBT mode for non-TC ports
  (jsc#SLE-7953).
- drm/i915/tgl: Fix doc not corresponding to code (jsc#SLE-7953).
- drm/i915: Fixup preempt-to-busy vs resubmission of a virtual
  request (jsc#SLE-7953).
- drm/i915/execlists: Refactor -EIO markup of hung requests
  (jsc#SLE-7953).
- drm/i915/gt: execlists->active is serialised by the tasklet
  (jsc#SLE-7953).
- drm/i915/execlists: Protect peeking at execlists->active
  (jsc#SLE-7953).
- drm/i915: Fixup preempt-to-busy vs reset of a virtual request
  (jsc#SLE-7953).
- drm/i915: Only enqueue already completed requests
  (jsc#SLE-7953).
- drm/i915/execlists: Drop redundant
  list_del_init(&rq->sched.link) (jsc#SLE-7953).
- drm/i915: Prevent bonded requests from overtaking each other
  on preemption (jsc#SLE-7953).
- drm/i915: Verify the engine after acquiring the active.lock
  (jsc#SLE-7953).
- drm/i915/execlists: Remove incorrect BUG_ON for schedule-out
  (jsc#SLE-7953).
- Revert "drm/i915: Fix DP-MST crtc_mask" (jsc#SLE-7953).
- drm/i915: Use NOEVICT for first pass on attemping to pin a
  GGTT mmap (jsc#SLE-7953).
- drm/i915: Flush the existing fence before GGTT read/write
  (jsc#SLE-7953).
- drm/i915: Hold irq-off for the entire fake lock period
  (jsc#SLE-7953).
- drm/i915/gvt: update RING_START reg of vGPU when the context
  is submitted to i915 (jsc#SLE-7953).
- drm/i915: Select DMABUF_SELFTESTS for the default i915.ko
  debug build (jsc#SLE-7953).
- drm/i915: Update DRIVER_DATE to 20190822 (jsc#SLE-7953).
- drm/i915: Replace i915_vma_put_fence() (jsc#SLE-7953).
- drm/i915: Track ggtt fence reservations under its own mutex
  (jsc#SLE-7953).
- drm/i915/selftests: Fixup a couple of missing serialisation
  with vma (jsc#SLE-7953).
- drm/i915/gtt: Add some range asserts (jsc#SLE-7953).
- drm/i915/execlists: Set priority hint prior to submission
  (jsc#SLE-7953).
- drm/i915: Replace PIN_NONFAULT with calls to PIN_NOEVICT
  (jsc#SLE-7953).
- drm/i915/gtt: Include asm/smp.h (jsc#SLE-7953).
- drm/i915/hdmi: make hdcp2_msg_data const (jsc#SLE-7953).
- drm/i915/hdmi: stylistic cleanup around hdcp2_msg_data
  (jsc#SLE-7953).
- drm/i915/dp: make hdcp2_dp_msg_data const (jsc#SLE-7953).
- drm/i915/dp: avoid shadowing variables (jsc#SLE-7953).
- drm/i915/dp: stylistic cleanup around hdcp2_msg_data
  (jsc#SLE-7953).
- drm/i915/gtt: Relax assertion for pt_used (jsc#SLE-7953).
- drm/i915: Fix DP-MST crtc_mask (jsc#SLE-7953).
- drm/i915/tgl: update DMC firmware to 2.04 (jsc#SLE-7953).
- drm/i915/tgl: Move transcoders to pipes' powerwells
  (jsc#SLE-7953).
- drm/i915/tgl: add support for reading the timestamp frequency
  (jsc#SLE-7953).
- drm/i915/tgl: disable DDIC (jsc#SLE-7953).
- drm/i915: Update DRIVER_DATE to 20190820 (jsc#SLE-7953).
- drm/i915/gtt: Relax pd_used assertion (jsc#SLE-7953).
- drm/i915: Dynamically allocate s0ix struct for VLV
  (jsc#SLE-7953).
- drm/i915/tgl: Gen12 render context size (jsc#SLE-7953).
- drm/i915/tgl: Updated Private PAT programming (jsc#SLE-7953).
- drm/i915/tgl: Introduce initial Tiger Lake workarounds
  (jsc#SLE-7953).
- drm/i915/tgl: Gen12 csb support (jsc#SLE-7953).
- drm/i915/tgl: add GEN12_MAX_CONTEXT_HW_ID (jsc#SLE-7953).
- drm/i915/tgl: add Gen12 default indirect ctx offset
  (jsc#SLE-7953).
- drm/i915/tgl: Report valid VDBoxes with SFC capability
  (jsc#SLE-7953).
- drm/i915: Be defensive when starting vma activity
  (jsc#SLE-7953).
- drm/i915: Serialize insertion into the file->mm.request_list
  (jsc#SLE-7953).
- drm/i915: Sanitize PHY state during display core uninit
  (jsc#SLE-7953).
- drm/i915: Assume exclusive access to objects inside resume
  (jsc#SLE-7953).
- drm/i915: Use 0 for the unordered context (jsc#SLE-7953).
- drm/i915: i915_active.retire() is optional (jsc#SLE-7953).
- drm/i915/gen11: Allow usage of all GPIO pins (jsc#SLE-7953).
- drm/i915: Serialize against vma moves (jsc#SLE-7953).
- drm/i915: Only emit the 'send bug report' once for a GPU hang
  (jsc#SLE-7953).
- drm/i915/gt: Mark up the nested engine-pm timeline lock as
  irqsafe (jsc#SLE-7953).
- drm/i915: Always wrap the ring offset before resetting
  (jsc#SLE-7953).
- drm/i915: Propagate fence errors (jsc#SLE-7953).
- drm/i915/uc: Never fail on HuC firmware errors (jsc#SLE-7953).
- drm/i915/uc: Don't always fail on unavailable GuC firmware
  (jsc#SLE-7953).
- drm/i915/guc: Don't open log relay if GuC is not running
  (jsc#SLE-7953).
- drm/i915/uc: Never fail on uC preparation step (jsc#SLE-7953).
- drm/i915/uc: Cleanup fw fetch on every GuC/HuC init failure
  (jsc#SLE-7953).
- drm/i915/uc: Cleanup fw fetch only if it was successful
  (jsc#SLE-7953).
- drm/i915/selftests: Check the context size (jsc#SLE-7953).
- drm/i915/gtt: Fold gen8 insertions into one (jsc#SLE-7953).
- drm/i915/uc: Add explicit DISABLED state for firmware
  (jsc#SLE-7953).
- drm/i915: Wrappers for display register waits (jsc#SLE-7953).
- drm/i915: Move gmbus definitions out of i915_reg.h
  (jsc#SLE-7953).
- drm/i915: Move engine IDs out of i915_reg.h (jsc#SLE-7953).
- drm/i915: Move i915_power_well_id out of i915_reg.h
  (jsc#SLE-7953).
- drm/i915/execlists: Lift process_csb() out of the irq-off
  spinlock (jsc#SLE-7953).
- drm/i915: Markup expected timeline locks for i915_active
  (jsc#SLE-7953).
- drm/i915/gt: Mark context->active_count as protected by
  timeline->mutex (jsc#SLE-7953).
- drm/i915/wopcm: Fix SPDX tag location (jsc#SLE-7953).
- drm/i915/wopcm: Update error messages (jsc#SLE-7953).
- drm/i915/wopcm: Try to use already locked WOPCM layout
  (jsc#SLE-7953).
- drm/i915/wopcm: Check WOPCM layout separately from calculations
  (jsc#SLE-7953).
- drm/i915/uc: Move FW size sanity check back to fetch
  (jsc#SLE-7953).
- drm/i915/buddy: use kmemleak_update_trace (jsc#SLE-7953).
- drm/i915/buddy: tidy up i915_buddy_fini (jsc#SLE-7953).
- drm/i915: Use the associated uncore for the vm (jsc#SLE-7953).
- drm/i915: Extract intel_frontbuffer active tracking
  (jsc#SLE-7953).
- drm/i915: Protect request retirement with timeline->mutex
  (jsc#SLE-7953).
- drm/i915/gt: Guard timeline pinning without relying on
  struct_mutex (jsc#SLE-7953).
- drm/i915/gt: Convert timeline tracking to spinlock
  (jsc#SLE-7953).
- drm/i915/gt: Track timeline activeness in enter/exit
  (jsc#SLE-7953).
- drm/i915: Move tasklet kicking to __i915_request_queue caller
  (jsc#SLE-7953).
- drm/i915/icl: Add gen11 specific render breadcrumbs
  (jsc#SLE-7953).
- drm/i915/icl: Add command cache invalidate (jsc#SLE-7953).
- drm/i915/icl: Implement gen11 flush including tile cache
  (jsc#SLE-7953).
- drm/i915/selftest/buddy: fixup igt_buddy_alloc_range
  (jsc#SLE-7953).
- drm/i915: Convert a few more bland dmesg info to be device
  specific (jsc#SLE-7953).
- drm/i915: Serialise read/write of the barrier's engine
  (jsc#SLE-7953).
- drm/i915: Print CCID for all renderCS (jsc#SLE-7953).
- drm/i915: Disregard drm_mode_config.fb_base (jsc#SLE-7953).
- drm/i915: Include engine->mmio_base in the debug dump
  (jsc#SLE-7953).
- drm/i915/guc: Remove client->submissions (jsc#SLE-7953).
- drm/i915: Update DRIVER_DATE to 20190813 (jsc#SLE-7953).
- drm/i915: Add _TRANS2() (jsc#SLE-7953).
- drm/i915/bdw+: Move misc display IRQ handling to it own function
  (jsc#SLE-7953).
- drm/i915/gvt: Double check batch buffer size after copy
  (jsc#SLE-7953).
- drm/i915/gvt: Add valid length check for MI variable commands
  (jsc#SLE-7953).
- drm/i915/gvt: Add MI command valid length check (jsc#SLE-7953).
- drm/i915/gvt: Utility for valid command length check
  (jsc#SLE-7953).
- drm/i915/gvt: factor out tlb and mocs register offset table
  (jsc#SLE-7953).
- drm/i915/gvt: no need to check return value of debugfs_create
  functions (jsc#SLE-7953).
- drm/i915/gvt: Fix typo of VBLANK_TIMER_PERIOD (jsc#SLE-7953).
- drm/i915/kvmgt: Use struct_size() helper (jsc#SLE-7953).
- drm/i915/gt: Save/restore interrupts around breadcrumb disable
  (jsc#SLE-7953).
- drm/i915: Push the wakeref->count deferral to the backend
  (jsc#SLE-7953).
- drm/i915/tgl: Fix missing parentheses on
  TGL_TRANS_DDI_FUNC_CTL_VAL_TO_PORT (jsc#SLE-7953).
- drm/i915/uc: Log fw status changes only under debug config
  (jsc#SLE-7953).
- drm/i915/guc: Use a local cancel_port_requests (jsc#SLE-7953).
- drm/i915: drop engine_pin/unpin_breadcrumbs_irq (jsc#SLE-7953).
- drm/i915/guc: keep breadcrumb irq always enabled (jsc#SLE-7953).
- drm/i915/overlay: Switch to using i915_active tracking
  (jsc#SLE-7953).
- drm/i915: Forgo last_fence active request tracking
  (jsc#SLE-7953).
- drm/i915: Extract general GT interrupt handlers (jsc#SLE-7953).
- drm/i915: Extract GT powermanagement interrupt handling
  (jsc#SLE-7953).
- drm/i915/gt: Use the local engine wakeref when checking RING
  registers (jsc#SLE-7953).
- drm/i915/selftests: Prevent the timeslice expiring during
  suppression tests (jsc#SLE-7953).
- drm/i915/execlists: Avoid sync calls during park (jsc#SLE-7953).
- drm/i915/uc: Update copyright and license (jsc#SLE-7953).
- drm/i915/tgl: Fixing up list of PG3 power domains
  (jsc#SLE-7953).
- drm/i915/icl: Remove DDI IO power domain from PG3 power domains
  (jsc#SLE-7953).
- drm/i915/uc: Use -EIO code for GuC initialization failures
  (jsc#SLE-7953).
- drm/i915/uc: Update messages from fw upload step (jsc#SLE-7953).
- drm/i915/uc: Include HuC firmware version in summary
  (jsc#SLE-7953).
- drm/i915/uc: Fail early if there is no GuC fw available
  (jsc#SLE-7953).
- drm/i915: Remove unused debugfs/i915_emon_status (jsc#SLE-7953).
- drm/i915: buddy allocator (jsc#SLE-7953).
- drm/i915/blt: support copying objects (jsc#SLE-7953).
- drm/i915/gtt: disable 2M pages for pre-gen11 (jsc#SLE-7953).
- drm/i915/gtt: enable GTT cache by default (jsc#SLE-7953).
- drm/i915/selftests: move gpu-write-dw into utils (jsc#SLE-7953).
- drm/i915/blt: bump the size restriction (jsc#SLE-7953).
- drm/i915/blt: don't assume pinned intel_context (jsc#SLE-7953).
- drm/i915: split out uncore_mmio_debug (jsc#SLE-7953).
- drm/i915: Stop reconfiguring our shmemfs mountpoint
  (jsc#SLE-7953).
- drm/i915: Push the ring creation flags to the backend
  (jsc#SLE-7953).
- drm/i915/gt: Make deferred context allocation explicit
  (jsc#SLE-7953).
- drm/i915: Remove i915_gem_context_create_gvt() (jsc#SLE-7953).
- drm/i915: Drop the fudge warning on ring restart for ctg/elk
  (jsc#SLE-7953).
- drm/i915: Generalise BSD default selection (jsc#SLE-7953).
- drm/i915: Replace global bsd_dispatch_index with random seed
  (jsc#SLE-7953).
- drm/i915: Check for a second VCS engine more carefully
  (jsc#SLE-7953).
- drm/i915/execlists: Backtrack along timeline (jsc#SLE-7953).
- drm/i915: Free the imported shmemfs file for phys objects
  (jsc#SLE-7953).
- drm/i915: extract i915_gem_shrinker.h from i915_drv.h
  (jsc#SLE-7953).
- drm/i915: extract gem/i915_gem_stolen.h from i915_drv.h
  (jsc#SLE-7953).
- drm/i915: extract i915_memcpy.h from i915_drv.h (jsc#SLE-7953).
- drm/i915: extract i915_sysfs.h from i915_drv.h (jsc#SLE-7953).
- drm/i915: move printing and load error inject to i915_utils.[ch]
  (jsc#SLE-7953).
- drm/i915: move I915_STATE_WARN() and _ON() to intel_display.h
  (jsc#SLE-7953).
- drm/i915: move add_taint_for_CI() to i915_utils.h
  (jsc#SLE-7953).
- drm/i915: remove unused dev_priv->no_aux_handshake
  (jsc#SLE-7953).
- drm/i915: Make debugfs/per_file_stats scale better
  (jsc#SLE-7953).
- drm/i915: Only include active engines in the capture state
  (jsc#SLE-7953).
- drm/i915/selftests: Fixup a missing legacy_idx (jsc#SLE-7953).
- drm/i915/tgl: Fix the read of the DDI that transcoder is
  attached to (jsc#SLE-7953).
- drm/i915: Get transcoder power domain before reading its
  register (jsc#SLE-7953).
- drm/i915: Fix up the inverse mapping for default ctx->engines[]
  (jsc#SLE-7953).
- drm/i915: Allocate kernel_contexts directly (jsc#SLE-7953).
- drm/i915/selftests: Pass intel_context to mock_request
  (jsc#SLE-7953).
- drm/i915/tgl/dsi: Enable blanking packets during BLLP for
  video mode (jsc#SLE-7953).
- drm/i915/tgl: Add mipi dsi support for TGL (jsc#SLE-7953).
- drm/i915/tgl/dsi: Gate the ddi clocks after pll mapping
  (jsc#SLE-7953).
- drm/i915/tgl/dsi: Do not override TA_SURE (jsc#SLE-7953).
- drm/i915/tgl/dsi: Set latency PCS_DW1 for tgl (jsc#SLE-7953).
- drm/i915/tgl/dsi: Program TRANS_VBLANK register (jsc#SLE-7953).
- drm/i915/uc: Hardening firmware fetch (jsc#SLE-7953).
- drm/i915/uc: WOPCM programming errors are not always real
  (jsc#SLE-7953).
- drm/i915: Make wopcm_to_i915() private (jsc#SLE-7953).
- drm/i915: Don't try to partition WOPCM without GuC firmware
  (jsc#SLE-7953).
- drm/i915/uc: Don't fetch HuC fw if GuC fw fetch already failed
  (jsc#SLE-7953).
- drm/i915/uc: HuC firmware can't be supported without GuC
  (jsc#SLE-7953).
- drm/i915/uc: Prefer dev_info for reporting options
  (jsc#SLE-7953).
- drm/i915/perf: Refactor oa object to better manage resources
  (jsc#SLE-7953).
- drm/i915: Include the DRIVER_DATE in the error state
  (jsc#SLE-7953).
- drm/i915: Use intel_engine_lookup_user for probing HAS_BSD etc
  (jsc#SLE-7953).
- drm/i915: Rename engines to match their user interface
  (jsc#SLE-7953).
- drm/i915: Drop expectations of VM_IO from our GGTT mmappings
  (jsc#SLE-7953).
- drm/i915: abstract display suspend/resume operations
  (jsc#SLE-7953).
- drm/i915: move property enums to intel_display_types.h
  (jsc#SLE-7953).
- drm/i915: remove unnecessary includes of intel_display_types.h
  header (jsc#SLE-7953).
- drm/i915: avoid including intel_drv.h via
  i915_drv.h->i915_trace.h (jsc#SLE-7953).
- drm/i915/tc: un-inline intel_tc_port_ref_held() (jsc#SLE-7953).
- drm/i915/mst: un-inline intel_dp_mst_encoder_active_links()
  (jsc#SLE-7953).
- drm/i915/bw: make intel_atomic_get_bw_state() static
  (jsc#SLE-7953).
- drm/i915/irq: un-inline functions to avoid i915_drv.h include
  (jsc#SLE-7953).
- drm/i915/sprite: un-inline icl_is_hdr_plane() (jsc#SLE-7953).
- drm/i915: move intel_display.c function declarations
  (jsc#SLE-7953).
- drm/i915/dmc: Load DMC on TGL (jsc#SLE-7953).
- drm/i915: Use drm_i915_private directly from drv_get_drvdata()
  (jsc#SLE-7953).
- drm/i915/gt: Remove stale kerneldoc for internal MOCS functions
  (jsc#SLE-7953).
- drm/i915/uc: Don't fail on HuC early init errors (jsc#SLE-7953).
- drm/i915/uc: Remove redundant GuC support checks (jsc#SLE-7953).
- drm/i915/huc: Prefer intel_huc_is_supported (jsc#SLE-7953).
- drm/i915/guc: Prefer intel_guc_is_submission_supported
  (jsc#SLE-7953).
- drm/i915: Teach execbuffer to take the engine wakeref not GT
  (jsc#SLE-7953).
- drm/i915: Flush the freed object list on file close
  (jsc#SLE-7953).
- drm/i915: Hide unshrinkable context objects from the shrinker
  (jsc#SLE-7953).
- drm/i915/wopcm: Don't fail on WOPCM partitioning failure
  (jsc#SLE-7953).
- drm/i915/uc: Inject probe errors into intel_uc_init_hw
  (jsc#SLE-7953).
- drm/i915/uc: Move GuC error log to uc and release it on fini
  (jsc#SLE-7953).
- drm/i915/uc: Reorder firmware status codes (jsc#SLE-7953).
- drm/i915/uc: Do full sanitize instead of pure reset
  (jsc#SLE-7953).
- drm/i915: Add i915 to i915_inject_probe_failure (jsc#SLE-7953).
- drm/i915: Report resv_obj allocation failure (jsc#SLE-7953).
- drm/i915: Fix documentation for __intel_wait_for_register_fw*
  (jsc#SLE-7953).
- drm/i915/oa: update the generated files (jsc#SLE-7953).
- drm/i915: Flush extra hard after writing relocations through
  the GTT (jsc#SLE-7953).
- drm/i915/pmu: Atomically acquire the gt_pm wakeref
  (jsc#SLE-7953).
- drm/i915/pmu: Make get_rc6 take intel_gt (jsc#SLE-7953).
- drm/i915/pmu: Convert sampling to gt (jsc#SLE-7953).
- drm/i915/pmu: Convert engine sampling to uncore mmio
  (jsc#SLE-7953).
- drm/i915/pmu: Make more struct i915_pmu centric (jsc#SLE-7953).
- drm/i915/tgl: allow the reg_read ioctl to read the RCS TIMESTAMP
  register (jsc#SLE-7953).
- drm/i915/uc: Stop sanitizing enable_guc modparam (jsc#SLE-7953).
- drm/i915/guc: Use dedicated flag to track submission mode
  (jsc#SLE-7953).
- drm/i915/uc: Consider enable_guc modparam during fw selection
  (jsc#SLE-7953).
- drm/i915/uc: Rename intel_uc_is_using* into intel_uc_supports*
  (jsc#SLE-7953).
- drm/i915/gt: Introduce intel_gt_runtime_suspend/resume
  (jsc#SLE-7953).
- drm/i915/uc: Move uC early functions inside the GT ones
  (jsc#SLE-7953).
- drm/i915/gt: Move gt_cleanup_early out of gem_cleanup_early
  (jsc#SLE-7953).
- drm/i915: Remove lrc default desc from GEM context
  (jsc#SLE-7953).
- drm/i915/ehl: Don't forget to handle port C's hotplug interrupts
  (jsc#SLE-7953).
- drm/i915/ehl: Ungate DDIC and DDID (jsc#SLE-7953).
- drm/i915: Move MOCS setup to intel_mocs.c (jsc#SLE-7953).
- drm/i915/tgl: Tigerlake only has global MOCS registers
  (jsc#SLE-7953).
- drm/i915/tgl: Define MOCS entries for Tigerlake (jsc#SLE-7953).
- drm/i915/tgl: stop using ERROR_GEN6 and DONE_REG (jsc#SLE-7953).
- drm/i915/tgl: Move fault registers to their new offset
  (jsc#SLE-7953).
- drm/i915: remove dangling forward declaration (jsc#SLE-7953).
- drm/i915/uc: Move uC WOPCM setup in uc_init_hw (jsc#SLE-7953).
- drm/i915/uc: Don't enable communication twice on resume
  (jsc#SLE-7953).
- drm/i915/selftests: Pass intel_context to igt_spinner
  (jsc#SLE-7953).
- drm/i915: Avoid ce->gem_context->i915 (jsc#SLE-7953).
- drm/i915: make i915_selftest.h self-contained (jsc#SLE-7953).
- drm/i915/tgl: handle DP aux interrupts (jsc#SLE-7953).
- drm/i915: stop using seqcount for fence pruning (jsc#SLE-7953).
- drm/i915: remove irrelevant DRM_UNLOCKED flag (jsc#SLE-7953).
- drm/i915: Update DRIVER_DATE to 20190730 (jsc#SLE-7953).
- drm/i915/gt: Provide a local intel_context.vm (jsc#SLE-7953).
- drm/i915: Move aliasing_ppgtt underneath its i915_ggtt
  (jsc#SLE-7953).
- drm/i915: Inline engine->init_context into its caller
  (jsc#SLE-7953).
- drm/i915: use upstream version of header tests (jsc#SLE-7953).
- drm/i915/uc: Don't fail on HuC firmware failure (jsc#SLE-7953).
- drm/i915: Flush the i915_vm_release before ggtt shutdown
  (jsc#SLE-7953).
- drm/i915/selftests: Careful not to flush hang_fini on error
  setups (jsc#SLE-7953).
- drm/i915/uc: Fixup kerneldoc after params were flipped and
  renamed (jsc#SLE-7953).
- drm/i915/tgl: update ddi/tc clock_off bits (jsc#SLE-7953).
- drm/i915/tgl: select correct bit for port select (jsc#SLE-7953).
- drm/i915/tgl: skip setting PORT_CL_DW12_* on initialization
  (jsc#SLE-7953).
- drm/i915/uc: Remove redundant RSA offset definition
  (jsc#SLE-7953).
- drm/i915/uc: Remove redundant ucode offset definition
  (jsc#SLE-7953).
- drm/i915/uc: Remove redundant header_offset/size definitions
  (jsc#SLE-7953).
- drm/i915/gt: Add to timeline requires the timeline mutex
  (jsc#SLE-7953).
- drm/i915/uc: Don't sanitize guc_log_level modparam
  (jsc#SLE-7953).
- drm/i915: Do not rely on for loop caching the mask
  (jsc#SLE-7953).
- drm/i915/perf: Initialise err to 0 before looping over
  ce->engines (jsc#SLE-7953).
- drm/i915/guc: init submission structures as part of guc_init
  (jsc#SLE-7953).
- drm/i915/uc: Reorder params in intel_uc_fw_fetch (jsc#SLE-7953).
- drm/i915: Capture vma contents outside of spinlock
  (jsc#SLE-7953).
- drm/i915/uc: Move uc firmware layout definitions to dedicated
  file (jsc#SLE-7953).
- drm/i915/uc: Unify uC firmware upload (jsc#SLE-7953).
- drm/i915/uc: Plumb the gt through fw_upload (jsc#SLE-7953).
- drm/i915/huc: Copy huc rsa only once (jsc#SLE-7953).
- drm/i915/uc: Move xfer rsa logic to common function
  (jsc#SLE-7953).
- drm/i915/uc: Unify uc_fw status tracking (jsc#SLE-7953).
- drm/i915/uc: Unify uC FW selection (jsc#SLE-7953).
- drm/i915: Fix handling of non-supported uC (jsc#SLE-7953).
- drm/i915/uc: Unify uC platform check (jsc#SLE-7953).
- drm/i915/guc: Set GuC init params only once (jsc#SLE-7953).
- drm/i915: Use dev_get_drvdata (jsc#SLE-7953).
- drm/i915/huc: fix status check (jsc#SLE-7953).
- drm/i915: Squelch nop wait-for-idle trace (jsc#SLE-7953).
- drm/i915/selftests: Let igt_vma_partial et al breathe
  (jsc#SLE-7953).
- drm/i915/uc: Sanitize uC when GT is sanitized (jsc#SLE-7953).
- drm/i915/uc: Gt-fy uc reset (jsc#SLE-7953).
- drm/i915: Add HDCP capability info to i915_display_info
  (jsc#SLE-7953).
- drm/i915: Rely on spinlock protection for GPU error capture
  (jsc#SLE-7953).
- drm/i915/gt: Hook up intel_context_fini() (jsc#SLE-7953).
- drm/i915: Remove obsolete engine cleanup (jsc#SLE-7953).
- drm/i915/gtt: Fix rounding for 36b (jsc#SLE-7953).
- drm/i915/dsi: remove set but not used variable 'hfront_porch'
  (jsc#SLE-7953).
- drm/i915/gtt: Don't try to clear failed empty pd allocation
  (jsc#SLE-7953).
- drm/i915/gtt: Correct unshifted 'from' for gen8_ppgtt_alloc
  errors (jsc#SLE-7953).
- Revert "drm/i915: Update description of i915.enable_guc
  modparam" (jsc#SLE-7953).
- Revert "drm/i915/guc: Turn on GuC/HuC auto mode" (jsc#SLE-7953).
- drm/i915/icl: Add Wa_1409178092 (jsc#SLE-7953).
- drm/i915/icl: Verify engine workarounds in GEN8_L3SQCREG4
  (jsc#SLE-7953).
- drm/i915: Skip CS verification of L3 bank registers
  (jsc#SLE-7953).
- drm/i915/execlists: Cancel breadcrumb on preempting the virtual
  engine (jsc#SLE-7953).
- drm/i915: Use maximum write flush for pwrite_gtt (jsc#SLE-7953).
- drm/i915: Drop wmb() inside pread_gtt (jsc#SLE-7953).
- drm/i915/ehl: Use an id of 4 while accessing DPLL4's CR0 and
  CR1 (jsc#SLE-7953).
- drm/i915: Add gen8_de_pipe_fault_mask() (jsc#SLE-7953).
- drm/i915/gt: Push engine stopping into reset-prepare
  (jsc#SLE-7953).
- drm/i915: Update description of i915.enable_guc modparam
  (jsc#SLE-7953).
- drm/i915/oa: Reconfigure contexts on the fly (jsc#SLE-7953).
- drm/i915/gtt: Tidy up ppgtt insertion for gen8 (jsc#SLE-7953).
- drm/i915/gtt: Recursive ppgtt alloc for gen8 (jsc#SLE-7953).
- drm/i915/execlists: Disable preemption under GVT (jsc#SLE-7953).
- drm/i915: Enable hotplug retry (jsc#SLE-7953).
- drm/i915: Add support for retrying hotplug (jsc#SLE-7953).
- drm/i915/ehl: Map MCC pins based on PHY, not port
  (jsc#SLE-7953).
- drm/i915/selftests: Ignore self-preemption suppression under
  gvt (jsc#SLE-7953).
- drm/i915/uc: kill <g,h>uc_to_i915 (jsc#SLE-7953).
- drm/i915/guc: prefer intel_gt in guc interrupt functions
  (jsc#SLE-7953).
- drm/i915/uc: prefer intel_gt over i915 in GuC/HuC paths
  (jsc#SLE-7953).
- drm/i915/uc: Move intel functions to intel_uc (jsc#SLE-7953).
- drm/i915/uc: move GuC/HuC inside intel_gt under a new intel_uc
  (jsc#SLE-7953).
- drm/i915/guc: unify guc irq handling (jsc#SLE-7953).
- drm/i915/guc: move guc irq functions to intel_guc parameter
  (jsc#SLE-7953).
- drm/i915/uc: introduce intel_uc_fw_supported (jsc#SLE-7953).
- drm/i915/uc: replace uc init/fini misc (jsc#SLE-7953).
- drm/i915/guc: Use system workqueue for log capture
  (jsc#SLE-7953).
- drm/i915/tgl: add modular FIA to device info (jsc#SLE-7953).
- drm/i915: Add modular FIA (jsc#SLE-7953).
- drm/i915/gtt: Recursive ppgtt clear for gen8 (jsc#SLE-7953).
- drm/i915/gtt: Recursive cleanup for gen8 (jsc#SLE-7953).
- drm/i915/display: Drop kerneldoc for 'intel_atomic_commit'
  (jsc#SLE-7953).
- drm/i915: Skip SINK_COUNT read on CH7511 (jsc#SLE-7953).
- drm/i915/guc: Turn on GuC/HuC auto mode (jsc#SLE-7953).
- drm/i915/guc: Don't enable GuC/HuC in auto mode on pre-Gen11
  (jsc#SLE-7953).
- drm/i915: Propagate "_probe" function name suffix down
  (jsc#SLE-7953).
- drm/i915: Propagate "_remove" function name suffix down
  (jsc#SLE-7953).
- drm/i915: Propagate "_release" function name suffix down
  (jsc#SLE-7953).
- drm/i915: Replace "_load" with "_probe" consequently
  (jsc#SLE-7953).
- drm/i915: Rename "_load"/"_unload" to match PCI entry points
  (jsc#SLE-7953).
- drm/i915/gtt: Use NULL to encode scratch shadow entries
  (jsc#SLE-7953).
- drm/i915/gtt: Convert vm->scratch into an array (jsc#SLE-7953).
- drm/i915/gtt: Markup i915_ppgtt height (jsc#SLE-7953).
- drm/i915/tgl: Update DPLL clock reference register
  (jsc#SLE-7953).
- drm/i915/tgl: Add DPLL registers (jsc#SLE-7953).
- drm/i915/tgl: Add vbt value mapping for DDC Bus pin
  (jsc#SLE-7953).
- drm/i915/tgl: port to ddc pin mapping (jsc#SLE-7953).
- drm/i915/tgl: Add gmbus gpio pin to port mapping (jsc#SLE-7953).
- drm/i915/gen12: MBUS B credit change (jsc#SLE-7953).
- drm/i915/tgl: apply Display WA #1178 to fix type C dongles
  (jsc#SLE-7953).
- drm/i915/tgl: init ddi port A-C for Tiger Lake (jsc#SLE-7953).
- drm/i915/tgl: Add additional PHYs for Tiger Lake (jsc#SLE-7953).
- drm/i915/tgl: Add additional ports for Tiger Lake
  (jsc#SLE-7953).
- drm/i915/tgl: Add pll manager (jsc#SLE-7953).
- drm/i915/tgl: Add new pll ids (jsc#SLE-7953).
- drm/i915/tgl: Add power well to support 4th pipe (jsc#SLE-7953).
- drm/i915/tgl: Add power well support (jsc#SLE-7953).
- drm/i915/tgl: rename TRANSCODER_EDP_VDSC to use on transcoder A
  (jsc#SLE-7953).
- drm/i915/tgl: Check if pipe D is fused (jsc#SLE-7953).
- drm/i915/tgl: Add TGL PCI IDs (jsc#SLE-7953).
- drm/i915/tgl: Add TGL PCH detection in virtualized environment
  (jsc#SLE-7953).
- drm/i915/tgl: Introduce Tiger Lake PCH (jsc#SLE-7953).
- drm/i915/tgl: add initial Tiger Lake definitions (jsc#SLE-7953).
- drm/i915: Add 4th pipe and transcoder (jsc#SLE-7953).
- drm/i915: Don't overestimate 4:2:0 link symbol clock
  (jsc#SLE-7953).
- drm/i915: Copy name string into ring buffer for
  intel_update/disable_plane tracepoints (jsc#SLE-7953).
- drm/i915/guc: Drop redundant ctx param from kerneldoc
  (jsc#SLE-7953).
- drm/i915: Don't pass stack garbage to pcode in the second data
  register (jsc#SLE-7953).
- drm/i915: Use intel_ types in intel_atomic_commit()
  (jsc#SLE-7953).
- drm/i915: Use intel_ types in intel_{lock,modeset}_all_pipes()
  (jsc#SLE-7953).
- drm/i915: Polish intel_atomic_track_fbs() (jsc#SLE-7953).
- drm/i915: Polish intel_shared_dpll_swap_state() (jsc#SLE-7953).
- drm/i915: Simplify modeset_get_crtc_power_domains() arguments
  (jsc#SLE-7953).
- drm/i915: Check crtc_state->wm.need_postvbl_update before
  grabbing wm.mutex (jsc#SLE-7953).
- drm/i915: Use the "display core" power domain in vlv/chv
  set_cdclk() (jsc#SLE-7953).
- drm/i915/selftests: Hold the vma manager lock while modifying
  mmap_offset (jsc#SLE-7953).
- drm/i915/sdvo: Fix handling if zero hbuf size (jsc#SLE-7953).
- drm/i915/guc: Simplify guc client (jsc#SLE-7953).
- drm/i915/guc: Remove preemption support for current fw
  (jsc#SLE-7953).
- drm/i915/selftests: Ensure we don't clamp a random offset to
  32b (jsc#SLE-7953).
- drm/i915/gt: Drop the duplicate icl workaround (jsc#SLE-7953).
- drm/i915/ehl: Enable DDI-D (jsc#SLE-7953).
- drm/i915: Transition port type checks to phy checks
  (jsc#SLE-7953).
- drm/i915/gen11: Convert combo PHY logic to use new 'enum phy'
  namespace (jsc#SLE-7953).
- drm/i915/gen11: Program ICL_DPCLKA_CFGCR0 according to PHY
  (jsc#SLE-7953).
- drm/i915/gen11: Start distinguishing 'phy' from 'port'
  (jsc#SLE-7953).
- drm/i915: move intel_ddi_set_fia_lane_count to intel_tc.c
  (jsc#SLE-7953).
- drm/i915: fix include order in intel_tc.* (jsc#SLE-7953).
- drm/i915: make new intel_tc.c use uncore accessors
  (jsc#SLE-7953).
- drm/i915/icl: Fixed Input CSC Co-efficients for BT601/709
  (jsc#SLE-7953).
- drm/i915/icl: Fix Y pre-offset for Full Range YCbCr
  (jsc#SLE-7953).
- drm/i915/icl: Handle YCbCr to RGB conversion for BT2020 case
  (jsc#SLE-7953).
- drm/i915/execlists: Record preemption for selftests
  (jsc#SLE-7953).
- drm/i915: Remove unused i915_gem_context_lookup_engine
  (jsc#SLE-7953).
- drm/i915: add infrastructure to hold off preemption on a request
  (jsc#SLE-7953).
- drm/i915: enumerate scratch fields (jsc#SLE-7953).
- drm/i915/icl: Clear the shared port PLLs from the new crtc state
  (jsc#SLE-7953).
- drm/i915: Clear the shared PLL from the put_dplls() hook
  (jsc#SLE-7953).
- drm/i915/sdvo: Add helpers to get the cmd/status string
  (jsc#SLE-7953).
- drm/i915/sdvo: Shrink sdvo_cmd_names[] strings (jsc#SLE-7953).
- drm/i915/sdvo: Remove duplicate SET_INPUT_TIMINGS_PART1 cmd
  name string (jsc#SLE-7953).
- drm/i915/sdvo: Use named initializers for the SDVO command names
  (jsc#SLE-7953).
- drm/i915: Add icl mipi dsi properties (jsc#SLE-7953).
- drm/i915/hdcp: debug logs for sink related failures
  (jsc#SLE-7953).
- drm/i915/gt: Remove presumption of RCS0 (jsc#SLE-7953).
- drm/i915/gt: Apply RCS workarounds to the render class
  (jsc#SLE-7953).
- drm/i915/selftests: Fill in a little more of the dummy fence
  (jsc#SLE-7953).
- drm/i915/selftests: Set igt_spinner.gt for early exit
  (jsc#SLE-7953).
- drm/i915: Update DRIVER_DATE to 20190708 (jsc#SLE-7953).
- drm/i915/selftests: Reorder error cleanup for whitelist checking
  (jsc#SLE-7953).
- drm/i915: Explicitly track active fw_domain timers
  (jsc#SLE-7953).
- drm/i915: Pull assert_forcewake_active() underneath the lock
  (jsc#SLE-7953).
- drm/i915/gtt: Introduce release_pd_entry (jsc#SLE-7953).
- drm/i915/gtt: Setup phys pages for 3lvl pdps (jsc#SLE-7953).
- drm/i915/gtt: Tear down setup and cleanup macros for page dma
  (jsc#SLE-7953).
- drm/i915: Remove set but not used variable 'intel_dig_port'
  (jsc#SLE-7953).
- drm/i915: Remove set but not used variable 'encoder'
  (jsc#SLE-7953).
- drm/i915: Order assert forcewake test (jsc#SLE-7953).
- drm/i915/ehl: Add support for DPLL4 (v10) (jsc#SLE-7953).
- drm/i915: Clean up skl vs. icl plane formats (jsc#SLE-7953).
- drm/i915: Cosmetic fix for skl+ plane switch statement
  (jsc#SLE-7953).
- drm/i915: Deal with cpp==8 for g4x watermarks (jsc#SLE-7953).
- drm/i915: Program plane gamma ramps (jsc#SLE-7953).
- drm/i915: Disable sprite gamma on ivb-bdw (jsc#SLE-7953).
- drm/i915: Add windowing for primary planes on gen2/3 and chv
  (jsc#SLE-7953).
- drm/i915: Move dev_priv->pm_i{m, e}r into intel_gt
  (jsc#SLE-7953).
- drm/i915: Remove some legacy mmio accessors from interrupt
  handling (jsc#SLE-7953).
- drm/i915: Rework some interrupt handling functions to take
  intel_gt (jsc#SLE-7953).
- drm/i915: Show instdone for each engine in debugfs
  (jsc#SLE-7953).
- drm/i915/selftests: Be engine agnostic (jsc#SLE-7953).
- drm/i915/overlay: Stash the kernel context on initialisation
  (jsc#SLE-7953).
- drm/i915/hangcheck: Look at instdone for all engines
  (jsc#SLE-7953).
- drm/i915/selftests: Drain the freedlists between exec passes
  (jsc#SLE-7953).
- drm/i915/gt: Pull engine w/a initialisation into common
  (jsc#SLE-7953).
- drm/i915: Dump w/a lists on all engines (jsc#SLE-7953).
- drm/i915/guc: Upgrade to GuC 33.0.0 (jsc#SLE-7953).
- drm/i915/gtt: Handle double alloc failures (jsc#SLE-7953).
- drm/i915: Show support for accurate sw PMU busyness tracking
  (jsc#SLE-7953).
- drm/i915/gem: Defer obj->base.resv fini until RCU callback
  (jsc#SLE-7953).
- drm/i915/gt: Ignore forcewake acquisition for posting_reads
  (jsc#SLE-7953).
- drm/i915/gt: Assume we hold forcewake for execlists resume
  (jsc#SLE-7953).
- drm/i915/gt: Use caller provided forcewake for
  intel_mocs_init_engine (jsc#SLE-7953).
- drm/i915: Check caller held wakerefs in assert_forcewakes_active
  (jsc#SLE-7953).
- drm/i915: Flush the workqueue before draining (jsc#SLE-7953).
- drm/i915: Move the renderstate setup under gt/ (jsc#SLE-7953).
- drm/i915: Add N & CTS values for 10/12 bit deep color
  (jsc#SLE-7953).
- drm/i915: Use port clock to set correct N value (jsc#SLE-7953).
- drm/i915: Mark up vma->active as safe for use inside shrinkers
  (jsc#SLE-7953).
- drm/i915/execlists: Hesitate before slicing (jsc#SLE-7953).
- drm/i915/selftests: Lock the drm_mm while modifying
  (jsc#SLE-7953).
- drm/i915/selftests: Common live setup/teardown (jsc#SLE-7953).
- drm/i915/display: Handle lost primary_port across suspend
  (jsc#SLE-7953).
- drm/i915: synchronize_irq() against the actual irq
  (jsc#SLE-7953).
- drm/i915/gtt: Don't check PPGTT presence on PPGTT-only platforms
  (jsc#SLE-7953).
- Revert "drm/i915: Introduce private PAT management"
  (jsc#SLE-7953).
- drm/i915: Report if i915_active is still busy upon waiting
  (jsc#SLE-7953).
- drm/i915/ehl: Don't program PHY_MISC on EHL PHY C
  (jsc#SLE-7953).
- drm/i915/ehl: Add third combo PHY offset (jsc#SLE-7953).
- drm/i915/icl: Drop port parameter to icl_get_combo_buf_trans()
  (jsc#SLE-7953).
- drm/i915/guc: Avoid reclaim locks during reset (jsc#SLE-7953).
- drm/i915: WARN about invalid lane reversal in TBT-alt/DP-alt
  modes (jsc#SLE-7953).
- drm/i915: Remove unneeded disconnect in TypeC legacy port mode
  (jsc#SLE-7953).
- drm/i915: Add state verification for the TypeC port mode
  (jsc#SLE-7953).
- drm/i915: Keep the TypeC port mode fixed when the port is active
  (jsc#SLE-7953).
- drm/i915/icl: Reserve all required PLLs for TypeC ports
  (jsc#SLE-7953).
- drm/i915/icl: Split getting the DPLLs to port type specific
  functions (jsc#SLE-7953).
- drm/i915: Sanitize the shared DPLL find/reference interface
  (jsc#SLE-7953).
- drm/i915: Sanitize the shared DPLL reserve/release interface
  (jsc#SLE-7953).
- drm/i915: Keep the TypeC port mode fixed for detect/AUX
  transfers (jsc#SLE-7953).
- drm/i915: Fix the TypeC port mode sanitization during
  loading/resume (jsc#SLE-7953).
- drm/i915: Sanitize the TypeC connect/detect sequences
  (jsc#SLE-7953).
- drm/i915: Handle the TCCOLD power-down event (jsc#SLE-7953).
- drm/i915: Wait for TypeC PHY complete flag to clear in safe mode
  (jsc#SLE-7953).
- drm/i915: Unify the TypeC port notation in debug/error messages
  (jsc#SLE-7953).
- drm/i915: Use the correct AUX power domain in TypeC TBT-alt mode
  (jsc#SLE-7953).
- drm/i915: Don't enable the DDI-IO power in the TypeC TBT-alt
  mode (jsc#SLE-7953).
- drm/i915: Sanitize the terminology used for TypeC port modes
  (jsc#SLE-7953).
- drm/i915: Tune down WARNs about TBT AUX power well enabling
  (jsc#SLE-7953).
- drm/i915/icl: Add support to read out the TBT PLL HW state
  (jsc#SLE-7953).
- drm/i915: Use intel state as much as possible in wm code
  (jsc#SLE-7953).
- drm/i915: Pass intel state to plane functions as well
  (jsc#SLE-7953).
- drm/i915: Use intel_crtc_state in sanitize_watermarks() too
  (jsc#SLE-7953).
- drm/i915: Convert hw state verifier to take more intel state,
  v2 (jsc#SLE-7953).
- drm/i915: rework reading pipe disable fuses (jsc#SLE-7953).
- drm/i915: Make i945gm_vblank_work_func static (jsc#SLE-7953).
- drm/i915/ehl: Add voltage level requirement table
  (jsc#SLE-7953).
- drm/i915/ehl: Remove unsupported cd clocks (jsc#SLE-7953).
- drm/i915: Initialize drm_driver vblank funcs at compile time
  (jsc#SLE-7953).
- drm/i915: Nuke drm_driver irq vfuncs (jsc#SLE-7953).
- drm/i915: Switch to per-crtc vblank vfuncs (jsc#SLE-7953).
- drm/i915/selftests: Drop manual request wakerefs around
  hangcheck (jsc#SLE-7953).
- drm/i915/selftests: Serialise nop reset with retirement
  (jsc#SLE-7953).
- drm/i915: Check backlight type while doing eDP backlight
  initializaiton (jsc#SLE-7953).
- drm/i915/icl: Add missing device ID (jsc#SLE-7953).
- drm/i915/gt: Add some debug tracing for context pinning
  (jsc#SLE-7953).
- drm/i915/gt: Always call kref_init for the timeline
  (jsc#SLE-7953).
- drm/i915/gt: Drop stale commentary for timeline density
  (jsc#SLE-7953).
- drm/i915/selftests: Hold ref on request across waits
  (jsc#SLE-7953).
- drm/i915/guc: Add debug capture of GuC exception (jsc#SLE-7953).
- drm/i915/execlists: Convert recursive defer_request() into
  iterative (jsc#SLE-7953).
- drm/i915/ehl: Add missing VECS engine (jsc#SLE-7953).
- drm/i915/ehl: Add one additional PCH ID to MCC (jsc#SLE-7953).
  Refresh patches.suse/drm-i915-cml-Add-second-PCH-ID-for-CMP.patch
- drm/i915/gem: Clear read/write domains for GPU clear
  (jsc#SLE-7953).
- drm/i915/execlists: Always clear ring_pause if we do not submit
  (jsc#SLE-7953).
- drm/i915/blt: Remove recursive vma->lock (jsc#SLE-7953).
- drm/i915: Local debug BUG_ON for intel_wakeref (jsc#SLE-7953).
- drm/i915: Provide an i915_active.acquire callback
  (jsc#SLE-7953).
- drm/i915: Throw away the active object retirement complexity
  (jsc#SLE-7953).
- drm/i915: Track i915_active using debugobjects (jsc#SLE-7953).
- drm/i915: Remove waiting & retiring from shrinker paths
  (jsc#SLE-7953).
- drm/i915/guc: handle GuC messages received with CTB disabled
  (jsc#SLE-7953).
- drm/i915/guc: reorder enable/disable communication steps
  (jsc#SLE-7953).
- drm/i915/gt: Fixup kerneldoc parameters (jsc#SLE-7953).
- drm/i915/gt: Rename i915_gt_timelines (jsc#SLE-7953).
- drm/i915: Eliminate dual personality of i915_scratch_offset
  (jsc#SLE-7953).
- drm/i915: Make timelines gt centric (jsc#SLE-7953).
- drm/i915: Compartmentalize ring buffer creation (jsc#SLE-7953).
- drm/i915: Store ggtt pointer in intel_gt (jsc#SLE-7953).
- drm/i915: Compartmentalize i915_gem_init_ggtt (jsc#SLE-7953).
- drm/i915: Compartmentalize i915_ggtt_cleanup_hw (jsc#SLE-7953).
- drm/i915: Compartmentalize timeline_init/park/fini
  (jsc#SLE-7953).
- drm/i915: Convert i915_gem_flush_ggtt_writes to intel_gt
  (jsc#SLE-7953).
- drm/i915: Compartmentalize i915_gem_suspend/restore_gtt_mappings
  (jsc#SLE-7953).
- drm/i915: Store intel_gt backpointer in vm (jsc#SLE-7953).
- drm/i915: Make ggtt invalidation work on ggtt (jsc#SLE-7953).
- drm/i915: Compartmentalize i915_ggtt_init_hw (jsc#SLE-7953).
- drm/i915: Compartmentalize i915_ggtt_probe_hw (jsc#SLE-7953).
- drm/i915: Consolidate some open coded mmio rmw (jsc#SLE-7953).
- drm/i915: Convert i915_ppgtt_init_hw to intel_gt (jsc#SLE-7953).
- drm/i915: Store backpointer to intel_gt in the engine
  (jsc#SLE-7953).
- drm/i915: Convert gt workarounds to intel_gt (jsc#SLE-7953).
- drm/i915: Convert init_unused_rings to intel_gt (jsc#SLE-7953).
- drm/i915: Use intel_uncore_rmw in intel_gt_init_swizzling
  (jsc#SLE-7953).
- drm/i915: Convert i915_gem_init_swizzling to intel_gt
  (jsc#SLE-7953).
- drm/i915: Make i915_check_and_clear_faults take intel_gt
  (jsc#SLE-7953).
- drm/i915: Store some backpointers in struct intel_gt
  (jsc#SLE-7953).
- drm/i915: Move intel_gt initialization to a separate file
  (jsc#SLE-7953).
- drm/i915: Introduce struct intel_gt as replacement for anonymous
  i915->gt (jsc#SLE-7953).
- drm/i915: Convert intel_vgt_(de)balloon to uncore
  (jsc#SLE-7953).
- drm/i915/execlists: Keep virtual context alive until after we
  kick (jsc#SLE-7953).
- drm/i915/gtt: Defer address space cleanup to an RCU worker
  (jsc#SLE-7953).
- drm/i915/ehl/dsi: Enable AFE over PPI strap (jsc#SLE-7953).
- drm/i915/ehl/dsi: Set lane latency optimization for DW1
  (jsc#SLE-7953).
- drm/i915/selftests: Use request managed wakerefs (jsc#SLE-7953).
- drm/i915: Rings are always flushed (jsc#SLE-7953).
- drm/i915/execlists: Minimalistic timeslicing (jsc#SLE-7953).
- drm/i915: dynamically allocate forcewake domains (jsc#SLE-7953).
- drm/i915: skip forcewake actions on forcewake-less uncore
  (jsc#SLE-7953).
- drm/i915: kill uncore_to_i915 (jsc#SLE-7953).
- drm/i915: kill uncore_sanitize (jsc#SLE-7953).
- drm/i915: use vfuncs for reg_read/write_fw_domains
  (jsc#SLE-7953).
- drm/i915/ehl: Allow combo PHY A to drive a third external
  display (jsc#SLE-7953).
- drm/i915: Flush the execution-callbacks on retiring
  (jsc#SLE-7953).
- drm/i915: Signal fence completion from i915_request_wait
  (jsc#SLE-7953).
- commit 04e08b4
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- PM / wakeup: Unexport wakeup_source_sysfs_{add,remove}()
  (jsc#SLE-9316).
- PM / wakeup: Register wakeup class kobj after device is added
  (jsc#SLE-9316).
- PM / wakeup: Fix sysfs registration error path (jsc#SLE-9316).
- commit 0972359
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- thermal: qoriq: Add hwmon support (jsc#SLE-9316).
- thermal_hwmon: Add devres wrapper for thermal_add_hwmon_sysfs()
  (jsc#SLE-9316).
- thermal: qoriq: Do not report invalid temperature reading
  (jsc#SLE-9316).
- thermal: qoriq: Enable all sensors before registering them
  (jsc#SLE-9316).
- thermal: qoriq: Convert driver to use regmap API (jsc#SLE-9316).
- thermal: qoriq: Drop unnecessary drvdata cleanup (jsc#SLE-9316).
- thermal: qoriq: Pass data to qoriq_tmu_calibration() directly
  (jsc#SLE-9316).
- thermal: qoriq: Pass data to qoriq_tmu_register_tmu_zone()
  directly (jsc#SLE-9316).
- thermal: qoriq: Embed per-sensor data into struct qoriq_tmu_data
  (jsc#SLE-9316).
- thermal: qoriq: Add local struct qoriq_sensor pointer
  (jsc#SLE-9316).
- thermal: qoriq: Don't store struct thermal_zone_device reference
  (jsc#SLE-9316).
- thermal: qoriq: Add local struct device pointer (jsc#SLE-9316).
- thermal: qoriq: add thermal monitor unit version 2 support
  (jsc#SLE-9316).
- thermal: qoriq: Use __maybe_unused instead of #if
  CONFIG_PM_SLEEP (jsc#SLE-9316).
- thermal: qoriq: Use devm_platform_ioremap_resource() instead
  of of_iomap() (jsc#SLE-9316).
- thermal: qoriq: Fix error path of calling
  qoriq_tmu_register_tmu_zone fail (jsc#SLE-9316).
- thermal: qoriq: Add clock operations (jsc#SLE-9316).
- commit 14652c6
* Tue Dec 17 2019 ggherdovich@suse.cz
- Delete
  patches.suse/cpufreq-intel_pstate-use-setpoint-of-10-on-servers.patch.
  Before v4.14 the intel_pstate powersave frequency governor used a
  P.I.D. controller based algorithm to select frequencies, and this patch
  was necessary to tune the "setpoint" parameter to a more aggressive value
  than in mainline kernel.
  From v4.14 onwards said algorithm is replaced by another where the
  frequency is proportional to non-idle time observed in the recent past,
  and this patch tuning pid_params.setpoint is thus obsolete.
- commit 80607d5
* Tue Dec 17 2019 ggherdovich@suse.cz
- cpufreq: intel_pstate: Temporarily boost P-state when exiting
  from idle (bnc#1066110, bnc#1066845).
- commit 0ab1412
* Tue Dec 17 2019 ggherdovich@suse.cz
- cpufreq, intel_pstate: Ramp up frequency faster when utilisation
  reaches setpoint (bsc#1068680).
- commit 741462c
* Tue Dec 17 2019 ggherdovich@suse.cz
- cpufreq: intel_pstate: Revert upstream changes to iowait
  boosting (bsc#1131437).
- commit 08e273b
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- PM / wakeup: Show wakeup sources stats in sysfs (jsc#SLE-9316).
- PM / wakeup: Use wakeup_source_register() in wakelock.c
  (jsc#SLE-9316).
- PM / wakeup: Drop wakeup_source_init(), wakeup_source_prepare()
  (jsc#SLE-9316).
- commit 4d80f94
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- rtc: fsl-ftm-alarm: remove select FSL_RCPM and default y from
  Kconfig (jsc#SLE-9316).
- mmc: sdhci: fix up CMD12 sending (jsc#SLE-9316).
- soc: fsl: add RCPM driver (jsc#SLE-9316).
- PM: wakeup: Add routine to help fetch wakeup source object
  (jsc#SLE-9316).
- mmc: sdhci-of-esdhc: poll ESDHC_FLUSH_ASYNC_FIFO bit until
  completion (jsc#SLE-9316).
- spi: spi-fsl-qspi: Introduce variable to fix different invalid
  master Id (jsc#SLE-9316).
- rtc: fsl-ftm-alarm: add FTM alarm driver (jsc#SLE-9316).
- mtd: spi-nor: Add support for mt35xu02g (jsc#SLE-9316).
- mmc: sdhci-of-esdhc: add erratum A011334 support in ls1028a
  1.0 SoC (jsc#SLE-9316).
- soc: fsl: guts: Add definition for LS1028A (jsc#SLE-9316).
- spi: fsl-qspi: Enhance binding to extend example for flash entry
  (jsc#SLE-9316).
- commit bfef95e
* Tue Dec 17 2019 jlee@suse.com
- Refresh and enable
  patches.suse/0004-MODSIGN-checking-the-blacklisted-hash-before-loading.patch.
  (fate#316531)
- commit d8c86dc
* Tue Dec 17 2019 jlee@suse.com
- Refresh and enable
  patches.suse/0003-MODSIGN-load-blacklist-from-MOKx.patch.
  (fate#316531)
- commit 9e30e45
* Tue Dec 17 2019 yousaf.kaukab@suse.com
- enetc: remove variable 'tc_max_sized_frame' set but not used
  (jsc#SLE-9316).
- enetc: add software timestamping (jsc#SLE-9316).
- enetc: disable EEE autoneg by default (jsc#SLE-9316).
- enetc: add support Credit Based Shaper(CBS) for hardware offload
  (jsc#SLE-9316).
- enetc: make enetc_setup_tc_mqprio static (jsc#SLE-9316).
- enetc: update TSN Qbv PSPEED set according to adjust link speed
  (jsc#SLE-9316).
- enetc: Configure the Time-Aware Scheduler via tc-taprio offload
  (jsc#SLE-9316).
- enetc: fix return value for enetc_ioctl() (jsc#SLE-9316).
- enetc: ethtool: add wake-on-lan callbacks (jsc#SLE-9316).
- enetc: add ioctl() support for PHY-related ops (jsc#SLE-9316).
- commit c54330b
* Mon Dec 16 2019 jack@suse.cz
- Update tags in
  patches.suse/ext4-add-more-paranoia-checking-in-ext4_expand_extra.patch
  (bnc#1151927 bsc#1159297 CVE-2019-19767 5.3.15).
- commit a5d00e3
* Mon Dec 16 2019 jgross@suse.com
- xen/blkback: Avoid unmapping unmapped grant pages (bsc#1065600).
- commit d227d91
* Mon Dec 16 2019 tiwai@suse.de
- staging: vchiq: call unregister_chrdev_region() when driver
  registration fails (git-fixes).
- xhci: make sure interrupts are restored to correct state
  (git-fixes).
- xhci: Increase STS_HALT timeout in xhci_suspend() (git-fixes).
- usb: xhci: only set D3hot for pci device (git-fixes).
- xhci: Fix memory leak in xhci_add_in_port() (git-fixes).
- usb: dwc3: gadget: Fix logical condition (git-fixes).
- USB: adutux: fix interface sanity check (git-fixes).
- USB: idmouse: fix interface sanity checks (git-fixes).
- USB: serial: io_edgeport: fix epic endpoint lookup (git-fixes).
- usb: mon: Fix a deadlock in usbmon between mmap and read
  (git-fixes).
- usb: typec: fix use after free in typec_register_port()
  (git-fixes).
- usb: roles: fix a potential use after free (git-fixes).
- virtio-balloon: fix managed page counts when migrating pages
  between zones (git-fixes).
- vfio/pci: call irq_bypass_unregister_producer() before freeing
  irq (git-fixes).
- tools: PCI: Fix fd leakage (git-fixes).
- stm class: Lose the protocol driver when dropping its reference
  (git-fixes).
- spi: rspi: Use platform_get_irq_byname_optional() for optional
  irqs (git-fixes).
- commit 6f16787
* Mon Dec 16 2019 tiwai@suse.de
- staging: rtl8712: fix interface sanity check (git-fixes).
- staging: rtl8188eu: fix interface sanity check (git-fixes).
- soc: aspeed: Fix snoop_file_poll()'s return type (git-fixes).
- soc: renesas: Add missing check for non-zero product register
  address (git-fixes).
- serial: 8250-mtk: Use platform_get_irq_optional() for optional
  irq (git-fixes).
- phy: qcom-usb-hs: Fix extcon double register after power cycle
  (git-fixes).
- phy: ti: gmii-sel: fix mac tx internal delay for rgmii-rxid
  (git-fixes).
- phy: renesas: rcar-gen3-usb2: Fix sysfs interface of "role"
  (git-fixes).
- rfkill: allocate static minor (git-fixes).
- phy: renesas: rcar-gen3-usb2: Use platform_get_irq_optional()
  for optional irq (git-fixes).
- software node: Get reference to parent swnode in get_parent op
  (git-fixes).
- driver core: platform: Add platform_get_irq_byname_optional()
  (git-fixes).
- commit 3dd636b
* Mon Dec 16 2019 mkubecek@suse.cz
- config: refresh
- only update headers
- commit 308eb35
* Mon Dec 16 2019 ykaukab@suse.de
- PCI: layerscape: Add LS1028a support (jsc#SLE-9316).
- PCI: layerscape: Add CONFIG_PCI_LAYERSCAPE_EP to build EP/RC
  separately (jsc#SLE-9316).
- PCI: dwc: Return directly when num-lanes is not found
  (jsc#SLE-9316).
- commit a994a9b
* Mon Dec 16 2019 tiwai@suse.de
- moduleparam: fix parameter description mismatch (git-fixes).
- net: wireless: ti: remove local VENDOR_ID and DEVICE_ID
  definitions (git-fixes).
- net: wireless: ti: wl1251 use new SDIO_VENDOR_ID_TI_WL1251
  definition (git-fixes).
- mmc: host: omap_hsmmc: add code for special init of wl1251 to
  get rid of pandora_wl1251_init_card (git-fixes).
- net: wireless: ti: wl1251 add device tree support (git-fixes).
- commit 55a0d46
* Mon Dec 16 2019 tiwai@suse.de
- interconnect: qcom: sdm845: Walk the list safely on node removal
  (git-fixes).
- commit dc37ad8
* Mon Dec 16 2019 tiwai@suse.de
- iio: adc: max9611: Fix too short conversion time delay
  (git-fixes).
- iio: imu: inv_mpu6050: fix temperature reporting using bad unit
  (git-fixes).
- iio: adc: ad7124: Enable internal reference (git-fixes).
- iio: adc: ad7606: fix reading unnecessary data from device
  (git-fixes).
- genalloc: Fix a set of docs build warnings (git-fixes).
- commit f2d6240
* Mon Dec 16 2019 tiwai@suse.de
- firmware: arm_scmi: Avoid double free in error flow (git-fixes).
- commit 83c312d
* Mon Dec 16 2019 tiwai@suse.de
- drm/nouveau/kms/nv50-: Limit MST BPC to 8 (git-fixes).
- drm/nouveau/kms/nv50-: Store the bpc we're using in
  nv50_head_atom (git-fixes).
- drm/nouveau/kms/nv50-: Call outp_atomic_check_view() before
  handling PBN (git-fixes).
- drm: meson: venc: cvbs: fix CVBS mode matching (git-fixes).
- drm/mcde: dsi: Fix invalid pointer dereference if panel cannot
  be found (git-fixes).
- drm/dp_mst: Correct the bug in drm_dp_update_payload_part1()
  (git-fixes).
- drm/mgag200: Store flags from PCI driver data in device
  structure (git-fixes).
- drm/mgag200: Extract device type from flags (git-fixes).
- commit 2452bc1
* Mon Dec 16 2019 tiwai@suse.de
- drm/amdgpu/vi: silence an uninitialized variable warning
  (git-fixes).
- commit 45e781e
* Mon Dec 16 2019 tiwai@suse.de
- drm/amd/display: add default clocks if not able to fetch them
  (git-fixes).
- drm/msm: Sanitize the modeset_is_locked checks in dpu
  (git-fixes).
- drm/msm: include linux/sched/task.h (git-fixes).
- drm/amdgpu: fix bad DMA from INTERRUPT_CNTL2 (git-fixes).
- drm/radeon: fix bad DMA from INTERRUPT_CNTL2 (git-fixes).
- drm: msm: a6xx: fix debug bus register configuration
  (git-fixes).
- commit 42a4df1
* Mon Dec 16 2019 tiwai@suse.de
- drm/tegra: Fix ordering of cleanup code (git-fixes).
- drm: Don't free jobs in wait_event_interruptible() (git-fixes).
- drm/rockchip: Round up _before_ giving to the clock framework
  (git-fixes).
- drm/amd/display: fix struct init in update_bounding_box
  (git-fixes).
- drm/amdgpu/mn: fix documentation for amdgpu_mn_read_lock
  (git-fixes).
- Revert "drm/amdgpu/nbio7.4: add hw bug workaround for vega20"
  (git-fixes).
- drm: rcar_lvds: Fix color mismatches on R-Car H2 ES2.0 and later
  (git-fixes).
- drm/mcde: Fix reference to DOC comment (git-fixes).
- Revert "drm/sun4i: dsi: Change the start delay calculation"
  (git-fixes).
- drm: panel-lvds: Potential Oops in probe error handling
  (git-fixes).
- commit 8624fb2
* Mon Dec 16 2019 tiwai@suse.de
- dmaengine: ti: edma: fix missed failure handling (git-fixes).
- drm/v3d: don't leak bin job if v3d_job_init fails (git-fixes).
- drm: mst: Fix query_payload ack reply struct (git-fixes).
- commit 5a5f2fc
* Mon Dec 16 2019 ykaukab@suse.de
- gpio: mpc8xxx: Add platform device to gpiochip->parent
  (jsc#SLE-9316).
- gpio/mpc8xxx: fix qoriq GPIO reading (jsc#SLE-9316).
- gpio/mpc8xxx: change irq handler from chained to normal
  (jsc#SLE-9316).
- gpio: mpc8xxx: add ls1088a platform special function
  (jsc#SLE-9316).
- gpio: mpc8xxx: Add ls1028a device specify function
  (jsc#SLE-9316).
- commit 748b19d
* Mon Dec 16 2019 tiwai@suse.de
- Update patch reference for ALSA timer fix (CVE-2019-19807 bsc#1159281)
- commit fdd89ba
* Mon Dec 16 2019 nsaenzjulienne@suse.de
- PCI: rockchip: Fix IO outbound ATU register number (git-fixes).
- commit fa4971b
* Mon Dec 16 2019 tiwai@suse.de
- rpm/kernel-subpackage-spec: Fix empty Recommends tag (bsc#1143959)
- commit 3fd22e2
* Mon Dec 16 2019 bp@suse.de
- crypto: ccp - Release all allocated memory if sha type is
  invalid (bsc#1156259 CVE-2019-18808).
- commit 9a2a2b6
* Mon Dec 16 2019 jslaby@suse.cz
- Linux 5.3.16 (bnc#1151927 5.3.16).
- Input: Fix memory leak in psxpad_spi_probe (bnc#1151927 5.3.16).
- io_uring: ensure req->submit is copied when req is deferred
  (bnc#1151927 5.3.16).
- CIFS: Fix NULL-pointer dereference in smb2_push_mandatory_locks
  (bnc#1151927 5.3.16).
- Input: synaptics-rmi4 - don't increment rmiaddr for SMBus
  transfers (bnc#1151927 5.3.16).
- Input: goodix - add upside-down quirk for Teclast X89 tablet
  (bnc#1151927 5.3.16).
- nfsd: Ensure CLONE persists data and metadata changes to the
  target file (bnc#1151927 5.3.16).
- nfsd: restore NFSv3 ACL support (bnc#1151927 5.3.16).
- io_uring: transform send/recvmsg() -ERESTARTSYS to -EINTR
  (bnc#1151927 5.3.16).
- fuse: verify nlink (bnc#1151927 5.3.16).
- fuse: verify attributes (bnc#1151927 5.3.16).
- arm64: dts: exynos: Revert "Remove unneeded address space
  mapping for soc node" (bnc#1151927 5.3.16).
- tty: vt: keyboard: reject invalid keycodes (bnc#1151927 5.3.16).
- serial: stm32: fix clearing interrupt error flags (bnc#1151927
  5.3.16).
- serial: serial_core: Perform NULL checks for break_ctl ops
  (bnc#1151927 5.3.16).
- serial: ifx6x60: add missed pm_runtime_disable (bnc#1151927
  5.3.16).
- serial: pl011: Fix DMA ->flush_buffer() (bnc#1151927 5.3.16).
- x86/PCI: Avoid AMD FCH XHCI USB PME# from D0 defect (bnc#1151927
  5.3.16).
- x86/mm/32: Sync only to VMALLOC_END in vmalloc_sync_all()
  (bnc#1151927 5.3.16).
- Input: synaptics - switch another X1 Carbon 6 to RMI/SMbus
  (bnc#1151927 5.3.16).
- sparc64: implement ioremap_uc (bnc#1151927 5.3.16).
- jbd2: Fix possible overflow in jbd2_log_space_left()
  (bnc#1151927 5.3.16).
- drm/msm: fix memleak on release (bnc#1151927 5.3.16).
- drm: damage_helper: Fix race checking plane->state->fb
  (bnc#1151927 5.3.16).
- drm/i810: Prevent underflow in ioctl (bnc#1151927 5.3.16).
- binder: Handle start==NULL in binder_update_page_range()
  (bnc#1151927 5.3.16).
- binder: Prevent repeated use of ->mmap() via NULL mapping
  (bnc#1151927 5.3.16).
- binder: Fix race between mmap() and binder_alloc_print_pages()
  (bnc#1151927 5.3.16).
- lp: fix sparc64 LPSETTIMEOUT ioctl (bnc#1151927 5.3.16).
- blacklist.conf: remove it
- coresight: etm4x: Fix input validation for sysfs (bnc#1151927
  5.3.16).
- usb: gadget: u_serial: add missing port entry locking
  (bnc#1151927 5.3.16).
- cpufreq: imx-cpufreq-dt: Correct i.MX8MN's default speed grade
  value (bnc#1151927 5.3.16).
- perf scripts python: exported-sql-viewer.py: Fix use of TRUE
  with SQLite (bnc#1151927 5.3.16).
- crypto: ccp - fix uninitialized list head (bnc#1151927 5.3.16).
- KVM: PPC: Book3S HV: XIVE: Fix potential page leak on error path
  (bnc#1151927 5.3.16).
- KVM: PPC: Book3S HV: XIVE: Free previous EQ page when setting
  up a new one (bnc#1151927 5.3.16).
- KVM: x86: Grab KVM's srcu lock when setting nested state
  (bnc#1151927 5.3.16).
- KVM: x86: do not modify masked bits of shared MSRs (bnc#1151927
  5.3.16).
- KVM: arm/arm64: vgic: Don't rely on the wrong pending table
  (bnc#1151927 5.3.16).
- KVM: PPC: Book3S HV: XIVE: Set kvm->arch.xive when VPs are
  allocated (bnc#1151927 5.3.16).
- KVM: nVMX: Always write vmcs02.GUEST_CR3 during nested VM-Enter
  (bnc#1151927 5.3.16).
- sched/core: Avoid spurious lock dependencies (bnc#1151927
  5.3.16).
- perf/core: Consistently fail fork on allocation failures
  (bnc#1151927 5.3.16).
- net: ep93xx_eth: fix mismatch of request_mem_region in remove
  (bnc#1151927 5.3.16).
- ravb: implement MTU change while device is up (bnc#1151927
  5.3.16).
- iwlwifi: pcie: don't consider IV len in A-MSDU (bnc#1151927
  5.3.16).
- xfrm: release device reference for invalid state (bnc#1151927
  5.3.16).
- rsxx: add missed destroy_workqueue calls in remove (bnc#1151927
  5.3.16).
- afs: Fix race in commit bulk status fetch (bnc#1151927 5.3.16).
- MIPS: SGI-IP27: fix exception handler replication (bnc#1151927
  5.3.16).
- selftests: kvm: fix build with glibc >= 2.30 (bnc#1151927
  5.3.16).
- drm/sun4i: tcon: Set min division of TCON0_DCLK to 1
  (bnc#1151927 5.3.16).
- audit_get_nd(): don't unlock parent too early (bnc#1151927
  5.3.16).
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev.
- exportfs_decode_fh(): negative pinned may become positive
  without the parent locked (bnc#1151927 5.3.16).
- cgroup: don't put ERR_PTR() into fc->root (bnc#1151927 5.3.16).
- autofs: fix a leak in autofs_expire_indirect() (bnc#1151927
  5.3.16).
- Input: cyttsp4_core - fix use after free bug (bnc#1151927
  5.3.16).
- commit 8b8fa5f
* Mon Dec 16 2019 jslaby@suse.cz
- Update
  patches.suse/0001-crypto-af_alg-cast-ki_complete-ternary-op-to-int.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/0001-crypto-ecdh-fix-big-endian-bug-in-ECC-library.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/0055-rbd-silence-bogus-uninitialized-warning-in-rbd_object_map_update_finish.patch
  (jsc#SES-1134 bnc#1151927 5.3.16).
- Update patches.suse/ALSA-hda-Add-Cometlake-S-PCI-ID.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-Add-mute-led-support-for-HP-ProBook-645-G4.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-Fix-pending-unsol-events-at-shutdown.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-Modify-stream-stripe-mask-only-when-needed.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-hdmi-fix-pin-setup-on-Tigerlake.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-realtek-Dell-headphone-has-noise-on-unmute-.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-realtek-Enable-internal-speaker-of-ASUS-UX4.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-hda-realtek-Enable-the-headset-mic-on-a-Xiaomi-.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-pcm-Fix-stream-lock-usage-in-snd_pcm_period_ela.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ALSA-pcm-oss-Avoid-potential-buffer-overflows.patch
  (git-fixes bnc#1151927 5.3.16).
- Update patches.suse/CIFS-Fix-SMB2-oplock-break-processing.patch
  (bsc#1154355 bnc#1151927 5.3.16).
- Update
  patches.suse/Input-synaptics-rmi4-re-enable-IRQs-in-f34v7_do_refl.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/NFC-nxp-nci-Fix-NULL-pointer-dereference-after-I2C-c.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/RDMA-hns-Correct-the-value-of-HNS_ROCE_HEM_CHUNK_LEN.patch
  (jsc#SLE-8449 bnc#1151927 5.3.16).
- Update
  patches.suse/RDMA-hns-Correct-the-value-of-srq_desc_size.patch
  (jsc#SLE-8449 bnc#1151927 5.3.16).
- Update
  patches.suse/RDMA-qib-Validate-show-store-callbacks-before-callin.patch
  (jsc#SLE-8449 bnc#1151927 5.3.16).
- Update
  patches.suse/SUNRPC-Avoid-RPC-delays-when-exiting-suspend.patch
  (bsc#1154353 bnc#1151927 5.3.16).
- Update
  patches.suse/aio-Fix-io_pgetevents-struct-__compat_aio_sigset-lay.patch
  (bsc#1158373 bnc#1151927 5.3.16).
- Update
  patches.suse/arm64-tegra-Fix-active-low-warning-for-Jetson-TX1-re.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/block-check-bi_size-overflow-before-merge.patch
  (bsc#1158370 bnc#1151927 5.3.16).
- Update
  patches.suse/can-slcan-Fix-use-after-free-Read-in-slcan_open.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/can-ucan-fix-non-atomic-allocation-in-completion-han.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/crypto-atmel-aes-Fix-IV-handling-when-req-nbytes-ivs.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/crypto-crypto4xx-fix-double-free-in-crypto4xx_destro.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/crypto-geode-aes-switch-to-skcipher-for-cbc-aes-fall.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/crypto-user-fix-memory-leak-in-crypto_report.patch
  (CVE-2019-19062 bsc#1157333 git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/crypto-user-fix-memory-leak-in-crypto_reportstat.patch
  (CVE-2019-19050 bsc#1157336 git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/drm-mcde-Fix-an-error-handling-path-in-mcde_probe.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/ecryptfs-fix-unlink-and-rmdir-in-face-of-underlying-.patch
  (bsc#1158374 bnc#1151927 5.3.16).
- Update
  patches.suse/edac-ghes-fix-locking-and-memory-barrier-issues.patch
  (bsc#1152489 bnc#1151927 5.3.16).
- Update
  patches.suse/i2c-core-fix-use-after-free-in-of_i2c_notify.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/iomap-Fix-pipe-page-leakage-during-splicing.patch
  (bsc#1158383 bnc#1151927 5.3.16).
- Update patches.suse/kernfs-fix-ino-wrap-around-detection.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/kselftest-Fix-NULL-INSTALL_PATH-for-TARGETS-runlist.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/kvm-x86-fix-out-of-bounds-write-in-kvm_get_emulated_cpuid-cve-2019-19332
  (CVE-2019-19332 bsc#1158827 bnc#1151927 5.3.16).
- Update
  patches.suse/kvm-x86-fix-presentation-of-tsx-feature-in-arch_capabilities
  (CVE-2019-19338 bsc#1158954 bnc#1151927 5.3.16).
- Update
  patches.suse/kvm-x86-remove-a-spurious-export-of-a-static-function
  (bsc#1158954 bnc#1151927 5.3.16).
- Update
  patches.suse/md-raid0-Fix-an-error-message-in-raid0_make_request.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/media-rc-mark-input-device-as-pointing-stick.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/net-hns3-fix-ETS-bandwidth-validation-bug.patch
  (bsc#1154353 bnc#1151927 5.3.16).
- Update
  patches.suse/net-hns3-reallocate-SSU-buffer-size-when-pfc_en-chan.patch
  (bsc#1154353 bnc#1151927 5.3.16).
- Update
  patches.suse/perf-script-Fix-invalid-LBR-binary-mismatch-error.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/rsi-release-skb-if-rsi_prepare_beacon-fails.patch
  (CVE-2019-19071,bsc#1157067 bnc#1151927 5.3.16).
- Update
  patches.suse/sched-pelt-Fix-update-of-blocked-PELT-ordering.patch
  (bnc#1155798 (CPU scheduler functional and performance
  backports) bnc#1151927 5.3.16).
- Update
  patches.suse/spi-Fix-NULL-pointer-when-setting-SPI_CS_HIGH-for-GP.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/spi-Fix-SPI_CS_HIGH-setting-when-using-native-and-GP.patch
  (git-fixes bnc#1151927 5.3.16).
- Update patches.suse/spi-atmel-Fix-CS-high-support.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/spi-spi-fsl-qspi-Clear-TDH-bits-in-FLSHCR-register.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/spi-stm32-qspi-Fix-kernel-oops-when-unbinding-driver.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/thermal-Fix-deadlock-in-thermal-thermal_zone_device_.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/time-Zero-the-upper-32-bits-in-__kernel_timespec-on-.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/tty-serial-fsl_lpuart-use-the-sg-count-from-dma_map_.patch
  (git-fixes bnc#1151927 5.3.16).
- Update patches.suse/tty-serial-msm_serial-Fix-flow-control.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/vcs-prevent-write-access-to-vcsu-devices.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/watchdog-aspeed-Fix-clock-behaviour-for-ast2600.patch
  (git-fixes bnc#1151927 5.3.16).
- Update
  patches.suse/x86-resctrl-fix-potential-lockdep-warning.patch
  (bsc#1152489 bnc#1151927 5.3.16).
- commit f542645
* Mon Dec 16 2019 jlee@suse.com
- Delete
  patches.suse/0002-MODSIGN-print-appropriate-status-message-when-gettin.patch.
  Be replaced by
  patches.suse/0001-efi-add-a-function-to-convert-the-status-code-to-a-s.patch
  patches.suse/0002-efi-show-error-messages-only-when-loading-certificat.patch
- commit 167e118
* Mon Dec 16 2019 jlee@suse.com
- efi: show error messages only when loading certificates is
  failed (fate#316531, bnc#854875).
- commit 9ff07ee
* Mon Dec 16 2019 jlee@suse.com
- efi: add a function to convert the status code to a string
  (fate#316531, bnc#854875).
- commit cd7aba4
* Mon Dec 16 2019 msuchanek@suse.de
- Refresh patches.suse/ibmvnic-Fix-typo-in-retry-check.patch.
- commit f89f0b0
* Sun Dec 15 2019 mkubecek@suse.cz
- config: refresh
- update headers
- drop options which are no longer accessible
- commit 82ffcd4
* Sun Dec 15 2019 mkubecek@suse.cz
- series.conf: refresh
  update mainline references and resort:
  patches.suse/scsi-qla2xxx-Add-debug-dump-of-LOGO-payload-and-ELS-.patch
  patches.suse/scsi-qla2xxx-Added-support-for-MPI-and-PEP-regions-f.patch
  patches.suse/scsi-qla2xxx-Allow-PLOGI-in-target-mode.patch
  patches.suse/scsi-qla2xxx-Change-discovery-state-before-PLOGI.patch
  patches.suse/scsi-qla2xxx-Configure-local-loop-for-N2N-target.patch
  patches.suse/scsi-qla2xxx-Correctly-retrieve-and-interpret-active.patch
  patches.suse/scsi-qla2xxx-Don-t-call-qlt_async_event-twice.patch
  patches.suse/scsi-qla2xxx-Don-t-defer-relogin-unconditonally.patch
  patches.suse/scsi-qla2xxx-Drop-superfluous-INIT_WORK-of-del_work.patch
  patches.suse/scsi-qla2xxx-Fix-PLOGI-payload-and-ELS-IOCB-dump-len.patch
  patches.suse/scsi-qla2xxx-Fix-incorrect-SFUB-length-used-for-Secu.patch
  patches.suse/scsi-qla2xxx-Ignore-NULL-pointer-in-tcm_qla2xxx_free.patch
  patches.suse/scsi-qla2xxx-Ignore-PORT-UPDATE-after-N2N-PLOGI.patch
  patches.suse/scsi-qla2xxx-Initialize-free_work-before-flushing-it.patch
  patches.suse/scsi-qla2xxx-Send-Notify-ACK-after-N2N-PLOGI.patch
  patches.suse/scsi-qla2xxx-Use-explicit-LOGO-in-target-mode.patch
- commit b803547
* Sat Dec 14 2019 tiwai@suse.de
- ACPI: PM: Avoid attaching ACPI PM domain to certain devices
  (git-fixes).
- ALSA: hda/realtek - Line-out jack doesn't work on a Dell AIO
  (git-fixes).
- ALSA: hda/hdmi - Fix duplicate unref of pci_dev (git-fixes).
- ALSA: fireface: fix return value in error path of isochronous
  resources reservation (git-fixes).
- ALSA: oxfw: fix return value in error path of isochronous
  resources reservation (git-fixes).
- ALSA: echoaudio: simplify get_audio_levels (git-fixes).
- dma-buf: Fix memory leak in sync_file_merge() (git-fixes).
- commit 1ccb9b7
* Fri Dec 13 2019 lduncan@suse.com
- scsi: bfa: release allocated memory in case of error
  (CVE-2019-19066 bsc#1157303).
- commit 8663bfd
* Fri Dec 13 2019 tiwai@suse.de
- spi: Fix NULL pointer when setting SPI_CS_HIGH for GPIO CS
  (git-fixes).
- commit be424a0
* Fri Dec 13 2019 tiwai@suse.de
- vcs: prevent write access to vcsu devices (git-fixes).
- tty: serial: pch_uart: correct usage of dma_unmap_sg
  (git-fixes).
- tty: serial: imx: use the sg count from dma_map_sg (git-fixes).
- tty: serial: fsl_lpuart: use the sg count from dma_map_sg
  (git-fixes).
- tty: serial: msm_serial: Fix flow control (git-fixes).
- tipc: fix wrong timeout input for tipc_wait_for_cond()
  (git-fixes).
- tipc: fix wrong socket reference counter after tipc_sk_timeout()
  returns (git-fixes).
- commit b38c936
* Fri Dec 13 2019 tiwai@suse.de
- tipc: fix potential memory leak in __tipc_sendmsg() (git-fixes).
- spi: atmel: Fix CS high support (git-fixes).
- spi: dw: Fix Designware SPI loopback (git-fixes).
- spi: atmel: fix handling of cs_change set on non-last xfer
  (git-fixes).
- spi: Fix SPI_CS_HIGH setting when using native and GPIO CS
  (git-fixes).
- spi: spi-fsl-qspi: Clear TDH bits in FLSHCR register
  (git-fixes).
- spi: stm32-qspi: Fix kernel oops when unbinding driver
  (git-fixes).
- tipc: update mon's self addr when node addr generated
  (git-fixes).
- tipc: reduce sensitive to retransmit failures (git-fixes).
- commit 03f889b
* Fri Dec 13 2019 tiwai@suse.de
- platform/chrome: wilco_ec: fix use after free issue (git-fixes).
- rtc: pm8xxx: update kerneldoc for struct pm8xxx_rtc (git-fixes).
- rtc: msm6242: Fix reading of 10-hour digit (git-fixes).
- rtc: bd70528: Add MODULE ALIAS to autoload module (git-fixes).
- rtc: brcmstb-waketimer: add missed clk_disable_unprepare
  (git-fixes).
- rtc: disable uie before setting time and enable after
  (git-fixes).
- pstore: Make pstore_choose_compression() static (git-fixes).
- pinctrl: lewisburg: Update pin list according to v1.1v6
  (git-fixes).
- pinctrl: armada-37xx: Fix irq mask access in
  armada_37xx_irq_set_type() (git-fixes).
- pinctrl: samsung: Fix device node refcount leaks in init code
  (git-fixes).
- commit 12b6898
* Fri Dec 13 2019 tiwai@suse.de
- of: unittest: fix memory leak in attach_node_and_children
  (git-fixes).
- of: overlay: add_changeset_property() memory leak (git-fixes).
- pinctrl: samsung: Fix device node refcount leaks in S3C64xx
  wakeup controller init (git-fixes).
- pinctrl: samsung: Fix device node refcount leaks in S3C24xx
  wakeup controller init (git-fixes).
- pinctrl: samsung: Fix device node refcount leaks in Exynos
  wakeup controller init (git-fixes).
- pinctrl: samsung: Add of_node_put() before return in error path
  (git-fixes).
- pinctrl: sh-pfc: Do not use platform_get_irq() to count
  interrupts (git-fixes).
- pinctrl: sh-pfc: Fix PINMUX_IPSR_PHYS() to set GPSR (git-fixes).
- pinctrl: rza2: Fix gpio name typos (git-fixes).
- hwrng: omap3-rom - Fix missing clock by probing with device tree
  (git-fixes).
- commit d48f475
* Fri Dec 13 2019 tiwai@suse.de
- clk: Add clk_hw_unregister_composite helper function definition
  (git-fixes).
- clk: Fix memory leak in clk_unregister() (git-fixes).
- clk: pxa: fix one of the pxa RTC clocks (git-fixes).
- clk: sprd: Use IS_ERR() to validate the return value of
  syscon_regmap_lookup_by_phandle() (git-fixes).
- clk: qcom: smd: Add missing pnoc clock (git-fixes).
- clk: imx7ulp: Correct DDR clock mux options (git-fixes).
- clk: imx7ulp: Correct system clock source option #7 (git-fixes).
- clk: imx: pll14xx: Fix quick switch of S/K parameter
  (git-fixes).
- clk: renesas: r8a77965: Remove superfluous semicolon
  (git-fixes).
- clk: samsung: exynos5420: Preserve CPU clocks configuration
  during suspend/resume (git-fixes).
- commit 10ab36e
* Fri Dec 13 2019 tiwai@suse.de
- arm64: mm: Fix initialisation of DMA zones on non-NUMA systems
  (git-fixes).
- arm64: tegra: Fix 'active-low' warning for Jetson TX1 regulator
  (git-fixes).
- ARM: OMAP2+: Add missing put_device() call in omapdss_init_of()
  (git-fixes).
- apparmor: fix unsigned len comparison with less than zero
  (git-fixes).
- clk: meson: axg-audio: fix regmap last register (git-fixes).
- ARM: 8937/1: spectre-v2: remove Brahma-B53 from hardening
  (git-fixes).
- ARM: 8918/2: only build return_address() if needed (git-fixes).
- ARM: 8928/1: ARM_ERRATA_775420: Spelling s/date/data/
  (git-fixes).
- arm64: Silence clang warning on mismatched value/register sizes
  (git-fixes).
- commit 7811b6b
* Fri Dec 13 2019 tiwai@suse.de
- ARM: dts: Fix vcsi regulator to be always-on for droid4 to
  prevent hangs (git-fixes).
- commit 228f19d
* Fri Dec 13 2019 tiwai@suse.de
- watchdog: sprd: Fix the incorrect pointer getting from driver
  data (git-fixes).
- staging: wilc1000: potential corruption in
  wilc_parse_join_bss_param() (git-fixes).
- virt_wifi: fix use-after-free in virt_wifi_newlink()
  (git-fixes).
- tpm: Switch to platform_get_irq_optional() (git-fixes).
- commit ff1979e
* Fri Dec 13 2019 tiwai@suse.de
- thermal: Fix deadlock in thermal thermal_zone_device_check
  (git-fixes).
- time: Zero the upper 32-bits in __kernel_timespec on 32-bit
  (git-fixes).
- seccomp: avoid overflow in implicit constant conversion
  (git-fixes).
- rtlwifi: rtl8192de: Fix missing enable interrupt flag
  (git-fixes).
- rtlwifi: rtl8192de: Fix missing callback that tests for hw
  release of buffer (git-fixes).
- rtlwifi: rtl8192de: Fix missing code to retrieve RX buffer
  address (git-fixes).
- rtw88: fix error handling when setup efuse info (git-fixes).
- rtw88: fix NSS of hw_cap (git-fixes).
- rtw88: fix beaconing mode rsvd_page memory violation issue
  (git-fixes).
- tpm: add check after commands attribs tab allocation
  (git-fixes).
- commit 05bccb9
* Fri Dec 13 2019 tiwai@suse.de
- power: supply: bd70528: Add MODULE_ALIAS to allow module auto
  loading (git-fixes).
- PM / devfreq: Lock devfreq in trans_stat_show (git-fixes).
- PM / devfreq: Check NULL governor in available_governors_show
  (git-fixes).
- regulator: core: Let boot-on regulators be powered off
  (git-fixes).
- regulator: ab8500: Remove SYSCLKREQ from enum
  ab8505_regulator_id (git-fixes).
- regulator: ab8500: Remove AB8505 USB regulator (git-fixes).
- regulator: core: Release coupled_rdevs on
  regulator_init_coupling() error (git-fixes).
- regulator: bd70528: Add MODULE_ALIAS to allow module auto
  loading (git-fixes).
- rt2800: remove errornous duplicate condition (git-fixes).
- rtlwifi: Remove unnecessary NULL check in rtl_regd_init
  (git-fixes).
- commit c414c52
* Fri Dec 13 2019 tiwai@suse.de
- PCI: rcar: Fix missing MACCTLR register setting in
  initialization sequence (git-fixes).
- PCI: amlogic: Fix probed clock names (git-fixes).
- PCI: dwc: Fix find_next_bit() usage (git-fixes).
- PCI: aardvark: Fix PCI_EXP_RTCTL register configuration
  (git-fixes).
- PCI: aardvark: Use LTSSM state to build link training flag
  (git-fixes).
- PCI: Apply Cavium ACS quirk to ThunderX2 and ThunderX3
  (git-fixes).
- PCI: Fix Intel ACS quirk UPDCR register address (git-fixes).
- PCI/switchtec: Read all 64 bits of part_event_bitmap
  (git-fixes).
- PCI: Do not use bus number zero from EA capability (git-fixes).
- pinctl: ti: iodelay: fix error checking on
  pinctrl_count_index_with_args call (git-fixes).
- commit f1a197e
* Fri Dec 13 2019 tiwai@suse.de
- PCI: Fix missing bridge dma_ranges resource list cleanup
  (git-fixes).
- PCI/PM: Clear PCIe PME Status even for legacy power management
  (git-fixes).
- PCI/PTM: Remove spurious "d" from granularity message
  (git-fixes).
- PCI: pciehp: Do not disable interrupt twice on suspend
  (git-fixes).
- PCI: pciehp: Avoid returning prematurely from sysfs requests
  (git-fixes).
- mtd: rawnand: brcmnand: Fix NULL pointer assignment (git-fixes).
- mtd: rawnand: Change calculating of position page containing
  BBM (git-fixes).
- mtd: spi-nor: fix silent truncation in spi_nor_read_raw()
  (git-fixes).
- mtd: spi-nor: fix silent truncation in spi_nor_read()
  (git-fixes).
- mtd: cfi_cmdset_0002: only check errors when ready in
  cfi_check_err_status() (git-fixes).
- commit a7c6767
* Fri Dec 13 2019 tiwai@suse.de
- mt76: mt76u: fix endpoint definition order (git-fixes).
- Revert "mt76: mt76x0e: don't use hw encryption for MT7630E"
  (git-fixes).
- mt76: mt76u: rely on usb_interface instead of usb_dev
  (git-fixes).
- mt7601u: fix bbp version check in mt7601u_wait_bbp_ready
  (git-fixes).
- mtd: devices: fix mchp23k256 read and write (git-fixes).
- mtd: spear_smi: Fix Write Burst mode (git-fixes).
- commit 4c444cf
* Fri Dec 13 2019 tiwai@suse.de
- mfd: rk808: Fix RK818 ID template (git-fixes).
- mei: fix modalias documentation (git-fixes).
- mmc: core: fix wl1251 sdio quirks (git-fixes).
- mmc: sdio: fix wl1251 vendor id (git-fixes).
- mmc: sdhci-of-esdhc: fix up erratum A-008171 workaround
  (git-fixes).
- media: hantro: Fix s_fmt for dynamic resolution changes
  (git-fixes).
- media: aspeed-video: Fix memory leaks in aspeed_video_probe
  (git-fixes).
- media: flexcop-usb: ensure -EIO is returned on error condition
  (git-fixes).
- media: venus: remove invalid compat_ioctl32 handler (git-fixes).
- commit 973a35e
* Fri Dec 13 2019 tiwai@suse.de
- media: cedrus: Use correct H264 8x8 scaling list (git-fixes).
- media: exynos4-is: fix wrong mdev and v4l2 dev order in error
  path (git-fixes).
- media: fdp1: Fix R-Car M3-N naming in debug message (git-fixes).
- media: coda: fix deadlock between decoder picture run and
  start command (git-fixes).
- media: exynos4-is: Fix recursive locking in isp_video_release()
  (git-fixes).
- media: radio: wl1273: fix interrupt masking on release
  (git-fixes).
- media: bdisp: fix memleak on release (git-fixes).
- media: ti-vpe: vpe: Fix Motion Vector vpdma stride (git-fixes).
- media: v4l: cadence: Fix how unsued lanes are handled in
  'csi2rx_start()' (git-fixes).
- media: rc: mark input device as pointing stick (git-fixes).
- commit 05115b9
* Fri Dec 13 2019 tiwai@suse.de
- media: ov6650: Fix stored crop rectangle not in sync with
  hardware (git-fixes).
- media: ov6650: Fix stored frame format not in sync with hardware
  (git-fixes).
- media: ov6650: Fix default format not applied on device probe
  (git-fixes).
- media: ov6650: Fix .get_fmt() V4L2_SUBDEV_FORMAT_TRY support
  (git-fixes).
- media: ov6650: Fix some format attributes not under control
  (git-fixes).
- media: ov6650: Fix incorrect use of JPEG colorspace (git-fixes).
- media: ov6650: Fix crop rectangle alignment not passed back
  (git-fixes).
- media: ov6650: Fix control handler not freed on init error
  (git-fixes).
- media: ov6650: Fix MODULE_DESCRIPTION (git-fixes).
- media: max2175: Fix build error without CONFIG_REGMAP_I2C
  (git-fixes).
- commit f24d029
* Fri Dec 13 2019 tiwai@suse.de
- leds: trigger: netdev: fix handling on interface rename
  (git-fixes).
- media: rcar-vin: Fix incorrect return statement in
  rvin_try_format() (git-fixes).
- media: vim2m: Fix abort issue (git-fixes).
- media: vim2m: Fix BUG_ON in vim2m_device_release() (git-fixes).
- media: seco-cec: Add a missing 'release_region()' in an error
  handling path (git-fixes).
- iwlwifi: check kasprintf() return value (git-fixes).
- iwlwifi: pcie: fix support for transmitting SKBs with fraglist
  (git-fixes).
- mac80211: consider QoS Null frames for STA_NULLFUNC_ACKED
  (git-fixes).
- iwlwifi: mvm: consider ieee80211 station max amsdu value
  (git-fixes).
- kernfs: fix ino wrap-around detection (git-fixes).
- commit 199f72e
* Fri Dec 13 2019 tiwai@suse.de
- Input: synaptics-rmi4 - re-enable IRQs in f34v7_do_reflash
  (git-fixes).
- i2c: i2c-stm32f7: fix 10-bits check in slave free id search loop
  (git-fixes).
- i2c: stm32f7: report dma error during probe (git-fixes).
- i2c: stm32f7: fix & reorder remove & probe error handling
  (git-fixes).
- i2c: stm32f7: rework slave_id allocation (git-fixes).
- iio: adis16480: Add debugfs_reg_access entry (git-fixes).
- iio: adis16480: Fix scales factors (git-fixes).
- iio: imu: adis: assign value only if return code zero in read
  funcs (git-fixes).
- iio: imu: adis: assign read val in debugfs hook only if op
  successful (git-fixes).
- intel_th: Fix a double put_device() in error path (git-fixes).
- commit a869d19
* Fri Dec 13 2019 tiwai@suse.de
- docs: admin-guide: Remove threads-max auto-tuning (git-fixes).
- docs: admin-guide: Fix min value of threads-max in kernel.rst
  (git-fixes).
- HID: i2c-hid: Reset ALPS touchpads on resume (git-fixes).
- gpio: mpc8xxx: Don't overwrite default irq_set_type callback
  (git-fixes).
- Documentation: Fix warning in drm-kms-helpers.rst (git-fixes).
- Documentation: debugfs: Document debugfs helper for unsigned
  long values (git-fixes).
- iio: imu: adis16480: assign bias value only if operation
  succeeded (git-fixes).
- hwmon: (pmbus/ibm-cffps) Switch LEDs to blocking brightness call
  (git-fixes).
- gpiolib: acpi: Add Terra Pad 1061 to the
  run_edge_events_on_boot_blacklist (git-fixes).
- Documentation: TLS: Add missing counter description (git-fixes).
- commit fc72e99
* Fri Dec 13 2019 tiwai@suse.de
- docs: networking: devlink-trap: Fix reference to other document
  (git-fixes).
- docs: Fix "make help" suggestion for SPHINXDIR (git-fixes).
- docs: Catch up with the new location of get_user_pages_fast()
  (git-fixes).
- cw1200: Fix a signedness bug in cw1200_load_firmware()
  (git-fixes).
- crypto: virtio - deal with unsupported input sizes (git-fixes).
- crypto: virtio - implement missing support for output IVs
  (git-fixes).
- crypto: tgr192 - remove unneeded semicolon (git-fixes).
- crypto: crypto4xx - fix double-free in crypto4xx_destroy_sdr
  (git-fixes).
- crypto: atmel - Fix authenc support when it is set to m
  (git-fixes).
- commit afa1ae2
* Fri Dec 13 2019 tiwai@suse.de
- can: ucan: fix non-atomic allocation in completion handler
  (git-fixes).
- can: slcan: Fix use-after-free Read in slcan_open (git-fixes).
- compat_ioctl: handle SIOCOUTQNSD (git-fixes).
- Bluetooth: Fix memory leak in hci_connect_le_scan (git-fixes).
- Bluetooth: delete a stray unlock (git-fixes).
- brcmfmac: disable PCIe interrupts before bus reset (git-fixes).
- Bluetooth: hci_core: fix init for HCI_USER_CHANNEL (git-fixes).
- crypto: geode-aes - convert to skcipher API and make thread-safe
  (git-fixes).
- crypto: geode-aes - switch to skcipher for cbc(aes) fallback
  (git-fixes).
- crypto: atmel-aes - Fix IV handling when req->nbytes < ivsize
  (git-fixes).
- commit 1788826
* Fri Dec 13 2019 tiwai@suse.de
- ASoC: fsl_audmix: Add spin lock to protect tdms (git-fixes).
- ASoC: rsnd: fix DALIGN register for SSIU (git-fixes).
- ALSA: cs4236: fix error return comparison of an unsigned integer
  (git-fixes).
- ASoC: SOF: Intel: Broadwell: clarify mutual exclusion with
  legacy driver (git-fixes).
- ASoC: soc-pcm: fixup dpcm_prune_paths() loop continue
  (git-fixes).
- Revert "ASoC: SOF: Force polling mode on CFL and CNL"
  (git-fixes).
- ASoC: simple_card_utils.h: Add missing include (git-fixes).
- ALSA: firewire-motu: Correct a typo in the clock proc string
  (git-fixes).
- ath10k: Correct error handling of dma_map_single() (git-fixes).
- ath10k: Check if station exists before forwarding tx airtime
  report (git-fixes).
- commit d2f34ae
* Fri Dec 13 2019 tiwai@suse.de
- ACPI: sysfs: Change ACPI_MASKABLE_GPE_MAX to 0x100 (git-fixes).
- ACPI: OSL: only free map once in osl.c (git-fixes).
- ACPI / hotplug / PCI: Allocate resources directly under the
  non-hotplug bridge (git-fixes).
- ACPI / utils: Move acpi_dev_get_first_match_dev() under
  CONFIG_ACPI (git-fixes).
- ACPI: LPSS: Add dmi quirk for skipping _DEP check for some
  device-links (git-fixes).
- ACPI: LPSS: Add LNXVIDEO -> BYT I2C1 to lpss_device_links
  (git-fixes).
- ACPI: LPSS: Add LNXVIDEO -> BYT I2C7 to lpss_device_links
  (git-fixes).
- commit e0be9a6
* Thu Dec 12 2019 nsaenzjulienne@suse.de
- hwrng: iproc-rng200 - Add support for BCM2711 (jsc#SLE-7772).
- commit 5106a14
* Thu Dec 12 2019 oneukum@suse.com
- USB: fix kABI padding (jsc#SLE-8133).
- commit 2bf99e9
* Thu Dec 12 2019 oneukum@suse.com
- typeC: add kABI padding (jsc#SLE-8133).
- commit e45f332
* Thu Dec 12 2019 msuchanek@suse.de
- powerpc/pseries/mobility: notify network peers after migration
  (bsc#1152631 ltc#181798).
- commit c61f369
* Thu Dec 12 2019 jslaby@suse.cz
- platform/x86: intel_pmc_core: Add Comet Lake (CML) platform
  support to intel_pmc_core driver (jsc#SLE-11113).
- platform/x86: intel_pmc_core: Fix the SoC naming inconsistency
  (jsc#SLE-11113).
- commit 1e10fa5
* Thu Dec 12 2019 jslaby@suse.cz
- x86/platform/uv: Account for UV Hubless in is_uvX_hub Ops
  (jsc#SLE-10790).
- x86/platform/uv: Check EFI Boot to set reboot type
  (jsc#SLE-10790).
- x86/platform/uv: Decode UVsystab Info (jsc#SLE-10790).
- x86/platform/uv: Add UV Hubbed/Hubless Proc FS Files
  (jsc#SLE-10790).
- x86/platform/uv: Setup UV functions for Hubless UV Systems
  (jsc#SLE-10790).
- x86/platform/uv: Add return code to UV BIOS Init function
  (jsc#SLE-10790).
- x86/platform/uv: Return UV Hubless System Type (jsc#SLE-10790).
- x86/platform/uv: Save OEM_ID from ACPI MADT probe
  (jsc#SLE-10790).
- commit a305bf3
* Thu Dec 12 2019 msuchanek@suse.de
- net/ibmvnic: Fix typo in retry check (bsc#1155689 ltc#182047).
- commit 59fccb6
* Wed Dec 11 2019 tbogendoerfer@suse.de
- mm: Implement no-MMU variant of vmalloc_user_node_flags
  (bsc#1154353).
- bpf: Add bpf_jit_blinding_enabled for !CONFIG_BPF_JIT
  (bsc#1154353).
- powerpc: Add const qual to local_read() parameter (bsc#1154353).
- net: sfp: fix sfp_bus_add_upstream() warning (bsc#1154353).
- commit 0920fda
* Wed Dec 11 2019 tbogendoerfer@suse.de
- RDMA/hns: Fix build error again (jsc#SLE-8449).
- Update config files.
- commit 56e934b
* Wed Dec 11 2019 tiwai@suse.de
- Update patch reference for wimax fix (CVE-2019-19051 bsc#1159024)
- commit a70fc76
* Wed Dec 11 2019 ykaukab@suse.de
- arm64: move patches to sorted section
  No code change.
- Refresh
  patches.suse/PCI-tegra-Fix-CLKREQ-dependency-programming.patch.
- Refresh
  patches.suse/ahci-tegra-use-regulator_bulk_set_supply_names.patch.
- Refresh
  patches.suse/arm64-kpti-Add-NVIDIA-s-Carmel-core-to-the-KPTI-whit.patch.
- Refresh
  patches.suse/clk-Add-API-to-get-index-of-the-clock-parent.patch.
- Refresh
  patches.suse/clk-tegra-Add-suspend-and-resume-support-on-Tegra210.patch.
- Refresh
  patches.suse/clk-tegra-Fix-build-error-without-CONFIG_PM_SLEEP.patch.
- Refresh
  patches.suse/clk-tegra-Move-SOR0-implementation-to-Tegra124.patch.
- Refresh
  patches.suse/clk-tegra-Reimplement-SOR-clock-on-Tegra124.patch.
- Refresh
  patches.suse/clk-tegra-Reimplement-SOR-clocks-on-Tegra210.patch.
- Refresh
  patches.suse/clk-tegra-Remove-last-remains-of-TEGRA210_CLK_SOR1_S.patch.
- Refresh
  patches.suse/clk-tegra-Rename-sor0_lvds-to-sor0_out.patch.
- Refresh
  patches.suse/clk-tegra-Share-clk-and-rst-register-defines-with-Te.patch.
- Refresh
  patches.suse/clk-tegra-Support-for-OSC-context-save-and-restore.patch.
- Refresh
  patches.suse/clk-tegra-Use-fence_udelay-during-PLLU-init.patch.
- Refresh
  patches.suse/clk-tegra-clk-dfll-Add-suspend-and-resume-support.patch.
- Refresh
  patches.suse/clk-tegra-clk-super-Add-restore-context-support.patch.
- Refresh
  patches.suse/clk-tegra-clk-super-Fix-to-enable-PLLP-branches-to-C.patch.
- Refresh
  patches.suse/clk-tegra-divider-Save-and-restore-divider-rate.patch.
- Refresh
  patches.suse/clk-tegra-periph-Add-restore_context-support.patch.
- Refresh
  patches.suse/clk-tegra-pll-Save-and-restore-pll-context.patch.
- Refresh
  patches.suse/clk-tegra-pllout-Save-and-restore-pllout-context.patch.
- Refresh
  patches.suse/cpufreq-tegra124-Add-suspend-and-resume-support.patch.
- Refresh
  patches.suse/dt-bindings-clock-tegra-Rename-SOR0_LVDS-to-SOR0_OUT.patch.
- Refresh
  patches.suse/firmware-tegra-Move-BPMP-resume-to-noirq-phase.patch.
- Refresh
  patches.suse/gpio-max77620-Do-not-allocate-IRQs-upfront.patch.
- Refresh patches.suse/gpio-max77620-Fix-interrupt-handling.patch.
- Refresh patches.suse/gpio-tegra186-Add-debounce-support.patch.
- Refresh
  patches.suse/gpio-tegra186-Derive-register-offsets-from-bank-port.patch.
- Refresh
  patches.suse/gpio-tegra186-Implement-wake-event-support.patch.
- Refresh
  patches.suse/gpio-tegra186-Program-interrupt-route-mapping.patch.
- Refresh
  patches.suse/iommu-tegra-smmu-Fix-client-enablement-order.patch.
- Refresh
  patches.suse/iommu-tegra-smmu-Fix-page-tables-in-4-GiB-memory.patch.
- Refresh
  patches.suse/iommu-tegra-smmu-Use-non-secure-register-for-flushin.patch.
- Refresh
  patches.suse/memory-tegra-Set-DMA-mask-based-on-supported-address.patch.
- Refresh
  patches.suse/mfd-max77620-Do-not-allocate-IRQs-upfront.patch.
- Refresh
  patches.suse/net-stmmac-Only-enable-enhanced-addressing-mode-when.patch.
- Refresh
  patches.suse/net-stmmac-Support-enhanced-addressing-mode-for-DWMA.patch.
- Refresh
  patches.suse/phy-tegra-use-regulator_bulk_set_supply_names.patch.
- Refresh
  patches.suse/phy-tegra-xusb-Add-XUSB-dual-mode-support-on-Tegra21.patch.
- Refresh
  patches.suse/phy-tegra-xusb-Add-usb3-port-fake-support-on-Tegra21.patch.
- Refresh
  patches.suse/phy-tegra-xusb-Add-vbus-override-support-on-Tegra186.patch.
- Refresh
  patches.suse/phy-tegra-xusb-Add-vbus-override-support-on-Tegra210.patch.
- Refresh
  patches.suse/soc-tegra-fuse-Add-FUSE-clock-check-in-tegra_fuse_re.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Add-missing-IRQ-callbacks-on-Tegra194.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Add-reset-sources-and-levels-on-Tegra1.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Add-wake-event-support-on-Tegra210.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Configure-core-power-request-polarity.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Configure-deep-sleep-control-settings.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Fix-crashes-for-hierarchical-interrupt.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Support-wake-events-on-more-Tegra-SoCs.patch.
- Refresh
  patches.suse/soc-tegra-pmc-Use-lower-case-for-hexadecimal-literal.patch.
- Refresh
  patches.suse/usb-host-xhci-tegra-Add-Tegra194-XHCI-support.patch.
- Refresh
  patches.suse/usb-host-xhci-tegra-Correct-phy-enable-sequence.patch.
- Refresh
  patches.suse/usb-host-xhci-tegra-use-devm_platform_ioremap_resour.patch.
- Refresh
  patches.suse/usb-host-xhci-tegra-use-regulator_bulk_set_supply_na.patch.
- Refresh
  patches.suse/xhci-tegra-Parameterize-mailbox-register-addresses.patch.
- commit 3cb7073
* Wed Dec 11 2019 tbogendoerfer@suse.de
- net/tls: allow compiling TLS TOE out (bsc#1154353).
- Update config files.
- commit 6230ee0
* Wed Dec 11 2019 ykaukab@suse.de
- drivers/perf: Add CCPI2 PMU support in ThunderX2 UNCORE driver
  (jsc#SLE-10207,jsc#SLE-9619).
- Documentation: perf: Update documentation for ThunderX2 PMU
  uncore driver (jsc#SLE-10207,jsc#SLE-9619).
- commit 1b0c5b1
* Wed Dec 11 2019 tbogendoerfer@suse.de
- bpf: Introduce BPF trampoline (bsc#1154353).
- Refresh
  patches.suse/bpf-Fix-race-in-btf_resolve_helper_id.patch.
- commit f6e150b
* Wed Dec 11 2019 jroedel@suse.de
- KVM: x86: Remove a spurious export of a static function
  (bsc#1158954).
- commit 00bd7c4
* Wed Dec 11 2019 tbogendoerfer@suse.de
- bpf: Track contents of read-only maps as scalars (bsc#1154353).
- Refresh
  patches.suse/bpf-Implement-accurate-raw_tp-context-access-via-BTF.patch.
- commit 188f581
* Wed Dec 11 2019 tbogendoerfer@suse.de
- net: sockmap: use bitmap for copy info (bsc#1154353).
- Refresh
  patches.suse/net-skmsg-fix-TLS-1.3-crash-with-full-sk_msg.patch.
- commit daf1422
* Wed Dec 11 2019 jack@suse.cz
- patches.suse/block-Warn-if-elevator-parameter-is-used.patch: Update tags
- commit ef8c281
* Wed Dec 11 2019 tbogendoerfer@suse.de
- net_sched: validate TCA_KIND attribute in tc_chain_tmplt_add()
  (bsc#1154353).
- inet: protect against too small mtu values (bsc#1154353).
- gre: refetch erspan header from skb->data after pskb_may_pull()
  (bsc#1154353).
- tcp: Protect accesses to .ts_recent_stamp with
  {READ,WRITE}_ONCE() (bsc#1154353).
- tcp: tighten acceptance of ACKs not matching a child socket
  (bsc#1154353).
- tcp: fix rejected syncookies due to stale timestamps
  (bsc#1154353).
- net/mlx5e: E-switch, Fix Ingress ACL groups in switchdev mode
  for prio tag (jsc#SLE-8464).
- net/mlx5e: ethtool, Fix analysis of speed setting
  (jsc#SLE-8464).
- net/mlx5e: Fix translation of link mode into speed
  (jsc#SLE-8464).
- net/mlx5e: Fix free peer_flow when refcount is 0 (jsc#SLE-8464).
- net/mlx5e: Fix freeing flow with kfree() and not kvfree()
  (jsc#SLE-8464).
- net/mlx5e: Fix SFF 8472 eeprom length (jsc#SLE-8464).
- net/mlx5e: Query global pause state before setting prio2buffer
  (jsc#SLE-8464).
- net/mlx5e: Fix TXQ indices to be sequential (jsc#SLE-8464).
- tcp: md5: fix potential overestimation of TCP option space
  (bsc#1154353).
- net-sysfs: Call dev_hold always in netdev_queue_add_kobject
  (bsc#1154353).
- net/tls: Fix return values to avoid ENOTSUPP (bsc#1154353).
- net: avoid an indirect call in ____sys_recvmsg() (bsc#1154353).
- mqprio: Fix out-of-bounds access in mqprio_dump (bsc#1154353).
- bpf: Fix a bug when getting subprog 0 jited image in
  check_attach_btf_id (bsc#1154353).
- net: hns3: fix VF ID issue for setting VF VLAN (bsc#1154353).
- net: hns3: fix a use after free problem in
  hns3_nic_maybe_stop_tx() (bsc#1154353).
- net: hns3: fix for TX queue not restarted problem (bsc#1154353).
- hsr: fix a NULL pointer dereference in hsr_dev_xmit()
  (bsc#1154353).
- net: Fixed updating of ethertype in skb_mpls_push()
  (bsc#1154353).
- net: sfp: fix hwmon (bsc#1154353).
- net: sfp: fix unbind (bsc#1154353).
- xdp: obtain the mem_id mutex before trying to remove an entry
  (bsc#1154353).
- act_ct: support asymmetric conntrack (bsc#1154353).
- net: ipv6_stub: use ip6_dst_lookup_flow instead of
  ip6_dst_lookup (bsc#1154353).
- net: ipv6: add net argument to ip6_dst_lookup_flow
  (bsc#1154353).
- cls_flower: Fix the behavior using port ranges with hw-offload
  (bsc#1154353).
- net: sched: fix dump qlen for sch_mq/sch_mqprio with NOLOCK
  subqueues (bsc#1154353).
- tcp: refactor tcp_retransmit_timer() (bsc#1154353).
- net/core: Populate VF index in struct ifla_vf_guid
  (bsc#1154353).
- net: bridge: deny dev_set_mac_address() when unregistering
  (bsc#1154353).
- net: fix a leak in register_netdevice() (bsc#1154353).
- Fixed updating of ethertype in function skb_mpls_pop
  (bsc#1154353).
- sch_cake: Add missing NLA policy entry TCA_CAKE_SPLIT_GSO
  (bsc#1154353).
- bpf: Fix build in minimal configurations (bsc#1154353).
- bpf: Fix static checker warning (bsc#1154353).
- SUNRPC: Fix backchannel latency metrics (bsc#1154353).
- SUNRPC: Fix svcauth_gss_proxy_init() (bsc#1154353).
- SUNRPC: Trace gssproxy upcall results (bsc#1154353).
- sunrpc: fix crash when cache_head become valid before update
  (bsc#1154353).
- svcrdma: Improve DMA mapping trace points (bsc#1154353).
- SUNRPC: Capture completion of all RPC tasks (bsc#1154353).
- SUNRPC: Fix another issue with MIC buffer space (bsc#1154353).
- xprtrdma: Replace dprintk in xprt_rdma_set_port (bsc#1154353).
- xprtrdma: Replace dprintk() in rpcrdma_update_connect_private()
  (bsc#1154353).
- xprtrdma: Refine trace_xprtrdma_fixup (bsc#1154353).
- xprtrdma: Report the computed connect delay (bsc#1154353).
- xprtrdma: Wake tasks after connect worker fails (bsc#1154353).
- xprtrdma: Pull up sometimes (bsc#1154353).
- xprtrdma: Refactor rpcrdma_prepare_msg_sges() (bsc#1154353).
- xprtrdma: Move the rpcrdma_sendctx::sc_wr field (bsc#1154353).
- xprtrdma: Remove rpcrdma_sendctx::sc_device (bsc#1154353).
- xprtrdma: Remove rpcrdma_sendctx::sc_xprt (bsc#1154353).
- xprtrdma: Ensure ri_id is stable during MR recycling
  (bsc#1154353).
- xprtrdma: Manage MRs in context of a single connection
  (bsc#1154353).
- xprtrdma: Fix MR list handling (bsc#1154353).
- xprtrdma: Close window between waking RPC senders and posting
  Receives (bsc#1154353).
- xprtrdma: Initialize rb_credits in one place (bsc#1154353).
- xprtrdma: Connection becomes unstable after a reconnect
  (bsc#1154353).
- SUNRPC: Add trace points to observe transport congestion control
  (bsc#1154353).
- SUNRPC: Eliminate log noise in call_reserveresult (bsc#1154353).
- SUNRPC: Avoid RPC delays when exiting suspend (bsc#1154353).
- net/mlx5e: Fix build error without IPV6 (jsc#SLE-8464).
- net: inet_is_local_reserved_port() port arg should be unsigned
  short (bsc#1154353).
- IB: mlx5: no need to check return value of debugfs_create
  functions (jsc#SLE-8446).
- RDMA/hns: Delete unnecessary callback functions for cq
  (jsc#SLE-8449).
- RDMA/hns: Rename the functions used inside creating cq
  (jsc#SLE-8449).
- RDMA/hns: Redefine the member of hns_roce_cq struct
  (jsc#SLE-8449).
- RDMA/hns: Redefine interfaces used in creating cq
  (jsc#SLE-8449).
- RDMA/efa: Expose RDMA read related attributes (jsc#SLE-5640).
- RDMA/efa: Support remote read access in MR registration
  (jsc#SLE-5640).
- RDMA/efa: Store network attributes in device attributes
  (jsc#SLE-5640).
- IB/hfi1: remove redundant assignment to variable ret
  (jsc#SLE-8449).
- RDMA/bnxt_re: Fix missing le16_to_cpu (jsc#SLE-8372
  bsc#1153275).
- RDMA/bnxt_re: Fix chip number validation Broadcom's Gen P5
  series (jsc#SLE-8372 bsc#1153275).
- RDMA/bnxt_re: Fix Kconfig indentation (jsc#SLE-8372
  bsc#1153275).
- IB/mlx5: Implement callbacks for getting VFs GUID attributes
  (jsc#SLE-8446).
- IB/ipoib: Add ndo operation for getting VFs GUID attributes
  (jsc#SLE-8449).
- IB/core: Add interfaces to get VF node and port GUIDs
  (jsc#SLE-8449).
- net/core: Add support for getting VF GUIDs (jsc#SLE-8449).
- RDMA/qedr: Fix null-pointer dereference when calling
  rdma_user_mmap_get_offset (jsc#SLE-8215).
- RDMA/cm: Use refcount_t type for refcount variable
  (jsc#SLE-8449).
- IB/mlx5: Support extended number of strides for Striding RQ
  (jsc#SLE-8446).
- IB/mlx4: Update HW GID table while adding vlan GID
  (jsc#SLE-8461).
- RDMA/iw_cgxb4: Fix an error handling path in 'c4iw_connect()'
  (jsc#SLE-8392).
- RDMA/cma: Use ACK timeout for RoCE packetLifeTime
  (jsc#SLE-8449).
- RDMA/efa: Clear the admin command buffer prior to its submission
  (jsc#SLE-5640).
- RDMA/siw: Cleanup unused mmap structures (jsc#SLE-8381).
- RDMA/qedr: Make qedr_iw_load_qp() static (jsc#SLE-8215).
- RDMA/ocrdma: Fix spelling mistake in variable name
  (jsc#SLE-8449).
- RDMA/qib: Validate ->show()/store() callbacks before calling
  them (jsc#SLE-8449).
- RDMA/i40iw: Fix potential use after free (jsc#SLE-8449).
- RDMA/qedr: Fix potential use after free (jsc#SLE-8215).
- RDMA/srpt: Report the SCSI residual to the initiator
  (jsc#SLE-8449).
- IB/mlx5: Support flow counters offset for bulk counters
  (jsc#SLE-8446).
- RDMA: Change MAD processing function to remove extra casting
  and parameter (jsc#SLE-8449).
- RDMA/hfi1: Delete unreachable code (jsc#SLE-8449).
- RDMA/hns: Modify appropriate printings (jsc#SLE-8449).
- RDMA/hns: Fix non-standard error codes (jsc#SLE-8449).
- RDMA/hns: Modify hns_roce_hw_v2_get_cfg to simplify the code
  (jsc#SLE-8449).
- RDMA/hns: Simplify doorbell initialization code (jsc#SLE-8449).
- RDMA/hns: Replace not intuitive function/macro names
  (jsc#SLE-8449).
- RDMA/hns: Modify fields of struct hns_roce_srq (jsc#SLE-8449).
- RDMA/hns: Delete unnecessary uar from hns_roce_cq
  (jsc#SLE-8449).
- RDMA/hns: Remove unnecessary structure hns_roce_sqp
  (jsc#SLE-8449).
- RDMA/hns: Delete unnecessary variable max_post (jsc#SLE-8449).
- RDMA/mlx5: Rewrite MAD processing logic to be readable
  (jsc#SLE-8446).
- RDMA/ocrdma: Simplify process_mad function (jsc#SLE-8449).
- RDMA/mad: Do not check MAD sizes in roce and ib drivers
  (jsc#SLE-8449).
- RDMA/ocrdma: Make ocrdma_pma_counters() return void
  (jsc#SLE-8449).
- RDMA/mad: Allocate zeroed MAD buffer (jsc#SLE-8449).
- RDMA/qib: Delete empty check_cc_key function (jsc#SLE-8449).
- RDMA/qib: Delete extra line (jsc#SLE-8449).
- RDMA/mad: Delete never implemented functions (jsc#SLE-8449).
- Revert "RDMA/srpt: Postpone HCA removal until after configfs
  directory removal" (jsc#SLE-8449).
- RDMA/qedr: Remove unsupported modify_port callback
  (jsc#SLE-8215).
- RDMA/ocrdma: Remove unsupported modify_port callback
  (jsc#SLE-8449).
- RDMA/hns: Remove unsupported modify_port callback
  (jsc#SLE-8449).
- RDMA/core: Fix return code when modify_port isn't supported
  (jsc#SLE-8449).
- RDMA/qedr: Add iWARP doorbell recovery support (jsc#SLE-8215).
- RDMA/qedr: Add doorbell overflow recovery support
  (jsc#SLE-8215).
- RDMA/qedr: Use the common mmap API (jsc#SLE-8215).
- RDMA/siw: Use the common mmap_xa helpers (jsc#SLE-8381).
- RDMA/efa: Use the common mmap_xa helpers (jsc#SLE-5640).
- RDMA: Connect between the mmap entry and the umap_priv structure
  (jsc#SLE-8449).
- RDMA/core: Create mmap database and cookie helper functions
  (jsc#SLE-8449).
- RDMA/core: Move core content from ib_uverbs to ib_core
  (jsc#SLE-8449).
- IB/mlx5: Test write combining support (jsc#SLE-8446).
- RDMA/mlx5: Return proper error value (jsc#SLE-8446).
- RDMA/odp: Remove broken debugging call to invalidate_range
  (jsc#SLE-8449).
- RDMA/mlx5: Do not race with mlx5_ib_invalidate_range during
  create and destroy (jsc#SLE-8446).
- RDMA/mlx5: Do not store implicit children in the odp_mkeys
  xarray (jsc#SLE-8446).
- RDMA/mlx5: Rework implicit ODP destroy (jsc#SLE-8446).
- RDMA/mlx5: Avoid double lookups on the pagefault path
  (jsc#SLE-8446).
- RDMA/mlx5: Reduce locking in implicit_mr_get_data()
  (jsc#SLE-8446).
- RDMA/mlx5: Use an xarray for the children of an implicit ODP
  (jsc#SLE-8446).
- RDMA/mlx5: Split implicit handling from pagefault_mr
  (jsc#SLE-8446).
- RDMA/mlx5: Set the HW IOVA of the child MRs to their place in
  the tree (jsc#SLE-8446).
- RDMA/mlx5: Lift implicit_mr_alloc() into the two routines that
  call it (jsc#SLE-8446).
- RDMA/mlx5: Rework implicit_mr_get_data (jsc#SLE-8446).
- RDMA/mlx5: Delete struct mlx5_priv->mkey_table (jsc#SLE-8446).
- RDMA/mlx5: Use a dedicated mkey xarray for ODP (jsc#SLE-8446).
- RDMA/mlx5: Split sig_err MR data into its own xarray
  (jsc#SLE-8446).
- RDMA/mlx5: Use SRCU properly in ODP prefetch (jsc#SLE-8446).
- RDMA/vmw_pvrdma: Use resource ids from physical device if
  available (jsc#SLE-8449).
- RDMA/core: Set DMA parameters correctly (jsc#SLE-8449).
- RDMA/siw: Increase DMA max_segment_size parameter
  (jsc#SLE-8381).
- RDMA/rxe: Increase DMA max_segment_size parameter
  (jsc#SLE-8449).
- RDMA/siw: Fix post_recv QP state locking (jsc#SLE-8381).
- RDMA/iw_cxgb4: Report correct port speed/width (jsc#SLE-8392).
- RDMA/qedr: Fix memory leak in user qp and mr (jsc#SLE-8215).
- RDMA/qedr: Fix synchronization methods and memory leaks in qedr
  (jsc#SLE-8215).
- RDMA/qedr: Fix qpids xarray api used (jsc#SLE-8215).
- RDMA/qedr: Fix srqs xarray initialization (jsc#SLE-8215).
- RDMA/hns: Fix memory leak on 'context' on error return path
  (jsc#SLE-8449).
- RDMA/hns: Bugfix for qpc/cqc timer configuration (jsc#SLE-8449).
- RDMA/hns: Fix to support 64K page for srq (jsc#SLE-8449).
- RDMA/srpt: Fix TPG creation (jsc#SLE-8449).
- RDMA/hns: Delete BITS_PER_BYTE redefinition (jsc#SLE-8449).
- RDMA/hns: Prevent undefined behavior in
  hns_roce_set_user_sq_size() (jsc#SLE-8449).
- RDMA/cm: Update copyright together with SPDX tag (jsc#SLE-8449).
- RDMA/cm: Use specific keyword to check define (jsc#SLE-8449).
- RDMA/cm: Delete unused cm_is_active_peer function
  (jsc#SLE-8449).
- RDMA/rxe: Remove useless rxe_init_device_param assignments
  (jsc#SLE-8449).
- RDMA/core: Check that process is still alive before sending
  it to the users (jsc#SLE-8449).
- RDMA/restrack: Remove PID namespace support (jsc#SLE-8449).
- IB/core: Do not notify GID change event of an unregistered
  device (jsc#SLE-8449).
- IB/mlx5: Align usage of QP1 create flags with rest of mlx5
  defines (jsc#SLE-8446).
- IB/mlx5: Remove dead code (jsc#SLE-8446).
- RDMA/uverbs: Add a check for uverbs_attr_get to
  uverbs_copy_to_struct_or_zero (jsc#SLE-8449).
- IB/cma: Honor traffic class from lower netdevice for RoCE
  (jsc#SLE-8449).
- RDMA/nldev: Provide MR statistics (jsc#SLE-8449).
- RDMA/mlx5: Return ODP type per MR (jsc#SLE-8446).
- RDMA/nldev: Allow different fill function per resource
  (jsc#SLE-8449).
- IB/mlx5: Introduce ODP diagnostic counters (jsc#SLE-8446).
- infiniband: fix sw/rdmavt/ kernel-doc notation (jsc#SLE-8449).
- infiniband: fix core/ kernel-doc notation (jsc#SLE-8449).
- infiniband: fix ulp/iser/iser_initiator.c kernel-doc warnings
  (jsc#SLE-8449).
- infiniband: fix ulp/iser/iser_verbs.c kernel-doc notation
  (jsc#SLE-8449).
- infiniband: fix core/verbs.c kernel-doc notation (jsc#SLE-8449).
- infiniband: fix ulp/srpt/ib_srpt.h kernel-doc notation
  (jsc#SLE-8449).
- infiniband: fix ulp/opa_vnic/opa_vnic_internal.h kernel-doc
  notation (jsc#SLE-8449).
- infiniband: fix ulp/iser/iscsi_iser.h kernel-doc warnings
  (jsc#SLE-8449).
- infiniband: fix core/ipwm_util.h kernel-doc warnings
  (jsc#SLE-8449).
- infiniband: fix ulp/iser/iscsi_iser. kernel-doc notation
  (jsc#SLE-8449).
- RDMA/mlx5: Add capability for max sge to get optimized
  performance (jsc#SLE-8446).
- RDMA/rw: Support threshold for registration vs scattering to
  local pages (jsc#SLE-8449).
- RDMA/siw: Fix SQ/RQ drain logic (jsc#SLE-8381).
- ib/srp: Add missing new line after displaying fast_io_fail_tmo
  param (jsc#SLE-8449).
- RDMA/hns: Release qp resources when failed to destroy qp
  (jsc#SLE-8449).
- RDMA/hns: Fix a spelling mistake in a macro (jsc#SLE-8449).
- RDMA/hns: Modify return value of restrack functions
  (jsc#SLE-8449).
- RDMA/hns: Modify variable/field name from vlan to vlan_id
  (jsc#SLE-8449).
- RDMA/hns: Fix wrong parameters when initial mtt of srq->idx_que
  (jsc#SLE-8449).
- RDMA/hns: remove a redundant le16_to_cpu (jsc#SLE-8449).
- IB/mlx5: Introduce and use mkey context setting helper routine
  (jsc#SLE-8446).
- RDMA/iser: Use iser_err instead of pr_err for logging
  (jsc#SLE-8449).
- RDMA/bnxt_re: Enable SRIOV VF support on Broadcom's 57500
  adapter series (jsc#SLE-8372 bsc#1153275).
- RDMA/srp: Calculate max_it_iu_size if remote max_it_iu length
  available (jsc#SLE-8449).
- RDMA/srp: Add parse function for maximum initiator to target
  IU size (jsc#SLE-8449).
- IB/cm: Use container_of() instead of typecast (jsc#SLE-8449).
- IB/mlx5: Remove unnecessary else statement (jsc#SLE-8446).
- IB/mlx5: Remove unnecessary return statement (jsc#SLE-8446).
- RDMA/mlx5: Group boolean parameters to take less space
  (jsc#SLE-8446).
- RDMA/srpt: Postpone HCA removal until after configfs directory
  removal (jsc#SLE-8449).
- RDMA/srpt: Make the code for handling port identities more
  systematic (jsc#SLE-8449).
- RDMA/srpt: Rework the code that waits until an RDMA port is
  no longer in use (jsc#SLE-8449).
- RDMA/srpt: Rework the approach for closing an RDMA channel
  (jsc#SLE-8449).
- RDMA/srpt: Improve a debug message (jsc#SLE-8449).
- RDMA/srpt: Fix handling of iWARP logins (jsc#SLE-8449).
- RDMA/srpt: Fix handling of SR-IOV and iWARP ports
  (jsc#SLE-8449).
- RDMA/srp: Make route resolving error messages more informative
  (jsc#SLE-8449).
- RDMA/srp: Honor the max_send_sge device attribute
  (jsc#SLE-8449).
- RDMA/srp: Remove two casts (jsc#SLE-8449).
- RDMA/siw: Make node GUIDs valid EUI-64 identifiers
  (jsc#SLE-8381).
- RDMA/rxe: Verify modify_device mask (jsc#SLE-8449).
- RDMA/bnxt_re: Remove unsupported modify_device callback
  (jsc#SLE-8372 bsc#1153275).
- RDMA/core: Fix return code when modify_device isn't supported
  (jsc#SLE-8449).
- RDMA/siw: Fix port number endianness in a debug message
  (jsc#SLE-8381).
- RDMA/siw: Simplify several debug messages (jsc#SLE-8381).
- IB/iser: remove redundant macro definitions (jsc#SLE-8449).
- IB/iser: bound protection_sg size by data_sg size
  (jsc#SLE-8449).
- IB/iser: add unlikely checks in the fast path (jsc#SLE-8449).
- RDMA/counter: Prevent QP counter manual binding in auto mode
  (jsc#SLE-8449).
- net/sched: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1154353).
- net/netfilter: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1154353).
- net/core: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1154353).
- bpf/cgroup: Replace rcu_swap_protected() with
  rcu_replace_pointer() (bsc#1154353).
- rcu: Upgrade rcu_swap_protected() to rcu_replace_pointer()
  (bsc#1154353).
- net: phy: add helpers phy_(un)lock_mdio_bus (bsc#1154353).
- bpf: Simplify __bpf_arch_text_poke poke type handling
  (bsc#1154353).
- bpf, x86: Emit patchable direct jump as tail call (bsc#1154353).
- bpf: Constant map key tracking for prog array pokes
  (bsc#1154353).
- bpf: Add poke dependency tracking for prog array maps
  (bsc#1154353).
- bpf: Add initial poke descriptor table for jit images
  (bsc#1154353).
- bpf: Move owner type, jited info into array auxiliary data
  (bsc#1154353).
- bpf: Move bpf_free_used_maps into sleepable section
  (bsc#1154353).
- bpf, x86: Generalize and extend bpf_arch_text_poke for direct
  jumps (bsc#1154353).
- bpf: Provide better register bounds after jmp32 instructions
  (bsc#1154353).
- xsk: Fix xsk_poll()'s return type (bsc#1154353).
- mlxsw: spectrum_router: Fix use of uninitialized adjacency index
  (bsc#1154488).
- mlxsw: spectrum_router: After underlay moves, demote conflicting
  tunnels (bsc#1154488).
- bnxt_en: Add support for flashing the device via devlink
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Allow PHY settings on multi-function or NPAR PFs if
  allowed by FW (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add async. event logic for PHY configuration changes
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor the initialization of the ethtool link
  settings (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Skip disabling autoneg before PHY loopback when
  appropriate (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Assign more RSS context resources to the VFs
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Initialize context memory to the value specified by
  firmware (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix suspend/resume path on 57500 chips (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Send FUNC_RESOURCE_QCAPS command in bnxt_resume()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Combine 2 functions calling the same HWRM_DRV_RGTR
  fw command (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Do driver unregister cleanup in bnxt_init_one()
  failure path (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Disable/enable Bus master during suspend/resume
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add chip IDs for 57452 and 57454 chips (jsc#SLE-8371
  bsc#1153274).
- sfc: fix build without CONFIG_RFS_ACCEL (jsc#SLE-8314).
- net: gro: use vlan API instead of accessing directly
  (bsc#1154353).
- net/mlx5e: Remove redundant pointer check (jsc#SLE-8464).
- net/mlx5e: TC, Stub out ipv6 tun create header function
  (jsc#SLE-8464).
- net/mlx5: DR, Add support for Geneve packets SW steering
  (jsc#SLE-8464).
- net/mlx5: DR, Add HW bits and definitions for Geneve flex parser
  (jsc#SLE-8464).
- net/mlx5: DR, Refactor VXLAN GPE flex parser tunnel code for
  SW steering (jsc#SLE-8464).
- net/mlx5: Don't write read-only fields in
  MODIFY_HCA_VPORT_CONTEXT command (jsc#SLE-8464).
- net: use rhashtable_lookup() instead of rhashtable_lookup_fast()
  (bsc#1154353).
- net: phy: initialise phydev speed and duplex sanely
  (bsc#1154353).
- net: phy: remove phy_ethtool_sset() (bsc#1154353).
- sfc: do ARFS expiry work occasionally even without NAPI poll
  (jsc#SLE-8314).
- sfc: add statistics for ARFS (jsc#SLE-8314).
- sfc: suppress MCDI errors from ARFS (jsc#SLE-8314).
- sfc: change ARFS expiry mechanism (jsc#SLE-8314).
- ice: Update FW API minor version (jsc#SLE-7926).
- ice: remove pointless NULL check of port_info (jsc#SLE-7926).
- ice: Implement ethtool ops for channels (jsc#SLE-7926).
- ice: implement VF stats NDO (jsc#SLE-7926).
- ice: add helpers for virtchnl (jsc#SLE-7926).
- ice: Add ice_pf_to_dev(pf) macro (jsc#SLE-7926).
- ice: Do not use devm* functions for local uses (jsc#SLE-7926).
- ice: Refactor removal of VLAN promiscuous rules (jsc#SLE-7926).
- ice: Fix setting coalesce to handle DCB configuration
  (jsc#SLE-7926).
- ice: Only disable VF state when freeing each VF resources
  (jsc#SLE-7926).
- ice: fix stack leakage (jsc#SLE-7926).
- ice: Don't modify stripping for add/del VLANs on VF
  (jsc#SLE-7926).
- ice: Disallow VF VLAN opcodes if VLAN offloads disabled
  (jsc#SLE-7926).
- ice: Correct capabilities reporting of max TCs (jsc#SLE-7926).
- ice: Store number of functions for the device (jsc#SLE-7926).
- net: inet_is_local_reserved_port() should return bool not int
  (bsc#1154353).
- cxgb4: add stats for MQPRIO QoS offload Tx path (jsc#SLE-8389).
- cxgb4: add UDP segmentation offload support (jsc#SLE-8389).
- cxgb4/chcr: update SGL DMA unmap for USO (jsc#SLE-8389).
- seg6: allow local packet processing for SRv6 End.DT6 behavior
  (bsc#1154353).
- ipv4: use dst hint for ipv4 list receive (bsc#1154353).
- ipv4: move fib4_has_custom_rules() helper to public header
  (bsc#1154353).
- ipv6: introduce and uses route look hints for list input
  (bsc#1154353).
- ipv6: keep track of routes using src (bsc#1154353).
- ipv6: add fib6_has_custom_rules() helper (bsc#1154353).
- bpf: skmsg, fix potential psock NULL pointer dereference
  (bsc#1154353).
- lwtunnel: check erspan options before allocating tun_info
  (bsc#1154353).
- lwtunnel: be STRICT to validate the new LWTUNNEL_IP(6)_OPTS
  (bsc#1154353).
- net: remove the unnecessary strict_start_type in some policies
  (bsc#1154353).
- net: sched: allow flower to match erspan options (bsc#1154353).
- net: sched: allow flower to match vxlan options (bsc#1154353).
- net: sched: add erspan option support to act_tunnel_key
  (bsc#1154353).
- net: sched: add vxlan option support to act_tunnel_key
  (bsc#1154353).
- net: sfp: soft status and control support (bsc#1154353).
- net: sfp: add some quirks for GPON modules (bsc#1154353).
- net: sfp: add support for module quirks (bsc#1154353).
- tcp: warn if offset reach the maxlen limit when using snprintf
  (bsc#1154353).
- ip_gre: Make none-tun-dst gre tunnel store tunnel info as
  metadat_dst in recv (bsc#1154353).
- bpf: Switch bpf_map_{area_alloc,area_mmapable_alloc}() to u64
  size (bsc#1154353).
- bpf: Make array_map_mmap static (bsc#1154353).
- bpf: Fix memory leak on object 'data' (bsc#1154353).
- bpf: Add mmap() support for BPF_MAP_TYPE_ARRAY (bsc#1154353).
- bpf: Convert bpf_prog refcnt to atomic64_t (bsc#1154353).
- bpf: Switch bpf_map ref counter to atomic64_t so bpf_map_inc()
  never fails (bsc#1154353).
- bpf: Support attaching tracing BPF program to other BPF programs
  (bsc#1154353).
- bpf: Compare BTF types of functions arguments with actual types
  (bsc#1154353).
- bpf: Annotate context types (bsc#1154353).
- bpf: Reserve space for BPF trampoline in BPF programs
  (bsc#1154353).
- bpf: Add kernel test functions for fentry testing (bsc#1154353).
- bpf: Add bpf_arch_text_poke() helper (bsc#1154353).
- bpf: Refactor x86 JIT into helpers (bsc#1154353).
- bpf: Support doubleword alignment in bpf_jit_binary_alloc
  (bsc#1154353).
- bpf: Add array support to btf_struct_access (bsc#1154353).
- net: ipconfig: Wait for deferred device probes (bsc#1154353).
- net: page_pool: add the possibility to sync DMA memory for
  device (bsc#1154353).
- net: sched: pie: enable timestamp based delay calculation
  (bsc#1154353).
- cxgb4: add TC-MATCHALL classifier ingress offload
  (jsc#SLE-8389).
- cxgb4: check rule prio conflicts before offload (jsc#SLE-8389).
- cxgb4: add TC-MATCHALL classifier egress offload (jsc#SLE-8389).
- net/mlx5e: Rx, Update page pool numa node when changed
  (jsc#SLE-8464).
- page_pool: Don't recycle non-reusable pages (bsc#1154353).
- page_pool: Add API to update numa node (bsc#1154353).
- lwtunnel: add support for multiple geneve opts (bsc#1154353).
- cxgb4: remove unneeded semicolon for switch block
  (jsc#SLE-8389).
- lwtunnel: change to use nla_put_u8 for
  LWTUNNEL_IP_OPT_ERSPAN_VER (bsc#1154353).
- bnxt_en: Abort waiting for firmware response if there is no
  heartbeat (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add a warning message for driver initiated reset
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Return proper error code for non-existent NVM variable
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Report health status update after reset is done
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Set MASTER flag during driver registration
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Extend ETHTOOL_RESET to hot reset driver (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Increase firmware response timeout for coredump
  commands (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Improve RX buffer error handling (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Update firmware interface spec to 1.10.1.12
  (jsc#SLE-8371 bsc#1153274).
- page_pool: add destroy attempts counter and rename tracepoint
  (bsc#1154353).
- xdp: remove memory poison on free for struct xdp_mem_allocator
  (bsc#1154353).
- net: phy: avoid matching all-ones clause 45 PHY IDs
  (bsc#1154353).
- net: phy: marvell10g: add SFP+ support (bsc#1154353).
- net: phy: add core phylib sfp support (bsc#1154353).
- net: phylink: update to use phy_support_asym_pause()
  (bsc#1154353).
- bonding: symmetric ICMP transmit (bsc#1154353).
- net: core: allow fast GRO for skbs with Ethernet header in head
  (bsc#1154353).
- bnx2x: Remove hw_reset_t function casts (bsc#1154395).
- bnx2x: Remove format_fw_ver_t function casts (bsc#1154395).
- bnx2x: Remove config_init_t function casts (bsc#1154395).
- bnx2x: Remove read_status_t function casts (bsc#1154395).
- bnx2x: Drop redundant callback function casts (bsc#1154395).
- page_pool: do not release pool until inflight == 0
  (bsc#1154353).
- tun: fix data-race in gro_normal_list() (bsc#1154353).
- mlxsw: spectrum_router: Allocate discard adjacency entry when
  needed (bsc#1154488).
- net/tls: Fix unused function warning (bsc#1154353).
- net/mlx5: Add devlink reload (jsc#SLE-8464).
- net/mlx5e: Set netdev name space on creation (jsc#SLE-8464).
- net/mlx5: Remove redundant NULL initializations (jsc#SLE-8464).
- net/mlx5: Read num_vfs before disabling SR-IOV (jsc#SLE-8464).
- net/mlx5: DR, Fix matcher builders select check (jsc#SLE-8464).
- net/mlx5: Add new chain for netfilter flow table offload
  (jsc#SLE-8464).
- net/mlx5: Refactor creating fast path prio chains
  (jsc#SLE-8464).
- net/mlx5: Accumulate levels for chains prio namespaces
  (jsc#SLE-8464).
- net/mlx5: Define fdb tc levels per prio (jsc#SLE-8464).
- net/mlx5: Rename FDB_* tc related defines to FDB_TC_* defines
  (jsc#SLE-8464).
- net/mlx5: Simplify fdb chain and prio eswitch defines
  (jsc#SLE-8464).
- IB/mlx5: Load profile according to RoCE enablement state
  (jsc#SLE-8446).
- IB/mlx5: Rename profile and init methods (jsc#SLE-8446).
- net/mlx5: Handle "enable_roce" devlink param (jsc#SLE-8464).
- net/mlx5: Document flow_steering_mode devlink param
  (jsc#SLE-8464).
- devlink: Add new "enable_roce" generic device param
  (bsc#1154353).
- net/mlx5: fix spelling mistake "metdata" -> "metadata"
  (jsc#SLE-8464).
- net/mlx5: fix kvfree of uninitialized pointer spec
  (jsc#SLE-8464).
- IB/mlx5: Introduce and use mlx5_core_is_vf() (jsc#SLE-8446).
- net/mlx5: E-switch, Enable metadata on own vport (jsc#SLE-8464).
- net/mlx5: Refactor ingress acl configuration (jsc#SLE-8464).
- net/mlx5: Restrict metadata disablement to offloads mode
  (jsc#SLE-8464).
- net/mlx5: E-switch, Offloads shift ACL programming during
  enable/disable vport (jsc#SLE-8464).
- net/mlx5: E-switch, Offloads introduce and use per vport acl
  tables APIs (jsc#SLE-8464).
- net/mlx5: Move ACL drop counters life cycle close to ACL
  lifecycle (jsc#SLE-8464).
- net/mlx5: E-switch, Legacy introduce and use per vport acl
  tables APIs (jsc#SLE-8464).
- net/mlx5: E-switch, Prepare code to handle vport enable error
  (jsc#SLE-8464).
- net/mlx5: Tide up state_lock and vport enabled flag usage
  (jsc#SLE-8464).
- net/mlx5: Move legacy drop counter and rule under legacy
  structure (jsc#SLE-8464).
- net/mlx5: Move metdata fields under offloads structure
  (jsc#SLE-8464).
- net/mlx5: Correct comment for legacy fields (jsc#SLE-8464).
- net/mlx5: Introduce and use mlx5_esw_is_manager_vport()
  (jsc#SLE-8464).
- net/mlx5: E-switch, Introduce and use vlan rule config helper
  (jsc#SLE-8464).
- net/mlx5: E-Switch, Rename ingress acl config in offloads mode
  (jsc#SLE-8464).
- net/mlx5: E-Switch, Rename egress config to generic name
  (jsc#SLE-8464).
- net/mlx5: Fixed a typo in a comment in esw_del_uc_addr()
  (jsc#SLE-8464).
- net/mlx5: Expose optimal performance scatter entries capability
  (jsc#SLE-8446).
- cxgb4: Fix an error code in cxgb4_mqprio_alloc_hw_resources()
  (jsc#SLE-8389).
- bnxt_en: Fix array overrun in bnxt_fill_l2_rewrite_fields()
  (jsc#SLE-8371 bsc#1153274).
- net: sfp: fix spelling mistake "requies" -> "requires"
  (bsc#1154353).
- bridge: implement get_link_ksettings ethtool method
  (bsc#1154353).
- vxlan: implement get_link_ksettings ethtool method
  (bsc#1154353).
- sfc: trace_xdp_exception on XDP failure (jsc#SLE-8314).
- net/sched: actions: remove unused 'order' (bsc#1154353).
- netdevsim: Update dummy reporter's devlink binary interface
  (bsc#1154353).
- net/mlx5: Dump of fw_fatal use updated devlink binary interface
  (jsc#SLE-8464).
- devlink: Allow large formatted message of binary output
  (bsc#1154353).
- cxgb4: make function 'cxgb4_mqprio_free_hw_resources' static
  (jsc#SLE-8389).
- mlxsw: spectrum: Enable EMAD string TLV (bsc#1154488).
- mlxsw: core: Add support for using EMAD string TLV
  (bsc#1154488).
- mlxsw: core: Extend EMAD information reported to devlink hwerr
  (bsc#1154488).
- mlxsw: core: Add support for EMAD string TLV parsing
  (bsc#1154488).
- mlxsw: core: Add EMAD string TLV (bsc#1154488).
- mlxsw: emad: Remove deprecated EMAD TLVs (bsc#1154488).
- mlxsw: core: Parse TLVs' offsets of incoming EMADs
  (bsc#1154488).
- cxgb4: remove redundant assignment to hdr_len (jsc#SLE-8389).
- mlxsw: core: Enable devlink reload only on probe (bsc#1154488).
- net: sfp: allow modules with slow diagnostics to probe
  (bsc#1154353).
- net: sfp: allow sfp to probe slow to initialise GPON modules
  (bsc#1154353).
- net: sfp: move module insert reporting out of probe
  (bsc#1154353).
- net: sfp: split power mode switching from probe (bsc#1154353).
- net: sfp: track upstream's attachment state in state machine
  (bsc#1154353).
- net: sfp: ensure TX_FAULT has deasserted before probing the PHY
  (bsc#1154353).
- net: sfp: allow fault processing to transition to other states
  (bsc#1154353).
- net: sfp: eliminate mdelay() from PHY probe (bsc#1154353).
- net: sfp: split the PHY probe from sfp_sm_mod_init()
  (bsc#1154353).
- net: sfp: control TX_DISABLE and phy only from main state
  machine (bsc#1154353).
- net: sfp: avoid power switch on address-change modules
  (bsc#1154353).
- net: sfp: parse SFP power requirement earlier (bsc#1154353).
- net: sfp: rename T_PROBE_WAIT to T_SERIAL (bsc#1154353).
- net: sfp: handle module remove outside state machine
  (bsc#1154353).
- net: sfp: rename sfp_sm_ins_next() as sfp_sm_mod_next()
  (bsc#1154353).
- net: sfp: move tx disable on device down to main state machine
  (bsc#1154353).
- net: sfp: move sfp sub-state machines into separate functions
  (bsc#1154353).
- net: sfp: fix sfp_bus_put() kernel documentation (bsc#1154353).
- lwtunnel: ignore any TUNNEL_OPTIONS_PRESENT flags set by users
  (bsc#1154353).
- lwtunnel: get nlsize for erspan options properly (bsc#1154353).
- lwtunnel: change to use nla_parse_nested on new options
  (bsc#1154353).
- net: sfp: rework upstream interface (bsc#1154353).
- devlink: disallow reload operation during device cleanup
  (bsc#1154353).
- packet: fix data-race in fanout_flow_is_huge() (bsc#1154353).
- ice: print opcode when printing controlq errors (jsc#SLE-7926).
- ice: use more accurate ICE_DBG mask types (jsc#SLE-7926).
- ice: Introduce and use ice_vsi_type_str (jsc#SLE-7926).
- ice: remove unnecessary conditional check (jsc#SLE-7926).
- ice: Update enum ice_flg64_bits to current specification
  (jsc#SLE-7926).
- ice: delay less (jsc#SLE-7926).
- ice: use pkg_dwnld_status instead of sq_last_status
  (jsc#SLE-7926).
- ice: Change max MSI-x vector_id check in cfg_irq_map
  (jsc#SLE-7926).
- ice: Check if VF is disabled for Opcode and other operations
  (jsc#SLE-7926).
- ice: configure software LLDP in ice_init_pf_dcb (jsc#SLE-7926).
- ice: Fix to change Rx/Tx ring descriptor size via ethtool with
  DCBx (jsc#SLE-7926).
- ice: avoid setting features during reset (jsc#SLE-7926).
- ice: Implement DCBNL support (jsc#SLE-7926).
- ice: Add NDO callback to set the maximum per-queue bitrate
  (jsc#SLE-7926).
- ice: Use ice_ena_vsi and ice_dis_vsi in DCB configuration flow
  (jsc#SLE-7926).
- net: icmp: fix data-race in cmp_global_allow() (bsc#1154353).
- cxgb4: fix 64-bit division on i386 (jsc#SLE-8389).
- cxgb4: Use match_string() helper to simplify the code
  (jsc#SLE-8389).
- net: add a READ_ONCE() in skb_peek_tail() (bsc#1154353).
- net: add annotations on hh->hh_len lockless accesses
  (bsc#1154353).
- net: use u64_stats_t in struct pcpu_lstats (bsc#1154353).
- tun: switch to u64_stats_t (bsc#1154353).
- u64_stats: provide u64_stats_t type (bsc#1154353).
- net: dummy: use standard dev_lstats_add() and dev_lstats_read()
  (bsc#1154353).
- vsockmon: use standard dev_lstats_add() and dev_lstats_read()
  (bsc#1154353).
- veth: use standard dev_lstats_add() and dev_lstats_read()
  (bsc#1154353).
- net: nlmon: use standard dev_lstats_add() and dev_lstats_read()
  (bsc#1154353).
- net: provide dev_lstats_add() helper (bsc#1154353).
- net: provide dev_lstats_read() helper (bsc#1154353).
- net: ethernet: intel: Demote MTU change prints to debug
  (jsc#SLE-7966).
- mlxsw: Add layer 3 devlink-trap exceptions support
  (bsc#1154488).
- mlxsw: Add specific trap for packets routed via invalid nexthops
  (bsc#1154488).
- mlxsw: Add new FIB entry type for reject routes (bsc#1154488).
- devlink: Add layer 3 generic packet exception traps
  (bsc#1154353).
- mlxsw: Add layer 3 devlink-trap support (bsc#1154488).
- devlink: Add layer 3 generic packet traps (bsc#1154353).
- tcp: Remove one extra ktime_get_ns() from cookie_init_timestamp
  (bsc#1154353).
- inetpeer: fix data-race in inet_putpeer / inet_putpeer
  (bsc#1154353).
- mlxsw: spectrum: Fix error return code in
  mlxsw_sp_port_module_info_init() (bsc#1154488).
- cxgb4: add FLOWC based QoS offload (jsc#SLE-8389).
- cxgb4: add Tx and Rx path for ETHOFLD traffic (jsc#SLE-8389).
- cxgb4: add ETHOFLD hardware queue support (jsc#SLE-8389).
- cxgb4: parse and configure TC-MQPRIO offload (jsc#SLE-8389).
- cxgb4: rework queue config and MSI-X allocation (jsc#SLE-8389).
- cxgb4: query firmware for QoS offload resources (jsc#SLE-8389).
- net_sched: gen_estimator: extend packet counter to 64bit
  (bsc#1154353).
- ice: Fix return value when SR-IOV is not supported
  (jsc#SLE-7926).
- ice: Rename VF function ice_vc_dis_vf to match its behavior
  (jsc#SLE-7926).
- ice: Get rid of ice_cleanup_header (jsc#SLE-7926).
- ice: print PCI link speed and width (jsc#SLE-7926).
- ice: print unsupported module message (jsc#SLE-7926).
- ice: write register with correct offset (jsc#SLE-7926).
- ice: Check for null pointer dereference when setting rings
  (jsc#SLE-7926).
- ice: save PCI state in probe (jsc#SLE-7926).
- ice: Adjust DCB INIT for SW mode (jsc#SLE-7926).
- ice: fix driver unload flow (jsc#SLE-7926).
- ice: handle DCBx non-contiguous TC request (jsc#SLE-7926).
- ice: Update Boot Configuration Section read of NVM
  (jsc#SLE-7926).
- ice: add ethtool -m support for reading i2c eeprom modules
  (jsc#SLE-7926).
- tcp: fix data-race in tcp_recvmsg() (bsc#1154353).
- net: silence data-races on sk_backlog.tail (bsc#1154353).
- lwtunnel: add options setting and dumping for erspan
  (bsc#1154353).
- lwtunnel: add options setting and dumping for vxlan
  (bsc#1154353).
- lwtunnel: add options setting and dumping for geneve
  (bsc#1154353).
- lwtunnel: add options process for cmp_encap (bsc#1154353).
- lwtunnel: add options process for arp request (bsc#1154353).
- net: annotate lockless accesses to sk->sk_max_ack_backlog
  (bsc#1154353).
- net: annotate lockless accesses to sk->sk_ack_backlog
  (bsc#1154353).
- net: use helpers to change sk_ack_backlog (bsc#1154353).
- net: avoid potential false sharing in neighbor related code
  (bsc#1154353).
- inet_diag: use jiffies_delta_to_msecs() (bsc#1154353).
- net: neigh: use long type to store jiffies delta (bsc#1154353).
- netdevsim: drop code duplicated by a merge (bsc#1154353).
- cxgb4: Add pci reset handler (jsc#SLE-8389).
- cnic: Set fp_hsi_ver as part of CLIENT_SETUP ramrod
  (bsc#1154395).
- bnx2x: Fix PF-VF communication over multi-cos queues
  (bsc#1154395).
- bnx2x: Enable Multi-Cos feature (bsc#1154395).
- bnx2x: Utilize FW 7.13.15.0 (bsc#1154395).
- net_sched: add TCA_STATS_PKT64 attribute (bsc#1154353).
- net_sched: extend packet counter to 64bit (bsc#1154353).
- net_sched: do not export gnet_stats_basic_packed to uapi
  (bsc#1154353).
- net: hns3: remove unused macros (bsc#1154353).
- vsock: Simplify '__vsock_release()' (bsc#1154353).
- icmp: remove duplicate code (bsc#1154353).
- icmp: add helpers to recognize ICMP error packets (bsc#1154353).
- ice: allow 3k MTU for XDP (jsc#SLE-7926).
- ice: add build_skb() support (jsc#SLE-7926).
- ice: introduce frame padding computation logic (jsc#SLE-7926).
- ice: introduce legacy Rx flag (jsc#SLE-7926).
- ice: Add support for AF_XDP (jsc#SLE-7926).
- ice: Move common functions to ice_txrx_lib.c (jsc#SLE-7926).
- ice: Add support for XDP (jsc#SLE-7926).
- ice: get rid of per-tc flow in Tx queue configuration routines
  (jsc#SLE-7926).
- ice: Introduce ice_base.c (jsc#SLE-7926).
- i40e: implement VF stats NDO (jsc#SLE-8025).
- i40e: enable X710 support (jsc#SLE-8025).
- ixgbe: protect TX timestamping from API misuse (jsc#SLE-7979
  jsc#SLE-7981).
- fm10k: update driver version to match out-of-tree
  (jsc#SLE-8009).
- ixgbe: Make use of cpumask_local_spread to improve RSS locality
  (jsc#SLE-7979 jsc#SLE-7981).
- fm10k: add support for ndo_get_vf_stats operation
  (jsc#SLE-8009).
- fm10k: add missing field initializers to TLV attributes)
  (jsc#SLE-8009).
- ipv6: use jhash2() in rt6_exception_hash() (bsc#1154353).
- net: bridge: fdb: eliminate extra port state tests from
  fast-path (bsc#1154353).
- net/mlx5: DR, Support IPv4 and IPv6 mixed matcher
  (jsc#SLE-8464).
- net/mlx5: LAG, Use affinity type enumerators (jsc#SLE-8464).
- net/mlx5: LAG, Use port enumerators (jsc#SLE-8464).
- net/mlx5: rate limit alloc_ent error messages (jsc#SLE-8464).
- net/mlx5e: Add ToS (DSCP) header rewrite support (jsc#SLE-8464).
- net/mlx5e: Bit sized fields rewrite support (jsc#SLE-8464).
- net/mlx5: WQ, Move short getters into header file
  (jsc#SLE-8464).
- net/mlx5e: TX, Dump WQs wqe descriptors on CQE with error events
  (jsc#SLE-8464).
- net/mlx5: Support lockless FTE read lookups (jsc#SLE-8464).
- net/mlx5: Do not hold group lock while allocating FTE in
  software (jsc#SLE-8464).
- net/mlx5e: Verify that rule has at least one fwd/drop action
  (jsc#SLE-8464).
- net/mlx5: Clear VF's configuration on disabling SRIOV
  (jsc#SLE-8464).
- net/mlx5: Remove unneeded variable in mlx5_unload_one
  (jsc#SLE-8464).
- net/mlx5: FPGA, support network cards with standalone FPGA
  (jsc#SLE-8464).
- net/mlx5: DR, Replace CRC32 implementation to use kernel lib
  (jsc#SLE-8464).
- net: icmp6: provide input address for traceroute6 (bsc#1154353).
- net: icmp: use input address in traceroute (bsc#1154353).
- xsk: Restructure/inline XSKMAP lookup/redirect/flush
  (bsc#1154353).
- bpf: Implement map_gen_lookup() callback for XSKMAP
  (bsc#1154353).
- xsk: Store struct xdp_sock as a flexible array member of the
  XSKMAP (bsc#1154353).
- bpf: Replace prog_raw_tp+btf_id with prog_tracing (bsc#1154353).
- bpf: Enforce 'return 0' in BTF-enabled raw_tp programs
  (bsc#1154353).
- net: bridge: fdb: restore unlikely() when taking over externally
  added entries (bsc#1154353).
- net: bridge: fdb: avoid two atomic bitops in
  br_fdb_external_learn_add() (bsc#1154353).
- net: bridge: fdb: br_fdb_update can take flags directly
  (bsc#1154353).
- bnxt_en: Call bnxt_ulp_stop()/bnxt_ulp_start() during
  suspend/resume (jsc#SLE-8372 bsc#1153275).
- bnxt_en: Call bnxt_ulp_stop()/bnxt_ulp_start() during error
  recovery (jsc#SLE-8372 bsc#1153275).
- bnxt_en: Improve bnxt_ulp_stop()/bnxt_ulp_start() call sequence
  (jsc#SLE-8372 bsc#1153275).
- bnxt_en: flow_offload: offload tunnel decap rules via indirect
  callbacks (jsc#SLE-8372 bsc#1153275).
- bnxt_en: Add support for NAT(L3/L4 rewrite) (jsc#SLE-8372
  bsc#1153275).
- bnxt: Avoid logging an unnecessary message when a flow can't
  be offloaded (jsc#SLE-8372 bsc#1153275).
- bnxt_en: Add support for L2 rewrite (jsc#SLE-8372 bsc#1153275).
- sfc: add XDP counters to ethtool stats (jsc#SLE-8314).
- sfc: handle XDP_TX outcomes of XDP eBPF programs (jsc#SLE-8314).
- sfc: allocate channels for XDP tx queues (jsc#SLE-8314).
- sfc: Enable setting of xdp_prog (jsc#SLE-8314).
- sfc: perform XDP processing on received packets (jsc#SLE-8314).
- sfc: support encapsulation of xdp_frames in efx_tx_buffer
  (jsc#SLE-8314).
- mlxsw: Fix 64-bit division in mlxsw_sp_sb_prs_init
  (bsc#1154488).
- net: hns3: cleanup byte order issues when printed (bsc#1154353).
- net: hns3: cleanup some print format warning (bsc#1154353).
- net: hns3: add or modify some comments (bsc#1154353).
- net: hns3: optimize local variable initialization (bsc#1154353).
- net: hns3: cleanup a format-truncation warning (bsc#1154353).
- net: hns3: cleanup some coding style issues (bsc#1154353).
- net: hns3: cleanup some magic numbers (bsc#1154353).
- net: hns3: add struct netdev_queue debug info for TX timeout
  (bsc#1154353).
- net: hns3: dump some debug information when reset fail
  (bsc#1154353).
- bnxt_en: Add support to collect crash dump via ethtool
  (jsc#SLE-8372 bsc#1153275).
- bnxt_en: Add support to invoke OP-TEE API to reset firmware
  (jsc#SLE-8372 bsc#1153275).
- mlxsw: spectrum: Generalize split count check (bsc#1154488).
- mlxsw: spectrum: Iterate over all ports in gap during unsplit
  create (bsc#1154488).
- mlxsw: spectrum: Fix base port get for split count 4 and 8
  (bsc#1154488).
- mlxsw: spectrum: Use port_module_max_width to compute base
  port index (bsc#1154488).
- mlxsw: spectrum: Remember split base local port and use it in
  unsplit (bsc#1154488).
- mlxsw: spectrum: Introduce resource for getting offset of 4
  lanes split port (bsc#1154488).
- mlxsw: spectrum: Push getting offsets of split ports into a
  helper (bsc#1154488).
- mlxsw: spectrum: Add sanity checks into module info get
  (bsc#1154488).
- mlxsw: spectrum: Pass mapping values in port mapping structure
  (bsc#1154488).
- mlxsw: spectrum: Use mapping of port being split for creating
  split ports (bsc#1154488).
- mlxsw: spectrum: Replace port_to_module array with array of
  structs (bsc#1154488).
- mlxsw: spectrum: Distinguish between unsplittable and split port
  (bsc#1154488).
- mlxsw: spectrum: Move max_width check up before count check
  (bsc#1154488).
- mlxsw: spectrum: Use PMTM register to get max module width
  (bsc#1154488).
- mlxsw: reg: Add Port Module Type Mapping Register (bsc#1154488).
- mlxsw: reg: Extend PMLP tx/rx lane value size to 4 bits
  (bsc#1154488).
- cxgb4/l2t: Simplify 't4_l2e_free()' and '_t4_l2e_free()'
  (jsc#SLE-8389).
- net: sched: update action implementations to support flags
  (bsc#1154353).
- net: sched: extend TCA_ACT space with TCA_ACT_FLAGS
  (bsc#1154353).
- net: sched: modify stats helper functions to support regular
  stats (bsc#1154353).
- net: sched: don't expose action qstats to skb_tc_reinsert()
  (bsc#1154353).
- net: sched: extract qstats update code into functions
  (bsc#1154353).
- net: sched: extract bstats update code into function
  (bsc#1154353).
- net: sched: extract common action counters update code into
  function (bsc#1154353).
- e1000e: Fix compiler warning when CONFIG_PM_SLEEP is not set
  (jsc#SLE-8100).
- e1000e: Add support for Tiger Lake (jsc#SLE-8100).
- i40e: Add UDP segmentation offload support (jsc#SLE-8025).
- ixgbe: Add UDP segmentation offload support (jsc#SLE-7979
  jsc#SLE-7981).
- igb: Add UDP segmentation offload support (jsc#SLE-7967
  jsc#SLE-8010).
- e1000e: Drop unnecessary __E1000_DOWN bit twiddling
  (jsc#SLE-8100).
- e1000e: Use rtnl_lock to prevent race conditions between net
  and pci/pm (jsc#SLE-8100).
- e1000e: Add support for Comet Lake (jsc#SLE-8100).
- vxlan: drop "vxlan" parameter in vxlan_fdb_alloc()
  (bsc#1154353).
- net: phy: marvell: add downshift support for 88E1145
  (bsc#1154353).
- bonding: balance ICMP echoes in layer3+4 mode (bsc#1154353).
- flow_dissector: extract more ICMP information (bsc#1154353).
- flow_dissector: skip the ICMP dissector for non ICMP packets
  (bsc#1154353).
- flow_dissector: add meaningful comments (bsc#1154353).
- mlxsw: Enforce firmware version for Spectrum-2 (bsc#1154488).
- mlxsw: Bump firmware version to 13.2000.2308 (bsc#1154488).
- mlxsw: pci: Increase PCI reset timeout for SN3800 systems
  (bsc#1154488).
- mlxsw: reg: Increase size of MPAR register (bsc#1154488).
- net: bridge: fdb: set flags directly in fdb_create
  (bsc#1154353).
- net: bridge: fdb: convert offloaded to use bitops (bsc#1154353).
- net: bridge: fdb: convert added_by_external_learn to use bitops
  (bsc#1154353).
- net: bridge: fdb: convert added_by_user to bitops (bsc#1154353).
- net: bridge: fdb: convert is_sticky to bitops (bsc#1154353).
- net: bridge: fdb: convert is_static to bitops (bsc#1154353).
- net: bridge: fdb: convert is_local to bitops (bsc#1154353).
- inet: do not call sublist_rcv on empty list (bsc#1154353).
- broadcom: bnxt: Fix use true/false for bool (bsc#1154353).
- cavium: thunder: Fix use true/false for bool type (bsc#1154353).
- net: phy: marvell: add PHY tunable support for more PHY versions
  (bsc#1154353).
- net: phy: marvell: add downshift support for M88E1111
  (bsc#1154353).
- net: phy: marvell: fix downshift function naming (bsc#1154353).
- net: phy: marvell: fix typo in constant
  MII_M1011_PHY_SRC_DOWNSHIFT_MASK (bsc#1154353).
- i40e: prevent memory leak in i40e_setup_macvlans (jsc#SLE-8025).
- i40e: Refactoring VF MAC filters counting to make more reliable
  (jsc#SLE-8025).
- i40e: Fix LED blinking flow for X710T*L devices (jsc#SLE-8025).
- i40e: allow ethtool to report SW and FW versions in recovery
  mode (jsc#SLE-8025).
- i40e: initialize ITRN registers with correct values
  (jsc#SLE-8025).
- i40e: Extend PHY access with page change flag (jsc#SLE-8025).
- i40e: Extract detection of HW flags into a function
  (jsc#SLE-8025).
- i40e: Wrong 'Advertised FEC modes' after set FEC to AUTO
  (jsc#SLE-8025).
- i40e: Fix for persistent lldp support (jsc#SLE-8025).
- sock: remove unneeded semicolon (bsc#1154353).
- mlxsw: spectrum_buffers: remove unneeded semicolon
  (bsc#1154488).
- mvpp2: prefetch frame header (bsc#1154353).
- mvpp2: sync only the received frame (bsc#1154353).
- mvpp2: refactor frame drop routine (bsc#1154353).
- net: Fix various misspellings of "connect" (bsc#1154353).
- net: Fix misspellings of "configure" and "configuration"
  (bsc#1154353).
- bpf: Prepare btf_ctx_access for non raw_tp use case
  (bsc#1154353).
- bpf: Allow __sk_buff tstamp in BPF_PROG_TEST_RUN (bsc#1154353).
- ipvs: batch __ip_vs_dev_cleanup (bsc#1154353).
- ipvs: batch __ip_vs_cleanup (bsc#1154353).
- ipvs: no need to update skb route entry for local destination
  packets (bsc#1154353).
- tcp: add TCP_INFO status for failed client TFO (bsc#1154353).
- mlxsw: spectrum_buffers: Calculate the size of the main pool
  (bsc#1154488).
- mlxsw: spectrum: Use guaranteed buffer size as pool size limit
  (bsc#1154488).
- net: phy: add support for clause 37 auto-negotiation
  (bsc#1154353).
- net: phy: modify assignment to OR for dev_flags in
  phy_attach_direct (bsc#1154353).
- fq_codel: do not include <linux/jhash.h> (bsc#1154353).
- mlxsw: core: Extend QSFP EEPROM size for ethtool (bsc#1154488).
- mlxsw: reg: Add macro for getting QSFP module EEPROM page number
  (bsc#1154488).
- igc: Clean up unused shadow_vfta pointer (jsc#SLE-7966).
- igc: Add Rx checksum support (jsc#SLE-7966).
- igc: Add set_rx_mode support (jsc#SLE-7966).
- e1000e: Add support for S0ix (jsc#SLE-8100).
- igc: Add SCTP CRC checksumming functionality (jsc#SLE-7966).
- net/sched: act_police: re-use tcf_tm_dump() (bsc#1154353).
- net: phy: marvell: remove superseded function
  marvell_set_downshift (bsc#1154353).
- net: phy: marvell: support downshift as PHY tunable
  (bsc#1154353).
- net: hns3: log and clear hardware error after reset complete
  (bsc#1154353).
- net: hns3: do not allocate linear data for fraglist skb
  (bsc#1154353).
- net: hns3: minor cleanup for hns3_handle_rx_bd() (bsc#1154353).
- net: hns3: make struct hns3_enet_ring cacheline aligned
  (bsc#1154353).
- net: hns3: introduce ring_to_netdev() in enet module
  (bsc#1154353).
- net: hns3: minor optimization for barrier in IO path
  (bsc#1154353).
- net: hns3: optimized MAC address in management table
  (bsc#1154353).
- net: hns3: remove struct hns3_nic_ring_data in hns3_enet module
  (bsc#1154353).
- mlxsw: spectrum: Register switched port analyzers (SPAN)
  as resource (bsc#1154488).
- net: phy: avoid NPE if read_page/write_page callbacks are not
  available (bsc#1154353).
- net: sched: Avoid using yield() in a busy waiting loop
  (bsc#1154353).
- pktgen: remove unnecessary assignment in pktgen_xmit()
  (bsc#1154353).
- net: sfp: move fwnode parsing into sfp-bus layer (bsc#1154353).
- net: phylink: use more linkmode_* (bsc#1154353).
- net_sched: sch_fq: remove one obsolete check in fq_dequeue()
  (bsc#1154353).
- net: core: use listified Rx for GRO_NORMAL in napi_gro_receive()
  (bsc#1154353).
- mlxsw: spectrum: Add support for 400Gbps (50Gbps per lane)
  link modes (bsc#1154488).
- ethtool: Add support for 400Gbps (50Gbps per lane) link modes
  (bsc#1154353).
- xdp: Trivial, fix spelling in function description
  (bsc#1154353).
- bpf: Fix cast to pointer from integer of different size warning
  (bsc#1154353).
- flow_dissector: Allow updating the flow dissector program
  atomically (bsc#1154353).
- bpf: Align struct bpf_prog_stats (bsc#1154353).
- bpf/flow_dissector: add mode to enforce global BPF flow
  dissector (bsc#1154353).
- genetlink: do not parse attributes for families with zero
  maxattr (bsc#1154353).
- tcp: improve recv_skip_hint for tcp_zerocopy_receive
  (bsc#1154353).
- netdevsim: implement couple of testing devlink health reporters
  (bsc#1154353).
- devlink: propagate extack down to health reporter ops
  (bsc#1154353).
- devlink: don't do reporter recovery if the state is healthy
  (bsc#1154353).
- sock_get_timeout: drop unnecessary return variable
  (bsc#1154353).
- af_unix: __unix_find_socket_byname() cleanup (bsc#1154353).
- ipvlan: consolidate TSO flags using NETIF_F_ALL_TSO
  (bsc#1154353).
- team: call RCU read lock when walking the port_list
  (bsc#1154353).
- Revert "tun: call dev_get_valid_name() before
  register_netdevice()" (bsc#1154353).
- net: tipc: prepare attrs in __tipc_nl_compat_dumpit()
  (bsc#1154353).
- net: genetlink: always allocate separate attrs for dumpit ops
  (bsc#1154353).
- net: hns3: support tx-scatter-gather-fraglist feature
  (bsc#1154353).
- net: hns3: add support for configuring VF MAC from the host
  (bsc#1154353).
- net: hns3: add support for configuring bandwidth of VF on the
  host (bsc#1154353).
- net: hns3: add support for setting VF trust (bsc#1154353).
- net: hns3: add support for spoof check setting (bsc#1154353).
- net: hns3: add support for setting VF link status on the host
  (bsc#1154353).
- tun: fix memory leak in error path (bsc#1154353).
- netdevsim: fix spelling mistake "forbidded" -> "forbid"
  (bsc#1154353).
- nfp: bpf: make array exp_mask static, makes object smaller
  (bsc#1154353).
- net: hns3: make array tick_array static, makes object smaller
  (bsc#1154353).
- net: hns: make arrays static, makes object smaller
  (bsc#1154353).
- net/tls: store decrypted on a single bit (bsc#1154353).
- net/tls: store async_capable on a single bit (bsc#1154353).
- net/tls: pass context to tls_device_decrypted() (bsc#1154353).
- net/tls: make allocation failure unlikely (bsc#1154353).
- net/tls: mark sk->err being set as unlikely (bsc#1154353).
- net: core: use helper skb_ensure_writable in more places
  (bsc#1154353).
- ipv6: Make ipv6_mc_may_pull() return bool (bsc#1154353).
- net: core: change return type of pskb_may_pull to bool
  (bsc#1154353).
- net: ena: ethtool: support set_channels callback (bsc#1154492).
- net: ena: remove redundant print of number of queues
  (bsc#1154492).
- net: ena: make ethtool -l show correct max number of queues
  (bsc#1154492).
- net: ena: ethtool: get_channels: use combined only
  (bsc#1154492).
- net: ena: multiple queue creation related cleanups
  (bsc#1154492).
- net: ena: change num_queues to num_io_queues for clarity and
  consistency (bsc#1154492).
- netdevsim: implement devlink dev_info op (bsc#1154353).
- net: devlink: fix reporter dump dumpit (bsc#1154353).
- mlxsw: minimal: Add validation for FW version (bsc#1154488).
- mlxsw: core: Push minor/subminor fw version check into helper
  (bsc#1154488).
- mlxsw: thermal: Provide optimization for QSFP modules number
  detection (bsc#1154488).
- mlxsw: hwmon: Provide optimization for QSFP modules number
  detection (bsc#1154488).
- mlxsw: reg: Extend MGPIR register with new field exposing the
  number of QSFP modules (bsc#1154488).
- netdevsim: add couple of debugfs bools to debug devlink reload
  (bsc#1154353).
- devlink: have genetlink code to parse the attrs during dumpit
  (bsc#1154353).
- net: tipc: allocate attrs locally instead of using
  genl_family_attrbuf in compat_dumpit() (bsc#1154353).
- net: tipc: have genetlink code to parse the attrs during dumpit
  (bsc#1154353).
- net: nfc: have genetlink code to parse the attrs during dumpit
  (bsc#1154353).
- net: ieee802154: have genetlink code to parse the attrs during
  dumpit (bsc#1154353).
- net: genetlink: parse attrs and store in contect info struct
  during dumpit (bsc#1154353).
- net: genetlink: push attrbuf allocation and parsing to a
  separate function (bsc#1154353).
- net: genetlink: introduce dump info struct to be available
  during dumpit op (bsc#1154353).
- net: genetlink: push doit/dumpit code from genl_family_rcv_msg
  (bsc#1154353).
- netdevsim: create devlink and netdev instances in namespace
  (bsc#1154353).
- net: devlink: export devlink net setter (bsc#1154353).
- net/tls: add TlsDeviceRxResync statistic (bsc#1154353).
- net/tls: add TlsDecryptError stat (bsc#1154353).
- net/tls: add statistics for installed sessions (bsc#1154353).
- net/tls: add skeleton of MIB statistics (bsc#1154353).
- net/tls: add device decrypted trace point (bsc#1154353).
- net/tls: add tracing for device/offload events (bsc#1154353).
- net: devlink: don't ignore errors during dumpit (bsc#1154353).
- igmp: uninline ip_mc_validate_checksum() (bsc#1154353).
- net: spread "enum sock_flags" (bsc#1154353).
- net/tls: rename tls_hw_* functions tls_toe_* (bsc#1154353).
- net/tls: move TOE-related code to a separate file (bsc#1154353).
- net/tls: move tls_build_proto() on init path (bsc#1154353).
- net/tls: rename tls_device to tls_toe_device (bsc#1154353).
- net/tls: move TOE-related structures to a separate header
  (bsc#1154353).
- net: devlink: allow to change namespaces during reload
  (bsc#1154353).
- netdevsim: take devlink net instead of init_net (bsc#1154353).
- netdevsim: register port netdevices into net of device
  (bsc#1154353).
- netdevsim: implement proper devlink reload (bsc#1154353).
- netdevsim: add all ports in nsim_dev_create() and del them in
  destroy() (bsc#1154353).
- mlxsw: Propagate extack down to register_fib_notifier()
  (bsc#1154488).
- mlxsw: Register port netdevices into net of core (bsc#1154488).
- mlxsw: spectrum: Take devlink net instead of init_net
  (bsc#1154488).
- net: devlink: export devlink net getter (bsc#1154353).
- net: fib_notifier: propagate extack down to the notifier block
  callback (bsc#1154353).
- mlxsw: spectrum_router: Don't rely on missing extack to
  symbolize dump (bsc#1154488).
- net: fib_notifier: propagate possible error during fib notifier
  registration (bsc#1154353).
- net: fib_notifier: make FIB notifier per-netns (bsc#1154353).
- netdevsim: change fib accounting and limitations to be
  per-device (bsc#1154353).
- net: propagate errors correctly in register_netdevice()
  (bsc#1154353).
- mvpp2: remove misleading comment (bsc#1154353).
- net_sched: remove need_resched() from qdisc_run() (bsc#1154353).
- net: introduce per-netns netdevice notifiers (bsc#1154353).
- net: push loops and nb calls into helper functions
  (bsc#1154353).
- ipv6: minor code reorg in inet6_fill_ifla6_attrs()
  (bsc#1154353).
- net: rtnetlink: add possibility to use alternative names as
  message handle (bsc#1154353).
- net: rtnetlink: introduce helper to get net_device instance
  by ifname (bsc#1154353).
- net: rtnetlink: unify the code in __rtnl_newlink get dev with
  the rest (bsc#1154353).
- net: rtnetlink: put alternative names to getlink message
  (bsc#1154353).
- net: rtnetlink: add linkprop commands to add and delete
  alternative ifnames (bsc#1154353).
- net: introduce name_node struct to be used in hashlist
  (bsc#1154353).
- net: procfs: use index hashlist instead of name hashlist
  (bsc#1154353).
- tcp: add ipv6_addr_v4mapped_loopback() helper (bsc#1154353).
- net: core: dev: replace state xoff flag comparison by
  netif_xmit_stopped method (bsc#1154353).
- ipv6: add priority parameter to ip6_xmit() (bsc#1154353).
- rocker: add missing init_net check in FIB notifier
  (bsc#1154353).
- commit 113b872
* Wed Dec 11 2019 tiwai@suse.de
- spi: pxa2xx: Add support for Intel Comet Lake-H (jsc#SLE-7946).
- mtd: spi-nor: intel-spi: Add support for Intel Comet Lake-H
  SPI serial flash (jsc#SLE-7946).
- commit 66b146b
* Wed Dec 11 2019 tiwai@suse.de
- mfd: intel-lpss: Add Intel Comet Lake PCH-H PCI IDs
  (jsc#SLE-7946).
- mfd: intel-lpss: Add default I2C device properties for Gemini
  Lake (jsc#SLE-7946).
- commit a741dd5
* Wed Dec 11 2019 tiwai@suse.de
- i2c: i801: Correct Intel Jasper Lake SOC naming (jsc#SLE-7946).
- i2c: i801: Add support for Intel Comet Lake PCH-H
  (jsc#SLE-7946).
- commit b378292
* Wed Dec 11 2019 tiwai@suse.de
- i2c: i801: Add support for Intel Jasper Lake (jsc#SLE-7946).
- commit a0fd0de
* Wed Dec 11 2019 tiwai@suse.de
- i2c: i801: Bring back Block Process Call support for certain
  platforms (jsc#SLE-7946).
- i2c: i801: Use iTCO version 6 in Cannon Lake PCH and beyond
  (jsc#SLE-7946).
- commit 7cc4af0
* Wed Dec 11 2019 jroedel@suse.de
- KVM: vmx: use MSR_IA32_TSX_CTRL to hard-disable TSX on guest
  that lack it (CVE-2019-19338 bsc#1158954).
- KVM: vmx: implement MSR_IA32_TSX_CTRL disable RTM functionality
  (CVE-2019-19338 bsc#1158954).
- KVM: x86: fix presentation of TSX feature in ARCH_CAPABILITIES
  (CVE-2019-19338 bsc#1158954).
- commit 431ce6a
* Wed Dec 11 2019 jroedel@suse.de
- KVM: x86: fix out-of-bounds write in KVM_GET_EMULATED_CPUID
  (CVE-2019-19332) (CVE-2019-19332 bsc#1158827).
- commit ed2bb4d
* Wed Dec 11 2019 tonyj@suse.de
- libbpf: Fix sym->st_value print on 32-bit arches (bsc#1158962).
- commit ff62fd7
* Tue Dec 10 2019 bp@suse.de
- EDAC/altera: Use fast register IO for S10 IRQs (bsc#1152489).
- commit 48045b4
* Tue Dec 10 2019 dwagner@suse.de
- scsi: qla2xxx: Add debug dump of LOGO payload and ELS IOCB
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Ignore PORT UPDATE after N2N PLOGI (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Don't defer relogin unconditonally (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Send Notify ACK after N2N PLOGI (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Configure local loop for N2N target (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix PLOGI payload and ELS IOCB dump length
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Don't call qlt_async_event twice (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Allow PLOGI in target mode (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Change discovery state before PLOGI (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Drop superfluous INIT_WORK of del_work
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Initialize free_work before flushing it
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use explicit LOGO in target mode (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Ignore NULL pointer in tcm_qla2xxx_free_mcmd
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix incorrect SFUB length used for Secure Flash
  Update MB Cmd (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Added support for MPI and PEP regions for ISP28XX
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Correctly retrieve and interpret active flash
  region (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- commit b9f4605
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Remove logical HW ID'
- commit c366de4
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix g4x sprite scaling stride check with GTT remapping'
- commit ed52fa1
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/dp: Fix dsc bpp calculations, v5.'
- commit 4e094fc
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Mark contents as dirty on a write fault'
- commit f55151a
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Bump skl+ max plane width to 5k for linear/x-tiled'
- commit 69b4952
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Don't mix srcu tag and negative error codes'
- commit 6d16d9a
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Restore relaxed padding (OCL_OOB_SUPPRES_ENABLE) for skl+'
- commit cd7484b
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Limit MST to <= 8bpc once again'
- commit ead6b3f
* Tue Dec 10 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/dp: Fix DSC enable code to use cpu_transcoder instead of encoder->type'
- commit d2a961c
* Tue Dec 10 2019 tiwai@suse.de
- Update patch reference for nfc fix (CVE-2019-19526 bsc#1158893)
- commit 9e59e81
* Tue Dec 10 2019 tzimmermann@suse.de
- drm/i915: Preload LUTs if the hw isn't currently using them (bsc#1152489)
- commit 7d0ea8f
* Tue Dec 10 2019 tzimmermann@suse.de
- video/hdmi: Fix AVI bar unpack (bsc#1152489)
- commit 0ac3f29
* Tue Dec 10 2019 tzimmermann@suse.de
- fbdev/sa1100fb: Remove even more dead code (bsc#1152489)
- commit 896a116
* Tue Dec 10 2019 mkubecek@suse.cz
- update mainline references
  update Patch-mainline tags:
  patches.suse/hugetlb-region_chg-provides-only-cache-entry.patch
  patches.suse/hugetlb-remove-duplicated-code.patch
  patches.suse/hugetlbfs-hugetlb_fault_mutex_hash-cleanup.patch
  patches.suse/hugetlbfs-take-read_lock-on-i_mmap-for-PMD-sharing.patch
  patches.suse/include-linux-memcontrol.h-fix-comments-based-on-per-node-memcg.patch
  patches.suse/mm-clean-up-and-clarify-lruvec-lookup-procedure.patch
  patches.suse/mm-drop-mmap_sem-before-calling-balance_dirty_pages-in-write-fault.patch
  patches.suse/mm-emit-tracepoint-when-RSS-changes.patch
  patches.suse/mm-filemap.c-remove-redundant-cache-invalidation-after-async-direct-io-write.patch
  patches.suse/mm-filemap.c-warn-if-stale-pagecache-is-left-after-direct-write.patch
  patches.suse/mm-hugetlb-avoid-looping-to-the-same-hugepage-if-pages-and-vmas.patch
  patches.suse/mm-introduce-compound_nr.patch
  patches.suse/mm-introduce-page_shift.patch
  patches.suse/mm-introduce-page_size.patch
  patches.suse/mm-madvise.c-replace-with-page_size-in-madvise_inject_error.patch
  patches.suse/mm-memcg-clean-up-reclaim-iter-array.patch
  patches.suse/mm-memcg-make-memory.emin-the-baseline-for-utilisation-determination.patch
  patches.suse/mm-memcg-make-scan-aggression-always-exclude-protection.patch
  patches.suse/mm-memcg-proportional-memory.-low-min-reclaim.patch
  patches.suse/mm-memcontrol-remove-dead-code-from-memory_max_write.patch
  patches.suse/mm-memfd-fix-COW-issue-on-MAP_PRIVATE-and-F_SEAL_FUTURE_WRITE-mappings.patch
  patches.suse/mm-memory-failure.c-clean-up-around-tk-pre-allocation.patch
  patches.suse/mm-migrate.c-handle-freed-page-at-the-first-place.patch
  patches.suse/mm-mmap.c-__vma_unlink_prev-is-not-necessary-now.patch
  patches.suse/mm-mmap.c-extract-__vma_unlink_list-as-counterpart-for-__vma_link_list.patch
  patches.suse/mm-mmap.c-prev-could-be-retrieved-from-vma-vm_prev.patch
  patches.suse/mm-mmap.c-rb_parent-is-not-necessary-in-__vma_link_list.patch
  patches.suse/mm-mmap.c-remove-a-never-triggered-warning-in-__vma_adjust.patch
  patches.suse/mm-mmap.c-use-IS_ERR_VALUE-to-check-return-value-of-get_unmapped_area.patch
  patches.suse/mm-page_io.c-annotate-refault-stalls-from-swap_readpage.patch
  patches.suse/mm-rmap.c-don-t-reuse-anon_vma-if-we-just-want-a-copy.patch
  patches.suse/mm-rmap.c-fix-outdated-comment-in-page_get_anon_vma.patch
  patches.suse/mm-rmap.c-reuse-mergeable-anon_vma-as-parent-when-fork.patch
  patches.suse/mm-rmap.c-use-VM_BUG_ON_PAGE-in-__page_check_anon_rmap.patch
  patches.suse/mm-shmem-use-proper-gfp-flags-for-shmem_writepage.patch
  patches.suse/mm-slab-make-kmalloc_info-contain-all-types-of-names.patch
  patches.suse/mm-slab-remove-unused-kmalloc_size.patch
  patches.suse/mm-slab_common-use-enum-kmalloc_cache_type-to-iterate-over-kmalloc-caches.patch
  patches.suse/mm-slub-print-the-offset-of-fault-addresses.patch
  patches.suse/mm-slub.c-clean-up-validate_slab.patch
  patches.suse/mm-slub.c-update-comments.patch
  patches.suse/mm-soft-offline-convert-parameter-to-pfn.patch
  patches.suse/mm-swap.c-piggyback-lru_add_drain_all-calls.patch
  patches.suse/mm-swap.c-trivial-mark_page_accessed-cleanup.patch
  patches.suse/mm-thp-do-not-queue-fully-unmapped-pages-for-deferred-split.patch
  patches.suse/mm-vmalloc-add-more-comments-to-the-adjust_va_to_fit_type.patch
  patches.suse/mm-vmalloc-do-not-keep-unpurged-areas-in-the-busy-tree.patch
  patches.suse/mm-vmalloc-modify-struct-vmap_area-to-reduce-its-size.patch
  patches.suse/mm-vmalloc-remove-preempt_disable-enable-when-doing-preloading.patch
  patches.suse/mm-vmalloc-respect-passed-gfp_mask-when-doing-preloading.patch
  patches.suse/mm-vmalloc-rework-vmap_area_lock.patch
  patches.suse/mm-vmalloc.c-move-area-pages-after-if-statement.patch
  patches.suse/mm-vmalloc.c-remove-unnecessary-highmem_mask-from-parameter-of-gfpflags_allow_blocking.patch
  patches.suse/mm-vmscan-detect-file-thrashing-at-the-reclaim-root.patch
  patches.suse/mm-vmscan-enforce-inactive-active-ratio-at-the-reclaim-root.patch
  patches.suse/mm-vmscan-harmonize-writeback-congestion-tracking-for-nodes-memcgs.patch
  patches.suse/mm-vmscan-memcontrol-remove-mem_cgroup_select_victim_node.patch
  patches.suse/mm-vmscan-move-file-exhaustion-detection-to-the-node-level.patch
  patches.suse/mm-vmscan-move-inactive_list_is_low-swap-check-to-the-caller.patch
  patches.suse/mm-vmscan-naming-fixes-global_reclaim-and-sane_reclaim.patch
  patches.suse/mm-vmscan-remove-unused-lru_pages-argument.patch
  patches.suse/mm-vmscan-replace-shrink_node-loop-with-a-retry-jump.patch
  patches.suse/mm-vmscan-simplify-lruvec_lru_size.patch
  patches.suse/mm-vmscan-split-shrink_node-into-node-part-and-memcgs-part.patch
  patches.suse/mm-vmscan-turn-shrink_node_memcg-into-shrink_lruvec.patch
  patches.suse/mm-vmscan.c-fix-typo-in-comment.patch
  patches.suse/mm-vmscan.c-remove-unused-scan_control-parameter-from-pageout.patch
  patches.suse/rss_stat-add-support-to-detect-RSS-updates-of-external-mm.patch
  patches.suse/shmem-pin-the-file-in-shmem_fault-if-mmap_sem-is-dropped.patch
  patches.suse/vmalloc-lift-the-arm-flag-for-coherent-mappings-to-common-code.patch
- commit fdd2a26
* Mon Dec  9 2019 bp@suse.de
- EDAC/ghes: Do not warn when incrementing refcount on 0
  (bsc#1152489).
- commit b152db6
* Mon Dec  9 2019 tiwai@suse.de
- Update patch reference for a media driver fix (CVE-2019-19533 bsc#1158834)
- commit 035b8ec
* Mon Dec  9 2019 tiwai@suse.de
- Update patch references for USB and HID fixes (CVE-2019-19532 bsc#1158824 CVE-2019-19523)
- commit b7c3995
* Mon Dec  9 2019 mbenes@suse.cz
- xprtrdma: Add unique trace points for posting Local Invalidate
  WRs (bsc#1158811).
- commit 0045bd6
* Mon Dec  9 2019 lhenriques@suse.com
- rbd: silence bogus uninitialized warning in
  rbd_object_map_update_finish() (jsc#SES-1134).
- ceph: increment/decrement dio counter on async requests
  (jsc#SES-1134).
- ceph: take the inode lock before acquiring cap refs
  (jsc#SES-1134).
- rbd: cancel lock_dwork if the wait is interrupted
  (jsc#SES-1134).
- ceph: call ceph_mdsc_destroy from destroy_fs_client
  (jsc#SES-1134).
- libceph: use ceph_kvmalloc() for osdmap arrays (jsc#SES-1134).
- libceph: avoid a __vmalloc() deadlock in ceph_kvmalloc()
  (jsc#SES-1134).
- commit 6eea6f4
* Mon Dec  9 2019 lhenriques@suse.com
- ceph: allow object copies across different filesystems in the
  same cluster (jsc#SES-1134).
- Refresh
  patches.suse/ceph-don-t-allow-copy_file_range-when-stripe_count-1.patch.
- commit 8a618ea
* Mon Dec  9 2019 lhenriques@suse.com
- ceph: include ceph_debug.h in cache.c (jsc#SES-1134).
- ceph: move static keyword to the front of declarations
  (jsc#SES-1134).
- rbd: pull rbd_img_request_create() dout out into the callers
  (jsc#SES-1134).
- libceph: drop unused con parameter of calc_target()
  (jsc#SES-1134).
- ceph: use release_pages() directly (jsc#SES-1134).
- rbd: fix response length parameter for encoded strings
  (jsc#SES-1134).
- ceph: allow arbitrary security.* xattrs (jsc#SES-1134).
- ceph: only set CEPH_I_SEC_INITED if we got a MAC label
  (jsc#SES-1134).
- ceph: turn ceph_security_invalidate_secctx into static inline
  (jsc#SES-1134).
- ceph: add buffered/direct exclusionary locking for reads and
  writes (jsc#SES-1134).
- libceph: handle OSD op ceph_pagelist_append() errors
  (jsc#SES-1134).
- ceph: don't return a value from void function (jsc#SES-1134).
- ceph: don't freeze during write page faults (jsc#SES-1134).
- ceph: update the mtime when truncating up (jsc#SES-1134).
- ceph: fix indentation in __get_snap_name() (jsc#SES-1134).
- ceph: remove incorrect comment above __send_cap (jsc#SES-1134).
- ceph: remove CEPH_I_NOFLUSH (jsc#SES-1134).
- ceph: remove unneeded test in try_flush_caps (jsc#SES-1134).
- ceph: have __mark_caps_flushing return flush_tid (jsc#SES-1134).
- ceph: fix comments over ceph_add_cap (jsc#SES-1134).
- ceph: eliminate session->s_trim_caps (jsc#SES-1134).
- ceph: remove ceph_get_cap_mds and __ceph_get_cap_mds
  (jsc#SES-1134).
- ceph: don't SetPageError on writepage errors (jsc#SES-1134).
- commit 3a5a01d
* Mon Dec  9 2019 lhenriques@suse.com
- ceph: auto reconnect after blacklisted (jsc#SES-1134).
- Refresh
  patches.suse/ceph-return-EINVAL-if-given-fsc-mount-option-on-kern.patch.
- commit a6819c7
* Mon Dec  9 2019 lhenriques@suse.com
- ceph: invalidate all write mode filp after reconnect
  (jsc#SES-1134).
- ceph: return -EIO if read/write against filp that lost file
  locks (jsc#SES-1134).
- ceph: add helper function that forcibly reconnects to ceph
  cluster (jsc#SES-1134).
- ceph: pass filp to ceph_get_caps() (jsc#SES-1134).
- ceph: track and report error of async metadata operation
  (jsc#SES-1134).
- ceph: allow closing session in restarting/reconnect state
  (jsc#SES-1134).
- libceph: add function that clears osd client's abort_err
  (jsc#SES-1134).
- libceph: add function that reset client's entity addr
  (jsc#SES-1134).
- ceph: don't list vxattrs in listxattr() (jsc#SES-1134).
- ceph: allow copy_file_range when src and dst inode are same
  (jsc#SES-1134).
- commit d6afa0a
* Mon Dec  9 2019 bp@suse.de
- EDAC/ghes: Fix locking and memory barrier issues (bsc#1152489).
- commit 7d2325a
* Mon Dec  9 2019 lhenriques@suse.com
- kabi/severities: whitelist libceph, rbd, and ceph (jsc#SES-1134).
- commit 1f1a9d5
* Mon Dec  9 2019 jeyu@suse.de
- kernel/module.c: wakeup processes in module_wq on module unload (git-fixes).
- commit 311cb05
* Mon Dec  9 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Preload LUTs if the hw isn't currently using them'
- commit 7964f08
* Sun Dec  8 2019 tiwai@suse.de
- ALSA: pcm: oss: Avoid potential buffer overflows (git-fixes).
- ALSA: hda: hdmi - Keep old slot assignment behavior for Intel
  platforms (git-fixes).
- ALSA: hda: Modify stream stripe mask only when needed
  (git-fixes).
- ALSA: hda - fixup for the bass speaker on Lenovo Carbon X1
  7th gen (git-fixes).
- ALSA: hda: hdmi - preserve non-MST PCM routing for Intel
  platforms (git-fixes).
- ALSA: hda: hdmi - fix kernel oops caused by invalid PCM idx
  (git-fixes).
- ALSA: hda/realtek - Fix inverted bass GPIO pin on Acer 8951G
  (git-fixes).
- ALSA: hda/realtek - Dell headphone has noise on unmute for
  ALC236 (git-fixes).
- ALSA: hda: hdmi - fix regression in connect list handling
  (git-fixes).
- ALSA: hda/hdmi - enable automatic runtime pm for AMD HDMI
  codecs by default (git-fixes).
- ALSA: hda/hdmi - enable runtime pm for newer AMD display audio
  (git-fixes).
- ALSA: hda/hdmi - Add new pci ids for AMD GPU display audio
  (git-fixes).
- ALSA: hda/hdmi - fix vgaswitcheroo detection for AMD
  (git-fixes).
- commit 4b98432
* Fri Dec  6 2019 jslaby@suse.cz
- Linux 5.3.15 (bnc#1151927 5.3.15).
- openvswitch: remove another BUG_ON() (bnc#1151927 5.3.15).
- openvswitch: drop unneeded BUG_ON() in ovs_flow_cmd_build_info()
  (bnc#1151927 5.3.15).
- net: sched: fix `tc -s class show` no bstats on class with
  nolock subqueues (bnc#1151927 5.3.15).
- selftests: pmtu: use -oneline for ip route list cache
  (bnc#1151927 5.3.15).
- net: macb: add missed tasklet_kill (bnc#1151927 5.3.15).
- selftests: bpf: correct perror strings (bnc#1151927 5.3.15).
- selftests: bpf: test_sockmap: handle file creation failures
  gracefully (bnc#1151927 5.3.15).
- net/tls: use sg_next() to walk sg entries (bnc#1151927 5.3.15).
- net/tls: remove the dead inplace_crypto code (bnc#1151927
  5.3.15).
- selftests/tls: add a test for fragmented messages (bnc#1151927
  5.3.15).
- net: skmsg: fix TLS 1.3 crash with full sk_msg (bnc#1151927
  5.3.15).
- net/tls: free the record on encryption error (bnc#1151927
  5.3.15).
- net/tls: take into account that bpf_exec_tx_verdict() may free
  the record (bnc#1151927 5.3.15).
- x86/fpu: Don't cache access to fpu_fpregs_owner_ctx (bnc#1151927
  5.3.15).
- platform/x86: hp-wmi: Fix ACPI errors caused by passing 0 as
  input size (bnc#1151927 5.3.15).
- platform/x86: hp-wmi: Fix ACPI errors caused by too small buffer
  (bnc#1151927 5.3.15).
- HID: core: check whether Usage Page item is after Usage ID items
  (bnc#1151927 5.3.15).
- ext4: add more paranoia checking in ext4_expand_extra_isize
  handling (bnc#1151927 5.3.15).
- net: disallow ancillary data for __sys_{send,recv}msg_file()
  (bnc#1151927 5.3.15).
- net: separate out the msghdr copy from ___sys_{send,recv}msg()
  (bnc#1151927 5.3.15).
- io_uring: async workers should inherit the user creds
  (bnc#1151927 5.3.15).
- gve: Fix the queue page list allocated pages count (bnc#1151927
  5.3.15).
- openvswitch: fix flow command message size (bnc#1151927 5.3.15).
- net: psample: fix skb_over_panic (bnc#1151927 5.3.15).
- tipc: fix link name length check (bnc#1151927 5.3.15).
- staging: rtl8723bs: Drop ACPI device ids (bnc#1151927 5.3.15).
- staging: rtl8723bs: Add 024c:0525 to the list of SDIO device-ids
  (bnc#1151927 5.3.15).
- staging: wilc1000: fix illegal memory access in
  wilc_parse_join_bss_param() (bnc#1151927 5.3.15).
- staging: rtl8192e: fix potential use after free (bnc#1151927
  5.3.15).
- thunderbolt: Power cycle the router if NVM authentication fails
  (bnc#1151927 5.3.15).
- mei: me: add comet point V device id (bnc#1151927 5.3.15).
- mei: bus: prefix device names on bus with the bus name
  (bnc#1151927 5.3.15).
- usb: dwc2: use a longer core rest timeout in dwc2_core_reset()
  (bnc#1151927 5.3.15).
- USB: serial: ftdi_sio: add device IDs for U-Blox C099-F9P
  (bnc#1151927 5.3.15).
- net: dsa: sja1105: fix sja1105_parse_rgmii_delays() (bnc#1151927
  5.3.15).
- macvlan: schedule bc_work even if error (bnc#1151927 5.3.15).
- mdio_bus: don't use managed reset-controller (bnc#1151927
  5.3.15).
- sctp: cache netns in sctp_ep_common (bnc#1151927 5.3.15).
- sctp: Fix memory leak in sctp_sf_do_5_2_4_dupcook (bnc#1151927
  5.3.15).
- net: fec: fix clock count mis-match (bnc#1151927 5.3.15).
- xfrm: Fix memleak on xfrm state destroy (bnc#1151927 5.3.15).
- ARM: dts: stm32: Fix CAN RAM mapping on stm32mp157c (bnc#1151927
  5.3.15).
- arm64: dts: zii-ultra: fix ARM regulator GPIO handle
  (bnc#1151927 5.3.15).
- ARM: dts: sun8i-a83t-tbs-a711: Fix WiFi resume from suspend
  (bnc#1151927 5.3.15).
- arm64: dts: imx8mm: fix compatible string for sdma (bnc#1151927
  5.3.15).
- ARM: dts: imx6qdl-sabreauto: Fix storm of accelerometer
  interrupts (bnc#1151927 5.3.15).
- arm64: dts: ls1028a: fix a compatible issue (bnc#1151927
  5.3.15).
- reset: fix reset_control_ops kerneldoc comment (bnc#1151927
  5.3.15).
- soundwire: intel: fix intel_register_dai PDI offsets and numbers
  (bnc#1151927 5.3.15).
- thunderbolt: Read DP IN adapter first two dwords in one go
  (bnc#1151927 5.3.15).
- x86/tsc: Respect tsc command line paraemeter for
  clocksource_tsc_early (bnc#1151927 5.3.15).
- perf scripting engines: Iterate on tep event arrays directly
  (bnc#1151927 5.3.15).
- watchdog: pm8916_wdt: fix pretimeout registration flow
  (bnc#1151927 5.3.15).
- mac80211: fix station inactive_time shortly after boot
  (bnc#1151927 5.3.15).
- net/fq_impl: Switch to kvmalloc() for memory allocation
  (bnc#1151927 5.3.15).
- net: stmmac: xgmac: Disable Flow Control when 1 or more queues
  are in AV (bnc#1151927 5.3.15).
- net: stmmac: xgmac: Fix TSA selection (bnc#1151927 5.3.15).
- net: stmmac: xgmac: bitrev32 returns u32 (bnc#1151927 5.3.15).
- net: stmmac: gmac4: bitrev32 returns u32 (bnc#1151927 5.3.15).
- netfilter: ipset: Fix nla_policies to fully support
  NL_VALIDATE_STRICT (bnc#1151927 5.3.15).
- netfilter: nf_tables_offload: skip EBUSY on chain update
  (bnc#1151927 5.3.15).
- netfilter: nf_tables: bogus EOPNOTSUPP on basechain update
  (bnc#1151927 5.3.15).
- net: mscc: ocelot: fix __ocelot_rmw_ix prototype (bnc#1151927
  5.3.15).
- samples/bpf: fix build by setting HAVE_ATTR_TEST to zero
  (bnc#1151927 5.3.15).
- can: mcp251x: mcp251x_restart_work_handler(): Fix potential
  force_quit race condition (bnc#1151927 5.3.15).
- can: flexcan: increase error counters if skb enqueueing via
  can_rx_offload_queue_sorted() fails (bnc#1151927 5.3.15).
- can: rx-offload: can_rx_offload_irq_offload_fifo(): continue
  on error (bnc#1151927 5.3.15).
- can: rx-offload: can_rx_offload_irq_offload_timestamp():
  continue on error (bnc#1151927 5.3.15).
- can: rx-offload: can_rx_offload_offload_one(): use ERR_PTR()
  to propagate error value in case of errors (bnc#1151927 5.3.15).
- can: rx-offload: can_rx_offload_offload_one(): increment
  rx_fifo_errors on queue overflow or OOM (bnc#1151927 5.3.15).
- can: c_can: D_CAN: c_can_chip_config(): perform a sofware
  reset on open (bnc#1151927 5.3.15).
- can: peak_usb: report bus recovery as well (bnc#1151927 5.3.15).
- net: fec: add missed clk_disable_unprepare in remove
  (bnc#1151927 5.3.15).
- block: drbd: remove a stray unlock in __drbd_send_protocol()
  (bnc#1151927 5.3.15).
- nvme-multipath: fix crash in nvme_mpath_clear_ctrl_paths
  (bnc#1151927 5.3.15).
- nvme-rdma: fix a segmentation fault during module unload
  (bnc#1151927 5.3.15).
- ceph: return -EINVAL if given fsc mount option on kernel w/o
  support (bnc#1151927 5.3.15).
- idr: Fix idr_alloc_u32 on 32-bit systems (bnc#1151927 5.3.15).
- idr: Fix integer overflow in idr_for_each_entry (bnc#1151927
  5.3.15).
- XArray: Fix xas_next() with a single entry at 0 (bnc#1151927
  5.3.15).
- ASoC: stm32: sai: add restriction on mmap support (bnc#1151927
  5.3.15).
- ASoC: hdac_hda: fix race in device removal (bnc#1151927 5.3.15).
- ASoC: rockchip: rockchip_max98090: Enable SHDN to fix headset
  detection (bnc#1151927 5.3.15).
- ASoC: compress: fix unsigned integer overflow check (bnc#1151927
  5.3.15).
- drm/amdgpu: add warning for GRBM 1-cycle delay issue in gfx9
  (bnc#1151927 5.3.15).
- drm/amd/swSMU: fix smu workload bit map error (bnc#1151927
  5.3.15).
- drm/amdgpu: dont schedule jobs while in reset (bnc#1151927
  5.3.15).
- clk: ti: dra7-atl-clock: Remove ti_clk_add_alias call
  (bnc#1151927 5.3.15).
- clk: meson: gxbb: let sar_adc_clk_div set the parent clock rate
  (bnc#1151927 5.3.15).
- scripts/gdb: fix debugging modules compiled with hot/cold
  partitioning (bnc#1151927 5.3.15).
- mm/gup_benchmark: fix MAP_HUGETLB case (bnc#1151927 5.3.15).
- commit de8adb7
* Fri Dec  6 2019 jslaby@suse.cz
- Update patches.suse/ALSA-hda-hdmi-add-Tigerlake-support.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-SOF-ipc-Fix-memory-leak-in-sof_set_get_large_ct.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-SOF-topology-Fix-bytes-control-size-checks.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-kirkwood-fix-device-remove-ordering.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-kirkwood-fix-external-clock-probe-defer.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-msm8916-wcd-analog-Fix-RX1-selection-in-RDAC2-M.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/ASoC-ti-sdma-pcm-Add-back-the-flags-parameter-for-no.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/bpf-Allow-narrow-loads-of-bpf_sysctl-fields-with-off.patch
  (bsc#1155518 bnc#1151927 5.3.15).
- Update
  patches.suse/bpf-Change-size-to-u64-for-bpf_map_-area_alloc-charg.patch
  (bsc#1155518 bnc#1151927 5.3.15).
- Update
  patches.suse/bridge-ebtables-don-t-crash-when-using-dnat-target-i.patch
  (bsc#1154353 bnc#1151927 5.3.15).
- Update
  patches.suse/can-rx-offload-can_rx_offload_offload_one-do-not-inc.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/can-rx-offload-can_rx_offload_queue_tail-fix-error-h.patch
  (git-fixes bnc#1151927 5.3.15).
- Update patches.suse/clk-at91-avoid-sleeping-early.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-at91-fix-update-bit-maps-on-CFG_MOR-write.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-at91-sam9x60-fix-programmable-clock.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-samsung-exynos5420-Preserve-PLL-configuration-du.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-samsung-exynos542x-Move-G3D-subsystem-clocks-to-.patch
  (git-fixes bnc#1151927 5.3.15).
- Update patches.suse/clk-samsung-exynos5433-Fix-error-paths.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-sunxi-Fix-operator-precedence-in-sunxi_divs_clk_.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-sunxi-ng-a80-fix-the-zero-ing-of-bits-16-and-18.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clk-ti-clkctrl-Fix-failed-to-enable-error-with-doubl.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/clocksource-drivers-mediatek-Fix-error-handling.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/drm-amdgpu-register-gpu-instance-before-fan-boost-fe.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/fbdev-c2p-Fix-link-failure-on-non-inlining.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/i40e-Fix-for-ethtool-m-issue-on-X722-NIC.patch
  (jsc#SLE-8025 bnc#1151927 5.3.15).
- Update
  patches.suse/iavf-initialize-ITRN-registers-with-correct-values.patch
  (jsc#SLE-7940 bnc#1151927 5.3.15).
- Update
  patches.suse/ice-fix-potential-infinite-loop-because-loop-counter.patch
  (jsc#SLE-7926 bnc#1151927 5.3.15).
- Update
  patches.suse/idr-Fix-idr_get_next_ul-race-with-idr_remove.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/mac80211-fix-ieee80211_txq_setup_flows-failure-path.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/net-bcmgenet-reapply-manual-settings-to-the-PHY.patch
  (jsc#SLE-7772 bnc#1151927 5.3.15).
- Update
  patches.suse/net-bcmgenet-use-RGMII-loopback-for-MAC-reset.patch
  (jsc#SLE-7772 bnc#1151927 5.3.15).
- Update
  patches.suse/net-mlx5e-Fix-eswitch-debug-print-of-max-fdb-flow.patch
  (jsc#SLE-8464 bnc#1151927 5.3.15).
- Update
  patches.suse/net-mlx5e-Use-correct-enum-to-determine-uplink-port.patch
  (jsc#SLE-8464 bnc#1151927 5.3.15).
- Update
  patches.suse/pinctrl-cherryview-Allocate-IRQ-chip-dynamic.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/powerpc-bpf-Fix-tail-call-implementation.patch
  (bsc#1157698 bnc#1151927 5.3.15).
- Update
  patches.suse/pwm-bcm-iproc-Prevent-unloading-the-driver-module-wh.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/reset-Fix-memory-leak-in-reset_control_array_put.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/slip-Fix-use-after-free-Read-in-slip_open.patch
  (git-fixes bnc#1151927 5.3.15).
- Update patches.suse/soc-imx-gpc-fix-initialiser-format.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/stacktrace-Don-t-skip-first-entry-on-noncurrent-task.patch
  (bnc#1154866 bnc#1151927 5.3.15).
- Update
  patches.suse/thunderbolt-Fix-lockdep-circular-locking-depedency-w.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/watchdog-bd70528-Add-MODULE_ALIAS-to-allow-module-au.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/watchdog-imx_sc_wdt-Pretimeout-should-follow-SCU-fir.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/watchdog-meson-Fix-the-wrong-value-of-left-time.patch
  (git-fixes bnc#1151927 5.3.15).
- Update
  patches.suse/x86-resctrl-prevent-null-pointer-dereference-when-reading-mondata.patch
  (bsc#1152489 bnc#1151927 5.3.15).
- commit ac8515c
* Fri Dec  6 2019 jlee@suse.com
- Refresh and enable
  patches.suse/0001-MODSIGN-do-not-load-mok-when-secure-boot-disabled.patch.
  (fate#316531)
- commit 44cbe3a
* Thu Dec  5 2019 nsaenzjulienne@suse.de
- supported.conf: Support Broadcom's Genet Ethernet driver (bsc#158563)
- commit 9ba4eec
* Thu Dec  5 2019 ykaukab@suse.de
- net: thunderx: start phy before starting autonegotiation
  (bsc#1158107).
- commit 7049617
* Thu Dec  5 2019 mbenes@suse.cz
- s390/livepatch: Implement reliable stack tracing for the
  consistency model (jsc#SLE-11050).
- Update config files.
- commit 069014a
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: add stack pointer alignment sanity checks
  (jsc#SLE-11050).
- commit 1bb4634
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: filter out unreliable bogus %%r14 (jsc#SLE-11050).
- commit 2756f26
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: start unwinding from reliable state
  (jsc#SLE-11050).
- commit f610667
* Thu Dec  5 2019 mbenes@suse.cz
- s390/test_unwind: print verbose unwinding results
  (jsc#SLE-11050).
- commit 0357290
* Thu Dec  5 2019 mbenes@suse.cz
- s390: fix register clobbering in CALL_ON_STACK (jsc#SLE-11050).
- commit 0d20bdc
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: always inline get_stack_pointer (jsc#SLE-11050).
- commit b82cd7f
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: stop gracefully at task pt_regs (jsc#SLE-11050).
- commit 02b1171
* Thu Dec  5 2019 mbenes@suse.cz
- s390/head64: correct init_task stack setup (jsc#SLE-11050).
- commit bb6645d
* Thu Dec  5 2019 jack@suse.cz
- blacklist.conf: Add 9163e0184bd7 and 91cbf01178c3
- commit 7e1a7fc
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: make reuse_sp default when unwinding pt_regs
  (jsc#SLE-11050).
- commit d6b50c9
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: report an error if pt_regs are not on stack
  (jsc#SLE-11050).
- commit 13143f4
* Thu Dec  5 2019 mbenes@suse.cz
- s390: avoid misusing CALL_ON_STACK for task stack setup
  (jsc#SLE-11050).
- commit 49822da
* Thu Dec  5 2019 mbenes@suse.cz
- s390: correct CALL_ON_STACK back_chain saving (jsc#SLE-11050).
- commit d1292ec
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: unify task is current checks (jsc#SLE-11050).
- commit f37218c
* Thu Dec  5 2019 mbenes@suse.cz
- s390: disable preemption when switching to nodat stack with
  CALL_ON_STACK (jsc#SLE-11050).
- commit 2b3e23a
* Thu Dec  5 2019 mbenes@suse.cz
- s390: always inline disabled_wait (jsc#SLE-11050).
- commit e18f4f8
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: drop unnecessary code around calling
  ftrace_graph_ret_addr() (jsc#SLE-11050).
- commit f07dfe2
* Thu Dec  5 2019 mbenes@suse.cz
- s390: always inline current_stack_pointer() (jsc#SLE-11050).
- commit b8e1cdf
* Thu Dec  5 2019 mbenes@suse.cz
- s390/process: avoid custom stack unwinding in get_wchan
  (jsc#SLE-11050).
- commit 83d7f05
* Thu Dec  5 2019 mbenes@suse.cz
- s390/unwind: fix get_stack_pointer(NULL, NULL) (jsc#SLE-11050).
- commit cf38773
* Thu Dec  5 2019 mbenes@suse.cz
- s390/stacktrace: use common arch_stack_walk infrastructure
  (jsc#SLE-11050).
- Update config files.
- commit c353280
* Wed Dec  4 2019 jack@suse.cz
- xfs: Sanity check flags of Q_XQUOTARM call (bsc#1158460).
- commit 57267ac
* Wed Dec  4 2019 jack@suse.cz
- fix compat handling of FICLONERANGE, FIDEDUPERANGE and
  FS_IOC_FIEMAP (bsc#1158459).
- commit d29bae9
* Wed Dec  4 2019 jack@suse.cz
- gfs2: add compat_ioctl support (bsc#1158458).
- commit fa0941a
* Wed Dec  4 2019 jack@suse.cz
- ocfs2: fix passing zero to 'PTR_ERR' warning (bsc#1158457).
- commit b1e2fe5
* Wed Dec  4 2019 jack@suse.cz
- splice: only read in as much information as there is pipe
  buffer space (bsc#1158456).
- commit 0d75db3
* Wed Dec  4 2019 jack@suse.cz
- ext4: update direct I/O read lock pattern for IOCB_NOWAIT
  (bsc#1158454).
- iomap: fix return value of iomap_dio_bio_actor on 32bit systems
  (bsc#1158455).
- loop: fix no-unmap write-zeroes request behavior (bsc#1158389).
- commit c9b89d4
* Wed Dec  4 2019 nsaenzjulienne@suse.de
- supported.conf: support gpio-regulator used by Raspberry Pi 4
  (bsc#1158451)
- commit 83d8e7e
* Wed Dec  4 2019 bp@suse.de
- EDAC/amd64: Set grain per DIMM (bsc#1152489).
- commit f4d7468
* Wed Dec  4 2019 mbenes@suse.cz
- ftrace: Introduce PERMANENT ftrace_ops flag (bsc#1120853).
- commit c038bf4
* Wed Dec  4 2019 tiwai@suse.de
- Update patch reference for ieee802154 fix (CVE-2019-19525 bsc#1158417)
- commit 0ca3a8c
* Wed Dec  4 2019 tiwai@suse.de
- Update patch references for input and USB fixes (CVE-2019-19524 bsc#1158413 CVE-2019-19528 bsc#1158407 CVE-2019-19534 bsc#1158398)
- commit 61129d2
* Wed Dec  4 2019 mgorman@suse.de
- mm/page_io.c: annotate refault stalls from swap_readpage
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: shmem: use proper gfp flags for shmem_writepage()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/madvise.c: replace with page_size() in madvise_inject_error()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, thp: do not queue fully unmapped pages for deferred split
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/migrate.c: handle freed page at the first place (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/hugetlb: avoid looping to the same hugepage if !pages
  and !vmas (bnc#1155780 (VM/FS functional and performance
  backports)).
- hugetlb: remove duplicated code (bnc#1155780 (VM/FS functional
  and performance backports)).
- hugetlb: region_chg provides only cache entry (bnc#1155780
  (VM/FS functional and performance backports)).
- hugetlbfs: take read_lock on i_mmap for PMD sharing (bnc#1155780
  (VM/FS functional and performance backports)).
- hugetlbfs: hugetlb_fault_mutex_hash() cleanup (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/vmscan.c: fix typo in comment (bnc#1155780 (VM/FS functional
  and performance backports)).
- mm: vmscan: enforce inactive:active ratio at the reclaim root
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: detect file thrashing at the reclaim root
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: move file exhaustion detection to the node level
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: harmonize writeback congestion tracking for
  nodes & memcgs (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm: vmscan: split shrink_node() into node part and memcgs part
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: turn shrink_node_memcg() into shrink_lruvec()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: replace shrink_node() loop with a retry jump
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: naming fixes: global_reclaim() and sane_reclaim()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: vmscan: move inactive_list_is_low() swap check to the caller
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: clean up and clarify lruvec lookup procedure (bnc#1155780
  (VM/FS functional and performance backports)).
- mm: vmscan: simplify lruvec_lru_size() (bnc#1155780 (VM/FS
  functional and performance backports)).
- mm/vmscan.c: remove unused scan_control parameter from pageout()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/vmscan: remove unused lru_pages argument (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/vmalloc: rework vmap_area_lock (bnc#1155780 (VM/FS functional
  and performance backports)).
- mm/vmalloc: add more comments to the adjust_va_to_fit_type()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/vmalloc: respect passed gfp_mask when doing preloading
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/vmalloc: remove preempt_disable/enable when doing preloading
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/vmalloc.c: remove unnecessary highmem_mask from parameter
  of gfpflags_allow_blocking() (bnc#1155780 (VM/FS functional
  and performance backports)).
- mm, soft-offline: convert parameter to pfn (bnc#1155780 (VM/FS
  functional and performance backports)).
- mm/memory-failure.c clean up around tk pre-allocation
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, memfd: fix COW issue on MAP_PRIVATE and F_SEAL_FUTURE_WRITE
  mappings (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm/rmap.c: use VM_BUG_ON_PAGE() in __page_check_anon_rmap()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/rmap.c: fix outdated comment in page_get_anon_vma()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/mmap.c: use IS_ERR_VALUE to check return value
  of get_unmapped_area (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm/rmap.c: reuse mergeable anon_vma as parent when fork
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/rmap.c: don't reuse anon_vma if we just want a copy
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/mmap.c: rb_parent is not necessary in __vma_link_list()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/mmap.c: extract __vma_unlink_list() as counterpart for
  __vma_link_list() (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm/mmap.c: __vma_unlink_prev() is not necessary now (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/mmap.c: prev could be retrieved from vma->vm_prev
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/swap.c: piggyback lru_add_drain_all() calls (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/mmap.c: remove a never-triggered warning in __vma_adjust()
  (bnc#1155780 (VM/FS functional and performance backports)).
- rss_stat: add support to detect RSS updates of external mm
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: emit tracepoint when RSS changes (bnc#1155780 (VM/FS
  functional and performance backports)).
- shmem: pin the file in shmem_fault() if mmap_sem is dropped
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: drop mmap_sem before calling balance_dirty_pages() in
  write fault (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm: vmscan: memcontrol: remove mem_cgroup_select_victim_node()
  (bnc#1155780 (VM/FS functional and performance backports)).
- include/linux/memcontrol.h: fix comments based on per-node memcg
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: memcontrol: remove dead code from memory_max_write()
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, memcg: clean up reclaim iter array (bnc#1155780 (VM/FS
  functional and performance backports)).
- mm/swap.c: trivial mark_page_accessed() cleanup (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/filemap.c: warn if stale pagecache is left after direct write
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/filemap.c: remove redundant cache invalidation after async
  direct-io write (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm/slub.c: clean up validate_slab() (bnc#1155780 (VM/FS
  functional and performance backports)).
- mm/slub.c: update comments (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm: slub: print the offset of fault addresses (bnc#1155780
  (VM/FS functional and performance backports)).
- mm, slab_common: use enum kmalloc_cache_type to iterate over
  kmalloc caches (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm, slab: remove unused kmalloc_size() (bnc#1155780 (VM/FS
  functional and performance backports)).
- mm, slab: make kmalloc_info[] contain all types of names
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, memcg: make scan aggression always exclude protection
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, memcg: make memory.emin the baseline for utilisation
  determination (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm, memcg: proportional memory.{low,min} reclaim (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/vmalloc.c: move 'area->pages' after if statement (bnc#1155780
  (VM/FS functional and performance backports)).
- mm/vmalloc: modify struct vmap_area to reduce its size
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/vmalloc: do not keep unpurged areas in the busy tree
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm: introduce compound_nr() (bnc#1155780 (VM/FS functional
  and performance backports)).
- mm: introduce page_shift() (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm: introduce page_size() (bnc#1155780 (VM/FS functional and
  performance backports)).
- vmalloc: lift the arm flag for coherent mappings to common code
  (bnc#1155780 (VM/FS functional and performance backports)).
- commit d67e35b
* Wed Dec  4 2019 glin@suse.com
- bpf, testing: Convert prog tests to probe_read_{user, kernel}{,
  _str} helper (bsc#1155518).
- bpf, samples: Use bpf_probe_read_user where appropriate
  (bsc#1155518).
- commit e02b4fe
* Wed Dec  4 2019 tiwai@suse.de
- Update patch reference for USB can security fix (CVE-2019-19529 bsc#1158381)
- commit a96958b
* Wed Dec  4 2019 jack@suse.cz
- iomap: Fix pipe page leakage during splicing (bsc#1158383).
- commit b73f21b
* Wed Dec  4 2019 jack@suse.cz
- ext4: Fix credit estimate for final inode freeing (bsc#1158380).
- commit 99e5121
* Wed Dec  4 2019 jack@suse.cz
- ubifs: Fix memory leak in __ubifs_node_verify_hmac error path
  (bsc#1158378).
- commit 7babaf3
* Wed Dec  4 2019 jack@suse.cz
- ubifs: Fix memory leak in read_znode() error path (bsc#1158376).
- commit b3fc39e
* Wed Dec  4 2019 jack@suse.cz
- ecryptfs: fix unlink and rmdir in face of underlying fs
  modifications (bsc#1158374).
- commit 9fe5fae
* Wed Dec  4 2019 jack@suse.cz
- aio: Fix io_pgetevents() struct __compat_aio_sigset layout
  (bsc#1158373).
- commit 569924c
* Wed Dec  4 2019 glin@suse.com
- xdp: Fix cleanup on map free for devmap_hash map type
  (bsc#1155518).
- libbpf: Fix call relocation offset calculation bug
  (bsc#1155518).
- selftests, bpf: Fix test_tc_tunnel hanging (bsc#1155518).
- selftests, bpf: xdping is not meant to be run standalone
  (bsc#1155518).
- bpf: Fix race in btf_resolve_helper_id() (bsc#1155518).
- libbpf: Improve handling of corrupted ELF during map
  initialization (bsc#1155518).
- libbpf: Make btf__resolve_size logic always check size error
  condition (bsc#1155518).
- libbpf: Fix another potential overflow issue in bpf_prog_linfo
  (bsc#1155518).
- libbpf: Fix potential overflow issue (bsc#1155518).
- libbpf: Fix memory leak/double free issue (bsc#1155518).
- libbpf: Fix negative FD close() in xsk_setup_xdp_prog()
  (bsc#1155518).
- bpf: Account for insn->off when doing bpf_probe_read_kernel
  (bsc#1155518).
- bpf: Switch BPF probe insns to bpf_probe_read_kernel
  (bsc#1155518).
- bpf: Add probe_read_{user, kernel} and probe_read_{user,
  kernel}_str helpers (bsc#1155518).
- bpf: Make use of probe_user_write in probe write helper
  (bsc#1155518).
- uaccess: Add strict non-pagefault kernel-space read function
  (bsc#1155518).
- uaccess: Add non-pagefault user-space write function
  (bsc#1155518).
- bpf: Fix bpf jit kallsym access (bsc#1155518).
- libbpf: Don't use kernel-side u32 type in xsk.c (bsc#1155518).
- libbpf: Fix off-by-one error in ELF sanity check (bsc#1155518).
- libbpf: Fix compatibility for kernels without need_wakeup
  (bsc#1155518).
- libbpf: Fix strncat bounds error in libbpf_prog_type_by_name
  (bsc#1155518).
- bpf: Fix build error without CONFIG_NET (bsc#1155518).
- bpf: Fix bpf_attr.attach_btf_id check (bsc#1155518).
- selftests/bpf: Add kfree_skb raw_tp test (bsc#1155518).
- bpf: Check types of arguments passed into helpers (bsc#1155518).
- bpf: Add support for BTF pointers to x86 JIT (bsc#1155518).
- bpf: Add support for BTF pointers to interpreter (bsc#1155518).
- bpf: Attach raw_tp program with BTF via type name (bsc#1155518).
- bpf: Implement accurate raw_tp context access via BTF
  (bsc#1155518).
- libbpf: Auto-detect btf_id of BTF-based raw_tracepoints
  (bsc#1155518).
- bpf: Add attach_btf_id attribute to program load (bsc#1155518).
- bpf: Process in-kernel BTF (bsc#1155518).
- bpf: Add typecast to bpf helpers to help BTF generation
  (bsc#1155518).
- bpf: Add typecast to raw_tracepoints to help BTF generation
  (bsc#1155518).
- bpf/stackmap: Fix deadlock with rq_lock in bpf_get_stack()
  (bsc#1155518).
- libbpf: Fix passing uninitialized bytes to setsockopt
  (bsc#1155518).
- selftests/bpf: Fix btf_dump padding test case (bsc#1155518).
- selftests/bpf: test_progs: add missing \n to CHECK_FAIL
  (bsc#1155518).
- selftests/bpf: test_progs: fix verbose mode garbage
  (bsc#1155518).
- selftests/bpf: test_progs: remove unused ret (bsc#1155518).
- selftests/bpf: test_progs: remove asserts from subtests
  (bsc#1155518).
- selftests/bpf: test_progs: remove global fail/success counts
  (bsc#1155518).
- selftests/bpf: test_progs: test__skip (bsc#1155518).
- selftests/bpf: test_progs: drop extra trailing tab
  (bsc#1155518).
- selftests/bpf: test_progs: test__printf -> printf (bsc#1155518).
- selftests/bpf: test_progs: switch to open_memstream
  (bsc#1155518).
- commit b4301c5
* Wed Dec  4 2019 jack@suse.cz
- blacklist.conf: Add fs/f2fs to blacklist
  We don't care about F2FS as we don't even compile it.
- commit d73a3d9
* Wed Dec  4 2019 jack@suse.cz
- ext4: set error return correctly when ext4_htree_store_dirent
  fails (bsc#1158371).
- commit 7f15da5
* Wed Dec  4 2019 jslaby@suse.cz
- Revert "nvme: Add quirk for Kingston NVME SSD running FW
  E8FK11.T" (git-fixes).
- PCI/MSI: Fix incorrect MSI-X masking on resume (git-fixes).
- commit e6e544b
* Wed Dec  4 2019 jack@suse.cz
- block: check bi_size overflow before merge (bsc#1158370).
- commit b8ddf8c
* Wed Dec  4 2019 mkubecek@suse.cz
- series.conf: cleanup
  update mainline references, refresh and move into sorted section:
  patches.suse/mm-pcp-Share-common-code-between-memory-hotplug-and-percpu-sysctl-handler.patch
  patches.suse/mm-pcpu-Make-zone-pcp-updates-and-reset-internal-to-the-mm.patch
  patches.suse/autonuma-fix-watermark-checking-in-migrate_balanced_pgdat.patch
  patches.suse/autonuma-reduce-cache-footprint-when-scanning-page-tables.patch
  patches.suse/CIFS-Fix-SMB2-oplock-break-processing.patch
  patches.suse/cifs-move-cifsFileInfo_put-logic-into-a-work-queue.patch
- commit f9fc458
* Wed Dec  4 2019 mkubecek@suse.cz
- series.conf: refresh
  update mainline references and resort:
  patches.suse/pci-aardvark-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-altera-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-dwc-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-export-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-faraday-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-ftpci100-use-inbound-resources-for-setup.patch
  patches.suse/pci-iproc-use-inbound-resources-for-setup.patch
  patches.suse/pci-iproc-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-mediatek-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-mobiveil-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-of-add-inbound-resource-parsing-to-helpers.patch
  patches.suse/pci-rcar-use-inbound-resources-for-setup.patch
  patches.suse/pci-rockchip-drop-storing-driver-private-outbound-resource-data.patch
  patches.suse/pci-rockchip-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-v3-semi-use-inbound-resources-for-setup.patch
  patches.suse/pci-v3-semi-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-versatile-enable-compile_test.patch
  patches.suse/pci-versatile-remove-usage-of-phys_offset.patch
  patches.suse/pci-versatile-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-xgene-use-inbound-resources-for-setup.patch
  patches.suse/pci-xgene-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-xilinx-nwl-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/pci-xilinx-use-pci_parse_request_of_pci_ranges.patch
  patches.suse/resource-add-a-resource_list_first_type-helper.patch
- commit 14fed6d
* Tue Dec  3 2019 mkubecek@suse.cz
- fix mainline references
  fix Patch-mainline:
  patches.suse/powercap-intel_rapl-add-support-for-CometLake-Mobile
  patches.suse/powercap-intel_rapl-add-support-for-Cometlake-desktop
- commit 68d56a7
* Tue Dec  3 2019 trenn@suse.com
- powercap/intel_rapl: add support for Cometlake desktop
  (jsc#SLE-8184).
- powercap/intel_rapl: add support for CometLake Mobile
  (jsc#SLE-8184).
- commit f7448e7
* Tue Dec  3 2019 mkubecek@suse.cz
- config: refresh
  Only update headers.
- commit 908f91e
* Tue Dec  3 2019 msuchanek@suse.de
- powerpc/pseries: Enable support for ibm,drc-info property
  (bsc#1157480 ltc#181028).
- PCI: rpaphp: Correctly match ibm, my-drc-index to drc-name
  when using drc-info (bsc#1157480 ltc#181028).
- PCI: rpaphp: Annotate and correctly byte swap DRC properties
  (bsc#1157480 ltc#181028).
- PCI: rpaphp: Add drc-info support for hotplug slot registration
  (bsc#1157480 ltc#181028).
- PCI: rpaphp: Don't rely on firmware feature to imply drc-info
  support (bsc#1157480 ltc#181028).
- PCI: rpaphp: Fix up pointer to first drc-info entry (bsc#1157480
  ltc#181028).
- powerpc/pseries: Add cpu DLPAR support for drc-info property
  (bsc#1157480 ltc#181028).
- powerpc/pseries: Fix drc-info mappings of logical cpus to
  drc-index (bsc#1157480 ltc#181028).
- powerpc/pseries: Fix bad drc_index_start value parsing of
  drc-info entry (bsc#1157480 ltc#181028).
- commit 557da83
* Tue Dec  3 2019 mbrugger@suse.com
- arm64: Update config files. (jsc#SLE-9943 bsc#1158193)
  Bump CONFIG_NODES_SHIFT from 2 to 6
- commit 0cfadc1
* Tue Dec  3 2019 tiwai@suse.de
- rpm/kernel-subpackage-spec: Exclude kernel-firmware recommends (bsc#1143959)
  For reducing the dependency on kernel-firmware in sub packages
- commit d950271
* Tue Dec  3 2019 tiwai@suse.de
- mwifiex: Fix heap overflow in
  mmwifiex_process_tdls_action_frame()
  (CVE-2019-14901,bsc#1157042).
- commit 7889fe2
* Tue Dec  3 2019 nmoreychaisemartin@suse.com
- mlx5: add parameter to disable enhanced IPoIB (bsc#1142095)
- commit 4ea5d32
* Tue Dec  3 2019 mbenes@suse.cz
- livepatch: Selftests of the API for tracking system state
  changes (bsc#1071995 fate#323487).
- supported.conf:
- commit 4fff100
* Tue Dec  3 2019 mbenes@suse.cz
- livepatch: Allow to distinguish different version of system
  state changes (bsc#1071995 fate#323487).
- commit 1b157ca
* Tue Dec  3 2019 mbenes@suse.cz
- livepatch: Basic API to track system state changes (bsc#1071995
  fate#323487).
- Refresh
  patches.suse/livepatch-create-and-include-UAPI-headers.patch.
- commit d8150c3
* Tue Dec  3 2019 mbenes@suse.cz
- livepatch: Keep replaced patches until post_patch callback is
  called (bsc#1071995 fate#323487).
- commit 3c51995
* Tue Dec  3 2019 mbenes@suse.cz
- tracing/kprobe: Check whether the non-suffixed symbol is notrace
  (bsc#1158279).
- commit 8be1214
* Tue Dec  3 2019 jslaby@suse.cz
- Linux 5.3.14 (bnc#1151927 5.3.14).
- staging: comedi: usbduxfast: usbduxfast_ai_cmdtest rounding
  error (bnc#1151927 5.3.14).
- usb-serial: cp201x: support Mark-10 digital force gauge
  (bnc#1151927 5.3.14).
- USB: serial: option: add support for Foxconn T77W968 LTE modules
  (bnc#1151927 5.3.14).
- USB: serial: option: add support for DW5821e with eSIM support
  (bnc#1151927 5.3.14).
- USB: serial: mos7840: add USB ID to support Moxa UPort 2210
  (bnc#1151927 5.3.14).
- USBIP: add config dependency for SGL_ALLOC (bnc#1151927 5.3.14).
- USB: chaoskey: fix error case of a timeout (bnc#1151927 5.3.14).
- usbip: tools: fix fd leakage in the function of
  read_attr_usbip_status (bnc#1151927 5.3.14).
- appledisplay: fix error handling in the scheduled work
  (bnc#1151927 5.3.14).
- media: imon: invalid dereference in imon_touch_event
  (bnc#1151927 5.3.14).
- media: uvcvideo: Fix error path in control parsing failure
  (bnc#1151927 5.3.14).
- media: cxusb: detect cxusb_ctrl_msg error in query (bnc#1151927
  5.3.14).
- media: usbvision: Fix races among open, close, and disconnect
  (bnc#1151927 5.3.14).
- media: usbvision: Fix invalid accesses after device disconnect
  (bnc#1151927 5.3.14).
- media: mceusb: fix out of bounds read in MCE receiver buffer
  (bnc#1151927 5.3.14).
- media: vivid: Set vid_cap_streaming and vid_out_streaming to
  true (bnc#1151927 5.3.14).
- cpufreq: Add NULL checks to show() and store() methods of
  cpufreq (bnc#1151927 5.3.14).
- futex: Prevent robust futex exit race (bnc#1151927 5.3.14).
- x86/entry/32: Fix FIXUP_ESPFIX_STACK with user CR3 (bnc#1151927
  5.3.14).
- x86/pti/32: Calculate the various PTI cpu_entry_area sizes
  correctly, make the CPU_ENTRY_AREA_PAGES assert precise
  (bnc#1151927 5.3.14).
- selftests/x86/sigreturn/32: Invalidate DS and ES when abusing
  the kernel (bnc#1151927 5.3.14).
- selftests/x86/mov_ss_trap: Fix the SYSENTER test (bnc#1151927
  5.3.14).
- x86/entry/32: Fix NMI vs ESPFIX (bnc#1151927 5.3.14).
- x86/entry/32: Unwind the ESPFIX stack earlier on exception entry
  (bnc#1151927 5.3.14).
- x86/entry/32: Move FIXUP_FRAME after pushing %%fs in SAVE_ALL
  (bnc#1151927 5.3.14).
- x86/entry/32: Use %%ss segment where required (bnc#1151927
  5.3.14).
- x86/entry/32: Fix IRET exception (bnc#1151927 5.3.14).
- x86/cpu_entry_area: Add guard page for entry stack on 32bit
  (bnc#1151927 5.3.14).
- x86/pti/32: Size initial_page_table correctly (bnc#1151927
  5.3.14).
- x86/doublefault/32: Fix stack canaries in the double fault
  handler (bnc#1151927 5.3.14).
- x86/xen/32: Simplify ring check in xen_iret_crit_fixup()
  (bnc#1151927 5.3.14).
- x86/xen/32: Make xen_iret_crit_fixup() independent of frame
  layout (bnc#1151927 5.3.14).
- x86/stackframe/32: Repair 32-bit Xen PV (bnc#1151927 5.3.14).
- x86/speculation: Fix redundant MDS mitigation message
  (bnc#1151927 5.3.14).
- x86/speculation: Fix incorrect MDS/TAA mitigation status
  (bnc#1151927 5.3.14).
- x86/insn: Fix awk regexp warnings (bnc#1151927 5.3.14).
- Bluetooth: Fix invalid-free in bcsp_close() (bnc#1151927
  5.3.14).
- ath10k: restore QCA9880-AR1A (v1) detection (bnc#1151927
  5.3.14).
- ath9k_hw: fix uninitialized variable data (bnc#1151927 5.3.14).
- ath10k: Fix HOST capability QMI incompatibility (bnc#1151927
  5.3.14).
- Revert "dm crypt: use WQ_HIGHPRI for the IO and crypt
  workqueues" (bnc#1151927 5.3.14).
- nbd: prevent memory leak (bnc#1151927 5.3.14).
- md/raid10: prevent access of uninitialized resync_pages offset
  (bnc#1151927 5.3.14).
- net: rtnetlink: prevent underflows in do_setvfinfo()
  (bnc#1151927 5.3.14).
- nfc: port100: handle command failure cleanly (bnc#1151927
  5.3.14).
- net/ipv4: fix sysctl max for fib_multipath_hash_policy
  (bnc#1151927 5.3.14).
- drm/i915/pmu: "Frequency" is reported as accumulated cycles
  (bnc#1151927 5.3.14).
- drm/i915: Don't oops in dumb_create ioctl if we have no crtcs
  (bnc#1151927 5.3.14).
- drm/amdgpu: disable gfxoff on original raven (bnc#1151927
  5.3.14).
- drm/amdgpu: disable gfxoff when using register read interface
  (bnc#1151927 5.3.14).
- drm/amd/powerplay: issue no PPSMC_MSG_GetCurrPkgPwr on
  unsupported ASICs (bnc#1151927 5.3.14).
- tools: gpio: Correctly add make dependencies for gpio_utils
  (bnc#1151927 5.3.14).
- fork: fix pidfd_poll()'s return type (bnc#1151927 5.3.14).
- ARM: 8904/1: skip nomap memblocks while finding the
  lowmem/highmem boundary (bnc#1151927 5.3.14).
- vhost/vsock: split packets to send using multiple buffers
  (bnc#1151927 5.3.14).
- commit c30f7a5
* Tue Dec  3 2019 jslaby@suse.cz
- Update
  patches.suse/0001-Revert-Bluetooth-hci_ll-set-operational-frequency-ea.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/0001-USB-serial-mos7720-fix-remote-wakeup.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/0001-USB-serial-mos7840-fix-remote-wakeup.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/0001-b2c2-flexcop-usb-add-sanity-checking.patch
  (bsc#1146540 CVE-2019-15291 bnc#1151927 5.3.14).
- Update patches.suse/0001-virtio_balloon-fix-shrinker-count.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/0001-virtio_console-allocate-inbufs-in-add_port-only-if-i.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/0001-virtio_ring-fix-return-code-on-DMA-mapping-fails.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/ALSA-usb-audio-Fix-NULL-dereference-at-parsing-BADD.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/KVM-PPC-Book3S-HV-Flush-link-stack-on-guest-exit-to-.patch
  (CVE-2019-18660 bsc#1157038 bsc#1157923 ltc#182612 bnc#1151927
  5.3.14).
- Update
  patches.suse/Revert-fs-ocfs2-fix-possible-null-pointer-dereferenc.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/drm-i915-userptr-Try-to-acquire-the-page-lock-around.patch
  (bnc#1156537 bnc#1151927 5.3.14).
- Update
  patches.suse/gpio-bd70528-Use-correct-unit-for-debounce-times.patch
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608 bnc#1151927 5.3.14).
- Update patches.suse/gpio-max77620-Fixup-debounce-delays.patch
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608 bnc#1151927 5.3.14).
- Update
  patches.suse/gve-fix-dma-sync-bug-where-not-all-pages-synced.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/ipv6-route-return-if-there-is-no-fib_nh_gw_family.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/mdio_bus-Fix-init-if-CONFIG_RESET_CONTROLLER-n.patch
  (git-fixes bnc#1151927 5.3.14).
- Update
  patches.suse/media-vivid-Fix-wrong-locking-that-causes-race-condi.patch
  (CVE-2019-18683,bsc#1155897 bnc#1151927 5.3.14).
- Update
  patches.suse/mlxsw-spectrum_router-Fix-determining-underlay-for-a.patch
  (bsc#1154488 bnc#1151927 5.3.14).
- Update
  patches.suse/mm-ksm.c-don-t-WARN-if-page-is-still-mapped-in-remove_stable_node.patch
  (git fixes (mm/ksm bnc#1151927 5.3.14).
- Update
  patches.suse/mm-memory_hotplug-don-t-access-uninitialized-memmaps-in-shrink_zone_span.patch
  (git fixes (mm/hotplug) bnc#1151927 5.3.14).
- Update
  patches.suse/mm-slub.c-init_on_free-1-should-wipe-freelist-ptr-for-bulk-allocations.patch
  (git fixes (mm/slub) bnc#1151927 5.3.14).
- Update patches.suse/nbd-fix-memory-leak-in-nbd_get_socket.patch
  (git-fixes bnc#1151927 5.3.14).
- Update patches.suse/net-ath10k-Fix-a-NULL-ptr-deref-bug.patch
  (CVE-2019-15099,bsc#1146368 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx4_en-Fix-wrong-limitation-for-number-of-TX-ri.patch
  (jsc#SLE-8460 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx4_en-fix-mlx4-ethtool-N-insertion.patch
  (jsc#SLE-8460 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx5-Fix-auto-group-size-calculation.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx5-Update-the-list-of-the-PCI-supported-device.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx5e-Do-not-use-non-EXT-link-modes-in-EXT-mode.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx5e-Fix-error-flow-cleanup-in-mlx5e_tc_tun_cre.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlx5e-Fix-set-vf-link-state-error-flow.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-mlxfw-Verify-FSM-error-code-translation-doesn-t-.patch
  (jsc#SLE-8464 bnc#1151927 5.3.14).
- Update
  patches.suse/net-sched-act_pedit-fix-WARN-in-the-traffic-path.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/net-sched-ensure-opts_len-IP_TUNNEL_OPTS_MAX-in-act_.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/net-tls-enable-sk_msg-redirect-to-tls-socket-egress.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/powerpc-64s-support-nospectre_v2-cmdline-option.patch
  (bsc#1131107 bnc#1151927 5.3.14).
- Update
  patches.suse/powerpc-book3s64-Fix-link-stack-flush-on-context-swi.patch
  (CVE-2019-18660 bsc#1157038 bsc#1157923 ltc#182612 bnc#1151927
  5.3.14).
- Update
  patches.suse/sfc-Only-cancel-the-PPS-workqueue-if-it-exists.patch
  (jsc#SLE-8314 bnc#1151927 5.3.14).
- Update
  patches.suse/taprio-don-t-reject-same-mqprio-settings.patch
  (bsc#1154353 bnc#1151927 5.3.14).
- Update
  patches.suse/usbip-Fix-uninitialized-symbol-nents-in-stub_recv_cm.patch
  (git-fixes bnc#1151927 5.3.14).
- commit 53302d0
* Tue Dec  3 2019 mbenes@suse.cz
- blacklist.conf: 1d200e9d6f63 ("block: Fix writeback throttling W=1 compiler warnings")
- commit e82481b
* Tue Dec  3 2019 jslaby@suse.cz
- hwrng: omap - Fix RNG wait loop timeout (git-fixes).
- commit 76a15d1
* Tue Dec  3 2019 mkubecek@suse.cz
- fix mainline references
- fix mainline references:
  patches.suse/0001-Revert-Bluetooth-hci_ll-set-operational-frequency-ea.patch
  patches.suse/0001-Revert-mfd-syscon-Set-name-of-regmap_config.patch
  patches.suse/0001-USB-serial-mos7720-fix-remote-wakeup.patch
  patches.suse/0001-USB-serial-mos7840-fix-remote-wakeup.patch
  patches.suse/0001-ppdev-fix-PPGETTIME-PPSETTIME-ioctls.patch
- commit d4e2479
* Tue Dec  3 2019 mkubecek@suse.cz
- series.conf: refresh
- update mainline references and resort:
  patches.suse/of-address-fix-of_pci_range_parser_one-translation-of-dma-addresses.patch
  patches.suse/of-address-follow-dma-parent-for-dma-coherent.patch
  patches.suse/of-address-introduce-of_get_next_dma_parent-helper.patch
  patches.suse/of-address-translate-dma-ranges-for-parent-nodes-missing-dma-ranges.patch
  patches.suse/of-factor-out-addr-size-cells-parsing.patch
  patches.suse/of-make-of_dma_get_range-work-on-bus-nodes.patch
  patches.suse/powerpc-book3s64-hash-Use-secondary-hash-for-bolted-.patch
  patches.suse/powerpc-fadump-when-fadump-is-supported-register-the.patch
  patches.suse/powerpc-papr_scm-Fix-an-off-by-one-check-in-papr_scm.patch
  patches.suse/powerpc-pseries-Don-t-fail-hash-page-table-insert-fo.patch
  patches.suse/powerpc-pseries-Don-t-opencode-HPTE_V_BOLTED.patch
  patches.suse/powerpc-pseries-address-checkpatch-warnings-in-dlpar.patch
  patches.suse/powerpc-pseries-safely-roll-back-failed-DLPAR-cpu-ad.patch
  patches.suse/powerpc-security-Fix-wrong-message-when-RFI-Flush-is.patch
  patches.suse/powerpc-security-book3s64-Report-L1TF-status-in-sysf.patch
  patches.suse/powerpc-xive-Prevent-page-fault-issues-in-the-machin.patch
  patches.suse/scsi-lpfc-Add-FA-WWN-Async-Event-reporting.patch
  patches.suse/scsi-lpfc-Add-FC-AL-support-to-lpe32000-models.patch
  patches.suse/scsi-lpfc-Add-additional-discovery-log-messages.patch
  patches.suse/scsi-lpfc-Add-enablement-of-multiple-adapter-dumps.patch
  patches.suse/scsi-lpfc-Add-log-macros-to-allow-print-by-serverity.patch
  patches.suse/scsi-lpfc-Add-registration-for-CPU-Offline-Online-ev.patch
  patches.suse/scsi-lpfc-Change-default-IRQ-model-on-AMD-architectu.patch
  patches.suse/scsi-lpfc-Clarify-FAWNN-error-message.patch
  patches.suse/scsi-lpfc-Complete-removal-of-FCoE-T10-PI-support-on.patch
  patches.suse/scsi-lpfc-Fix-GPF-on-scsi-command-completion.patch
  patches.suse/scsi-lpfc-Fix-NULL-check-before-mempool_destroy-is-n.patch
  patches.suse/scsi-lpfc-Fix-NVME-io-abort-failures-causing-hangs.patch
  patches.suse/scsi-lpfc-Fix-NVMe-ABTS-in-response-to-receiving-an-.patch
  patches.suse/scsi-lpfc-Fix-SLI3-hba-in-loop-mode-not-discovering-.patch
  patches.suse/scsi-lpfc-Fix-a-kernel-warning-triggered-by-lpfc_get.patch
  patches.suse/scsi-lpfc-Fix-a-kernel-warning-triggered-by-lpfc_sli.patch
  patches.suse/scsi-lpfc-Fix-bad-ndlp-ptr-in-xri-aborted-handling.patch
  patches.suse/scsi-lpfc-Fix-configuration-of-BB-credit-recovery-in.patch
  patches.suse/scsi-lpfc-Fix-coverity-errors-on-NULL-pointer-checks.patch
  patches.suse/scsi-lpfc-Fix-device-recovery-errors-after-PLOGI-fai.patch
  patches.suse/scsi-lpfc-Fix-discovery-failures-when-target-device-.patch
  patches.suse/scsi-lpfc-Fix-duplicate-unreg_rpi-error-in-port-offl.patch
  patches.suse/scsi-lpfc-Fix-dynamic-fw-log-enablement-check.patch
  patches.suse/scsi-lpfc-Fix-hardlockup-in-lpfc_abort_handler.patch
  patches.suse/scsi-lpfc-Fix-hdwq-sgl-locks-and-irq-handling.patch
  patches.suse/scsi-lpfc-Fix-host-hang-at-boot-or-slow-boot.patch
  patches.suse/scsi-lpfc-Fix-kernel-crash-at-lpfc_nvme_info_show-du.patch
  patches.suse/scsi-lpfc-Fix-list-corruption-detected-in-lpfc_put_s.patch
  patches.suse/scsi-lpfc-Fix-list-corruption-in-lpfc_sli_get_iocbq.patch
  patches.suse/scsi-lpfc-Fix-lockdep-errors-in-sli_ringtx_put.patch
  patches.suse/scsi-lpfc-Fix-locking-on-mailbox-command-completion.patch
  patches.suse/scsi-lpfc-Fix-lpfc_cpumask_of_node_init.patch
  patches.suse/scsi-lpfc-Fix-miss-of-register-read-failure-check.patch
  patches.suse/scsi-lpfc-Fix-premature-re-enabling-of-interrupts-in.patch
  patches.suse/scsi-lpfc-Fix-pt2pt-discovery-on-SLI3-HBAs.patch
  patches.suse/scsi-lpfc-Fix-reporting-of-read-only-fw-error-errors.patch
  patches.suse/scsi-lpfc-Fix-rpi-release-when-deleting-vport.patch
  patches.suse/scsi-lpfc-Fix-spinlock_irq-issues-in-lpfc_els_flush_.patch
  patches.suse/scsi-lpfc-Fix-unexpected-error-messages-during-RSCN-.patch
  patches.suse/scsi-lpfc-Initialize-cpu_map-for-not-present-cpus.patch
  patches.suse/scsi-lpfc-Make-FW-logging-dynamically-configurable.patch
  patches.suse/scsi-lpfc-Make-function-lpfc_defer_pt2pt_acc-static.patch
  patches.suse/scsi-lpfc-Make-lpfc_debugfs_ras_log_data-static.patch
  patches.suse/scsi-lpfc-Remove-lock-contention-target-write-path.patch
  patches.suse/scsi-lpfc-Revise-interrupt-coalescing-for-missing-sc.patch
  patches.suse/scsi-lpfc-Slight-fast-path-performance-optimizations.patch
  patches.suse/scsi-lpfc-Sync-with-FC-NVMe-2-SLER-change-to-require.patch
  patches.suse/scsi-lpfc-Update-async-event-logging.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.4.0.1.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.6.0.0.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.6.0.1.patch
  patches.suse/scsi-lpfc-Update-lpfc-version-to-12.6.0.2.patch
  patches.suse/scsi-lpfc-cleanup-remove-unused-fcp_txcmlpq_cnt.patch
  patches.suse/scsi-lpfc-fix-Coverity-lpfc_cmpl_els_rsp-Null-pointe.patch
  patches.suse/scsi-lpfc-fix-Coverity-lpfc_get_scsi_buf_s3-Null-poi.patch
  patches.suse/scsi-lpfc-fix-build-error-of-lpfc_debugfs.c-for-vfre.patch
  patches.suse/scsi-lpfc-fix-coverity-error-of-dereference-after-nu.patch
  patches.suse/scsi-lpfc-fix-inlining-of-lpfc_sli4_cleanup_poll_lis.patch
  patches.suse/scsi-lpfc-fix-lpfc_nvmet_mrq-to-be-bound-by-hdw-queu.patch
  patches.suse/scsi-lpfc-fix-spelling-error-in-MAGIC_NUMER_xxx.patch
  patches.suse/scsi-lpfc-lpfc_attr-Fix-Use-plain-integer-as-NULL-po.patch
  patches.suse/scsi-lpfc-lpfc_nvmet-Fix-Use-plain-integer-as-NULL-p.patch
  patches.suse/scsi-lpfc-revise-nvme-max-queues-to-be-hdwq-count.patch
  patches.suse/scsi-megaraid_sas-Unique-names-for-MSI-X-vectors.patch
  patches.suse/scsi-megaraid_sas-remove-unused-variables-debugBlk-f.patch
  patches.suse/scsi-mpt3sas-Add-app-owned-flag-support-for-diag-buf.patch
  patches.suse/scsi-mpt3sas-Bump-mpt3sas-driver-version-to-32.100.0.patch
  patches.suse/scsi-mpt3sas-Display-message-before-releasing-diag-b.patch
  patches.suse/scsi-mpt3sas-Fail-release-cmnd-if-diag-buffer-is-rel.patch
  patches.suse/scsi-mpt3sas-Fix-clear-pending-bit-in-ioctl-status.patch
  patches.suse/scsi-mpt3sas-Fix-module-parameter-max_msix_vectors.patch
  patches.suse/scsi-mpt3sas-Free-diag-buffer-without-any-status-che.patch
  patches.suse/scsi-mpt3sas-Maintain-owner-of-buffer-through-Unique.patch
  patches.suse/scsi-mpt3sas-Register-trace-buffer-based-on-NVDATA-s.patch
  patches.suse/scsi-mpt3sas-Reject-NVMe-Encap-cmnds-to-unsupported-.patch
  patches.suse/scsi-mpt3sas-Reuse-diag-buffer-allocated-at-load-tim.patch
  patches.suse/scsi-mpt3sas-Use-Component-img-header-to-get-Package.patch
  patches.suse/scsi-mpt3sas-clear-release-bit-when-buffer-reregiste.patch
  patches.suse/scsi-qedf-Add-port_id-getter.patch
  patches.suse/scsi-qla2xxx-Add-error-handling-for-PLOGI-ELS-passth.patch
  patches.suse/scsi-qla2xxx-Capture-FW-dump-on-MPI-heartbeat-stop-e.patch
  patches.suse/scsi-qla2xxx-Check-for-MB-timeout-while-capturing-IS.patch
  patches.suse/scsi-qla2xxx-Do-command-completion-on-abort-timeout.patch
  patches.suse/scsi-qla2xxx-Dual-FCP-NVMe-target-port-support.patch
  patches.suse/scsi-qla2xxx-Fix-SRB-leak-on-switch-command-timeout.patch
  patches.suse/scsi-qla2xxx-Fix-a-dma_pool_free-call.patch
  patches.suse/scsi-qla2xxx-Fix-device-connect-issues-in-P2P-config.patch
  patches.suse/scsi-qla2xxx-Fix-double-scsi_done-for-abort-path.patch
  patches.suse/scsi-qla2xxx-Fix-driver-unload-hang.patch
  patches.suse/scsi-qla2xxx-Improve-logging-for-scan-thread.patch
  patches.suse/scsi-qla2xxx-Remove-an-include-directive.patch
  patches.suse/scsi-qla2xxx-Retry-PLOGI-on-FC-NVMe-PRLI-failure.patch
  patches.suse/scsi-qla2xxx-Set-remove-flag-for-all-VP.patch
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.20-k.patch
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.21-k.patch
  patches.suse/scsi-qla2xxx-don-t-use-zero-for-FC4_PRIORITY_NVME.patch
  patches.suse/scsi-qla2xxx-initialize-fc4_type_priority.patch
  patches.suse/scsi-qla2xxx-remove-redundant-assignment-to-pointer-.patch
  patches.suse/scsi-smartpqi-Align-driver-syntax-with-oob.patch
  patches.suse/scsi-smartpqi-add-inquiry-timeouts.patch
  patches.suse/scsi-smartpqi-bump-version-to-1.2.10-025.patch
  patches.suse/scsi-smartpqi-change-TMF-timeout-from-60-to-30-secon.patch
  patches.suse/scsi-smartpqi-clean-up-indentation-of-a-statement.patch
  patches.suse/scsi-smartpqi-correct-syntax-issue.patch
  patches.suse/scsi-smartpqi-fix-LUN-reset-when-fw-bkgnd-thread-is-.patch
  patches.suse/scsi-smartpqi-fix-call-trace-in-device-discovery.patch
  patches.suse/scsi-smartpqi-fix-controller-lockup-observed-during-.patch
  patches.suse/scsi-smartpqi-fix-problem-with-unique-ID-for-physica.patch
  patches.suse/scsi-smartpqi-remove-set-but-not-used-variable-ctrl_.patch
  patches.suse/scsi-smartpqi-remove-unused-manifest-constants.patch
  patches.suse/scsi-target-compare-full-CHAP_A-Algorithm-strings.patch
  patches.suse/scsi-target-fix-SendTargets-All-string-compares.patch
  patches.suse/scsi-target-iscsi-CHAP-add-support-for-SHA1-SHA256-a.patch
  patches.suse/scsi-target-iscsi-rename-some-variables-to-avoid-con.patch
  patches.suse/scsi-target-iscsi-tie-the-challenge-length-to-the-ha.patch
  patches.suse/scsi-target-remove-unused-extension-parameters.patch
  No effect on expanded tree.
- commit 1cb26c8
* Tue Dec  3 2019 mkubecek@suse.cz
- fix mainline references
  Fix patch-mainline tag:
  patches.suse/btrfs-fix-memory-leaks-in-the-test-test_find_first_c.patch
  patches.suse/btrfs-make-test_find_first_clear_extent_bit-fail-on-.patch
- commit 5794053
* Tue Dec  3 2019 neilb@suse.de
- NFSv4.1 - backchannel request should hold ref on xprt
  (bsc#1152624).
- commit 1203c55
* Mon Dec  2 2019 fdmanana@suse.com
- Btrfs: make test_find_first_clear_extent_bit fail on incorrect
  results (bsc#1158210).
- commit e7e7b18
* Mon Dec  2 2019 fdmanana@suse.com
- Btrfs: fix memory leaks in the test
  test_find_first_clear_extent_bit (bsc#1158210).
- commit 04b8200
* Mon Dec  2 2019 oneukum@suse.com
- Revert "mfd: syscon: Set name of regmap_config" (git-fixes).
- commit da59436
* Mon Dec  2 2019 oneukum@suse.com
- blacklist.conf: specific to SPARC64
- commit 6880b65
* Mon Dec  2 2019 oneukum@suse.com
- ppdev: fix PPGETTIME/PPSETTIME ioctls (git-fixes).
- commit 71fc6dc
* Mon Dec  2 2019 oneukum@suse.com
- USB: serial: mos7840: fix remote wakeup (git-fixes).
- commit 6ebc1fd
* Mon Dec  2 2019 oneukum@suse.com
- USB: serial: mos7720: fix remote wakeup (git-fixes).
- commit aeee58e
* Mon Dec  2 2019 oneukum@suse.com
- Revert "Bluetooth: hci_ll: set operational frequency earlier"
  (git-fixes).
- commit 8b8f5bf
* Mon Dec  2 2019 jslaby@suse.cz
- perf script: Fix invalid LBR/binary mismatch error (git-fixes).
- watchdog: aspeed: Fix clock behaviour for ast2600 (git-fixes).
- slip: Fix use-after-free Read in slip_open (git-fixes).
- net/sched: annotate lockless accesses to qdisc->empty
  (git-fixes).
- kselftest: Fix NULL INSTALL_PATH for TARGETS runlist
  (git-fixes).
- md/raid0: Fix an error message in raid0_make_request()
  (git-fixes).
- io_uring: Fix mm_fault with READ/WRITE_FIXED (git-fixes).
- Revert "fs: ocfs2: fix possible null-pointer dereferences in
  ocfs2_xa_prepare_entry()" (git-fixes).
- nbd:fix memory leak in nbd_get_socket() (git-fixes).
- KVM: x86/mmu: Take slots_lock when using kvm_mmu_zap_all_fast()
  (git-fixes).
- ARM: dts: stm32: remove OV5640 pinctrl definition on
  stm32mp157c-ev1 (git-fixes).
- Refresh
  patches.suse/ARM-dts-stm32-change-joystick-pinctrl-definition-on-.patch.
- commit c09426f
* Mon Dec  2 2019 jthumshirn@suse.de
- libnvdimm: Export the target_node attribute for regions and
  namespaces (bsc#1158071).
- commit 9d24c0f
* Mon Dec  2 2019 jslaby@suse.cz
- blacklist.conf: add four more entries
- commit 49fe688
* Mon Dec  2 2019 jslaby@suse.cz
- drm/mcde: Fix an error handling path in 'mcde_probe()'
  (git-fixes).
- usb: gadget: configfs: Fix missing spin_lock_init() (git-fixes).
- usbip: Fix uninitialized symbol 'nents' in
  stub_recv_cmd_submit() (git-fixes).
- commit 53a444b
* Fri Nov 29 2019 ggherdovich@suse.cz
- platform/x86: ISST: Allow additional TRL MSRs (jsc#SLE-10687).
- commit 435b3fb
* Fri Nov 29 2019 mkubecek@suse.cz
- supported.conf: sort
- commit ac3011b
* Fri Nov 29 2019 msuchanek@suse.de
- Update config files.
  ppc64 is lats architecture without PRINTK_TIME. Align with the rest.
- commit 4fb63b6
* Fri Nov 29 2019 ptesarik@suse.cz
- s390: vfio-ap: fix warning reset not completed (jsc#SLE-7524
  LTC#178970).
- commit fd793bf
* Fri Nov 29 2019 ptesarik@suse.cz
- Update config files (bsc#1158055 LTC#182629).
- commit 1b24df4
* Fri Nov 29 2019 tiwai@suse.de
- Move upstreamed patches into sorted section
  Refresh:
  patches.suse/0001-b2c2-flexcop-usb-add-sanity-checking.patch
  patches.suse/driver-core-simplify-definitions-of-platform_get_irq.patch
  patches.suse/drm-amdgpu-Add-DC-feature-mask-to-disable-fractional.patch
- commit 71f50c8
* Fri Nov 29 2019 tiwai@suse.de
- mwifiex: fix possible heap overflow in
  mwifiex_process_country_ie() (CVE-2019-14895 bsc#1157158).
- commit d8b66ee
* Fri Nov 29 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference and resort:
  patches.suse/RDMA-bnxt_re-Fix-stat-push-into-dma-buffer-on-gen-p5-devices.patch
  No effect on expanded tree.
- commit b878e91
* Fri Nov 29 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort
  patches.suse/dma-direct-avoid-a-forward-declaration-for-phys_to_dma.patch
  patches.suse/dma-direct-check-for-overflows-on-32-bit-dma-addresses.patch
  patches.suse/dma-direct-exclude-dma_direct_map_resource-from-the-min_low_pfn-check.patch
  patches.suse/dma-direct-unify-the-dma_capable-definitions.patch
  patches.suse/dma-mapping-treat-dev-bus_dma_mask-as-a-dma-limit.patch
  patches.suse/x86-pci-sta2x11-use-default-dma-address-translation.patch
- commit 3b7773d
* Thu Nov 28 2019 oneukum@suse.com
- virtio_balloon: fix shrinker count (git-fixes).
- commit 923948e
* Thu Nov 28 2019 oneukum@suse.com
- virtio_balloon: fix shrinker scan number of pages (gif-fixes).
- commit 217c80e
* Thu Nov 28 2019 oneukum@suse.com
- virtio_ring: fix return code on DMA mapping fails (git-fixes).
- commit d775d67
* Thu Nov 28 2019 yousaf.kaukab@suse.com
- regulator: core: make regulator_register() EPROBE_DEFER aware
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- regulator: core: Add label to collate of_node_put() statements
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- regulator: core: Add of_node_put() before return
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- commit 48eb6c5
* Thu Nov 28 2019 ptesarik@suse.cz
- net/smc: receive pending data after RCV_SHUTDOWN (jsc#SLE-7521
  LTC#178954).
- net/smc: receive returns without data (jsc#SLE-7521 LTC#178954).
- net/smc: fix SMCD link group creation with VLAN id (jsc#SLE-7521
  LTC#178954).
- commit 83dcb05
* Thu Nov 28 2019 ptesarik@suse.cz
- s390: add support for IBM z15 machines (bsc#1156538 LTC#182406).
- Update config files.
- commit c53f40a
* Thu Nov 28 2019 tbogendoerfer@suse.de
- Update
  patches.suse/RDMA-Fix-goto-target-to-release-the-allocated-memory.patch
  (jsc#SLE-8449 bsc#1157171 CVE-2019-19077).
- commit e1bdb30
* Thu Nov 28 2019 tbogendoerfer@suse.de
- Update
  patches.suse/nfp-flower-fix-memory-leak-in-nfp_flower_spawn_vnic_.patch
  (bnc#1151927 5.3.4 bsc#1157045 CVE-2019-19081).
- commit e720525
* Thu Nov 28 2019 tbogendoerfer@suse.de
- Update
  patches.suse/nfp-flower-prevent-memory-leak-in-nfp_flower_spawn_p.patch
  (bnc#1151927 5.3.4 bsc#1157044 CVE-2019-19080).
- commit 8b64c31
* Thu Nov 28 2019 tbogendoerfer@suse.de
- Update
  patches.suse/RDMA-hfi1-Prevent-memory-leak-in-sdma_init.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9 bsc#1157191 CVE-2019-19065).
- commit 29b1120
* Thu Nov 28 2019 yousaf.kaukab@suse.com
- gpio: stubs in headers should be inline
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- commit d6eb08d
* Thu Nov 28 2019 ptesarik@suse.cz
- s390/cpumsf: Check for CPU Measurement sampling
  (bsc#1156561 LTC#182407).
- commit 02c88d4
* Thu Nov 28 2019 yousaf.kaukab@suse.com
- regulator: add missing 'static inline' to a helper's stub
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- commit a58ac0e
* Thu Nov 28 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/ibmvnic-Bound-waits-for-device-queries.patch
  patches.suse/ibmvnic-Fix-completion-structure-initialization-again.patch
  patches.suse/ibmvnic-Serialize-device-queries.patch
  patches.suse/ibmvnic-Terminate-waiting-device-threads-after-loss-.patch
- commit 223cb4b
* Thu Nov 28 2019 mkubecek@suse.cz
- series.conf: cleanup
- move unsortable patches out of sorted section
  patches.suse/CIFS-Fix-SMB2-oplock-break-processing.patch
  patches.suse/cifs-move-cifsFileInfo_put-logic-into-a-work-queue.patch
- update Patch-mainline tag
  patches.suse/smb3-fix-leak-in-open-on-server-perf-counter.patch
- commit 4594952
* Thu Nov 28 2019 msuchanek@suse.de
- powerpc: add link stack flush mitigation in debugfs
  (CVE-2019-18660 bsc#1157038 bsc#1157923 ltc#182612).
- KVM: PPC: Book3S HV: Flush link stack on guest exit to host
  kernel (CVE-2019-18660 bsc#1157038 bsc#1157923 ltc#182612).
- powerpc/book3s64: Fix link stack flush on context switch
  (CVE-2019-18660 bsc#1157038 bsc#1157923 ltc#182612).
- commit 538ee5a
* Wed Nov 27 2019 msuchanek@suse.de
- net/ibmvnic: Ignore H_FUNCTION return from H_EOI to tolerate
  XIVE mode (bsc#1089644, ltc#166495, ltc#165544, git-fixes).
- Delete patches.suse/net-ibmvnic-Fix-EOI-when-running-in-XIVE-mode.patch - reverted upstream
- blacklist.conf: Add the removed patch and revert.
- commit e63bc30
* Wed Nov 27 2019 tiwai@suse.de
- PCI: Fix missing inline for pci_pr3_present() (git-fixes).
- PCI: Add a helper to check Power Resource Requirements _PR3
  existence (git-fixes).
- commit 071c077
* Wed Nov 27 2019 yousaf.kaukab@suse.com
- regulator: provide regulator_bulk_set_supply_names()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- commit ef060bf
* Wed Nov 27 2019 oneukum@suse.com
- blacklist.conf: no need to watch for android fixes
- commit 4abf123
* Wed Nov 27 2019 ptesarik@suse.cz
- s390/pkey: fix memory leak within _copy_apqns_from_user()
  (jsc#SLE-7533 LTC#178844).
- commit 3fe4d6e
* Wed Nov 27 2019 ptesarik@suse.cz
- s390/crypto: Fix unsigned variable compared with zero
  (jsc#SLE-7545 LTC#179078).
- commit d517803
* Wed Nov 27 2019 ptesarik@suse.cz
- s390/crypto: Support for SHA3 via CPACF (MSA6) (jsc#SLE-7545
  LTC#179078).
- Update config files.
- supported.conf: Add sha3_256_s390 and sha3_512_s390.
- commit 39adadf
* Wed Nov 27 2019 mkubecek@suse.cz
- update upstream references
- move into sorted section:
  patches.suse/sched-pelt-Fix-update-of-blocked-PELT-ordering.patch
- update upstream reference and move into sorted section:
  patches.suse/sched-cpufreq-Move-the-cfs_rq_util_change-call-to-cpufreq_update_util.patch
- update Patch-mainline:
  patches.suse/sched-core-Further-clarify-sched_class-set_next_task.patch
  patches.suse/sched-core-Make-pick_next_task_idle-more-consistent.patch
  patches.suse/sched-core-Optimize-pick_next_task.patch
  patches.suse/sched-core-Simplify-sched_class-pick_next_task.patch
  patches.suse/sched-fair-Add-comments-for-group_type-and-balancing-at-SD_NUMA-level.patch
  patches.suse/sched-fair-Better-document-newidle_balance.patch
  patches.suse/sched-fair-Clean-up-asym-packing.patch
  patches.suse/sched-fair-Fix-rework-of-find_idlest_group.patch
  patches.suse/sched-fair-Optimize-find_idlest_group.patch
  patches.suse/sched-fair-Remove-meaningless-imbalance-calculation.patch
  patches.suse/sched-fair-Rename-sg_lb_stats-sum_nr_running-to-sum_h_nr_running.patch
  patches.suse/sched-fair-Rework-find_idlest_group.patch
  patches.suse/sched-fair-Rework-load_balance.patch
  patches.suse/sched-fair-Spread-out-tasks-evenly-when-not-overloaded.patch
  patches.suse/sched-fair-Use-load-instead-of-runnable-load-in-load_balance.patch
  patches.suse/sched-fair-Use-load-instead-of-runnable-load-in-wakeup-path.patch
  patches.suse/sched-fair-Use-mul_u32_u32.patch
  patches.suse/sched-fair-Use-rq-nr_running-when-balancing-load.patch
  patches.suse/sched-fair-Use-utilization-to-select-misfit-task.patch
  patches.suse/sched-fair-util_est-Implement-faster-ramp-up-EWMA-on-utilization-increases.patch
  patches.suse/sched-pelt-Fix-update-of-blocked-PELT-ordering.patch
  patches.suse/sched-topology-Don-t-set-SD_BALANCE_WAKE-on-cpuset-domain-relax.patch
- commit d845674
* Wed Nov 27 2019 yousaf.kaukab@suse.com
- soc/tegra: pmc: Add reset sources and levels on Tegra194
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Add missing IRQ callbacks on Tegra194
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Use lower-case for hexadecimal literals
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- usb: host: xhci-tegra: Correct phy enable sequence
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: tegra186: Add debounce support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: tegra186: Program interrupt route mapping
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: tegra186: Derive register offsets from bank/port
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- memory: tegra: Set DMA mask based on supported address bits
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Fix build error without CONFIG_PM_SLEEP
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Add suspend and resume support on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Share clk and rst register defines with Tegra
  clock driver (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: clk-super: Fix to enable PLLP branches to CPU
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: clk-dfll: Add suspend and resume support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Use fence_udelay() during PLLU init
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: clk-super: Add restore-context support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: periph: Add restore_context support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Support for OSC context save and restore
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: pll: Save and restore pll context
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: pllout: Save and restore pllout context
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: divider: Save and restore divider rate
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Reimplement SOR clocks on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Reimplement SOR clock on Tegra124
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Rename sor0_lvds to sor0_out
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Move SOR0 implementation to Tegra124
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: tegra: Remove last remains of TEGRA210_CLK_SOR1_SRC
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- clk: Add API to get index of the clock parent
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- dt-bindings: clock: tegra: Rename SOR0_LVDS to SOR0_OUT
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- mfd: max77620: Do not allocate IRQs upfront
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- arm64: kpti: Add NVIDIA's Carmel core to the KPTI whitelist
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Configure deep sleep control settings
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Configure core power request polarity
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Add wake event support on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Support wake events on more Tegra SoCs
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- cpufreq: tegra124: Add suspend and resume support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- ahci: tegra: use regulator_bulk_set_supply_names()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: use regulator_bulk_set_supply_names()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: xusb: Add vbus override support on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: xusb: Add vbus override support on Tegra186
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: xusb: Add usb3 port fake support on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: xusb: Add XUSB dual mode support on Tegra210
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- iommu/tegra-smmu: Use non-secure register for flushing
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- iommu/tegra-smmu: Fix page tables in > 4 GiB memory
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- iommu/tegra-smmu: Fix client enablement order
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: tegra: Fix CLKREQ dependency programming
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- usb: host: xhci-tegra: Add Tegra194 XHCI support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- xhci: tegra: Parameterize mailbox register addresses
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: tegra186: Implement wake event support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: max77620: Fix interrupt handling
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: max77620: Do not allocate IRQs upfront
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- usb: host: xhci-tegra: use regulator_bulk_set_supply_names()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- usb: host: xhci-tegra: use devm_platform_ioremap_resource()
  to simplify code (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- net: stmmac: Support enhanced addressing mode for DWMAC 4.10
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- net: stmmac: Only enable enhanced addressing mode when needed
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: pmc: Fix crashes for hierarchical interrupts
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- soc/tegra: fuse: Add FUSE clock check in tegra_fuse_readl()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- firmware: tegra: Move BPMP resume to noirq phase
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: bd70528: Use correct unit for debounce times
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: max77620: Fixup debounce delays
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- thermal: tegra: Fix a typo
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- i2c: tegra: Compile PM functions unconditionally
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- arm64: tegra: Add PCIe slot supply information in p2972-0000
  platform (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: tegra: Add support to enable slot regulators
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: tegra: Add support to configure sideband pins
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: tegra: Add Tegra194 PCIe support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- phy: tegra: Add PCIe PIPE2UPHY support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: dwc: Add support to enable CDM register check
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: dwc: Export dw_pcie_wait_for_link() API
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: dwc: Add extended configuration space capability search
  API (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: dwc: Move config space capability search API
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: dwc: Group DBI registers writes requiring unlocking
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: Disable MSI for Tegra root ports
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- PCI: Add #defines for some of PCIe spec r4.0 features
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- pinctrl: tegra: Flush pinctrl writes during resume
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- pinctrl: tegra210: Add Tegra210 pinctrl pm ops
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- pinctrl: tegra: Add suspend and resume support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- net: stmmac: Do not request stmmaceth clock
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- net: stmmac: Make MDIO bus reset optional
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: Add PIO mode support
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: report clk rate errors
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: add support to adjust baud rate
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: DT for Adjusted baud rates
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: add support to use 8 bytes trigger
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: set maximum num of uart ports to 8
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: check for FIFO mode enabled status
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: report error to upper tty layer
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: flush the RX fifo on frame error
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: avoid reg access when clk disabled
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: add support to ignore read
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: protect IER against LCR.DLAB
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- serial: tegra: add internal loopback functionality
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- dmaengine: tegra210-adma: Don't program FIFO threshold
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- dmaengine: tegra-apb: Support per-burst residue granularity
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: pca953x: Drop %%s for constant string literals
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: pca953x: Remove explicit comparison with 0
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: pca953x: Use GENMASK() consistently
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: pca953x: Switch to use device_get_match_data()
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- gpio: Add support for hierarchical IRQ domains
  (jsc#SLE-9391,jsc#SLE-9388,jsc#SLE-10608).
- commit e2e7db7
* Wed Nov 27 2019 ptesarik@suse.cz
- s390/qeth: use IQD Multi-Write (jsc#SLE-7795 LTC#179220).
- s390/qdio: implement IQD Multi-Write (jsc#SLE-7795 LTC#179220).
- s390/qeth: add xmit_more support for IQD devices (jsc#SLE-7795
  LTC#179220).
- s390/qeth: add BQL support for IQD devices (jsc#SLE-7795
  LTC#179220).
- s390/qeth: when in TX NAPI mode, use napi_consume_skb()
  (jsc#SLE-7795 LTC#179220).
- s390/qeth: add TX NAPI support for IQD devices (jsc#SLE-7795
  LTC#179220).
- s390/qeth: collect accurate TX statistics (jsc#SLE-7795
  LTC#179220).
- s390/qdio: let drivers opt-out from Output Queue scanning
  (jsc#SLE-7795 LTC#179220).
- s390/qdio: enable drivers to poll for Output completions
  (jsc#SLE-7795 LTC#179220).
- commit a827279
* Wed Nov 27 2019 ptesarik@suse.cz
- s390/pkey: Add sysfs attributes to emit AES CIPHER key blobs
  (jsc#SLE-7533 LTC#178844).
- s390/zcrypt: fix wrong handling of cca cipher keygenflags
  (jsc#SLE-7533 LTC#178844).
- s390/paes: Prepare paes functions for large key blobs
  (jsc#SLE-7533 LTC#178844).
- s390/pkey: add CCA AES cipher key support (jsc#SLE-7533
  LTC#178844).
- s390/zcrypt: Add low level functions for CCA AES cipher keys
  (jsc#SLE-7533 LTC#178844).
- s390/zcrypt: extend cca_findcard function and helper
  (jsc#SLE-7533 LTC#178844).
- s390/pkey: pkey cleanup: narrow in-kernel API, fix some variable
  types (jsc#SLE-7533 LTC#178844).
- commit 5c983d1
* Wed Nov 27 2019 nsaenzjulienne@suse.de
- of: Make of_dma_get_range() work on bus nodes (jsc#SLE-7772).
- of/address: Fix of_pci_range_parser_one translation of DMA
  addresses (jsc#SLE-7772).
- of/address: Translate 'dma-ranges' for parent nodes missing
  'dma-ranges' (jsc#SLE-7772).
- of: Factor out #{addr,size}-cells parsing (jsc#SLE-7772).
- of: address: Follow DMA parent for "dma-coherent"
  (jsc#SLE-7772).
- of/address: Introduce of_get_next_dma_parent() helper
  (jsc#SLE-7772).
- commit 6061577
* Wed Nov 27 2019 msuchanek@suse.de
- ibmvnic: Serialize device queries (bsc#1155689 ltc#182047).
- ibmvnic: Bound waits for device queries (bsc#1155689
  ltc#182047).
- ibmvnic: Terminate waiting device threads after loss of service
  (bsc#1155689 ltc#182047).
- ibmvnic: Fix completion structure initialization (bsc#1155689
  ltc#182047).
- commit 0ff402a
* Wed Nov 27 2019 mkubecek@suse.cz
- config: refresh
- drop SOUNDWIRE from ppc64le/kvmsmall (no longer visible)
- update headers
- commit 1859c8f
* Wed Nov 27 2019 mgorman@suse.de
- Refresh
  patches.suse/sched-core-Further-clarify-sched_class-set_next_task.patch.
- Refresh
  patches.suse/sched-core-Make-pick_next_task_idle-more-consistent.patch.
- Refresh patches.suse/sched-core-Optimize-pick_next_task.patch.
- Refresh
  patches.suse/sched-core-Simplify-sched_class-pick_next_task.patch.
- Refresh
  patches.suse/sched-fair-Add-comments-for-group_type-and-balancing-at-SD_NUMA-level.patch.
- Refresh
  patches.suse/sched-fair-Better-document-newidle_balance.patch.
- Refresh patches.suse/sched-fair-Clean-up-asym-packing.patch.
- Refresh
  patches.suse/sched-fair-Fix-rework-of-find_idlest_group.patch.
- Refresh
  patches.suse/sched-fair-Optimize-find_idlest_group.patch.
- Refresh
  patches.suse/sched-fair-Remove-meaningless-imbalance-calculation.patch.
- Refresh
  patches.suse/sched-fair-Rename-sg_lb_stats-sum_nr_running-to-sum_h_nr_running.patch.
- Refresh patches.suse/sched-fair-Rework-find_idlest_group.patch.
- Refresh patches.suse/sched-fair-Rework-load_balance.patch.
- Refresh
  patches.suse/sched-fair-Spread-out-tasks-evenly-when-not-overloaded.patch.
- Refresh
  patches.suse/sched-fair-Use-load-instead-of-runnable-load-in-load_balance.patch.
- Refresh
  patches.suse/sched-fair-Use-load-instead-of-runnable-load-in-wakeup-path.patch.
- Refresh patches.suse/sched-fair-Use-mul_u32_u32.patch.
- Refresh
  patches.suse/sched-fair-Use-rq-nr_running-when-balancing-load.patch.
- Refresh
  patches.suse/sched-fair-Use-utilization-to-select-misfit-task.patch.
- Refresh
  patches.suse/sched-fair-util_est-Implement-faster-ramp-up-EWMA-on-utilization-increases.patch.
- Refresh
  patches.suse/sched-topology-Don-t-set-SD_BALANCE_WAKE-on-cpuset-domain-relax.patch.
- commit 20b4948
* Wed Nov 27 2019 mkubecek@suse.cz
- fix Patch-mainline tags
  fix Patch-mainline:
  patches.suse/0001-Bluetooth-btusb-fix-PM-leak-in-error-case-of-setup.patch
  patches.suse/0001-crypto-af_alg-cast-ki_complete-ternary-op-to-int.patch
  patches.suse/0001-crypto-algif_skcipher-Use-chunksize-instead-of-block.patch
  patches.suse/0001-crypto-ecdh-fix-big-endian-bug-in-ECC-library.patch
  patches.suse/0001-crypto-user-fix-memory-leak-in-crypto_report.patch
  patches.suse/0001-crypto-user-fix-memory-leak-in-crypto_reportstat.patch
  patches.suse/0001-libbpf-Fix-struct-end-padding-in-btf_dump.patch
- commit 03de6a8
* Wed Nov 27 2019 mkubecek@suse.cz
- series.conf: cleanup
  Keep the number of top level section reasonable.
- commit b91f28d
* Wed Nov 27 2019 tiwai@suse.de
- ALSA: usb-audio: Fix Focusrite Scarlett 6i6 gen1 - input
  handling (git-fixes).
- ALSA: usb-audio: Fix NULL dereference at parsing BADD
  (git-fixes).
- ALSA: usb-audio: Fix Scarlett 6i6 Gen 2 port data (git-fixes).
- ALSA: usb-audio: Add skip_validation option (git-fixes).
- ALSA: 6fire: Drop the dead code (git-fixes).
- ALSA: usb-audio: sound: usb: usb true/false for bool return type
  (git-fixes).
- commit f395c96
* Wed Nov 27 2019 tiwai@suse.de
- ALSA: docs: Update about the new PCM sync_stop ops (git-fixes).
- ALSA: pcm: Add card sync_irq field (git-fixes).
- ALSA: pcm: Add the support for sync-stop operation (git-fixes).
- ALSA: pcm: Move PCM_RUNTIME_CHECK() macro into local header
  (git-fixes).
- ALSA: docs: Update document about the default PCM ioctl ops
  (git-fixes).
- ALSA: pcm: Allow NULL ioctl ops (git-fixes).
- ALSA: docs: Update for managed buffer allocation mode
  (git-fixes).
- ALSA: pcm: Introduce managed buffer allocation mode (git-fixes).
- ALSA: timer: Fix the breakage of slave link open (git-fixes).
- ALSA: pcm: Yet another missing check of non-cached buffer type
  (git-fixes).
- ALSA: timer: Fix possible race at assigning a timer instance
  (git-fixes).
- ALSA: timer: Make snd_timer_close() returning void (git-fixes).
- ALSA: timer: Unify master/slave linking code (git-fixes).
- ALSA: timer: Limit max amount of slave instances (git-fixes).
- ALSA: docs: Remove snd_dma_pci_data() usage in documentation
  (git-fixes).
- ALSA: pcm: Create proc files only for non-empty preallocations
  (git-fixes).
- ALSA: pcm: Warn if doubly preallocated (git-fixes).
- ALSA: docs: Update documentation about SG- and vmalloc-buffers
  (git-fixes).
- ALSA: pcm: Handle special page mapping in the default mmap
  handler (git-fixes).
- ALSA: memalloc: Add vmalloc buffer allocation support
  (git-fixes).
- ALSA: memalloc: Allow NULL device for SNDRV_DMA_TYPE_CONTINUOUS
  type (git-fixes).
- commit a9f5790
* Wed Nov 27 2019 tiwai@suse.de
- ALSA: hda/realtek - Enable internal speaker of ASUS UX431FLC
  (git-fixes).
- ALSA: hda/hdmi - Clear codec->relaxed_resume flag at unbinding
  (git-fixes).
- ALSA: hda - Disable audio component for legacy Nvidia HDMI
  codecs (git-fixes).
- ALSA: hda/realtek - Enable the headset-mic on a Xiaomi's laptop
  (git-fixes).
- ALSA: hda/realtek - Move some alc236 pintbls to fallback table
  (git-fixes).
- ALSA: hda/realtek - Move some alc256 pintbls to fallback table
  (git-fixes).
- ALSA: hda - Add mute led support for HP ProBook 645 G4
  (git-fixes).
- ALSA: hda - Add DP-MST support for NVIDIA codecs (git-fixes).
- ALSA: hda - Add DP-MST support for non-acomp codecs (git-fixes).
- ALSA: hda - Add DP-MST jack support (git-fixes).
- ALSA: hda - Rename snd_hda_pin_sense to snd_hda_jack_pin_sense
  (git-fixes).
- ALSA: hda - remove forced polling workaround for CFL and CNL
  (git-fixes).
- ALSA: hda: hdmi - remove redundant code comments (git-fixes).
- ALSA: hda: hdmi - fix port numbering for ICL and TGL platforms
  (git-fixes).
- ALSA: hda/hdmi - Clean up Intel platform-specific fixup checks
  (git-fixes).
- ALSA: hda/hdmi - implement mst_no_extra_pcms flag (git-fixes).
- ALSA: hda: Disable regmap internal locking (git-fixes).
- ALSA: hda - Fix pending unsol events at shutdown (git-fixes).
- ALSA: hda: Allow HDA to be runtime suspended when dGPU is not
  bound to a driver (git-fixes).
- commit 81f6f50
* Wed Nov 27 2019 tiwai@suse.de
- media: vivid: Fix wrong locking that causes race conditions
  on streaming stop (CVE-2019-18683,bsc#1155897).
- media: rcar_drif: fix a memory disclosure
  (CVE-2019-18786,bsc#1156043).
- media: usb: fix memory leak in af9005_identify_state
  (CVE-2019-18809,bsc#1156258).
- commit 5b09130
* Wed Nov 27 2019 jgross@suse.com
- xen/gntdev: Use select for DMA_SHARED_BUFFER (bsc#1065600).
- commit 97a6782
* Wed Nov 27 2019 mgorman@suse.de
- sched/cpufreq: Move the cfs_rq_util_change() call to
  cpufreq_update_util() (bnc#1155798 (CPU scheduler functional
  and performance backports)).
- sched/pelt: Fix update of blocked PELT ordering (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Add comments for group_type and balancing at
  SD_NUMA level (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/fair: Fix rework of find_idlest_group() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/core: Further clarify sched_class::set_next_task()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Use mul_u32_u32() (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/core: Simplify sched_class::pick_next_task() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/core: Optimize pick_next_task() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/core: Make pick_next_task_idle() more consistent
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Better document newidle_balance() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair/util_est: Implement faster ramp-up EWMA on
  utilization increases (bnc#1155798 (CPU scheduler functional
  and performance backports)).
- sched/fair: Rework find_idlest_group() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/fair: Optimize find_idlest_group() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/fair: Use load instead of runnable load in wakeup
  path (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Use utilization to select misfit task (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Spread out tasks evenly when not overloaded
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Use load instead of runnable load in load_balance()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Use rq->nr_running when balancing load (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Rework load_balance() (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/fair: Remove meaningless imbalance calculation
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Rename sg_lb_stats::sum_nr_running to
  sum_h_nr_running (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/fair: Clean up asym packing (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched/topology: Don't set SD_BALANCE_WAKE on cpuset domain
  relax (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 0c439b5
* Tue Nov 26 2019 nsaenzjulienne@suse.de
- arm64: mm: reserve CMA and crashkernel in ZONE_DMA32
  (jsc#SLE-7772).
- commit 8dd0df2
* Tue Nov 26 2019 aaptel@suse.com
- cifs: move cifsFileInfo_put logic into a work-queue
  (bsc#1154355).
- commit 3fc1ff0
* Tue Nov 26 2019 aaptel@suse.com
- CIFS: Fix SMB2 oplock break processing (bsc#1154355).
- commit 6ea244c
* Tue Nov 26 2019 aaptel@suse.com
- cifs: add a helper to find an existing readable handle to a file
  (bsc#1154355).
- commit 86876f3
* Tue Nov 26 2019 aaptel@suse.com
- smb3: fix signing verification of large reads (bsc#1154355).
- commit 151844a
* Tue Nov 26 2019 aaptel@suse.com
- cifs: use existing handle for compound_op(OP_SET_INFO) when
  possible (bsc#1154355).
- commit bbed94e
* Tue Nov 26 2019 aaptel@suse.com
- cifs: create a helper to find a writeable handle by path name
  (bsc#1154355).
- Refresh
  patches.suse/smb3-improve-handling-of-share-deleted-and-share-recreated-.patch.
- commit b4e2014
* Tue Nov 26 2019 aaptel@suse.com
- smb3: Incorrect size for netname negotiate context
  (bsc#1154355).
- commit 2e876d6
* Tue Nov 26 2019 aaptel@suse.com
- cifs: prepare SMB2_Flush to be usable in compounds
  (bsc#1154355).
- commit 94efab3
* Tue Nov 26 2019 oneukum@suse.com
- libbpf: Fix struct end padding in btf_dump (git-fixes).
- commit 3ff85da
* Tue Nov 26 2019 oneukum@suse.com
- crypto: ecdh - fix big endian bug in ECC library (git-fixes).
- commit 3ed4e6a
* Tue Nov 26 2019 oneukum@suse.com
- crypto: user - fix memory leak in crypto_reportstat (git-fixes).
- commit 11b554d
* Tue Nov 26 2019 oneukum@suse.com
- crypto: user - fix memory leak in crypto_report (git-fixes).
- commit 905d0c3
* Tue Nov 26 2019 oneukum@suse.com
- crypto: af_alg - cast ki_complete ternary op to int (git-fixes).
- commit 62b6457
* Tue Nov 26 2019 oneukum@suse.com
- crypto: algif_skcipher - Use chunksize instead of blocksize
  (git-fixes).
- commit 638ebae
* Tue Nov 26 2019 aaptel@suse.com
- smb3: improve handling of share deleted (and share recreated)
  (bsc#1154355).
- Refresh
  patches.suse/smb3-fix-leak-in-open-on-server-perf-counter.patch.
- commit b021da1
* Tue Nov 26 2019 nsaenzjulienne@suse.de
- PCI: brcmstb: add MSI capability (jsc#SLE-7772).
- PCI: brcmstb: add Broadcom STB PCIe host controller driver
  (jsc#SLE-7772).
- config: arm64: enable RPi4 PCIe controller
- supported.conf: add pcie-brcmstb RPi4's PCIe controller
- linux/log2.h: Add roundup/rounddown_pow_two64() family of
  functions (jsc#SLE-7772).
- commit b2ce31d
* Tue Nov 26 2019 nsaenzjulienne@suse.de
- dma-mapping: treat dev->bus_dma_mask as a DMA limit
  (jsc#SLE-7772).
- dma-direct: exclude dma_direct_map_resource from the min_low_pfn
  check (jsc#SLE-7772).
- dma-direct: avoid a forward declaration for phys_to_dma
  (jsc#SLE-7772).
- dma-direct: unify the dma_capable definitions (jsc#SLE-7772).
- x86/PCI: sta2x11: use default DMA address translation
  (jsc#SLE-7772).
- dma-direct: check for overflows on 32 bit DMA addresses
  (jsc#SLE-7772).
- commit 94cc441
* Tue Nov 26 2019 msuchanek@suse.de
- powerpc/book3s64/hash: Use secondary hash for bolted mapping
  if the primary is full (bsc#1157778 ltc#182520).
- powerpc/pseries: Don't fail hash page table insert for bolted
  mapping (bsc#1157778 ltc#182520).
- powerpc/pseries: Don't opencode HPTE_V_BOLTED (bsc#1157778
  ltc#182520).
- commit b6eca43
* Tue Nov 26 2019 msuchanek@suse.de
- seltests/powerpc: Add a selftest for memcpy_mcsafe (bsc#1157774
  ltc#182579).
- powerpc/memcpy: Fix stack corruption for smaller sizes
  (bsc#1157774 ltc#182579).
- commit 34c7004
* Tue Nov 26 2019 msuchanek@suse.de
- Delete patches.suse/soundwire-depend-on-ACPI-OF.patch.
- Update config files.
- blacklist
- commit b6ee2ab
* Tue Nov 26 2019 nsaenzjulienne@suse.de
- PCI: rcar: Use inbound resources for setup (jsc#SLE-7772).
- PCI: iproc: Use inbound resources for setup (jsc#SLE-7772).
- PCI: xgene: Use inbound resources for setup (jsc#SLE-7772).
- PCI: v3-semi: Use inbound resources for setup (jsc#SLE-7772).
- PCI: ftpci100: Use inbound resources for setup (jsc#SLE-7772).
- PCI: of: Add inbound resource parsing to helpers (jsc#SLE-7772).
- Refresh: patches.suse/PCI-mobiveil-Make-mobiveil_host_init-can-be-used-to-.patch
- Refresh: patches.suse/PCI-mobiveil-Refactor-Mobiveil-PCIe-Host-Bridge-IP-d.patch
- PCI: versatile: Enable COMPILE_TEST (jsc#SLE-7772).
- PCI: versatile: Remove usage of PHYS_OFFSET (jsc#SLE-7772).
- PCI: versatile: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: xilinx-nwl: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: xilinx: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: xgene: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: v3-semi: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: rockchip: Drop storing driver private outbound resource
  data (jsc#SLE-7772).
- PCI: rockchip: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: mobiveil: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- Refresh patches.suse/PCI-mobiveil-Refactor-Mobiveil-PCIe-Host-Bridge-IP-d.patch.
- Refresh: patches.suse/PCI-mobiveil-Make-mobiveil_host_init-can-be-used-to-.patch
- PCI: mediatek: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: iproc: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: faraday: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: dwc: Use pci_parse_request_of_pci_ranges() (jsc#SLE-7772).
- PCI: altera: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: aardvark: Use pci_parse_request_of_pci_ranges()
  (jsc#SLE-7772).
- PCI: Export pci_parse_request_of_pci_ranges() (jsc#SLE-7772).
- resource: Add a resource_list_first_type helper (jsc#SLE-7772).
- commit 89f0599
* Tue Nov 26 2019 oneukum@suse.com
- Bluetooth: btusb: fix PM leak in error case of setup
  (git-fixes).
- virtio_console: allocate inbufs in add_port() only if it is
  needed (git-fixes).
- commit 74ff161
* Tue Nov 26 2019 yousaf.kaukab@suse.com
- config: arm64: enable options for nvidia jetson tx1
  References: jsc#SLE-9391
- commit 380d090
* Tue Nov 26 2019 nsaenzjulienne@suse.de
- arm64: mm: Fix unused variable warning in zone_sizes_init
  (jsc#SLE-7772).
- commit 6fb4438
* Tue Nov 26 2019 jlee@suse.com
- Delete
  patches.suse/0041-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mo.patch.
  (jsc#SLE-9870)
  This patch be replaced by
  patches.suse/0003-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mode.patch
- commit 736d395
* Tue Nov 26 2019 jlee@suse.com
- Delete patches.suse/0039-efi-Add-EFI_SECURE_BOOT-bit.patch.
  (jsc#SLE-9870)
  This patch be replaced by
  patches.suse/0002-efi-Add-an-EFI_SECURE_BOOT-flag-to-indicate-secure-boot-mode.patch
- commit 06804cf
* Tue Nov 26 2019 nmoreychaisemartin@suse.com
- RDMA/bnxt_re: Fix stat push into dma buffer on gen p5 devices (bsc#1157115)
- commit fc79fc5
* Tue Nov 26 2019 tiwai@suse.de
- ipmi: Fix memory leak in __ipmi_bmc_register
  (CVE-2019-19046,bsc#1157304).
- spi: lpspi: fix memory leak in fsl_lpspi_probe
  (CVE-2019-19064,bsc#1157300).
- spi: gpio: prevent memory leak in spi_gpio_probe
  (CVE-2019-19070,bsc#1157294).
- mwifiex: pcie: Fix memory leak in mwifiex_pcie_init_evt_ring
  (CVE-2019-19057,bsc#1157193).
- mwifiex: pcie: Fix memory leak in mwifiex_pcie_alloc_cmdrsp_buf
  (CVE-2019-19056,bsc#1157197).
- ath10k: fix memory leak (CVE-2019-19078,bsc#1157032).
- rtl8xxxu: prevent leaking urb (CVE-2019-19068,bsc#1157307).
- rtlwifi: prevent memory leak in rtl_usb_probe
  (CVE-2019-19063,bsc#1157298).
- rsi: release skb if rsi_prepare_beacon fails
  (CVE-2019-19071,bsc#1157067).
- crypto: user - fix memory leak in crypto_reportstat
  (CVE-2019-19050,bsc#1157336).
- crypto: user - fix memory leak in crypto_report
  (CVE-2019-19062,bsc#1157333).
- commit f284309
* Tue Nov 26 2019 jlee@suse.com
- efi: Lock down the kernel at the integrity level if booted in
  secure boot mode (jsc#SLE-9870).
- commit d022ad5
* Tue Nov 26 2019 mkubecek@suse.cz
- series.conf: cleanup
- rename patches.suse/scsi-qla2xxx-fix-wait-condition-in-loop.patch
  to patches.suse/scsi-qla2xxx-fix-NPIV-tear-down-process.patch
  (to match mainline commit subject)
- update upstream references and move into sorted section:
  patches.suse/arm64-Fake-the-IminLine-size-on-systems-affected-by-.patch
  patches.suse/arm64-compat-Workaround-Neoverse-N1-1542419-for-comp.patch
  patches.suse/arm64-errata-Hide-CTR_EL0.DIC-on-systems-affected-by.patch
  patches.suse/libertas-fix-a-potential-NULL-pointer-dereference.patch
  patches.suse/net-ath10k-Fix-a-NULL-ptr-deref-bug.patch
  patches.suse/scsi-qla2xxx-fix-NPIV-tear-down-process.patch
- move out of "almost mainline" section (the patch has been effectively
  rejected in this form):
  patches.suse/ibmveth-Update-ethtool-settings-to-reflect-virtual-p.patch
  No effect on expanded tree.
- commit ab5c717
* Tue Nov 26 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and resort:
  patches.suse/0001-arm64-mm-use-arm64_dma_phys_limit-instead-of-calling.patch
  patches.suse/0002-arm64-rename-variables-used-to-calculate-ZONE_DMA32-.patch
  patches.suse/0003-arm64-use-both-ZONE_DMA-and-ZONE_DMA32.patch
  patches.suse/0004-mm-refresh-ZONE_DMA-and-ZONE_DMA32-comments-in-enum-.patch
  patches.suse/Bluetooth-hci_bcm-Fix-RTS-handling-during-startup.patch
  patches.suse/net-bcmgenet-Add-BCM2711-support.patch
  patches.suse/net-bcmgenet-Add-RGMII_RXID-support.patch
  patches.suse/net-bcmgenet-Add-a-shutdown-callback.patch
  patches.suse/net-bcmgenet-Avoid-touching-non-existent-interrupt.patch
  patches.suse/net-bcmgenet-Fix-error-handling-on-IRQ-retrieval.patch
  patches.suse/net-bcmgenet-Generate-a-random-MAC-if-none-is-valid.patch
  patches.suse/net-bcmgenet-Refactor-register-access-in-bcmgenet_mi.patch
  No effect on expanded tree.
- commit 6d8a72c
* Tue Nov 26 2019 jlee@suse.com
- efi: Lock down the kernel if booted in secure boot mode
  (jsc#SLE-9870).
- Update config files. (jsc#SLE-9870)
- commit 7f8d57d
* Tue Nov 26 2019 jlee@suse.com
- efi: Add an EFI_SECURE_BOOT flag to indicate secure boot mode
  (jsc#SLE-9870).
- commit 4d3145f
* Tue Nov 26 2019 jlee@suse.com
- security: lockdown: expose a hook to lock the kernel down
  (jsc#SLE-9870).
- commit d2adcd5
* Mon Nov 25 2019 tonyj@suse.de
- perf/x86/intel: Support PEBS output to PT (jsc#SLE-8896).
- perf: Allow normal events to output AUX data (jsc#SLE-8896).
- commit bac2bbc
* Mon Nov 25 2019 mkubecek@suse.cz
- update patch references
  Update Patch-mainline:
  patches.suse/bdi-Add-bdi-id.patch
  patches.suse/fs-fs-writeback.c-fix-kernel-doc-warning.patch
  patches.suse/memcg-only-record-foreign-writebacks-with-dirty-pages-when-memcg-is-not-disabled.patch
  patches.suse/mm-debug.c-PageAnon-is-true-for-PageKsm-pages.patch
  patches.suse/mm-debug.c-__dump_page-prints-an-extra-line.patch
  patches.suse/mm-hmm-fix-hmm_range_fault-s-handling-of-swapped-out-pages.patch
  patches.suse/mm-memcontrol-update-lruvec-counters-in-mem_cgroup_move_account.patch
  patches.suse/mm-memory_hotplug-don-t-access-uninitialized-memmaps-in-shrink_pgdat_span.patch
  patches.suse/mm-memory_hotplug-fix-updating-the-node-span.patch
  patches.suse/mm-move-mem_cgroup_uncharge-out-of-__page_cache_release.patch
  patches.suse/mm-shrinker-make-shrinker-not-depend-on-memcg-kmem.patch
  patches.suse/mm-slab.c-fix-kernel-doc-warning-for-__ksize.patch
  patches.suse/mm-thp-extract-split_queue_-into-a-struct.patch
  patches.suse/mm-thp-make-deferred-split-shrinker-memcg-aware.patch
  patches.suse/writeback-Generalize-and-expose-wb_completion.patch
  patches.suse/writeback-Separate-out-wb_get_lookup-from-wb_get_create.patch
  patches.suse/writeback-fix-use-after-free-in-finish_writeback_work.patch
  patches.suse/writeback-memcg-Implement-cgroup_writeback_by_id.patch
  patches.suse/writeback-memcg-Implement-foreign-dirty-flushing.patch
- commit c99b532
* Mon Nov 25 2019 tiwai@suse.de
- Update patch reference for mlx5 driver fix (CVE-2019-19047 bsc#1157715)
- commit 9e3d31d
* Mon Nov 25 2019 tiwai@suse.de
- Update patch reference for vbox driver fix (CVE-2019-19048 bsc#1157720)
- commit a46881b
* Mon Nov 25 2019 mgorman@suse.de
- mm/memory_hotplug: fix updating the node span (git fixes
  (mm/memcontrol)).
- fs/fs-writeback.c: fix kernel-doc warning (git fixes
  (mm/memcontrol)).
- memcg: only record foreign writebacks with dirty pages when
  memcg is not disabled (git fixes (mm/memcontrol)).
- writeback: fix use-after-free in finish_writeback_work()
  (git fixes (mm/memcontrol)).
- commit cdafbd8
* Mon Nov 25 2019 msuchanek@suse.de
- powerpc/bpf: Fix tail call implementation (bsc#1157698).
- commit 68da2db
* Mon Nov 25 2019 mgorman@suse.de
- writeback, memcg: Implement cgroup_writeback_by_id() (git fixes
  (mm/memcontrol)).
- writeback: Separate out wb_get_lookup() from wb_get_create()
  (git fixes (mm/memcontrol)).
- bdi: Add bdi->id (git fixes (mm/memcontrol)).
- writeback: Generalize and expose wb_completion (git fixes
  (mm/memcontrol)).
- commit 14fbce3
* Mon Nov 25 2019 mgorman@suse.de
- mm/ksm.c: don't WARN if page is still mapped in
  remove_stable_node() (git fixes (mm/ksm).
- commit 89108e1
* Mon Nov 25 2019 mgorman@suse.de
- mm/memory_hotplug: don't access uninitialized memmaps in
  shrink_zone_span() (git fixes (mm/hotplug)).
- commit 990c666
* Mon Nov 25 2019 mgorman@suse.de
- mm/debug.c: PageAnon() is true for PageKsm() pages (git fixes
  (mm/debug)).
- mm/debug.c: __dump_page() prints an extra line (git fixes
  (mm/debug)).
- commit c8d910e
* Mon Nov 25 2019 mgorman@suse.de
- mm/memcontrol: update lruvec counters in mem_cgroup_move_account
  (git fixes (mm/memcontrol)).
- mm: thp: make deferred split shrinker memcg aware (git fixes
  (mm/memcontrol)).
- mm: shrinker: make shrinker not depend on memcg kmem (git fixes
  (mm/memcontrol)).
- mm: move mem_cgroup_uncharge out of __page_cache_release()
  (git fixes (mm/memcontrol)).
- mm: thp: extract split_queue_* into a struct (git fixes
  (mm/memcontrol)).
- writeback, memcg: Implement foreign dirty flushing (git fixes
  (mm/memcontrol)).
- commit 0f63fa2
* Mon Nov 25 2019 mgorman@suse.de
- mm/memory_hotplug: don't access uninitialized memmaps in
  shrink_pgdat_span() (git fixes (mm/hotplug)).
- commit 3e5e1ed
* Mon Nov 25 2019 mgorman@suse.de
- mm/slab.c: fix kernel-doc warning for __ksize() (git fixes
  (mm/slab)).
- commit 5cc4ee9
* Mon Nov 25 2019 mgorman@suse.de
- mm/hmm: fix hmm_range_fault()'s handling of swapped out pages
  (git fixes (mm/hmm)).
- commit c8ec9ab
* Mon Nov 25 2019 jslaby@suse.cz
- drm/i915/userptr: Try to acquire the page lock around
  set_page_dirty() (bnc#1156537).
- commit 60d22de
* Mon Nov 25 2019 tbogendoerfer@suse.de
- net-ipv6: IPV6_TRANSPARENT - check NET_RAW prior to NET_ADMIN
  (bsc#1154353).
- sfc: Only cancel the PPS workqueue if it exists (jsc#SLE-8314).
- net-sysfs: fix netdev_queue_add_kobject() breakage
  (bsc#1154353).
- net/mlxfw: Verify FSM error code translation doesn't exceed
  array size (jsc#SLE-8464).
- net/mlx5: Update the list of the PCI supported devices
  (jsc#SLE-8464).
- net/mlx5: Fix auto group size calculation (jsc#SLE-8464).
- net/mlx5e: Add missing capability bit check for IP-in-IP
  (jsc#SLE-8464).
- net/mlx5e: Do not use non-EXT link modes in EXT mode
  (jsc#SLE-8464).
- net/mlx5e: Fix set vf link state error flow (jsc#SLE-8464).
- net/mlx5: DR, Limit STE hash table enlarge based on bytemask
  (jsc#SLE-8464).
- net/mlx5: DR, Skip rehash for tables with byte mask zero
  (jsc#SLE-8464).
- net/mlx5: DR, Fix invalid EQ vector number on CQ creation
  (jsc#SLE-8464).
- net/mlx5e: Reorder mirrer action parsing to check for encap
  first (jsc#SLE-8464).
- net/mlx5e: Fix ingress rate configuration for representors
  (jsc#SLE-8464).
- net/mlx5e: Fix error flow cleanup in
  mlx5e_tc_tun_create_header_ipv4/6 (jsc#SLE-8464).
- ipv6/route: return if there is no fib_nh_gw_family
  (bsc#1154353).
- net-sysfs: Fix reference count leak in
  rx|netdev_queue_add_kobject (bsc#1154353).
- net: hns3: fix a wrong reset interrupt status mask
  (bsc#1154353).
- net/sched: act_pedit: fix WARN() in the traffic path
  (bsc#1154353).
- net: phylink: fix link mode modification in PHY mode
  (bsc#1154353).
- net: phylink: update documentation on create and destroy
  (bsc#1154353).
- taprio: don't reject same mqprio settings (bsc#1154353).
- net/tls: enable sk_msg redirect to tls socket egress
  (bsc#1154353).
- gve: fix dma sync bug where not all pages synced (bsc#1154353).
- net/mlx4_en: Fix wrong limitation for number of TX rings
  (jsc#SLE-8460).
- net: sched: ensure opts_len <= IP_TUNNEL_OPTS_MAX in
  act_tunnel_key (bsc#1154353).
- mlxsw: spectrum_router: Fix determining underlay for a GRE
  tunnel (bsc#1154488).
- net/mlx4_en: fix mlx4 ethtool -N insertion (jsc#SLE-8460).
- net: hns3: cleanup of stray struct hns3_link_mode_mapping
  (bsc#1154353).
- net: hns3: fix ETS bandwidth validation bug (bsc#1154353).
- net: hns3: reallocate SSU' buffer size when pfc_en changes
  (bsc#1154353).
- net: hns3: add compatible handling for MAC VLAN switch parameter
  configuration (bsc#1154353).
- RDMA/hns: Correct the value of srq_desc_size (jsc#SLE-8449).
- RDMA/hns: Correct the value of HNS_ROCE_HEM_CHUNK_LEN
  (jsc#SLE-8449).
- ixgbe: need_wakeup flag might not be set for Tx (jsc#SLE-7979
  jsc#SLE-7981).
- i40e: need_wakeup flag might not be set for Tx (jsc#SLE-8025).
- igb/igc: use ktime accessors for skb->tstamp (jsc#SLE-7967
  jsc#SLE-8010 jsc#SLE-7966).
- i40e: Fix for ethtool -m issue on X722 NIC (jsc#SLE-8025).
- iavf: initialize ITRN registers with correct values
  (jsc#SLE-7940).
- ice: fix potential infinite loop because loop counter being
  too small (jsc#SLE-7926).
- net: hns3: add compatible handling for command
  HCLGE_OPC_PF_RST_DONE (bsc#1154353).
- net/mlx5e: Use correct enum to determine uplink port
  (jsc#SLE-8464).
- net/mlx5: DR, Fix memory leak during rule creation
  (jsc#SLE-8464).
- net/mlx5: DR, Fix memory leak in modify action destroy
  (jsc#SLE-8464).
- net/mlx5e: Fix eswitch debug print of max fdb flow
  (jsc#SLE-8464).
- bridge: ebtables: don't crash when using dnat target in output
  chains (bsc#1154353).
- mlx4_core: fix wrong comment about the reason of subtract one
  from the max_cqes (jsc#SLE-8460).
- net: hns3: Use the correct style for SPDX License Identifier
  (bsc#1154353).
- taprio: fix panic while hw offload sched list swap
  (bsc#1154353).
- net: sched: taprio: fix -Wmissing-prototypes warnings
  (bsc#1154353).
- net: update net_dim documentation after rename (bsc#1154353).
- net: taprio: Fix returning EINVAL when configuring without flags
  (bsc#1154353).
- taprio: Add support for hardware offloading (bsc#1154353).
- taprio: remove unused variable 'entry_list_policy'
  (bsc#1154353).
- commit 3090b61
* Mon Nov 25 2019 jslaby@suse.cz
- Linux 5.3.13 (bnc#1151927 5.3.13).
- arm64: uaccess: Ensure PAN is re-enabled after unhandled
  uaccess fault (bnc#1151927 5.3.13).
- net: cdc_ncm: Signedness bug in cdc_ncm_set_dgram_size()
  (bnc#1151927 5.3.13).
- block, bfq: deschedule empty bfq_queues not referred by any
  process (bnc#1151927 5.3.13).
- mm/memory_hotplug: fix updating the node span (bnc#1151927
  5.3.13).
- mm/memory_hotplug: don't access uninitialized memmaps in
  shrink_pgdat_span() (bnc#1151927 5.3.13).
- fbdev: Ditch fb_edid_add_monspecs (bnc#1151927 5.3.13).
- commit 0c2740a
* Mon Nov 25 2019 mbrugger@suse.com
- driver core: simplify definitions of platform_get_irq*
  (jsc#SLE-7772).
- mm: refresh ZONE_DMA and ZONE_DMA32 comments in 'enum zone_type'
  (jsc#SLE-7772).
- arm64: use both ZONE_DMA and ZONE_DMA32 (jsc#SLE-7772).
  Enable CONFIG_ZONE_DMA and CONFIG_BOUNCE
- arm64: rename variables used to calculate ZONE_DMA32's size
  (jsc#SLE-7772).
- arm64: mm: use arm64_dma_phys_limit instead of calling
  max_zone_dma_phys() (jsc#SLE-7772).
- net: bcmgenet: Add RGMII_RXID support (jsc#SLE-7772).
- net: bcmgenet: Refactor register access in bcmgenet_mii_config
  (jsc#SLE-7772).
- net: bcmgenet: Add BCM2711 support (jsc#SLE-7772).
- net: bcmgenet: Fix error handling on IRQ retrieval
  (jsc#SLE-7772).
- net: bcmgenet: Avoid touching non-existent interrupt
  (jsc#SLE-7772).
- Bluetooth: hci_bcm: Fix RTS handling during startup
  (jsc#SLE-7772).
- net: bcmgenet: Add a shutdown callback (jsc#SLE-7772).
- net: bcmgenet: Generate a random MAC if none is valid
  (jsc#SLE-7772).
- clocksource/drivers/sh_mtu2: Do not loop using
  platform_get_irq_by_name() (jsc#SLE-7772).
- net: bcmgenet: reapply manual settings to the PHY
  (jsc#SLE-7772).
- Revert "net: bcmgenet: soft reset 40nm EPHYs before MAC init"
  (jsc#SLE-7772).
- net: bcmgenet: use RGMII loopback for MAC reset (jsc#SLE-7772).
- iommu/ipmmu-vmsa: Only call platform_get_irq() when interrupt
  is mandatory (jsc#SLE-7772).
- iommu/rockchip: Don't use platform_get_irq to implicitly count
  irqs (jsc#SLE-7772).
- mmc: sdhci-iproc: fix spurious interrupts on Multiblock reads
  with bcm2711 (jsc#SLE-7772).
- mmc: sh_mmcif: Use platform_get_irq_optional() for optional
  interrupt (jsc#SLE-7772).
- mmc: renesas_sdhi: Do not use platform_get_irq() to count
  interrupts (jsc#SLE-7772).
- platform/x86: intel_punit_ipc: Avoid error message when
  retrieving IRQ (jsc#SLE-7772).
- tty: serial: imx: Use platform_get_irq_optional() for optional
  IRQs (jsc#SLE-7772).
- serial: sh-sci: Use platform_get_irq_optional() for optional
  interrupts (jsc#SLE-7772).
- clk: bcm2835: Mark PLLD_PER as CRITICAL (jsc#SLE-7772).
- clk: bcm2835: Add BCM2711_CLOCK_EMMC2 support (jsc#SLE-7772).
- clk: bcm2835: Introduce SoC specific clock registration
  (jsc#SLE-7772).
- dt-bindings: bcm2835-cprman: Add bcm2711 support (jsc#SLE-7772).
- pinctrl: bcm2835: Pass irqchip when adding gpiochip
  (jsc#SLE-7772).
- pinctrl: bcm2835: Add support for BCM2711 pull-up functionality
  (jsc#SLE-7772).
- bluetooth: hci_bcm: Give more time to come out of reset
  (jsc#SLE-7772).
- bluetooth: bcm: Add support for loading firmware for BCM4345C5
  (jsc#SLE-7772).
- Bluetooth: hci_bcm: Fix -Wunused-const-variable warnings
  (jsc#SLE-7772).
- net: bcmgenet: use devm_platform_ioremap_resource() to simplify
  code (jsc#SLE-7772).
- driver core: platform: Export platform_get_irq_optional()
  (jsc#SLE-7772).
- driver core: platform: Introduce platform_get_irq_optional()
  (jsc#SLE-7772).
- driver core: platform: Add an error message to
  platform_get_irq*() (jsc#SLE-7772).
- mmc: bcm2835: Take SWIOTLB memory size limitation into account
  (jsc#SLE-7772).
- mmc: Remove dev_err() usage after platform_get_irq()
  (jsc#SLE-7772).
- mmc: sdhci-iproc: Add support for emmc2 of the BCM2711
  (jsc#SLE-7772).
- commit 24df065
* Mon Nov 25 2019 mkubecek@suse.cz
- config: disable SECURITY_DMESG_RESTRICT (bsc#1157066)
  Enabling this option which restricts access to dmesg was not intentional
  and happened accidentally as part of a commit aiming to enable features
  which were enabled in SLE. We might restrict dmesg in the future if there
  is a consensus but for now the proper action is to revert this accidental
  change which only affected some architectures anyway.
- commit 8898c88
* Mon Nov 25 2019 glin@suse.com
- bpf, offload: Unlock on error in bpf_offload_dev_create()
  (bsc#1155518).
- commit dc0b929
* Fri Nov 22 2019 mkubecek@suse.cz
- config: refresh
  Just unify the headers.
- commit f54dfa4
* Fri Nov 22 2019 jslaby@suse.cz
- Refresh
  patches.suse/btrfs-fix-log-context-list-corruption-after-rename-e.patch.
  Update upstream status.
- commit 9923f87
* Fri Nov 22 2019 jslaby@suse.cz
- Linux 5.3.12 (bnc#1151927 5.3.12).
- iommu/vt-d: Fix QI_DEV_IOTLB_PFSID and QI_DEV_EIOTLB_PFSID
  macros (bnc#1151927 5.3.12).
- i2c: acpi: Force bus speed to 400KHz if a Silead touchscreen
  is present (bnc#1151927 5.3.12).
- x86/quirks: Disable HPET on Intel Coffe Lake platforms
  (bnc#1151927 5.3.12).
- net/smc: fix fastopen for non-blocking connect() (bnc#1151927
  5.3.12).
- net: gemini: add missed free_netdev (bnc#1151927 5.3.12).
- ax88172a: fix information leak on short answers (bnc#1151927
  5.3.12).
- slcan: Fix memory leak in error path (bnc#1151927 5.3.12).
- slip: Fix memory leak in slip_open error path (bnc#1151927
  5.3.12).
- net: usb: qmi_wwan: add support for Foxconn T77W968 LTE modules
  (bnc#1151927 5.3.12).
- dpaa2-eth: free already allocated channels on probe defer
  (bnc#1151927 5.3.12).
- net/smc: fix refcount non-blocking connect() -part 2
  (bnc#1151927 5.3.12).
- mlxsw: core: Enable devlink reload only on probe (bnc#1151927
  5.3.12).
- devlink: Add method for time-stamp on reporter's dump
  (bnc#1151927 5.3.12).
- tcp: remove redundant new line from tcp_event_sk_skb
  (bnc#1151927 5.3.12).
- devlink: disallow reload operation during device cleanup
  (bnc#1151927 5.3.12).
- mm/page_io.c: do not free shared swap slots (bnc#1151927
  5.3.12).
- mm/memory_hotplug: fix try_offline_node() (bnc#1151927 5.3.12).
- mm: slub: really fix slab walking for init_on_free (bnc#1151927
  5.3.12).
- mm: hugetlb: switch to css_tryget() in
  hugetlb_cgroup_charge_cgroup() (bnc#1151927 5.3.12).
- mm: memcg: switch to css_tryget() in get_mem_cgroup_from_mm()
  (bnc#1151927 5.3.12).
- mm: mempolicy: fix the wrong return value and potential pages
  leak of mbind (bnc#1151927 5.3.12).
- Input: synaptics-rmi4 - destroy F54 poller workqueue when
  removing (bnc#1151927 5.3.12).
- Input: ff-memless - kill timer in destroy() (bnc#1151927
  5.3.12).
- io_uring: ensure registered buffer import returns the IO length
  (bnc#1151927 5.3.12).
- drm/i915: update rawclk also on resume (bnc#1151927 5.3.12).
- ecryptfs_lookup_interpose(): lower_dentry->d_parent is not
  stable either (bnc#1151927 5.3.12).
- ecryptfs_lookup_interpose(): lower_dentry->d_inode is not stable
  (bnc#1151927 5.3.12).
- IB/hfi1: TID RDMA WRITE should not return
  IB_WC_RNR_RETRY_EXC_ERR (bnc#1151927 5.3.12).
- IB/hfi1: Calculate flow weight based on QP MTU for TID RDMA
  (bnc#1151927 5.3.12).
- IB/hfi1: Ensure r_tid_ack is valid before building TID RDMA
  ACK packet (bnc#1151927 5.3.12).
- IB/hfi1: Ensure full Gen3 speed in a Gen4 system (bnc#1151927
  5.3.12).
- Input: synaptics-rmi4 - clear IRQ enables for F54 (bnc#1151927
  5.3.12).
- Input: synaptics-rmi4 - do not consume more data than we have
  (F11, F12) (bnc#1151927 5.3.12).
- Input: synaptics-rmi4 - disable the relative position IRQ in
  the F12 driver (bnc#1151927 5.3.12).
- KVM: MMU: Do not treat ZONE_DEVICE pages as being reserved
  (bnc#1151927 5.3.12).
- cgroup: freezer: call cgroup_enter_frozen() with preemption
  disabled in ptrace_stop() (bnc#1151927 5.3.12).
- scsi: core: Handle drivers which set sg_tablesize to zero
  (bnc#1151927 5.3.12).
- commit 5f76c3b
* Fri Nov 22 2019 jslaby@suse.cz
- Update
  patches.suse/0003-Revert-drm-i915-ehl-Update-MOCS-table-for-EHL.patch
  (bsc#1152489 bnc#1151927 5.3.12).
- Update
  patches.suse/ALSA-usb-audio-Fix-incorrect-NULL-check-in-create_ya.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/ALSA-usb-audio-Fix-incorrect-size-check-for-processi.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/ALSA-usb-audio-Fix-missing-error-check-at-mixer-reso.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/ALSA-usb-audio-not-submit-urb-for-stopped-endpoint.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/IB-hfi1-Use-a-common-pad-buffer-for-9B-and-16B-packe.patch
  (jsc#SLE-8449 bnc#1151927 5.3.12).
- Update
  patches.suse/Input-synaptics-rmi4-fix-video-buffer-size.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/btrfs-fix-log-context-list-corruption-after-rename-e.patch
  (bsc#1156494 bnc#1151927 5.3.12).
- Update
  patches.suse/ipmr-Fix-skb-headroom-in-ipmr_get_route.patch
  (git-fixes bnc#1151927 5.3.12).
- Update patches.suse/mmc-sdhci-of-at91-fix-quirk2-overwrite.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/net-ethernet-dwmac-sun8i-Use-the-correct-function-in.patch
  (git-fixes bnc#1151927 5.3.12).
- Update
  patches.suse/ntp-y2038-Remove-incorrect-time_t-truncation.patch
  (git-fixes bnc#1151927 5.3.12).
- commit 4df5d22
* Thu Nov 21 2019 lpechacek@suse.com
- Add crypto modules required by tcrypt (FIPS)
  References: bsc#1153192
- commit 465a0e6
* Wed Nov 20 2019 msuchanek@suse.de
- Refresh patches.suse/scsi-sr-wait-for-the-medium-to-become-ready.patch.
  Fix refleak on -ENXIO.
- commit c02819b
* Wed Nov 20 2019 tiwai@suse.de
- mdio_bus: Fix init if CONFIG_RESET_CONTROLLER=n (git-fixes).
- opp: Reinitialize the list_kref before adding the static OPPs
  again (git-fixes).
- commit 61e3e2f
* Wed Nov 20 2019 tiwai@suse.de
- lib: Remove select of inexistant GENERIC_IO (git-fixes).
- opp: Don't decrement uninitialized list_kref (git-fixes).
- opp: Not all power-domains are scalable (git-fixes).
- commit 85c2a10
* Wed Nov 20 2019 tiwai@suse.de
- software node: Initialize the return value in
  software_node_to_swnode() (git-fixes).
- commit e35cf03
* Wed Nov 20 2019 tiwai@suse.de
- selftests: mlxsw: Adjust test to recent changes (git-fixes).
- selftests: bpf: Skip write only files in debugfs (git-fixes).
- selftests/bpf: fix race in flow dissector tests (git-fixes).
- commit 7648c5c
* Wed Nov 20 2019 tiwai@suse.de
- riscv: fp: add missing __user pointer annotations (git-fixes).
- riscv: init: merge split string literals in preprocessor
  directive (git-fixes).
- riscv: tlbflush: remove confusing comment on
  local_flush_tlb_all() (git-fixes).
- commit d38ab66
* Wed Nov 20 2019 tiwai@suse.de
- ntp/y2038: Remove incorrect time_t truncation (git-fixes).
- NFC: nxp-nci: Fix NULL pointer dereference after I2C
  communication error (git-fixes).
- commit 0b6da77
* Wed Nov 20 2019 tiwai@suse.de
- ipmr: Fix skb headroom in ipmr_get_route() (git-fixes).
- mdio_bus: Fix PTR_ERR applied after initialization to constant
  (git-fixes).
- net: ethernet: dwmac-sun8i: Use the correct function in exit
  path (git-fixes).
- idr: Fix idr_get_next_ul race with idr_remove (git-fixes).
- commit b4c1f6c
* Wed Nov 20 2019 tiwai@suse.de
- i2c: core: fix use after free in of_i2c_notify (git-fixes).
- commit d2cbfd2
* Wed Nov 20 2019 tiwai@suse.de
- arm64: hibernate: check pgd table allocation (git-fixes).
- arm64: cpufeature: Treat ID_AA64ZFR0_EL1 as RAZ when SVE is
  not enabled (git-fixes).
- ARM: aspeed: ast2500 is ARMv6K (git-fixes).
- ARM: 8896/1: VDSO: Don't leak kernel addresses (git-fixes).
- ARM: ux500: add missing of_node_put() (git-fixes).
- commit cb4b4ca
* Wed Nov 20 2019 tiwai@suse.de
- Update patch reference for nl80211 fix (CVE-2019-19055 bsc#1157319)
- commit f616ca4
* Wed Nov 20 2019 tiwai@suse.de
- Update patch reference for can driver fix (CVE-2019-19052 bsc#1157324)
- commit 02e7eba
* Wed Nov 20 2019 bp@suse.de
- x86/resctrl: Fix potential lockdep warning (bsc#1152489).
- x86/resctrl: Prevent NULL pointer dereference when reading
  mondata (bsc#1152489).
- commit c754fb9
* Tue Nov 19 2019 tiwai@suse.de
- Update patch reference for another iio driver fix (CVE-2019-19061 bsc#1157192)
- commit 75969fc
* Tue Nov 19 2019 tiwai@suse.de
- Update s390 patch reference for cpu idle time calculation (bsc#1156773)
- commit 71d745b
* Tue Nov 19 2019 tiwai@suse.de
- Update patch reference for amdgpu fix (CVE-2019-19067 bsc#1157180)
- commit 294533e
* Tue Nov 19 2019 tiwai@suse.de
- Update patch reference for iio driver fix (CVE-2019-19060 bsc#1157178)
- commit 572806f
* Tue Nov 19 2019 tiwai@suse.de
- Update patch reference for of-unittest fix (CVE-2019-19049 bsc#1157173)
- commit 6bfcd8f
* Tue Nov 19 2019 tiwai@suse.de
- Update patch reference for ieee802154 security fix (CVE-2019-19075 bsc#1157162)
- commit 0855aff
* Tue Nov 19 2019 pmladek@suse.com
- tracing: Have error path in predicate_parse() free its allocated
  memory (bsc#1157069 CVE-2019-19072).
- commit 387f713
* Tue Nov 19 2019 tiwai@suse.de
- iwlwifi: dbg_ini: fix memory leak in alloc_sgtable
  (CVE-2019-19058,bsc#1157145).
- commit cb8333d
* Tue Nov 19 2019 tiwai@suse.de
- ath9k: release allocated buffer if timed out
  (CVE-2019-19074,bsc#1157143).
- commit 98c32c1
* Tue Nov 19 2019 tzimmermann@suse.de
- Revert "drm/etnaviv: fix dumping of iommuv2 (bsc#1152472)"
  This reverts commit 48b3bfdd21261e7df15f5aebe2ccb1cc61521bd0.
  ATM the backported patch doesn't build on arm64.
- commit c35e5f9
* Tue Nov 19 2019 dwagner@suse.de
- Drop scsi-qla2xxx-Fix-memory-leak-when-sending-I-O-fails.patch
  This patch has introduces an double free. Upstream has dropped it from
  the scsi-queue before it hit mainline. So let's drop it as well.
- commit 44fa42b
* Mon Nov 18 2019 tiwai@suse.de
- ath9k_htc: release allocated buffer if timed out
  (CVE-2019-19073,bsc#1157070).
- commit 08bd2bd
* Mon Nov 18 2019 tiwai@suse.de
- Update patch reference for fastrpc bug fix (CVE-2019-19069 bsc#1157064)
- commit 69da730
* Mon Nov 18 2019 tiwai@suse.de
- Update patch reference for amdgpu security fix (CVE-2019-19083 bsc#1157049)
- commit 7f52050
* Mon Nov 18 2019 tiwai@suse.de
- drm/amd/display: prevent memory leak
  (CVE-2019-19082,bsc#1157046).
- commit fca18a5
* Mon Nov 18 2019 tzimmermann@suse.de
- Revert "drm/i915/ehl: Update MOCS table for EHL" (bsc#1152489)
- commit 76a5ebd
* Mon Nov 18 2019 tzimmermann@suse.de
- drm/i915/gvt: fix dropping obj reference twice (bsc#1152489)
- commit 4f5c644
* Mon Nov 18 2019 tzimmermann@suse.de
- drm/etnaviv: fix dumping of iommuv2 (bsc#1152472)
- commit 48b3bfd
* Sat Nov 16 2019 tiwai@suse.de
- mmc: sdhci-of-at91: fix quirk2 overwrite (git-fixes).
- Input: synaptics-rmi4 - fix video buffer size (git-fixes).
- commit 22c351b
* Fri Nov 15 2019 tiwai@suse.de
- ALSA: usb-audio: Fix incorrect size check for
  processing/extension units (git-fixes).
- ALSA: usb-audio: Fix incorrect NULL check in
  create_yamaha_midi_quirk() (git-fixes).
- ALSA: pcm: Fix stream lock usage in snd_pcm_period_elapsed()
  (git-fixes).
- ALSA: usb-audio: not submit urb for stopped endpoint
  (git-fixes).
- ALSA: hda: hdmi - fix pin setup on Tigerlake (git-fixes).
- ALSA: hda: Add Cometlake-S PCI ID (git-fixes).
- ALSA: usb-audio: Fix missing error check at mixer resolution
  test (git-fixes).
- commit 8e17c40
* Fri Nov 15 2019 msuchanek@suse.de
- powerpc/xive: Prevent page fault issues in the machine crash
  handler (bsc#1156882 ltc#182435).
- commit 7d95bd5
* Thu Nov 14 2019 msuchanek@suse.de
- Refresh patches.suse/bdev-add-open_finish.patch.
- commit 687caa9
* Thu Nov 14 2019 mkubecek@suse.cz
- supported.conf: drop dax_pmem_compat
  This module is no longer built (jsc#SLE-10690).
- commit 359a9f7
* Thu Nov 14 2019 fdmanana@suse.com
- Btrfs: remove unnecessary condition in btrfs_clone() to avoid
  too much nesting (bsc#1156782).
- commit 4154585
* Thu Nov 14 2019 fdmanana@suse.com
- Btrfs: fix ENOSPC errors, leading to transaction aborts,
  when cloning extents (bsc#1156782).
- commit 6466273
* Thu Nov 14 2019 fdmanana@suse.com
- Btrfs: factor out extent dropping code from hole punch handler
  (bsc#1156782).
- commit 037e1c6
* Thu Nov 14 2019 hare@suse.de
- scsi: virtio_scsi: unplug LUNs when events missed
  (bsc#1156419,jsc#SLE-8281).
- scsi: fcoe: fix null-ptr-deref Read in fc_release_transport
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs-hisi: use devm_platform_ioremap_resource() to
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufshcd: use devm_platform_ioremap_resource() to
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: use devm_platform_ioremap_resource() to
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Use kmemdup in ufshcd_read_string_desc()
  (bsc#1156419,jsc#SLE-8281).
- scsi: arm64: dts: qcom: sdm845: Specify UFS device-reset GPIO
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs-qcom: Implement device_reset vops
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Introduce vops for resetting device
  (bsc#1156419,jsc#SLE-8281).
- scsi: sd: Improve unaligned completion resid message
  (bsc#1156419,jsc#SLE-8281).
- scsi: fnic: fix msix interrupt allocation
  (bsc#1156419,jsc#SLE-8281).
- scsi: fnic: print port speed only at driver init or speed
  (bsc#1156419,jsc#SLE-8281).
- commit fdbb6dd
* Thu Nov 14 2019 hare@suse.de
- scsi: core: fix dh and multipathing for SCSI hosts without
  request batching (bsc#1156419,jsc#SLE-8281).
- scsi: core: fix missing .cleanup_rq for SCSI hosts without
  request batching (bsc#1156419,jsc#SLE-8281).
- commit add131d
* Thu Nov 14 2019 hare@suse.de
- scsi: ufs: remove set but not used variable 'val'
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: remove set but not used variable 'irq_value'
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: fix broken hba->outstanding_tasks
  (bsc#1156419,jsc#SLE-8281).
- scsi: fcoe: remove redundant call to skb_transport_header
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Disable local LCC in .link_startup_notify() in
  Cadence UFS (bsc#1156419,jsc#SLE-8281).
- scsi: bfa: remove redundant assignment to variable error
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs-qcom: Make structure ufs_hba_qcom_vops constant
  (bsc#1156419,jsc#SLE-8281).
- scsi: fnic: remove redundant assignment of variable rc
  (bsc#1156419,jsc#SLE-8281).
- scsi: use __u{8,16,32,64} instead of uint{8,16,32,64}_t in
  uapi headers (bsc#1156419,jsc#SLE-8281).
- scsi: esas2r: Prefer pcie_capability_read_word()
  (bsc#1156419,jsc#SLE-8281).
- scsi: sym53c8xx_2: remove redundant assignment to retv
  (bsc#1156419,jsc#SLE-8281).
- scsi: pmcraid: Fix a typo - pcmraid --> pmcraid
  (bsc#1156419,jsc#SLE-8281).
- commit 6f40ae3
* Thu Nov 14 2019 hare@suse.de
- Update config files: disable CONFIG_DEV_DAX_PMEM_COMPAT (jsc#SLE-10690)
- commit 56d1ae7
* Thu Nov 14 2019 hare@suse.de
- scsi: lpfc: Update lpfc version to 12.6.0.2
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: revise nvme max queues to be hdwq count
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Initialize cpu_map for not present cpus
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix inlining of lpfc_sli4_cleanup_poll_list()
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix: Coverity: lpfc_cmpl_els_rsp(): Null pointer
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix: Coverity: lpfc_get_scsi_buf_s3(): Null
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix lpfc_cpumask_of_node_init()
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix a kernel warning triggered by
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.6.0.1
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add enablement of multiple adapter dumps
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Change default IRQ model on AMD architectures
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add registration for CPU Offline/Online events
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Clarify FAWNN error message
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Sync with FC-NVMe-2 SLER change to require Conf
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix dynamic fw log enablement check
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix unexpected error messages during RSCN
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix kernel crash at lpfc_nvme_info_show during
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix configuration of BB credit recovery in
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix duplicate unreg_rpi error in port offline
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Make lpfc_debugfs_ras_log_data static
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix NULL check before mempool_destroy is not
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix spelling error in MAGIC_NUMER_xxx
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix build error of lpfc_debugfs.c for
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: lpfc_nvmet: Fix Use plain integer as NULL pointer
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: lpfc_attr: Fix Use plain integer as NULL pointer
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.6.0.0
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add additional discovery log messages
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add FC-AL support to lpe32000 models
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add FA-WWN Async Event reporting
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Add log macros to allow print by serverity or
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Make FW logging dynamically configurable
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Revise interrupt coalescing for missing scenarios
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Remove lock contention target write path
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Slight fast-path performance optimizations
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix coverity error of dereference after null
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix hardlockup in lpfc_abort_handler
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix bad ndlp ptr in xri aborted handling
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix SLI3 hba in loop mode not discovering devices
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix lockdep errors in sli_ringtx_put
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: Fix reporting of read-only fw error errors
  (bsc#1156632,jsc#SLE-8654).
- scsi: lpfc: fix lpfc_nvmet_mrq to be bound by hdw queue count
  (bsc#1156632,jsc#SLE-8654).
- scsi: megaraid_sas: remove unused variables 'debugBlk','fusion'
  (bsc#1156632,jsc#SLE-10720).
- scsi: megaraid_sas: Unique names for MSI-X vectors
  (bsc#1156632,jsc#SLE-10720).
- scsi: smartpqi: bump version to 1.2.10-025
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: Align driver syntax with oob
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: remove unused manifest constants
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: fix problem with unique ID for physical
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: correct syntax issue (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: change TMF timeout from 60 to 30 seconds
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: fix LUN reset when fw bkgnd thread is hung
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add inquiry timeouts (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: fix call trace in device discovery
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: fix controller lockup observed during force
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: remove set but not used variable 'ctrl_info'
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: clean up indentation of a statement
  (bsc#1156632,jsc#SLE-8633).
- scsi: mpt3sas: Bump mpt3sas driver version to 32.100.00.00
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Fix module parameter max_msix_vectors
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Reject NVMe Encap cmnds to unsupported HBA
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Use Component img header to get Package ver
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Fail release cmnd if diag buffer is released
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Add app owned flag support for diag buffer
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Reuse diag buffer allocated at load time
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: clear release bit when buffer reregistered
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Maintain owner of buffer through UniqueID
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Free diag buffer without any status check
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Fix clear pending bit in ioctl status
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Display message before releasing diag buffer
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Register trace buffer based on NVDATA settings
  (bsc#1156632,jsc#SLE-10717).
- scsi: bnx2fc: Handle scope bits when array returns BUSY or
  (jsc#SLE-9696).
- scsi: bnx2fc: remove set but not used variables (jsc#SLE-9696).
- scsi: bnx2fc: remove set but not used variable 'fh'
  (jsc#SLE-9696).
- scsi: smartpqi: bump version to 1.2.8-026
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: update copyright (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add new pci ids (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: correct REGNEWD return status
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add gigabyte controller
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: correct hang when deleting 32 lds
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add bay identifier (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add sysfs entries (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add module param to hide vsep
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add pci ids for fiberhome controller
  (bsc#1156632,jsc#SLE-8633).
- scsi: smartpqi: add module param for exposure order
  (bsc#1156632,jsc#SLE-8633).
- scsi: mpt3sas: Introduce module parameter to override queue
  depth (bsc#1156632,jsc#SLE-10717).
- scsi: csiostor: Prefer pcie_capability_read_word()
  (jsc#SLE-9687).
- scsi: megaraid_sas: Introduce module parameter for default
  queue depth (bsc#1156632,jsc#SLE-10720).
- scsi: mpt3sas: Update driver version to 31.100.00.00
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Run SAS DEVICE STATUS CHANGE EVENT from ISR
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Reduce the performance drop
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Handle fault during HBA initialization
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Add sysfs to know supported features
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Support MEMORY MOVE Tool box command
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Allow ioctls to blocked access status NVMe
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Enumerate SES of a managed PCIe switch
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Update MPI headers to 2.6.8 spec
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Gracefully handle online firmware update
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: memset request frame before reusing
  (bsc#1156632,jsc#SLE-10717).
- scsi: mpt3sas: Add support for PCIe Lane margin
  (bsc#1156632,jsc#SLE-10717).
- scsi: pm80xx: remove redundant assignments to variable rc
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Consolidate internal abort calls in LU reset
  operation (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: replace "%%p" with "%%pK"
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Remove some unnecessary code
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Modify return type of debugfs functions
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Drop free_irq() when devm_request_irq() failed
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Drop SMP resp frame DMA mapping
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Drop kmap_atomic() in SMP command completion
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Make slot buf minimum allocation of PAGE_SIZE
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Don't bother clearing status buffer IU in task
  prep (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Fix out of bound at debug_I_T_nexus_reset()
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Snapshot AXI and RAS register at debugfs
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Snapshot HW cache of IOST and ITCT at debugfs
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Fix pointer usage error in show debugfs
  IOST/ITCT (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Drop hisi_sas_hw.get_free_slot
  (bsc#1156419,jsc#SLE-8281).
- scsi: hisi_sas: Make max IPTT count equal for all hw revisions
  (bsc#1156419,jsc#SLE-8281).
- scsi: ncr53c8xx: Mark expected switch fall-through
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Configure clock in .hce_enable_notify() in Cadence
  UFS (bsc#1156419,jsc#SLE-8281).
- scsi: core: Complain if scsi_target_block() fails
  (bsc#1156419,jsc#SLE-8281).
- scsi: core: Make scsi_internal_device_unblock_nowait() reject
  invalid new_state (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: revamp string descriptor reading
  (bsc#1156419,jsc#SLE-8281).
- scsi: wd33c93: Mark expected switch fall-through
  (bsc#1156419,jsc#SLE-8281).
- scsi: sun3_scsi: Mark expected switch fall-throughs
  (bsc#1156419,jsc#SLE-8281).
- scsi: qlogicpti: Mark expected switch fall-throughs
  (bsc#1156419,jsc#SLE-8281).
- scsi: ibmvfc: Mark expected switch fall-throughs
  (bsc#1156419,jsc#SLE-8281).
- scsi: megaraid_sas: Fix a compilation warning
  (bsc#1156419,jsc#SLE-8281).
- scsi: megaraid_sas: Make a bunch of functions static
  (bsc#1156419,jsc#SLE-8281).
- scsi: mpt3sas: support target smid for [abort|query] task
  (bsc#1156419,jsc#SLE-8281).
- scsi: ibmvscsi_tgt: Mark expected switch fall-throughs
  (bsc#1156419,jsc#SLE-8281).
- scsi: mpt3sas: clean up a couple sizeof() uses
  (bsc#1156419,jsc#SLE-8281).
- scsi: scsi_debugfs: Use for_each_set_bit to simplify code
  (bsc#1156419,jsc#SLE-8281).
- scsi: fdomain_isa: use CFG1_IRQ_MASK (bsc#1156419,jsc#SLE-8281).
- scsi: fdomain: use BSTAT_{MSG|CMD|IO} in fdomain_work()
  (bsc#1156419,jsc#SLE-8281).
- scsi: fdomain: use BCTL_RST in fdomain_reset()
  (bsc#1156419,jsc#SLE-8281).
- scsi: aic94xx: Remove unnecessary null check
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: change msleep to usleep_range
  (bsc#1156419,jsc#SLE-8281).
- scsi: virtio_scsi: implement request batching
  (bsc#1156419,jsc#SLE-8281).
- scsi: core: add support for request batching
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Add history of fatal events
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Do not reset error history during host reset
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Add fatal and auto-hibern8 error history
  (bsc#1156419,jsc#SLE-8281).
- scsi: ufs: Change names related to error history
  (bsc#1156419,jsc#SLE-8281).
- commit 9419833
* Thu Nov 14 2019 msuchanek@suse.de
- powerpc/security/book3s64: Report L1TF status in sysfs
  (bsc#1091041).
- commit 4c13792
* Thu Nov 14 2019 guillaume.gardet@arm.com
- arm64: Enable CONFIG_IR_GPIO_CIR (boo#1156748)
- commit f832bd8
* Thu Nov 14 2019 msuchanek@suse.de
- Refresh patches.suse/powerpc-fadump-when-fadump-is-supported-register-the.patch.
  Add upstream metadata.
- commit eb3a775
* Thu Nov 14 2019 msuchanek@suse.de
- powerpc/security: Fix wrong message when RFI Flush is disable
  (bsc#1131107).
- commit f4d03f9
* Thu Nov 14 2019 msuchanek@suse.de
- powerpc/pseries: safely roll back failed DLPAR cpu add
  (bsc#1156700 ltc#182459).
- powerpc/pseries: address checkpatch warnings in
  dlpar_offline_cpu (bsc#1156700 ltc#182459).
- commit ce23e84
* Thu Nov 14 2019 mkubecek@suse.cz
- series.conf: cleanup
  Move queued patches into "almost mainline" section.
- commit b0c29ce
* Wed Nov 13 2019 yousaf.kaukab@suse.com
- arm64: compat: Workaround Neoverse-N1 #1542419 for compat
  user-space (jsc#SLE-10259).
- arm64: Fake the IminLine size on systems affected by Neoverse-N1
  [#1542419] (jsc#SLE-10259).
- arm64: errata: Hide CTR_EL0.DIC on systems affected by
  Neoverse-N1 #1542419 (jsc#SLE-10259).
  Update arm64 configs (eneable ARM64_ERRATUM_1542419).
- commit ecac0a4
* Wed Nov 13 2019 dwagner@suse.de
- scsi: qla2xxx: don't use zero for FC4_PRIORITY_NVME
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: initialize fc4_type_priority (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix a dma_pool_free() call (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove an include directive (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Update driver version to 10.01.00.21-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix device connect issues in P2P configuration
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix memory leak when sending I/O fails
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix double scsi_done for abort path (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix driver unload hang (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix SRB leak on switch command timeout
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Do command completion on abort timeout
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Retry PLOGI on FC-NVMe PRLI failure (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- commit e0be784
* Wed Nov 13 2019 dwagner@suse.de
- Refresh series.conf
- commit 043b271
* Wed Nov 13 2019 mkubecek@suse.cz
- config: disable TSX by default
  The reasons for leaving TSX enabled by default in SLE15-SP2 do not apply to
  openSUSE so let's use the safer default as we do in Tumbleweed.
- commit 07d6fe1
* Wed Nov 13 2019 ohering@suse.de
- hv_netvsc: Fix error handling in netvsc_set_features()
  (fate#323887).
- commit 2074f53
* Wed Nov 13 2019 mkubecek@suse.cz
- config: leave TSX enabled by default
  This is to preserve the behaviour of previous SLE versions. Users who
  wnat to disable TSX can use "tsx=off" on command line.
- commit f1407d4
* Wed Nov 13 2019 tiwai@suse.de
- Update patch references for i915 security fixes (CVE-2019-0154 bsc#1135966 CVE-2019-0155 bsc#1135967)
- commit 697e88e
* Wed Nov 13 2019 jslaby@suse.cz
- Linux 5.3.11 (bnc#1151927 5.3.11).
- x86/speculation/taa: Fix printing of TAA_MSG_SMT on IBRS_ALL
  CPUs (bnc#1151927 5.3.11).
- Documentation: Add ITLB_MULTIHIT documentation (bnc#1151927
  5.3.11).
- kvm: x86: mmu: Recovery of shattered NX large pages (bnc#1151927
  5.3.11).
- kvm: Add helper function for creating VM worker threads
  (bnc#1151927 5.3.11).
- kvm: mmu: ITLB_MULTIHIT mitigation (bnc#1151927 5.3.11).
- cpu/speculation: Uninline and export CPU mitigations helpers
  (bnc#1151927 5.3.11).
- x86/cpu: Add Tremont to the cpu vulnerability whitelist
  (bnc#1151927 5.3.11).
- x86/bugs: Add ITLB_MULTIHIT bug infrastructure (bnc#1151927
  5.3.11).
- x86/tsx: Add config options to set tsx=on|off|auto (bnc#1151927
  5.3.11).
- Update config files.
  Set CONFIG_X86_INTEL_TSX_MODE_OFF=y (the default).
- x86/speculation/taa: Add documentation for TSX Async Abort
  (bnc#1151927 5.3.11).
- x86/tsx: Add "auto" option to the tsx= cmdline parameter
  (bnc#1151927 5.3.11).
- kvm/x86: Export MDS_NO=0 to guests when TSX is enabled
  (bnc#1151927 5.3.11).
- x86/speculation/taa: Add sysfs reporting for TSX Async Abort
  (bnc#1151927 5.3.11).
- x86/speculation/taa: Add mitigation for TSX Async Abort
  (bnc#1151927 5.3.11).
- x86/cpu: Add a "tsx=" cmdline option with TSX disabled by
  default (bnc#1151927 5.3.11).
- x86/cpu: Add a helper function x86_read_arch_cap_msr()
  (bnc#1151927 5.3.11).
- x86/msr: Add the IA32_TSX_CTRL MSR (bnc#1151927 5.3.11).
- drm/i915/cmdparser: Fix jump whitelist clearing (bnc#1151927
  5.3.11).
- drm/i915/gen8+: Add RC6 CTX corruption WA (bnc#1151927 5.3.11).
- drm/i915: Lower RM timeout to avoid DSI hard hangs (bnc#1151927
  5.3.11).
- drm/i915/cmdparser: Ignore Length operands during command
  matching (bnc#1151927 5.3.11).
- drm/i915/cmdparser: Add support for backward jumps (bnc#1151927
  5.3.11).
- drm/i915/cmdparser: Use explicit goto for error paths
  (bnc#1151927 5.3.11).
- drm/i915: Add gen9 BCS cmdparsing (bnc#1151927 5.3.11).
- drm/i915: Allow parsing of unsized batches (bnc#1151927 5.3.11).
- drm/i915: Support ro ppgtt mapped cmdparser shadow buffers
  (bnc#1151927 5.3.11).
- drm/i915: Add support for mandatory cmdparsing (bnc#1151927
  5.3.11).
- drm/i915: Remove Master tables from cmdparser (bnc#1151927
  5.3.11).
- drm/i915: Disable Secure Batches for gen6+ (bnc#1151927 5.3.11).
- drm/i915: Rename gen7 cmdparser tables (bnc#1151927 5.3.11).
- ARM: dts: stm32: change joystick pinctrl definition on
  stm32mp157c-ev1 (bnc#1151927 5.3.11).
- ARM: sunxi: Fix CPU powerdown on A83T (bnc#1151927 5.3.11).
- ARM: dts: imx6-logicpd: Re-enable SNVS power key (bnc#1151927
  5.3.11).
- iio: srf04: fix wrong limitation in distance measuring
  (bnc#1151927 5.3.11).
- intel_th: pci: Add Jasper Lake PCH support (bnc#1151927 5.3.11).
- intel_th: pci: Add Comet Lake PCH support (bnc#1151927 5.3.11).
- x86/dumpstack/64: Don't evaluate exception stacks before setup
  (bnc#1151927 5.3.11).
- x86/apic/32: Avoid bogus LDR warnings (bnc#1151927 5.3.11).
- timekeeping/vsyscall: Update VDSO data unconditionally
  (bnc#1151927 5.3.11).
- perf tools: Fix time sorting (bnc#1151927 5.3.11).
- SMB3: Fix persistent handles reconnect (bnc#1151927 5.3.11).
- btrfs: save i_size to avoid double evaluation of i_size_read
  in compress_file_range (bnc#1151927 5.3.11).
- btrfs: tree-checker: Fix wrong check on max devid (bnc#1151927
  5.3.11).
- btrfs: Consider system chunk array size for new SYSTEM chunks
  (bnc#1151927 5.3.11).
- qede: fix NULL pointer deref in __qede_remove() (bnc#1151927
  5.3.11).
- net: fix data-race in neigh_event_send() (bnc#1151927 5.3.11).
- vsock/virtio: fix sock refcnt holding during the shutdown
  (bnc#1151927 5.3.11).
- net: ethernet: octeon_mgmt: Account for second possible VLAN
  header (bnc#1151927 5.3.11).
- ipv4: Fix table id reference in fib_sync_down_addr (bnc#1151927
  5.3.11).
- ipv6: fixes rt6_probe() and fib6_nh->last_probe init
  (bnc#1151927 5.3.11).
- net: hns: Fix the stray netpoll locks causing deadlock in NAPI
  path (bnc#1151927 5.3.11).
- net: usb: qmi_wwan: add support for DW5821e with eSIM support
  (bnc#1151927 5.3.11).
- CDC-NCM: handle incomplete transfer of MTU (bnc#1151927 5.3.11).
- NFC: st21nfca: fix double free (bnc#1151927 5.3.11).
- netfilter: ipset: Copy the right MAC address in hash:ip,mac
  IPv6 sets (bnc#1151927 5.3.11).
- netfilter: ipset: Fix an error code in ip_set_sockfn_get()
  (bnc#1151927 5.3.11).
- netfilter: nf_tables: Align nft_expr private data to 64-bit
  (bnc#1151927 5.3.11).
- net/smc: fix ethernet interface refcounting (bnc#1151927
  5.3.11).
- selftests/tls: add test for concurrent recv and send
  (bnc#1151927 5.3.11).
- net/tls: add a TX lock (bnc#1151927 5.3.11).
- net/tls: don't pay attention to sk_write_pending when pushing
  partial records (bnc#1151927 5.3.11).
- net: mscc: ocelot: fix NULL pointer on LAG slave removal
  (bnc#1151927 5.3.11).
- net: mscc: ocelot: don't handle netdev events for other netdevs
  (bnc#1151927 5.3.11).
- NFC: fdp: fix incorrect free object (bnc#1151927 5.3.11).
- net: prevent load/store tearing on sk->sk_stamp (bnc#1151927
  5.3.11).
- net: qualcomm: rmnet: Fix potential UAF when unregistering
  (bnc#1151927 5.3.11).
- net/tls: fix sk_msg trim on fallback to copy mode (bnc#1151927
  5.3.11).
- net: sched: prevent duplicate flower rules from tcf_proto
  destroy race (bnc#1151927 5.3.11).
- bonding: fix state transition issue in link monitoring
  (bnc#1151927 5.3.11).
- cgroup,writeback: don't switch wbs immediately on dead wbs if
  the memcg is dead (bnc#1151927 5.3.11).
- blkcg: make blkcg_print_stat() print stats only for online blkgs
  (bnc#1151927 5.3.11).
- ceph: don't allow copy_file_range when stripe_count != 1
  (bnc#1151927 5.3.11).
- ceph: don't try to handle hashed dentries in non-O_CREAT
  atomic_open (bnc#1151927 5.3.11).
- ceph: add missing check in d_revalidate snapdir handling
  (bnc#1151927 5.3.11).
- ceph: fix RCU case handling in ceph_d_revalidate() (bnc#1151927
  5.3.11).
- ceph: fix use-after-free in __ceph_remove_cap() (bnc#1151927
  5.3.11).
- arm64: Do not mask out PTE_RDONLY in pte_same() (bnc#1151927
  5.3.11).
- cpufreq: intel_pstate: Fix invalid EPB setting (bnc#1151927
  5.3.11).
- drm/radeon: fix si_enable_smc_cac() failed issue (bnc#1151927
  5.3.11).
- clk: imx8m: Use SYS_PLL1_800M as intermediate parent of CLK_ARM
  (bnc#1151927 5.3.11).
- mm: memcontrol: fix network errors from failing __GFP_ATOMIC
  charges (bnc#1151927 5.3.11).
- mm: slab: make page_cgroup_ino() to recognize non-compound
  slab pages properly (bnc#1151927 5.3.11).
- dump_stack: avoid the livelock of the dump_lock (bnc#1151927
  5.3.11).
- mm/khugepaged: fix might_sleep() warn with CONFIG_HIGHPTE=y
  (bnc#1151927 5.3.11).
- mm, vmstat: hide /proc/pagetypeinfo from normal users
  (bnc#1151927 5.3.11).
- ocfs2: protect extent tree in ocfs2_prepare_inode_for_write()
  (bnc#1151927 5.3.11).
- mm: thp: handle page cache THP correctly in PageTransCompoundMap
  (bnc#1151927 5.3.11).
- mm: memcontrol: fix NULL-ptr deref in percpu stats flush
  (bnc#1151927 5.3.11).
- clone3: validate stack arguments (bnc#1151927 5.3.11).
- tools: gpio: Use !building_out_of_srctree to determine srctree
  (bnc#1151927 5.3.11).
- usbip: Fix free of unallocated memory in vhci tx (bnc#1151927
  5.3.11).
- usbip: tools: Fix read_usb_vudc_device() error path handling
  (bnc#1151927 5.3.11).
- USB: ldusb: use unsigned size format specifiers (bnc#1151927
  5.3.11).
- USB: Skip endpoints with 0 maxpacket length (bnc#1151927
  5.3.11).
- usb: dwc3: remove the call trace of USBx_GFLADJ (bnc#1151927
  5.3.11).
- usb: gadget: configfs: fix concurrent issue between composite
  APIs (bnc#1151927 5.3.11).
- usb: gadget: composite: Fix possible double free memory bug
  (bnc#1151927 5.3.11).
- usb: fsl: Check memory resource before releasing it (bnc#1151927
  5.3.11).
- scsi: sd: define variable dif as unsigned int instead of bool
  (bnc#1151927 5.3.11).
- scsi: lpfc: Honor module parameter lpfc_use_adisc (bnc#1151927
  5.3.11).
- scsi: ufs-bsg: Wake the device before sending raw upiu commands
  (bnc#1151927 5.3.11).
- powerpc/32s: fix allow/prevent_user_access() when crossing
  segment boundaries (bnc#1151927 5.3.11).
- gve: Fixes DMA synchronization (bnc#1151927 5.3.11).
- iwlwifi: pcie: 0x2720 is qu and 0x30DC is not (bnc#1151927
  5.3.11).
- iwlwifi: pcie: fix all 9460 entries for qnj (bnc#1151927
  5.3.11).
- iwlwifi: pcie: fix PCI ID 0x2720 configs that should be soc
  (bnc#1151927 5.3.11).
- net: ethernet: arc: add the missed clk_disable_unprepare
  (bnc#1151927 5.3.11).
- hv_netvsc: Fix error handling in netvsc_attach() (bnc#1151927
  5.3.11).
- net: mscc: ocelot: refuse to overwrite the port's native vlan
  (bnc#1151927 5.3.11).
- net: mscc: ocelot: fix vlan_filtering when enslaving to bridge
  before link is up (bnc#1151927 5.3.11).
- selftests/bpf: More compatible nc options in test_tc_edt
  (bnc#1151927 5.3.11).
- net: phy: smsc: LAN8740: add PHY_RST_AFTER_CLK_EN flag
  (bnc#1151927 5.3.11).
- net: stmmac: Fix the problem of tso_xmit (bnc#1151927 5.3.11).
- NFSv4: Don't allow a cached open with a revoked delegation
  (bnc#1151927 5.3.11).
- nvme-multipath: fix possible io hang after ctrl reconnect
  (bnc#1151927 5.3.11).
- sched/topology: Allow sched_asym_cpucapacity to be disabled
  (bnc#1151927 5.3.11).
- sched/topology: Don't try to build empty sched domains
  (bnc#1151927 5.3.11).
- perf/x86/uncore: Fix event group support (bnc#1151927 5.3.11).
- perf/x86/amd/ibs: Handle erratum #420 only on the affected
  CPU family (10h) (bnc#1151927 5.3.11).
- perf/x86/amd/ibs: Fix reading of the IBS OpData register and
  thus precise RIP validity (bnc#1151927 5.3.11).
- x86, efi: Never relocate kernel below lowest acceptable address
  (bnc#1151927 5.3.11).
- efi: libstub/arm: Account for firmware reserved memory at the
  base of RAM (bnc#1151927 5.3.11).
- arm64: apply ARM64_ERRATUM_843419 workaround for Brahma-B53 core
  (bnc#1151927 5.3.11).
- arm64: Brahma-B53 is SSB and spectre v2 safe (bnc#1151927
  5.3.11).
- arm64: apply ARM64_ERRATUM_845719 workaround for Brahma-B53 core
  (bnc#1151927 5.3.11).
- arm64: cpufeature: Enable Qualcomm Falkor errata 1009 for Kryo
  (bnc#1151927 5.3.11).
- dc.c:use kzalloc without test (bnc#1151927 5.3.11).
- drm/amd/display: Passive DP->HDMI dongle detection fix
  (bnc#1151927 5.3.11).
- drm/amd/display: add 50us buffer as WA for pstate switch in
  active (bnc#1151927 5.3.11).
- drm/amd/display: do not synchronize "drr" displays (bnc#1151927
  5.3.11).
- drm/amdgpu: If amdgpu_ib_schedule fails return back the error
  (bnc#1151927 5.3.11).
- drm/sched: Set error to s_fence if HW job submission failed
  (bnc#1151927 5.3.11).
- drm/amdgpu/sdma5: do not execute 0-sized IBs (v2) (bnc#1151927
  5.3.11).
- dmaengine: xilinx_dma: Fix control reg update in
  vdma_channel_set_config (bnc#1151927 5.3.11).
- dmaengine: xilinx_dma: Fix 64-bit simple AXIDMA transfer
  (bnc#1151927 5.3.11).
- iommu/amd: Apply the same IVRS IOAPIC workaround to Acer Aspire
  A315-41 (bnc#1151927 5.3.11).
- ARC:: Enable on-board SPI NOR flash IC (bnc#1151927 5.3.11).
- HID: intel-ish-hid: fix wrong error handling in
  ishtp_cl_alloc_tx_ring() (bnc#1151927 5.3.11).
- HID: google: add magnemite/masterball USB ids (bnc#1151927
  5.3.11).
- arm64: errata: Update stale comment (bnc#1151927 5.3.11).
- soundwire: bus: set initial value to port_status (bnc#1151927
  5.3.11).
- configfs: fix a deadlock in configfs_symlink() (bnc#1151927
  5.3.11).
- usbip: Implement SG support to vhci-hcd and stub driver
  (bnc#1151927 5.3.11).
- perf map: Use zalloc for map_groups (bnc#1151927 5.3.11).
- commit 8a2e23a
* Wed Nov 13 2019 jslaby@suse.cz
- mm, meminit: recalculate pcpu batch and high limits after init
  completes (bnc#1155628).
  Update to upstream version (and update metadata).
- commit 8d03909
* Wed Nov 13 2019 jslaby@suse.cz
- Update
  patches.suse/ALSA-bebob-fix-to-detect-configured-source-of-sampli.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-hda-ca0132-Fix-possible-workqueue-stall.patch
  (bsc#1155836 bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-timer-Fix-incorrectly-assigned-timer-instance.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Clean-up-check_input_term.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Fix-copy-paste-error-in-the-validator.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Fix-possible-NULL-dereference-at-crea.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-More-validations-of-descriptor-units.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Remove-superfluous-bLength-checks.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Simplify-parse_audio_unit.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ALSA-usb-audio-Unify-the-release-of-usb_mixer_elem_i.patch
  (git-fixes bnc#1151927 5.3.11).
- Update patches.suse/ALSA-usb-audio-remove-some-dead-code.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ASoC-SOF-Intel-hda-stream-fix-the-CONFIG_-prefix-mis.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ASoC-rsnd-dma-fix-SSI9-4-5-6-7-busif-dma-address.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/HID-wacom-generic-Treat-serial-number-and-related-fi.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/IB-core-Use-rdma_read_gid_l2_fields-to-compare-GID-L.patch
  (jsc#SLE-8449 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-hns-Prevent-memory-leaks-of-eq-buf_list.patch
  (jsc#SLE-8449 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-iw_cxgb4-Avoid-freeing-skb-twice-in-arp-failure.patch
  (jsc#SLE-8392 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-mlx5-Clear-old-rate-limit-when-closing-QP.patch
  (jsc#SLE-8446 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-nldev-Skip-counter-if-port-doesn-t-match.patch
  (jsc#SLE-8449 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-qedr-Fix-reported-firmware-version.patch
  (jsc#SLE-8215 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-siw-free-siw_base_qp-in-kref-release-routine.patch
  (jsc#SLE-8381 bnc#1151927 5.3.11).
- Update
  patches.suse/RDMA-uverbs-Prevent-potential-underflow.patch
  (jsc#SLE-8449 bnc#1151927 5.3.11).
- Update
  patches.suse/SUNRPC-Destroy-the-back-channel-when-we-destroy-the-.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/SUNRPC-The-RDMA-back-channel-mustn-t-disappear-while.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/SUNRPC-The-TCP-back-channel-mustn-t-disappear-while-.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/bonding-fix-unexpected-IFF_BONDING-bit-unset.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/bonding-fix-using-uninitialized-mode_lock.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/bonding-use-dynamic-lockdep-key-instead-of-subclass.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/bpf-Fix-use-after-free-in-bpf_get_prog_name.patch
  (bsc#1155518 bnc#1151927 5.3.11).
- Update
  patches.suse/bpf-Fix-use-after-free-in-subprog-s-jited-symbol-rem.patch
  (bsc#1155518 bnc#1151927 5.3.11).
- Update
  patches.suse/bpf-lwtunnel-Fix-reroute-supplying-invalid-dst.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/can-c_can-c_can_poll-only-read-status-register-after.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-dev-add-missing-of_node_put-after-calling-of_get.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-flexcan-disable-completely-the-ECC-mechanism.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-gs_usb-gs_can_open-prevent-memory-leak.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-mcba_usb-fix-use-after-free-on-disconnect.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-peak_usb-fix-a-potential-out-of-sync-while-decod.patch
  (git-fixes bnc#1151927 5.3.11).
- Update patches.suse/can-peak_usb-fix-slab-info-leak.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-rx-offload-can_rx_offload_queue_sorted-fix-error.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/can-usb_8dev-fix-use-after-free-on-disconnect.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/dmaengine-sprd-Fix-the-link-list-pointer-register-co.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/dmaengine-sprd-Fix-the-possible-memory-leak-issue.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/drm-v3d-Fix-memory-leak-in-v3d_submit_cl_ioctl.patch
  (git-fixes bnc#1151927 5.3.11).
- Update patches.suse/e1000-fix-memory-leaks.patch (jsc#SLE-8100
  bnc#1151927 5.3.11).
- Update
  patches.suse/efi-tpm-Return-EINVAL-when-determining-tpm-final-eve.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/fjes-Handle-workqueue-allocation-failure.patch
  (CVE-2019-16231,bsc#1150466 bnc#1151927 5.3.11).
- Update patches.suse/hwmon-ina3221-Fix-read-timeout-issue.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/igb-Fix-constant-media-auto-sense-switching-when-no-.patch
  (jsc#SLE-7967 jsc#SLE-8010 bnc#1151927 5.3.11).
- Update patches.suse/iio-adc-stm32-adc-fix-stopping-dma.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/iio-imu-adis16480-make-sure-provided-frequency-is-po.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/iio-imu-inv_mpu6050-fix-no-data-on-MPU6050.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/intel_th-gth-Fix-the-window-switching-sequence.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/ipvs-don-t-ignore-errors-in-case-refcounting-ip_vs-m.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/ipvs-move-old_secure_tcp-into-struct-netns_ipvs.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/iw_cxgb4-fix-ECN-check-on-the-passive-accept.patch
  (jsc#SLE-8392 bnc#1151927 5.3.11).
- Update
  patches.suse/kvm-x86-powerpc-do-not-allow-clearing-largepages-debugfs-entry
  (bsc#1117665 bnc#1151927 5.3.11).
- Update
  patches.suse/macsec-fix-refcnt-leak-in-module-exit-routine.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/mm-filemap.c-don-t-initiate-writeback-if-mapping-has-no-dirty-pages.patch
  (bnc#1155780 (VM/FS functional and performance backports)
  bnc#1151927 5.3.11).
- Update
  patches.suse/mm-meminit-Recalculate-pcpu-batch-and-high-limits-after-init-completes.patch
  (bnc#1155628 bnc#1151927 5.3.11).
- Update
  patches.suse/mt76-dma-fix-buffer-unmap-with-non-linear-skbs.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/net-hisilicon-Fix-Trying-to-free-already-free-IRQ.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/net-ibmvnic-unlock-rtnl_lock-in-reset-so-linkwatch_e.patch
  (bsc#1152457 ltc#174432 bnc#1151927 5.3.11).
- Update
  patches.suse/net-mlx5-fix-memory-leak-in-mlx5_fw_fatal_reporter_d.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11).
- Update
  patches.suse/net-mlx5-prevent-memory-leak-in-mlx5_fpga_conn_creat.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11).
- Update
  patches.suse/net-mlx5e-TX-Fix-consumer-index-of-error-cqe-dump.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11).
- Update
  patches.suse/net-mlx5e-Tx-Fix-assumption-of-single-WQEBB-of-NOP-i.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11).
- Update
  patches.suse/net-mlx5e-kTLS-Release-reference-on-DUMPed-fragments.patch
  (jsc#SLE-8464 bnc#1151927 5.3.11).
- Update
  patches.suse/net-openvswitch-free-vport-unless-register_netdevice.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/netfilter-nf_flow_table-set-timeout-before-insertion.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/netfilter-nft_payload-fix-missing-check-for-matching.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- Update
  patches.suse/nfc-netlink-fix-double-device-reference-drop.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/pinctrl-cherryview-Fix-irq_valid_mask-calculation.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/pinctrl-intel-Avoid-potential-glitches-if-pin-is-in-.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/r8169-fix-page-read-in-r8168g_mdio_read.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/scsi-lpfc-Check-queue-pointer-before-use.patch
  (bsc#1154242 bnc#1151927 5.3.11).
- Update
  patches.suse/scsi-qla2xxx-Initialized-mailbox-to-prevent-driver-l.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.11).
- Update
  patches.suse/scsi-qla2xxx-fixup-incorrect-usage-of-host_byte.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.11).
- Update
  patches.suse/scsi-qla2xxx-stop-timer-in-shutdown-path.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.11).
- Update patches.suse/soundwire-depend-on-ACPI-OF.patch
  (bsc#1148868 bnc#1151927 5.3.11).
- Update patches.suse/soundwire-depend-on-ACPI.patch (bsc#1148868
  bnc#1151927 5.3.11).
- Update
  patches.suse/usb-dwc3-gadget-fix-race-when-disabling-ep-with-canc.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/usb-dwc3-pci-prevent-memory-leak-in-dwc3_pci_probe.patch
  (git-fixes, CVE-2019-18813, bsc#1156278 bnc#1151927 5.3.11).
- Update patches.suse/usb-dwc3-select-CONFIG_REGMAP_MMIO.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/usb-gadget-udc-atmel-Fix-interrupt-storm-in-FIFO-mod.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/virt_wifi-fix-refcnt-leak-in-module-exit-routine.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/wimax-i2400-Fix-memory-leak-in-i2400m_op_rfkill_sw_t.patch
  (git-fixes bnc#1151927 5.3.11).
- Update
  patches.suse/xsk-Fix-registration-of-Rx-only-sockets.patch
  (bsc#1154353 bnc#1151927 5.3.11).
- commit 334001e
* Wed Nov 13 2019 jslaby@suse.cz
- Linux 5.3.10 (bnc#1151927 5.3.10).
- selftests: net: reuseport_dualstack: fix uninitalized parameter
  (bnc#1151927 5.3.10).
- rxrpc: Fix handling of last subpacket of jumbo packet
  (bnc#1151927 5.3.10).
- net/mlx5: Fix flow counter list auto bits struct (bnc#1151927
  5.3.10).
- net/smc: fix refcounting for non-blocking connect() (bnc#1151927
  5.3.10).
- net: usb: lan78xx: Disable interrupts before calling
  generic_handle_irq() (bnc#1151927 5.3.10).
- net: ethernet: ftgmac100: Fix DMA coherency issue with SW
  checksum (bnc#1151927 5.3.10).
- selftests: fib_tests: add more tests for metric update
  (bnc#1151927 5.3.10).
- net/smc: keep vlan_id for SMC-R in smc_listen_work()
  (bnc#1151927 5.3.10).
- net/smc: fix closing of fallback SMC sockets (bnc#1151927
  5.3.10).
- perf kmem: Fix memory leak in compact_gfp_flags() (bnc#1151927
  5.3.10).
- perf c2c: Fix memory leak in build_cl_output() (bnc#1151927
  5.3.10).
- perf tools: Fix resource leak of closedir() on the error paths
  (bnc#1151927 5.3.10).
- irqchip/sifive-plic: Skip contexts except supervisor in
  plic_init() (bnc#1151927 5.3.10).
- irqchip/gic-v3-its: Use the exact ITSList for VMOVP (bnc#1151927
  5.3.10).
- cifs: Fix cifsInodeInfo lock_sem deadlock when reconnect occurs
  (bnc#1151927 5.3.10).
- CIFS: Fix retry mid list corruption on reconnects (bnc#1151927
  5.3.10).
- MIPS: bmips: mark exception vectors as char arrays (bnc#1151927
  5.3.10).
- nbd: handle racing with error'ed out commands (bnc#1151927
  5.3.10).
- nbd: protect cmd->status with cmd->lock (bnc#1151927 5.3.10).
- scsi: hpsa: add missing hunks in reset-patch (bnc#1151927
  5.3.10).
- scsi: target: core: Do not overwrite CDB byte 1 (bnc#1151927
  5.3.10).
- scsi: fix kconfig dependency warning related to 53C700_LE_ON_BE
  (bnc#1151927 5.3.10).
- scsi: sni_53c710: fix compilation error (bnc#1151927 5.3.10).
- scsi: scsi_dh_alua: handle RTPG sense code correctly during
  state transitions (bnc#1151927 5.3.10).
- arm64: dts: allwinner: a64: sopine-baseboard: Add PHY regulator
  delay (bnc#1151927 5.3.10).
- arm64: dts: allwinner: a64: Drop PMU node (bnc#1151927 5.3.10).
- arm64: dts: allwinner: a64: pine64-plus: Add PHY regulator delay
  (bnc#1151927 5.3.10).
- ARM: dts: bcm2837-rpi-cm3: Avoid leds-gpio probing issue
  (bnc#1151927 5.3.10).
- ARM: davinci: dm365: Fix McBSP dma_slave_map entry (bnc#1151927
  5.3.10).
- arm64: dts: rockchip: Fix usb-c on Hugsun X99 TV Box
  (bnc#1151927 5.3.10).
- arm64: dts: rockchip: fix RockPro64 sdmmc settings (bnc#1151927
  5.3.10).
- arm64: dts: rockchip: fix RockPro64 sdhci settings (bnc#1151927
  5.3.10).
- arm64: dts: rockchip: fix RockPro64 vdd-log regulator settings
  (bnc#1151927 5.3.10).
- arm64: dts: rockchip: fix Rockpro64 RK808 interrupt line
  (bnc#1151927 5.3.10).
- arm64: dts: imx8mm: Use correct clock for usdhc's ipg clk
  (bnc#1151927 5.3.10).
- arm64: dts: imx8mq: Use correct clock for usdhc's ipg clk
  (bnc#1151927 5.3.10).
- ARM: dts: imx7s: Correct GPT's ipg clock source (bnc#1151927
  5.3.10).
- ARM: dts: vf610-zii-scu4-aib: Specify 'i2c-mux-idle-disconnect'
  (bnc#1151927 5.3.10).
- ARM: dts: imx6q-logicpd: Re-Enable SNVS power key (bnc#1151927
  5.3.10).
- arm64: dts: lx2160a: Correct CPU core idle state name
  (bnc#1151927 5.3.10).
- arm64: dts: zii-ultra: fix ARM regulator states (bnc#1151927
  5.3.10).
- ARM: dts: Use level interrupt for omap4 & 5 wlcore (bnc#1151927
  5.3.10).
- ARM: dts: am3874-iceboard: Fix 'i2c-mux-idle-disconnect' usage
  (bnc#1151927 5.3.10).
- ARM: dts: logicpd-torpedo-som: Remove twl_keypad (bnc#1151927
  5.3.10).
- arm64: dts: Fix gpio to pinmux mapping (bnc#1151927 5.3.10).
- selftests: kvm: fix sync_regs_test with newer gccs (bnc#1151927
  5.3.10).
- selftests: kvm: vmx_set_nested_state_test: don't check for
  VMX support twice (bnc#1151927 5.3.10).
- of: unittest: fix memory leak in unittest_data_add (bnc#1151927
  5.3.10).
- tracing: Fix "gfp_t" format for synthetic events (bnc#1151927
  5.3.10).
- ARM: 8926/1: v7m: remove register save to stack before svc
  (bnc#1151927 5.3.10).
- ARM: 8914/1: NOMMU: Fix exc_ret for XIP (bnc#1151927 5.3.10).
- ARM: 8908/1: add __always_inline to functions called from
  __get_user_check() (bnc#1151927 5.3.10).
- ARM: mm: fix alignment handler faults under memory pressure
  (bnc#1151927 5.3.10).
- selftests/powerpc: Fix compile error on tlbie_test due to
  newer gcc (bnc#1151927 5.3.10).
- selftests/powerpc: Add test case for tlbie vs mtpidr ordering
  issue (bnc#1151927 5.3.10).
- arm64: dts: ti: k3-am65-main: Fix gic-its node unit-address
  (bnc#1151927 5.3.10).
- commit c4dc2d2
* Wed Nov 13 2019 jslaby@suse.cz
- Update
  patches.suse/8250-men-mcb-fix-error-checking-when-get_num_ports-r.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ALSA-hda-Add-Tigerlake-Jasperlake-PCI-ID.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-Intel-sof-rt5682-add-a-check-for-devm_clk_get.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-Intel-hda-Disable-DMI-L1-entry-during-captu.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-Intel-hda-fix-warnings-during-FW-load.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-Intel-initialise-and-verify-FW-crash-dump-d.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-control-return-true-when-kcontrol-values-ch.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-loader-fix-kernel-oops-on-firmware-boot-fai.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-SOF-topology-fix-parse-fail-issue-for-byte-bool.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-intel-bytcr_rt5651-add-null-check-to-support_bu.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-intel-sof_rt5682-add-remove-function-to-disable.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-msm8916-wcd-digital-add-missing-MIX2-path-for-R.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-pcm3168a-The-codec-does-not-support-S32_LE.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-rt5682-add-NULL-handler-to-set_jack-function.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-samsung-arndale-Add-missing-OF-node-dereferenci.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-simple_card_utils.h-Fix-potential-multiple-rede.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-topology-Fix-a-signedness-bug-in-soc_tplg_dapm_.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-wm8994-Do-not-register-inapplicable-controls-fo.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/ASoC-wm_adsp-Don-t-generate-kcontrols-without-READ-f.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/ASoc-rockchip-i2s-Fix-RPM-imbalance.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/cxgb4-fix-panic-when-attaching-to-ULD-fail.patch
  (jsc#SLE-8389 bnc#1151927 5.3.10).
- Update
  patches.suse/cxgb4-request-the-TX-CIDX-updates-to-status-page.patch
  (jsc#SLE-8389 bnc#1151927 5.3.10).
- Update patches.suse/dccp-do-not-leak-jiffies-on-the-wire.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/drm-amdgpu-fix-error-handling-in-amdgpu_bo_list_crea.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/drm-amdgpu-fix-potential-VM-faults.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/drm-komeda-Don-t-flush-inactive-pipes.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/erspan-fix-the-tun_info-options_len-check-for-erspan.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/i2c-aspeed-fix-master-pending-state-handling.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/i2c-mt65xx-fix-NULL-ptr-dereference.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/i2c-stm32f7-fix-a-race-in-slave-mode-with-arbitratio.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/i2c-stm32f7-fix-first-byte-to-send-in-slave-mode.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/i2c-stm32f7-remove-warning-when-compiling-with-W-1.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/inet-stop-leaking-jiffies-on-the-wire.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/ipv4-fix-IPSKB_FRAG_PMTU-handling-with-fragmentation.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/ipv4-fix-route-update-on-metric-change.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/keys-Fix-memory-leak-in-copy_net_ns.patch
  (bsc#1154353 git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/mlxsw-core-Unpublish-devlink-parameters-during-reloa.patch
  (bsc#1154488 bnc#1151927 5.3.10).
- Update
  patches.suse/net-Zeroing-the-structure-ethtool_wolinfo-in-ethtool.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-add-READ_ONCE-annotation-in-__skb_wait_for_more_.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/net-add-skb_queue_empty_lockless.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-annotate-accesses-to-sk-sk_incoming_cpu.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-annotate-lockless-accesses-to-sk-sk_napi_id.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-bcmgenet-don-t-set-phydev-link-from-MAC.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/net-bcmgenet-reset-40nm-EPHY-on-energy-detect.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/net-dsa-b53-Do-not-clear-existing-mirrored-port-mask.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/net-dsa-bcm_sf2-Fix-IMP-setup-for-port-different-tha.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/net-dsa-fix-switch-tree-list.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/net-ensure-correct-skb-tstamp-in-various-fragmenters.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-fix-sk_page_frag-recursion-from-memory-reclaim.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/net-flow_dissector-switch-to-siphash.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-hisilicon-Fix-ping-latency-when-deal-with-high-t.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-hns3-fix-mis-counting-IRQ-vector-numbers-issue.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx4_core-Dynamically-set-guaranteed-amount-of-c.patch
  (jsc#SLE-8460 bnc#1151927 5.3.10).
- Update patches.suse/net-mlx5-Fix-rtable-reference-leak.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx5e-Determine-source-port-properly-for-vlan-pu.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx5e-Fix-ethtool-self-test-link-speed.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx5e-Fix-handling-of-compressed-CQEs-in-case-of.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx5e-Initialize-on-stack-link-modes-bitmap.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-mlx5e-Remove-incorrect-match-criteria-assignment.patch
  (jsc#SLE-8464 bnc#1151927 5.3.10).
- Update
  patches.suse/net-netem-correct-the-parent-s-backlog-when-corrupte.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-netem-fix-error-path-for-corrupted-GSO-frames.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-phy-bcm7xxx-define-soft_reset-for-40nm-EPHY.patch
  (git-fixes bnc#1151927 5.3.10).
- Update patches.suse/net-phylink-Fix-phylink_dbg-macro.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-reorder-struct-net-fields-to-avoid-false-sharing.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/net-rtnetlink-fix-a-typo-fbd-fdb.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-usb-lan78xx-Connect-PHY-before-registering-MAC.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/net-use-skb_queue_empty_lockless-in-busy-poll-contex.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/net-use-skb_queue_empty_lockless-in-poll-handlers.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/netns-fix-GFP-flags-in-rtnl_net_notifyid.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/pinctrl-intel-Allocate-IRQ-chip-dynamic.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/pinctrl-ns2-Fix-off-by-one-bugs-in-ns2_pinmux_enable.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/pinctrl-stmfx-fix-null-pointer-on-remove.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/platform-x86-pmc_atom-Add-Siemens-SIMATIC-IPC227E-to.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/r8152-add-device-id-for-Lenovo-ThinkPad-USB-C-Dock-G.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/r8169-fix-wrong-PHY-ID-issue-with-RTL8168dp.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/regulator-da9062-fix-suspend_enable-disable-preparat.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/regulator-of-fix-suspend-min-max-voltage-parsing.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/regulator-pfuze100-regulator-Variable-val-in-pfuze10.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/regulator-ti-abb-Fix-timeout-in-ti_abb_wait_txdone-t.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/scsi-qla2xxx-fix-a-potential-NULL-pointer-dereferenc.patch
  (bsc#1150457 CVE-2019-16233 bnc#1151927 5.3.10).
- Update
  patches.suse/udp-fix-data-race-in-udp_set_dev_scratch.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update patches.suse/udp-use-skb_queue_empty_lockless.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- Update
  patches.suse/usb-gadget-udc-core-Fix-segfault-if-udc_bind_to_driv.patch
  (git-fixes bnc#1151927 5.3.10).
- Update
  patches.suse/vxlan-check-tun_info-options_len-properly.patch
  (bsc#1154353 bnc#1151927 5.3.10).
- commit db35794
* Wed Nov 13 2019 mkubecek@suse.cz
- refresh config files
- commit 18453ef
* Wed Nov 13 2019 mkubecek@suse.cz
- series.conf: cleanup
- move submitted and accepted patch into "almost mainline" section
- commit 8e9e103
* Tue Nov 12 2019 fdmanana@suse.com
- Btrfs: fix log context list corruption after rename exchange
  operation (bsc#1156494).
- commit 73bdb1d
* Tue Nov 12 2019 jslaby@suse.cz
- Linux 5.3.9 (bnc#1151927 5.3.9).
- Revert "nvme: allow 64-bit results in passthru commands"
  (bnc#1151927 5.3.9).
- scsi: target: cxgbit: Fix cxgbit_fw4_ack() (bnc#1151927 5.3.9).
- s390/idle: fix cpu idle time calculation (bnc#1151927 5.3.9).
- s390/unwind: fix mixing regs and sp (bnc#1151927 5.3.9).
- s390/cmm: fix information leak in cmm_timeout_handler()
  (bnc#1151927 5.3.9).
- NFS: Fix an RCU lock leak in nfs4_refresh_delegation_stateid()
  (bnc#1151927 5.3.9).
- io_uring: ensure we clear io_kiocb->result before each issue
  (bnc#1151927 5.3.9).
- um-ubd: Entrust re-queue to the upper layers (bnc#1151927
  5.3.9).
- arm64: cpufeature: Enable Qualcomm Falkor/Kryo errata 1003
  (bnc#1151927 5.3.9).
- arm64: Ensure VM_WRITE|VM_SHARED ptes are clean by default
  (bnc#1151927 5.3.9).
- KVM: vmx, svm: always run with EFER.NXE=1 when shadow paging
  is active (bnc#1151927 5.3.9).
- drm/amdgpu: Fix SDMA hang when performing VKexample test
  (bnc#1151927 5.3.9).
- iommu/vt-d: Fix panic after kexec -p for kdump (bnc#1151927
  5.3.9).
- fuse: truncate pending writes on O_TRUNC (bnc#1151927 5.3.9).
- fuse: flush dirty data/metadata before non-truncate setattr
  (bnc#1151927 5.3.9).
- ARC: perf: Accommodate big-endian CPU (bnc#1151927 5.3.9).
- perf/aux: Fix tracking of auxiliary trace buffer allocation
  (bnc#1151927 5.3.9).
- perf annotate: Fix multiple memory and file descriptor leaks
  (bnc#1151927 5.3.9).
- net: usb: sr9800: fix uninitialized local variable (bnc#1151927
  5.3.9).
- io_uring: fix up O_NONBLOCK handling for sockets (bnc#1151927
  5.3.9).
- dm snapshot: rework COW throttling to fix deadlock (bnc#1151927
  5.3.9).
- dm snapshot: introduce account_start_copy() and
  account_end_copy() (bnc#1151927 5.3.9).
- serial/sifive: select SERIAL_EARLYCON (bnc#1151927 5.3.9).
- perf/x86/amd: Change/fix NMI latency mitigation to use a
  timestamp (bnc#1151927 5.3.9).
- perf/core: Fix corner case in perf_rotate_context() (bnc#1151927
  5.3.9).
- perf/core: Rework memory accounting in perf_mmap() (bnc#1151927
  5.3.9).
- perf annotate: Don't return -1 for error when doing BPF
  disassembly (bnc#1151927 5.3.9).
- perf annotate: Return appropriate error code for allocation
  failures (bnc#1151927 5.3.9).
- perf annotate: Fix arch specific ->init() failure errors
  (bnc#1151927 5.3.9).
- perf annotate: Propagate the symbol__annotate() error return
  (bnc#1151927 5.3.9).
- perf annotate: Fix the signedness of failure returns
  (bnc#1151927 5.3.9).
- perf annotate: Propagate perf_env__arch() error (bnc#1151927
  5.3.9).
- perf tools: Propagate get_cpuid() error (bnc#1151927 5.3.9).
- perf jevents: Fix period for Intel fixed counters (bnc#1151927
  5.3.9).
- perf script brstackinsn: Fix recovery from LBR/binary mismatch
  (bnc#1151927 5.3.9).
- perf map: Fix overlapped map handling (bnc#1151927 5.3.9).
- perf tests: Avoid raising SEGV using an obvious NULL dereference
  (bnc#1151927 5.3.9).
- libsubcmd: Make _FORTIFY_SOURCE defines dependent on the feature
  (bnc#1151927 5.3.9).
- efi/x86: Do not clean dummy variable in kexec path (bnc#1151927
  5.3.9).
- efi/cper: Fix endianness of PCIe class code (bnc#1151927 5.3.9).
- riscv: Correct the handling of unexpected ebreak in
  do_trap_break() (bnc#1151927 5.3.9).
- riscv: avoid sending a SIGTRAP to a user thread trapped in
  WARN() (bnc#1151927 5.3.9).
- riscv: avoid kernel hangs when trapped in BUG() (bnc#1151927
  5.3.9).
- MIPS: fw: sni: Fix out of bounds init of o32 stack (bnc#1151927
  5.3.9).
- MIPS: include: Mark __xchg as __always_inline (bnc#1151927
  5.3.9).
- MIPS: include: Mark __cmpxchg as __always_inline (bnc#1151927
  5.3.9).
- x86/xen: Return from panic notifier (bnc#1151927 5.3.9).
- s390/uaccess: avoid (false positive) compiler warnings
  (bnc#1151927 5.3.9).
- s390/cio: fix virtio-ccw DMA without PV (bnc#1151927 5.3.9).
- NFSv4: Fix leak of clp->cl_acceptor string (bnc#1151927 5.3.9).
- nfs: Fix nfsi->nrequests count error on nfs_inode_remove_request
  (bnc#1151927 5.3.9).
- fs: cifs: mute -Wunused-const-variable message (bnc#1151927
  5.3.9).
- nbd: fix possible sysfs duplicate warning (bnc#1151927 5.3.9).
- btrfs: silence maybe-uninitialized warning in clone_range
  (bnc#1151927 5.3.9).
- arm64: armv8_deprecated: Checking return value for memory
  allocation (bnc#1151927 5.3.9).
- arm64: vdso32: Don't use KBUILD_CPPFLAGS unconditionally
  (bnc#1151927 5.3.9).
- arm64: Default to building compat vDSO with clang when
  CONFIG_CC_IS_CLANG (bnc#1151927 5.3.9).
- arm64: vdso32: Detect binutils support for dmb ishld
  (bnc#1151927 5.3.9).
- arm64: vdso32: Fix broken compat vDSO build warnings
  (bnc#1151927 5.3.9).
- arm64: ftrace: Ensure synchronisation in PLT setup for
  Neoverse-N1 #1542419 (bnc#1151927 5.3.9).
- arm64: Fix incorrect irqflag restore for priority masking for
  compat (bnc#1151927 5.3.9).
- arm64: cpufeature: Effectively expose FRINT capability to
  userspace (bnc#1151927 5.3.9).
- selftests/kselftest/runner.sh: Add 45 second timeout per test
  (bnc#1151927 5.3.9).
- kselftest: exclude failed TARGETS from runlist (bnc#1151927
  5.3.9).
- fs: ocfs2: fix a possible null-pointer dereference in
  ocfs2_info_scan_inode_alloc() (bnc#1151927 5.3.9).
- fs: ocfs2: fix possible null-pointer dereferences in
  ocfs2_xa_prepare_entry() (bnc#1151927 5.3.9).
- ocfs2: clear zero in unaligned direct IO (bnc#1151927 5.3.9).
- Btrfs: fix inode cache block reserve leak on failure to allocate
  data space (bnc#1151927 5.3.9).
- Refresh
  patches.suse/0001-btrfs-qgroup-Always-free-PREALLOC-META-reserve-in-bt.patch.
- s390/pci: fix MSI message data (bnc#1151927 5.3.9).
- arm64: dts: qcom: Add Asus NovaGo TP370QL (bnc#1151927 5.3.9).
- arm64: dts: qcom: Add HP Envy x2 (bnc#1151927 5.3.9).
- arm64: dts: qcom: Add Lenovo Miix 630 (bnc#1151927 5.3.9).
- commit 613af05
* Tue Nov 12 2019 jslaby@suse.cz
- Update
  patches.suse/0001-btrfs-qgroup-Always-free-PREALLOC-META-reserve-in-bt.patch
  (bsc#1155179 bnc#1151927 5.3.9).
- Update
  patches.suse/0001-thunderbolt-Correct-path-indices-for-PCIe-tunnel.patch
  (jsc#SLE-8714 bnc#1151927 5.3.9).
- Update
  patches.suse/0001-thunderbolt-Use-32-bit-writes-when-writing-ring-prod.patch
  (jsc#SLE-8714 bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-bebob-Fix-prototype-of-helper-function-to-retur.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-hda-realtek-Add-support-for-ALC623.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-hda-realtek-Fix-2-front-mics-of-codec-0x623.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-timer-Fix-mutex-deadlock-at-releasing-card.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-usb-audio-Add-DSD-support-for-Gustard-U16-X26-U.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-usb-audio-DSD-auto-detection-for-Playback-Desig.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/ALSA-usb-audio-Update-DSD-support-quirks-for-Oppo-an.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-Fix-assumption-that-devices-have-inputs.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-fix-error-message-in-hid_open_report.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-i2c-hid-add-Trekstor-Primebook-C11B-to-descripto.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-logitech-hidpp-do-all-FF-cleanup-in-hidpp_ff_des.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-logitech-hidpp-rework-device-validation.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/HID-logitech-hidpp-split-g920_get_config.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/IB-hfi1-Avoid-excessive-retry-for-TID-RDMA-READ-requ.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/NFC-pn533-fix-use-after-free-and-memleaks.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-cm-Fix-memory-leak-in-cm_add-remove_one.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-core-Fix-an-error-handling-path-in-res_get_comm.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-hfi1-Prevent-memory-leak-in-sdma_init.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-iw_cxgb4-fix-SRQ-access-from-dump_qp.patch
  (jsc#SLE-8392 bnc#1151927 5.3.9).
- Update patches.suse/RDMA-iwcm-Fix-a-lock-inversion-issue.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-mlx5-Add-missing-synchronize_srcu-for-MW-cases.patch
  (jsc#SLE-8446 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-mlx5-Do-not-allow-rereg-of-a-ODP-MR.patch
  (jsc#SLE-8446 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-mlx5-Order-num_pending_prefetch-properly-with-s.patch
  (jsc#SLE-8446 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-mlx5-Use-irq-xarray-locking-for-mkey_table.patch
  (jsc#SLE-8446 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-nldev-Reshuffle-the-code-to-avoid-need-to-rebin.patch
  (jsc#SLE-8449 bnc#1151927 5.3.9).
- Update
  patches.suse/RDMA-siw-Fix-serialization-issue-in-write_space.patch
  (jsc#SLE-8381 bnc#1151927 5.3.9).
- Update
  patches.suse/Revert-ALSA-hda-Flush-interrupts-on-disabling.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/SUNRPC-fix-race-to-sk_err-after-xs_error_report.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/UAS-Revert-commit-3ae62a42090f-UAS-fix-alignment-of-.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/USB-gadget-Reject-endpoints-with-0-maxpacket-value.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/USB-ldusb-fix-control-message-timeout.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/USB-ldusb-fix-ring-buffer-locking.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/USB-legousbtower-fix-a-signedness-bug-in-tower_probe.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/USB-serial-whiteheat-fix-line-speed-endianness.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/USB-serial-whiteheat-fix-potential-slab-corruption.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/ath10k-fix-latency-issue-for-QCA988x.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/batman-adv-Avoid-free-alloc-race-when-handling-OGM-b.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/bonding-fix-potential-NULL-deref-in-bond_update_slav.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/dmaengine-cppi41-Fix-cppi41_dma_prep_slave_sg-when-i.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/dmaengine-imx-sdma-fix-size-check-for-sdma-script_nu.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/dmaengine-qcom-bam_dma-Fix-resource-leak.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/dmaengine-tegra210-adma-fix-transfer-failure.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/drm-amdgpu-fix-memory-leak.patch (git-fixes
  bnc#1151927 5.3.9).
- Update
  patches.suse/drm-amdgpu-gfx10-update-gfx-golden-settings.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/drm-amdgpu-gmc10-properly-set-BANK_SELECT-and-FRAGME.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/drm-amdgpu-powerplay-vega10-allow-undervolting-in-p7.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/drm-i915-Fix-PCH-reference-clock-for-FDI-on-HSW-BDW.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/gpio-max77620-Use-correct-unit-for-debounce-times.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/iio-adc-meson_saradc-Fix-memory-allocation-order.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/iio-fix-center-temperature-of-bmc150-accel-core.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/iio-imu-adis16400-fix-memory-leak.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/iio-imu-adis16400-release-allocated-memory-on-failur.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/iio-imu-st_lsm6dsx-fix-waitime-for-st_lsm6dsx-i2c-co.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/iwlwifi-exclude-GEO-SAR-support-for-3168.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/llc-fix-sk_buff-leak-in-llc_conn_service.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/llc-fix-sk_buff-leak-in-llc_sap_state_process.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/misc-fastrpc-prevent-memory-leak-in-fastrpc_dma_buf_.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/msft-hv-1953-HID-hyperv-Use-in-place-iterator-API-in-the-channel-.patch
  (fate#323887 bnc#1151927 5.3.9).
- Update
  patches.suse/nbd-verify-socket-is-supported-during-setup.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/net-ath6kl-Fix-a-NULL-ptr-deref-bug.patch
  (CVE-2019-15098,bsc#1146378,CVE-2019-15290,bsc#1146543
  bnc#1151927 5.3.9).
- Update
  patches.suse/net-sched-sch_sfb-don-t-call-qdisc_put-while-holding.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/netfilter-conntrack-avoid-possible-false-sharing.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/nl80211-fix-validation-of-mesh-path-nexthop.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/powerpc-powernv-Fix-CPU-idle-to-be-called-with-IRQs-.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/rtlwifi-Fix-potential-overflow-on-P2P-code.patch
  (bsc#1154372 CVE-2019-17666 bnc#1151927 5.3.9).
- Update
  patches.suse/rtlwifi-rtl_pci-Fix-problem-of-too-small-skb-len.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/rtw88-Fix-misuse-of-GENMASK-macro.patch
  (git-fixes bnc#1151927 5.3.9).
- Update patches.suse/rxrpc-Fix-call-ref-leak.patch (bsc#1154353
  bnc#1151927 5.3.9).
- Update
  patches.suse/rxrpc-Fix-trace-after-put-looking-at-the-put-peer-re.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/rxrpc-rxrpc_peer-needs-to-hold-a-ref-on-the-rxrpc_lo.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/sch_netem-fix-rcu-splat-in-netem_enqueue.patch
  (bsc#1154353 bnc#1151927 5.3.9).
- Update
  patches.suse/sched-fair-Fix-Wunused-but-set-variable-warnings.patch
  (bnc#1155798 (CPU scheduler functional and performance
  backports) bnc#1151927 5.3.9).
- Update
  patches.suse/sched-fair-Fix-low-cpu-usage-with-high-throttling-by-removing-expiration-of-cpu-local-slices.patch
  (bnc#1155798 (CPU scheduler functional and performance
  backports) bnc#1151927 5.3.9).
- Update
  patches.suse/sched-fair-Scale-bandwidth-quota-and-period-without-losing-quota-period-ratio-precision.patch
  (git fixes (sched) bnc#1151927 5.3.9).
- Update
  patches.suse/sched-vtime-Fix-guest-system-mis-accounting-on-task-switch.patch
  (git fixes (cputime accounting) bnc#1151927 5.3.9).
- Update
  patches.suse/scsi-qla2xxx-Fix-partial-flash-write-of-MBI.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.9).
- Update
  patches.suse/serial-8250_omap-Fix-gpio-check-for-auto-RTS-CTS.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/serial-mctrl_gpio-Check-for-NULL-pointer.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/staging-rtl8188eu-fix-null-dereference-when-kzalloc-.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/tracing-Initialize-iter-seq-after-zeroing-in-tracing.patch
  (bsc#1151508 bnc#1151927 5.3.9).
- Update patches.suse/tty-n_hdlc-fix-build-on-SPARC.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/tty-serial-owl-Fix-the-link-time-qualifier-of-owl_ua.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/tty-serial-rda-Fix-the-link-time-qualifier-of-rda_ua.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/usb-storage-Revert-commit-747668dbc061-usb-storage-S.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/usb-xhci-fix-Immediate-Data-Transfer-endianness.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/usb-xhci-fix-__le32-__le64-accessors-in-debugfs-code.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/virt-vbox-fix-memory-leak-in-hgcm_call_preprocess_li.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/virtio_ring-fix-stalls-for-packed-rings.patch
  (git-fixes bnc#1151927 5.3.9).
- Update
  patches.suse/x86-cpu-add-comet-lake-to-the-intel-cpu-models-header.patch
  (jsc#SLE-7935 bnc#1151927 5.3.9).
- Update
  patches.suse/xhci-Fix-use-after-free-regression-in-xhci-clear-hub.patch
  (git-fixes bnc#1151927 5.3.9).
- commit d0f752b
* Tue Nov 12 2019 hare@suse.de
- nvme: Move ctrl sqsize to generic space
  (bsc#1156419,jsc#SLE-8281).
- nvme: Add ctrl attributes for queue_count and sqsize
  (bsc#1156419,jsc#SLE-8281).
- commit 20e4a40
* Tue Nov 12 2019 hare@suse.de
- nvmet-tcp: remove superflous check on request sgl
  (bsc#1156419,jsc#SLE-8281).
- commit 19797e4
* Tue Nov 12 2019 hare@suse.de
- nvmet: change ppl to lpp (bsc#1156419,jsc#SLE-8281).
- commit 00bb531
* Tue Nov 12 2019 hare@suse.de
- blk-mq: apply normal plugging for HDD
  (bsc#1156419,jsc#SLE-8281).
- commit 1007f9a
* Tue Nov 12 2019 hare@suse.de
- iocost: bump up default latency targets for hard disks
  (bsc#1156419,jsc#SLE-8281).
- iocost: improve nr_lagging handling (bsc#1156419,jsc#SLE-8281).
- iocost: better trace vrate changes (bsc#1156419,jsc#SLE-8281).
- commit 6d144e8
* Tue Nov 12 2019 hare@suse.de
- block: t10-pi: fix -Wswitch warning (bsc#1156419,jsc#SLE-8281).
- block, bfq: increase update frequency of inject limit
  (bsc#1156419,jsc#SLE-8281).
- block, bfq: reduce upper bound for inject limit to
  max_rq_in_driver+1 (bsc#1156419,jsc#SLE-8281).
- block, bfq: update inject limit only after injection occurred
  (bsc#1156419,jsc#SLE-8281).
- commit 11db1c7
* Tue Nov 12 2019 hare@suse.de
- mmc: queue: Fix bigger segments usage
  (bsc#1156419,jsc#SLE-8281).
- dma-mapping: fix filename references (bsc#1156419,jsc#SLE-8281).
- iommu/dma: add a new dma_map_ops of get_merge_boundary()
  (bsc#1156419,jsc#SLE-8281).
- dma-mapping: introduce dma_get_merge_boundary()
  (bsc#1156419,jsc#SLE-8281).
- mmc: queue: use bigger segments if DMA MAP layer can merge
  the segments (bsc#1156419,jsc#SLE-8281).
- block: add a helper function to merge the segments
  (bsc#1156419,jsc#SLE-8281).
- commit 0574516
* Tue Nov 12 2019 hare@suse.de
- nvmet: fix a wrong error status returned in error log page
  (bsc#1156419,jsc#SLE-8281).
- nvme: send discovery log page change events to userspace
  (bsc#1156419,jsc#SLE-8281).
- nvme: add uevent variables for controller devices
  (bsc#1156419,jsc#SLE-8281).
- nvme: enable aen regardless of the presence of I/O queues
  (bsc#1156419,jsc#SLE-8281).
- nvme-fabrics: allow discovery subsystems accept a kato
  (bsc#1156419,jsc#SLE-8281).
- nvmet: Use PTR_ERR_OR_ZERO() in nvmet_init_discovery()
  (bsc#1156419,jsc#SLE-8281).
- nvme: Remove redundant assignment of cq vector
  (bsc#1156419,jsc#SLE-8281).
- nvme: Assign subsys instance from first ctrl
  (bsc#1156419,jsc#SLE-8281).
- nvme: tcp: remove redundant assignment to variable ret
  (bsc#1156419,jsc#SLE-8281).
- nvme: include admin_q sync with nvme_sync_queues
  (bsc#1156419,jsc#SLE-8281).
- nvme: Treat discovery subsystems as unique subsystems
  (bsc#1156419,jsc#SLE-8281).
- nvme: fix ns removal hang when failing to revalidate due to
  a transient error (bsc#1156419,jsc#SLE-8281).
- nvme: make nvme_report_ns_ids propagate error back
  (bsc#1156419,jsc#SLE-8281).
- nvme: make nvme_identify_ns propagate errors back
  (bsc#1156419,jsc#SLE-8281).
- nvme: pass status to nvme_error_status
  (bsc#1156419,jsc#SLE-8281).
- nvme-fc: Fail transport errors with NVME_SC_HOST_PATH
  (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: fail command with NVME_SC_HOST_PATH_ERROR send failed
  (bsc#1156419,jsc#SLE-8281).
- nvme: fail cancelled commands with NVME_SC_HOST_PATH_ERROR
  (bsc#1156419,jsc#SLE-8281).
- commit b7d6f8e
* Tue Nov 12 2019 hare@suse.de
- block: also check RQF_STATS in blk_mq_need_time_stamp()
  (bsc#1156419,jsc#SLE-8281).
- commit 8e18ffe
* Tue Nov 12 2019 hare@suse.de
- bfq: Fix bfq linkage error (bsc#1156419,jsc#SLE-8281).
- block: bypass blk_set_runtime_active for uninitialized q->dev
  (bsc#1156419,jsc#SLE-8281).
- commit c4398cc
* Tue Nov 12 2019 hare@suse.de
- iocost_monitor: Report debt (bsc#1156419,jsc#SLE-8281).
- iocost_monitor: Report more info with higher accuracy
  (bsc#1156419,jsc#SLE-8281).
- iocost_monitor: Always use strings for json values
  (bsc#1156419,jsc#SLE-8281).
- commit 5643f67
* Tue Nov 12 2019 hare@suse.de
- blk-iocost: Don't let merges push vtime into the future
  (bsc#1156419,jsc#SLE-8281).
- blk-iocost: Account force-charged overage in absolute vtime
  (bsc#1156419,jsc#SLE-8281).
- commit 5e399b3
* Tue Nov 12 2019 hare@suse.de
- bfq: Add per-device weight (bsc#1156419,jsc#SLE-8281).
- bfq: Extract bfq_group_set_weight from bfq_io_set_weight_legacy
  (bsc#1156419,jsc#SLE-8281).
- bfq: Fix the missing barrier in __bfq_entity_update_weight_prio
  (bsc#1156419,jsc#SLE-8281).
- commit c8fb944
* Tue Nov 12 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream references and move:
  patches.suse/soundwire-depend-on-ACPI-OF.patch
  patches.suse/soundwire-depend-on-ACPI.patch
- commit db2a325
* Tue Nov 12 2019 mkubecek@suse.cz
- update upstream references
- update Patch-mainline:
  patches.suse/mm-gup-fix-a-misnamed-write-argument-and-a-related-bug.patch
  patches.suse/sched-Fix-pick_next_task-vs-change-pattern-race.patch
- commit f1c7235
* Tue Nov 12 2019 mkubecek@suse.cz
- move patches.suse/stacktrace-Don-t-skip-first-entry-on-noncurrent-task.patch into sorted section
- commit 2b73785
* Mon Nov 11 2019 mbrugger@suse.com
- arm64: Update config files. (bsc#1156466)
  Enable HW_RANDOM_OMAP used by machiattobin
  and mark omap-rng as supported
- commit 97cc63c
* Mon Nov 11 2019 hare@suse.de
- block: fix elevator_get_by_features()
  (bsc#1156419,jsc#SLE-8281).
- commit 178e768
* Mon Nov 11 2019 hare@suse.de
- iocost: don't nest spin_lock_irq in ioc_weight_write()
  (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: Initialize sk->sk_ll_usec only with NET_RX_BUSY_POLL
  (bsc#1156419,jsc#SLE-8281).
- blkcg: Fix multiple bugs in blkcg_activate_policy()
  (bsc#1156419,jsc#SLE-8281).
- block: don't release queue's sysfs lock during switching
  elevator (bsc#1156419,jsc#SLE-8281).
- block: fix race between switching elevator and removing queues
  (bsc#1156419,jsc#SLE-8281).
- blk-iocost: Fix incorrect operation order during iocg free
  (bsc#1156419,jsc#SLE-8281).
- commit e443933
* Mon Nov 11 2019 hare@suse.de
- sd: Set ELEVATOR_F_ZBD_SEQ_WRITE for ZBC disks
  (bsc#1156419,jsc#SLE-8281).
- block: Set ELEVATOR_F_ZBD_SEQ_WRITE for nullblk zoned disks
  (bsc#1156419,jsc#SLE-8281).
- block: Delay default elevator initializatio
  (bsc#1156419,jsc#SLE-8281).
- commit 71cd228
* Mon Nov 11 2019 hare@suse.de
- block: Improve default elevator selection
  (bsc#1156419,jsc#SLE-8281).
- block: Introduce elevator features (bsc#1156419,jsc#SLE-8281).
- block: Change elevator_init_mq() to always succeed
  (bsc#1156419,jsc#SLE-8281).
- commit 2d709aa
* Mon Nov 11 2019 hare@suse.de
- block: Cleanup elevator_init_mq() use
  (bsc#1156419,jsc#SLE-8281).
- commit f9e5dd5
* Mon Nov 11 2019 hare@suse.de
- Documentation:kernel-per-CPU-kthreads.txt: Remove reference
  to elevator= (bsc#1156419,jsc#SLE-8281).
- Documenation: switching-sched: Remove notes about elevator
  argument (bsc#1156419,jsc#SLE-8281).
- block: elevator.c: Remove now unused elevator= argument
  (bsc#1156419,jsc#SLE-8281).
- commit 4c19565
* Mon Nov 11 2019 hare@suse.de
- nvme-rdma: Use rq_dma_dir macro (bsc#1156419,jsc#SLE-8281).
- nvme-fc: Use rq_dma_dir macro (bsc#1156419,jsc#SLE-8281).
- nvme-pci: Tidy up nvme_unmap_data (bsc#1156419,jsc#SLE-8281).
- commit f389b9a
* Mon Nov 11 2019 hare@suse.de
- nvme: make fabrics command run on a separate request queue
  (bsc#1156419,jsc#SLE-8281).
- Update
  patches.suse/nvme-rdma-Fix-max_hw_sectors-calculation.patch
  (bsc#1156419,jsc#SLE-8281).
- commit 6ad508a
* Mon Nov 11 2019 hare@suse.de
- nvme-pci: Support shared tags across queues for Apple 2018
  controllers (bsc#1156419,jsc#SLE-8281).
- nvme-pci: Add support for Apple 2018+ models
  (bsc#1156419,jsc#SLE-8281).
- nvme-pci: Add support for variable IO SQ element size
  (bsc#1156419,jsc#SLE-8281).
- nvme-pci: Pass the queue to SQ_SIZE/CQ_SIZE macros
  (bsc#1156419,jsc#SLE-8281).
- nvme: trace bio completion (bsc#1156419,jsc#SLE-8281).
- commit ab59099
* Mon Nov 11 2019 hare@suse.de
- nvmet-tcp: Add TOS for tcp transport (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: Add TOS for tcp transport (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: Use struct nvme_ctrl directly
  (bsc#1156419,jsc#SLE-8281).
- nvme-rdma: Add TOS for rdma transport
  (bsc#1156419,jsc#SLE-8281).
- nvme-fabrics: Add type of service (TOS) configuration
  (bsc#1156419,jsc#SLE-8281).
- nvmet-tcp: fix possible memory leak (bsc#1156419,jsc#SLE-8281).
- nvmet-tcp: fix possible NULL deref (bsc#1156419,jsc#SLE-8281).
- nvmet: trace: parse Get LBA Status command in detail
  (bsc#1156419,jsc#SLE-8281).
- nvme: trace: parse Get LBA Status command in detail
  (bsc#1156419,jsc#SLE-8281).
- nvme: trace: support for Get LBA Status opcode parsed
  (bsc#1156419,jsc#SLE-8281).
- nvme: add Get LBA Status command opcode
  (bsc#1156419,jsc#SLE-8281).
- commit 51901f2
* Mon Nov 11 2019 hare@suse.de
- nvme-tcp: support simple polling (bsc#1156419,jsc#SLE-8281).
- nvme: tcp: selects CRYPTO_CRC32C for nvme-tcp
  (bsc#1156419,jsc#SLE-8281).
- nvme: don't pass cap to nvme_disable_ctrl
  (bsc#1156419,jsc#SLE-8281).
- nvme: move sqsize setting to the core
  (bsc#1156419,jsc#SLE-8281).
- nvme-pci: set ctrl sqsize to the device q_depth
  (bsc#1156419,jsc#SLE-8281).
- nvme: have nvme_init_identify set ctrl->cap
  (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: Use protocol specific operations while reading socket
  (bsc#1156419,jsc#SLE-8281).
- nvme-tcp: cleanup nvme_tcp_recv_pdu (bsc#1156419,jsc#SLE-8281).
- commit bda85fb
* Mon Nov 11 2019 hare@suse.de
- block: centralize PI remapping logic to the block layer
  (bsc#1156419,jsc#SLE-8281).
- block: use symbolic constants for t10_pi type
  (bsc#1156419,jsc#SLE-8281).
- commit e299de5
* Mon Nov 11 2019 jack@suse.cz
- block: elevator.c: Remove now unused elevator= argument
  (bsc#1156055).
- commit 95954cd
* Mon Nov 11 2019 hare@suse.de
- blkcg: add missing NULL check in ioc_cpd_alloc()
  (bsc#1156419,jsc#SLE-8281).
- blkcg: fix missing free on error path of blk_iocost_init()
  (bsc#1156419,jsc#SLE-8281).
- blkcg: blk-iocost: predeclare used structs
  (bsc#1156419,jsc#SLE-8281).
- blkcg: add tools/cgroup/iocost_coef_gen.py
  (bsc#1156419,jsc#SLE-8281).
- blkcg: add tools/cgroup/iocost_monitor.py
  (bsc#1156419,jsc#SLE-8281).
- blkcg: implement blk-iocost (bsc#1156419,jsc#SLE-8281).
- update config files (add BLK_CGROUP_IOCOST=y, BLK_RQ_ALLOC_TIME=y)
- blk-mq: add optional request->alloc_time_ns
  (bsc#1156419,jsc#SLE-8281).
- blkcg: s/RQ_QOS_CGROUP/RQ_QOS_LATENCY/
  (bsc#1156419,jsc#SLE-8281).
- block/rq_qos: implement rq_qos_ops->queue_depth_changed()
  (bsc#1156419,jsc#SLE-8281).
- block/rq_qos: add rq_qos_merge() (bsc#1156419,jsc#SLE-8281).
- blkcg: separate blkcg_conf_get_disk() out of blkg_conf_prep()
  (bsc#1156419,jsc#SLE-8281).
- blkcg: make ->cpd_init_fn() optional (bsc#1156419,jsc#SLE-8281).
- blkcg: pass @q and @blkcg into blkcg_pol_alloc_pd_fn()
  (bsc#1156419,jsc#SLE-8281).
- block: split .sysfs_lock into two locks
  (bsc#1156419,jsc#SLE-8281).
- block: add helper for checking if queue is registered
  (bsc#1156419,jsc#SLE-8281).
- blk-mq: don't hold q->sysfs_lock in blk_mq_map_swqueue
  (bsc#1156419,jsc#SLE-8281).
- block: don't hold q->sysfs_lock in elevator_init_mq
  (bsc#1156419,jsc#SLE-8281).
- block: Remove blk_mq_register_dev() (bsc#1156419,jsc#SLE-8281).
- block: move same page handling from __bio_add_pc_page to the
  callers (bsc#1156419,jsc#SLE-8281).
- block: create a bio_try_merge_pc_page helper
  (bsc#1156419,jsc#SLE-8281).
- block: improve the gap check in __bio_add_pc_page
  (bsc#1156419,jsc#SLE-8281).
- block: sed-opal: Removed duplicate OPAL_METHOD_LENGTH definition
  (bsc#1156419,jsc#SLE-8281).
- block: sed-opal: Remove always false conditional statement
  (bsc#1156419,jsc#SLE-8281).
- block: sed-opal: Add/remove spaces (bsc#1156419,jsc#SLE-8281).
- block: remove struct request_queue queue_head
  (bsc#1156419,jsc#SLE-8281).
- block: annotate refault stalls from IO submission
  (bsc#1156419,jsc#SLE-8281).
- block: stop exporting bio_map_kern (bsc#1156419,jsc#SLE-8281).
- lightnvm: pblk: use kvmalloc for metadata
  (bsc#1156419,jsc#SLE-8281).
- lightnvm: move metadata mapping to lower level driver
  (bsc#1156419,jsc#SLE-8281).
- lightnvm: remove nvm_submit_io_sync_fn
  (bsc#1156419,jsc#SLE-8281).
- commit e17d5ba
* Mon Nov 11 2019 tiwai@suse.de
- Update patch reference for ASoC SOF fix (CVE-2019-18812, bsc#1156277)
- commit 34489e1
* Mon Nov 11 2019 tiwai@suse.de
- ASoC: SOF: Intel: hda-stream: fix the CONFIG_ prefix missing
  (git-fixes).
- commit 0996041
* Mon Nov 11 2019 hare@suse.de
- blk-mq: balance mapping between present CPUs and queues
  (bsc#1156419,jsc#SLE-8281).
- null_blk: implement REQ_OP_ZONE_RESET_ALL
  (bsc#1156419,jsc#SLE-8281).
- scsi: implement REQ_OP_ZONE_RESET_ALL
  (bsc#1156419,jsc#SLE-8281).
- blk-zoned: implement REQ_OP_ZONE_RESET_ALL
  (bsc#1156419,jsc#SLE-8281).
- block: add req op to reset all zones and flag
  (bsc#1156419,jsc#SLE-8281).
- block: Fix a comment in blk_cleanup_queue()
  (bsc#1156419,jsc#SLE-8281).
- block: Fix spelling in the header above blkg_lookup()
  (bsc#1156419,jsc#SLE-8281).
- block: Improve physical block alignment of split bios
  (bsc#1156419,jsc#SLE-8281).
- block: Simplify blk_bio_segment_split()
  (bsc#1156419,jsc#SLE-8281).
- block: Simplify bvec_split_segs() (bsc#1156419,jsc#SLE-8281).
- block: Document the bio splitting functions
  (bsc#1156419,jsc#SLE-8281).
- block: Declare several function pointer arguments 'const'
  (bsc#1156419,jsc#SLE-8281).
- blk-mq: remove blk_mq_complete_request_sync
  (bsc#1156419,jsc#SLE-8281).
- nvme: wait until all completed request's complete fn is called
  (bsc#1156419,jsc#SLE-8281).
- nvme: don't abort completed request in nvme_cancel_request
  (bsc#1156419,jsc#SLE-8281).
- blk-mq: introduce blk_mq_tagset_wait_completed_request()
  (bsc#1156419,jsc#SLE-8281).
- blk-mq: introduce blk_mq_request_completed()
  (bsc#1156419,jsc#SLE-8281).
- commit 0d15be1
* Mon Nov 11 2019 tiwai@suse.de
- soc: imx: gpc: fix initialiser format (git-fixes).
- reset: fix reset_control_get_exclusive kerneldoc comment
  (git-fixes).
- reset: fix reset_control_lookup kerneldoc comment (git-fixes).
- reset: fix of_reset_control_get_count kerneldoc comment
  (git-fixes).
- reset: fix of_reset_simple_xlate kerneldoc comment (git-fixes).
- reset: Fix memory leak in reset_control_array_put() (git-fixes).
- iio: adc: stm32-adc: fix stopping dma (git-fixes).
- iio: imu: inv_mpu6050: fix no data on MPU6050 (git-fixes).
- iio: imu: adis16480: make sure provided frequency is positive
  (git-fixes).
- intel_th: gth: Fix the window switching sequence (git-fixes).
- thunderbolt: Drop unnecessary read when writing LC command in
  Ice Lake (git-fixes).
- thunderbolt: Fix lockdep circular locking depedency warning
  (git-fixes).
- clocksource/drivers/mediatek: Fix error handling (git-fixes).
- pinctrl: cherryview: Allocate IRQ chip dynamic (git-fixes).
- pinctrl: cherryview: Fix irq_valid_mask calculation (git-fixes).
- pinctrl: intel: Avoid potential glitches if pin is in GPIO mode
  (git-fixes).
- watchdog: bd70528: Add MODULE_ALIAS to allow module auto loading
  (git-fixes).
- watchdog: imx_sc_wdt: Pretimeout should follow SCU firmware
  format (git-fixes).
- watchdog: meson: Fix the wrong value of left time (git-fixes).
- mac80211: fix ieee80211_txq_setup_flows() failure path
  (git-fixes).
- nfc: netlink: fix double device reference drop (git-fixes).
- r8169: fix page read in r8168g_mdio_read (git-fixes).
- can: rx-offload: can_rx_offload_offload_one(): do not increase
  the skb_queue beyond skb_queue_len_max (git-fixes).
- can: rx-offload: can_rx_offload_queue_tail(): fix error
  handling, avoid skb mem leak (git-fixes).
- can: rx-offload: can_rx_offload_queue_sorted(): fix error
  handling, avoid skb mem leak (git-fixes).
- can: c_can: c_can_poll(): only read status register after
  status IRQ (git-fixes).
- can: peak_usb: fix slab info leak (git-fixes).
- can: peak_usb: fix a potential out-of-sync while decoding
  packets (git-fixes).
- can: flexcan: disable completely the ECC mechanism (git-fixes).
- can: usb_8dev: fix use-after-free on disconnect (git-fixes).
- can: mcba_usb: fix use-after-free on disconnect (git-fixes).
- can: gs_usb: gs_can_open(): prevent memory leak (git-fixes).
- can: dev: add missing of_node_put() after calling
  of_get_child_by_name() (git-fixes).
- dccp: do not leak jiffies on the wire (git-fixes).
- pwm: bcm-iproc: Prevent unloading the driver module while in
  use (git-fixes).
- drm/amdgpu: register gpu instance before fan boost feature
  enablment (git-fixes).
- drm/i915: Avoid HPD poll detect triggering a new detect cycle
  (git-fixes).
- fbdev: c2p: Fix link failure on non-inlining (git-fixes).
- clk: samsung: exynos5420: Preserve PLL configuration during
  suspend/resume (git-fixes).
- clk: samsung: exynos542x: Move G3D subsystem clocks to its
  sub-CMU (git-fixes).
- clk: samsung: exynos5433: Fix error paths (git-fixes).
- clk: sunxi-ng: a80: fix the zero'ing of bits 16 and 18
  (git-fixes).
- clk: sunxi: Fix operator precedence in sunxi_divs_clk_setup
  (git-fixes).
- clk: ti: clkctrl: Fix failed to enable error with double udelay
  timeout (git-fixes).
- clk: at91: avoid sleeping early (git-fixes).
- clk: at91: sam9x60: fix programmable clock (git-fixes).
- r8152: add device id for Lenovo ThinkPad USB-C Dock Gen 2
  (git-fixes).
- dmaengine: cppi41: Fix cppi41_dma_prep_slave_sg() when idle
  (git-fixes).
- dmaengine: qcom: bam_dma: Fix resource leak (git-fixes).
- dmaengine: sprd: Fix the possible memory leak issue (git-fixes).
- dmaengine: imx-sdma: fix size check for sdma script_number
  (git-fixes).
- dmaengine: tegra210-adma: fix transfer failure (git-fixes).
- dmaengine: sprd: Fix the link-list pointer register
  configuration issue (git-fixes).
- drm/amdgpu: fix error handling in amdgpu_bo_list_create
  (git-fixes).
- drm/amdgpu: fix potential VM faults (git-fixes).
- drm/komeda: Don't flush inactive pipes (git-fixes).
- regulator: pfuze100-regulator: Variable "val" in
  pfuze100_regulator_probe() could be uninitialized (git-fixes).
- regulator: ti-abb: Fix timeout in
  ti_abb_wait_txdone/ti_abb_clear_all_txdone (git-fixes).
- usb: gadget: udc: core: Fix segfault if udc_bind_to_driver()
  for pending driver fails (git-fixes).
- commit d6c29b6
* Mon Nov 11 2019 jack@suse.cz
- block: Warn if elevator= parameter is used (bsc#1156055).
- commit 87814cc
* Mon Nov 11 2019 mgorman@suse.de
- sched: Fix pick_next_task() vs 'change' pattern race (git fixes
  (sched)).
- commit 75aac31
* Mon Nov 11 2019 tiwai@suse.de
- ASoC: SOF: topology: Fix bytes control size checks (git-fixes).
- ASoC: ti: sdma-pcm: Add back the flags parameter for non
  standard dma names (git-fixes).
- ASoC: SOF: ipc: Fix memory leak in sof_set_get_large_ctrl_data
  (git-fixes).
- ASoC: SOF: Fix memory leak in sof_dfsentry_write (git-fixes).
- ASoC: kirkwood: fix device remove ordering (git-fixes).
- ASoC: rsnd: dma: fix SSI9 4/5/6/7 busif dma address (git-fixes).
- ASoC: hdmi-codec: drop mutex locking again (git-fixes).
- ASoC: kirkwood: fix external clock probe defer (git-fixes).
- ASoC: msm8916-wcd-analog: Fix RX1 selection in RDAC2 MUX
  (git-fixes).
- ASoC: SOF: control: return true when kcontrol values change
  (git-fixes).
- ASoC: Intel: sof-rt5682: add a check for devm_clk_get
  (git-fixes).
- ASoC: msm8916-wcd-digital: add missing MIX2 path for RX1/2
  (git-fixes).
- ASoC: wm_adsp: Don't generate kcontrols without READ flags
  (git-fixes).
- ASoC: intel: bytcr_rt5651: add null check to
  support_button_press (git-fixes).
- ASoC: intel: sof_rt5682: add remove function to disable jack
  (git-fixes).
- ASoC: rt5682: add NULL handler to set_jack function (git-fixes).
- ASoC: SOF: Intel: hda: Disable DMI L1 entry during capture
  (git-fixes).
- update config files (add SND_SOC_SOF_HDA_ALWAYS_ENABLE_DMI_L1=y on x86_64)
- ASoC: SOF: Intel: initialise and verify FW crash dump data
  (git-fixes).
- ASoC: SOF: Intel: hda: fix warnings during FW load (git-fixes).
- ASoC: SOF: topology: fix parse fail issue for byte/bool tuple
  types (git-fixes).
- ASoC: SOF: loader: fix kernel oops on firmware boot failure
  (git-fixes).
- ASoC: wm8994: Do not register inapplicable controls for WM1811
  (git-fixes).
- ASoC: samsung: arndale: Add missing OF node dereferencing
  (git-fixes).
- ASoC: pcm3168a: The codec does not support S32_LE (git-fixes).
- commit 6ff8cc0
* Mon Nov 11 2019 jslaby@suse.cz
- Refresh
  patches.suse/stacktrace-Don-t-skip-first-entry-on-noncurrent-task.patch.
  Update upstream status.
- commit fac489f
* Mon Nov 11 2019 mgorman@suse.de
- mm/gup: fix a misnamed "write" argument, and a related bug
  (git fixes (mm/gup)).
- commit d17d319
* Mon Nov 11 2019 mgorman@suse.de
- blacklist.conf: Blacklist change in THP allocation behaviour
- commit e194e08
* Mon Nov 11 2019 mgorman@suse.de
- blacklist.conf: Blacklist change in THP allocation behaviour
- commit 7e51886
* Mon Nov 11 2019 msuchanek@suse.de
- powerpc/mm/mce: Keep irqs disabled during lockless page table
  walk (bsc#1156395).
- commit 9275ddd
* Mon Nov 11 2019 glin@suse.com
- bpf: Change size to u64 for bpf_map_{area_alloc, charge_init}()
  (bsc#1155518).
- commit 04b6b83
* Mon Nov 11 2019 glin@suse.com
- bpf: Allow narrow loads of bpf_sysctl fields with offset > 0
  (bsc#1155518).
- commit 1c48ac9
* Fri Nov  8 2019 tiwai@suse.de
- Move upstreamed CA0132 patch into sorted section
- commit 04d225f
* Fri Nov  8 2019 tiwai@suse.de
- ALSA: timer: Fix incorrectly assigned timer instance
  (git-fixes).
- ALSA: hda: hdmi - add Tigerlake support (git-fixes).
- ALSA: bebob: fix to detect configured source of sampling clock
  for Focusrite Saffire Pro i/o series (git-fixes).
- commit b69261d
* Fri Nov  8 2019 tiwai@suse.de
- HID: Fix assumption that devices have inputs (git-fixes).
- Refresh
  patches.suse/HID-logitech-hidpp-split-g920_get_config.patch.
- commit 313ea5d
* Fri Nov  8 2019 tiwai@suse.de
- HID: wacom: generic: Treat serial number and related fields
  as unsigned (git-fixes).
- USB: serial: whiteheat: fix line-speed endianness (git-fixes).
- USB: gadget: Reject endpoints with 0 maxpacket value
  (git-fixes).
- usb: xhci: fix __le32/__le64 accessors in debugfs code
  (git-fixes).
- net: dsa: bcm_sf2: Fix IMP setup for port different than 8
  (git-fixes).
- rtlwifi: rtl_pci: Fix problem of too small skb->len (git-fixes).
- batman-adv: Avoid free/alloc race when handling OGM buffer
  (git-fixes).
- net: openvswitch: free vport unless register_netdevice()
  succeeds (git-fixes).
- drm/amdgpu/gmc10: properly set BANK_SELECT and FRAGMENT_SIZE
  (git-fixes).
- drm/amdgpu/powerplay/vega10: allow undervolting in p7
  (git-fixes).
- drm/amdgpu/gfx10: update gfx golden settings (git-fixes).
- HID: i2c-hid: add Trekstor Primebook C11B to descriptor override
  (git-fixes).
- misc: fastrpc: prevent memory leak in fastrpc_dma_buf_attach
  (git-fixes).
- iio: imu: adis16400: fix memory leak (git-fixes).
- iio: imu: adis16400: release allocated memory on failure
  (git-fixes).
- iio: fix center temperature of bmc150-accel-core (git-fixes).
- staging: rtl8188eu: fix null dereference when kzalloc fails
  (git-fixes).
- serial: 8250_omap: Fix gpio check for auto RTS/CTS (git-fixes).
- serial: mctrl_gpio: Check for NULL pointer (git-fixes).
- drm/amdgpu: fix memory leak (git-fixes).
- gpio: max77620: Use correct unit for debounce times (git-fixes).
- rtw88: Fix misuse of GENMASK macro (git-fixes).
- commit 7396a58
* Fri Nov  8 2019 tiwai@suse.de
- fjes: Handle workqueue allocation failure
  (CVE-2019-16231,bsc#1150466).
- commit 026d312
* Fri Nov  8 2019 tiwai@suse.de
- Update patch reference tag for dwc3 security fix (CVE-2019-18813, bsc#1156278)
- commit 2c755c4
* Fri Nov  8 2019 mkubecek@suse.cz
- series.conf: move sortable patches into sorted section
- move into sorted section:
  patches.suse/scsi-target-compare-full-CHAP_A-Algorithm-strings.patch
  patches.suse/scsi-target-fix-SendTargets-All-string-compares.patch
  patches.suse/scsi-target-remove-unused-extension-parameters.patch
  patches.suse/scsi-target-iscsi-CHAP-add-support-for-SHA1-SHA256-a.patch
  patches.suse/scsi-target-iscsi-tie-the-challenge-length-to-the-ha.patch
  patches.suse/scsi-target-iscsi-rename-some-variables-to-avoid-con.patch
- commit 80f0994
* Thu Nov  7 2019 msuchanek@suse.de
- Refresh patches.suse/powerpc-fadump-when-fadump-is-supported-register-the.patch.
- commit 035dc7c
* Thu Nov  7 2019 ddiss@suse.de
- patches.suse/scsi-target-iscsi-rename-some-variables-to-avoid-con.patch:
  (jsc#SES-1080).
- patches.suse/scsi-target-iscsi-tie-the-challenge-length-to-the-ha.patch:
  (jsc#SES-1080).
- patches.suse/scsi-target-iscsi-CHAP-add-support-for-SHA1-SHA256-a.patch:
  (jsc#SES-1080).
- patches.suse/scsi-target-remove-unused-extension-parameters.patch:
  (jsc#SES-1080).
- patches.suse/scsi-target-fix-SendTargets-All-string-compares.patch:
  (jsc#SES-1080).
- patches.suse/scsi-target-compare-full-CHAP_A-Algorithm-strings.patch:
  (jsc#SES-1080).
- commit d620bcd
* Thu Nov  7 2019 oneukum@suse.com
- media: Revert "media: vimc: propagate pixel format in the
  stream" (git-fixes).
- commit 34b5c83
* Thu Nov  7 2019 oneukum@suse.com
- media: vimc: stream: fix style of argument description
  (git-fixes).
- commit b398d8c
* Thu Nov  7 2019 oneukum@suse.com
- media: vimc: stream: remove obsolete function doc (git-fixes).
- commit eb41435
* Thu Nov  7 2019 oneukum@suse.com
- media: Revert "media: vimc: Remove or modify stream checks"
  (git-fixes).
- commit 249cb6d
* Thu Nov  7 2019 mkubecek@suse.cz
- supported.conf: cleanup
- drop modules built into vmlinux now:
  crypto/crc32
  drivers/video/macmodes
  fs/autofs4/autofs4
- drop extension
  drivers/hwmon/ina3221
- commit 6d1628e
* Thu Nov  7 2019 mkubecek@suse.cz
- update upstream references
- update Patch-mainline:
  patches.suse/cpusets-Rebuild-root-domain-deadline-accounting-information.patch
  patches.suse/membarrier-Fix-RCU-locking-bug-caused-by-faulty-merge.patch
  patches.suse/sched-Add-task_struct-pointer-to-sched_class-set_curr_task.patch
  patches.suse/sched-Allow-put_prev_task-to-drop-rq-lock.patch
  patches.suse/sched-Rework-CPU-hotplug-task-selection.patch
  patches.suse/sched-Rework-pick_next_task-slow-path.patch
  patches.suse/sched-core-Streamle-calls-to-task_rq_unlock.patch
  patches.suse/sched-fair-Avoid-redundant-EAS-calculation.patch
  patches.suse/sched-fair-Change-task_numa_work-storage-to-static.patch
  patches.suse/sched-fair-Expose-newidle_balance.patch
  patches.suse/sched-fair-Fall-back-to-sched-idle-CPU-if-idle-CPU-isn-t-found.patch
  patches.suse/sched-fair-Fix-Wunused-but-set-variable-warnings.patch
  patches.suse/sched-fair-Fix-low-cpu-usage-with-high-throttling-by-removing-expiration-of-cpu-local-slices.patch
  patches.suse/sched-fair-Introduce-fits_capacity.patch
  patches.suse/sched-fair-Move-init_numa_balancing-below-task_numa_work.patch
  patches.suse/sched-fair-Move-task_numa_work-init-to-init_numa_balancing.patch
  patches.suse/sched-fair-Speed-up-energy-aware-wake-ups.patch
  patches.suse/sched-fair-Start-tracking-SCHED_IDLE-tasks-count-in-cfs_rq.patch
  patches.suse/sched-isolation-Prefer-housekeeping-CPU-in-local-node.patch
  patches.suse/sched-membarrier-Fix-p-mm-membarrier_state-racy-load.patch
  patches.suse/sched-membarrier-Remove-redundant-check.patch
  patches.suse/sched-membarrier-Return-ENOMEM-to-userspace-on-memory-allocation-failure.patch
  patches.suse/sched-membarrier-Skip-IPIs-when-mm-mm_users-1.patch
  patches.suse/sched-rt-deadline-Fix-set_next_task-vs-pick_next_task.patch
  patches.suse/sched-stats-Fix-unlikely-use-of-sched_info_on.patch
  patches.suse/sched-topology-Add-partition_sched_domains_locked.patch
  patches.suse/stop_machine-Fix-stop_cpus_in_progress-ordering.patch
- commit 7497999
* Thu Nov  7 2019 mgorman@suse.de
- membarrier: Fix RCU locking bug caused by faulty merge
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit 49ddad8
* Wed Nov  6 2019 mgorman@suse.de
- sched/fair: Avoid redundant EAS calculation (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Fix -Wunused-but-set-variable warnings (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/membarrier: Return -ENOMEM to userspace on memory
  allocation failure (bnc#1155798 (CPU scheduler functional and
  performance backports)).
- sched/membarrier: Skip IPIs when mm->mm_users == 1 (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/membarrier: Fix p->mm->membarrier_state racy load
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/membarrier: Remove redundant check (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/fair: Speed-up energy-aware wake-ups (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched: Rework pick_next_task() slow-path (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched: Allow put_prev_task() to drop rq->lock (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Expose newidle_balance() (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- sched: Add task_struct pointer to sched_class::set_curr_task
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched: Rework CPU hotplug task selection (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/{rt,deadline}: Fix set_next_task vs pick_next_task
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- stop_machine: Fix stop_cpus_in_progress ordering (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Fix low cpu usage with high throttling by removing
  expiration of cpu-local slices (bnc#1155798 (CPU scheduler
  functional and performance backports)).
- cpusets: Rebuild root domain deadline accounting information
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/core: Streamle calls to task_rq_unlock() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/topology: Add partition_sched_domains_locked()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Introduce fits_capacity() (bnc#1155798 (CPU
  scheduler functional and performance backports)).
- sched/isolation: Prefer housekeeping CPU in local node
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/stats: Fix unlikely() use of sched_info_on() (bnc#1155798
  (CPU scheduler functional and performance backports)).
- sched/fair: Fall back to sched-idle CPU if idle CPU isn't
  found (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Start tracking SCHED_IDLE tasks count in cfs_rq
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Change task_numa_work() storage to static
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Move task_numa_work() init to init_numa_balancing()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- sched/fair: Move init_numa_balancing() below task_numa_work()
  (bnc#1155798 (CPU scheduler functional and performance
  backports)).
- commit daa1350
* Wed Nov  6 2019 oneukum@suse.com
- blacklist.conf: rendered moot by subsequent removal of the driver
  (which we didn't compile in SLE15 in the first place)
- commit 4972748
* Wed Nov  6 2019 yousaf.kaukab@suse.com
- enetc: Add mdio bus driver for the PCIe MDIO endpoint
  (jsc#SLE-9316).
- enetc: Clean up makefile (jsc#SLE-9316).
- commit 2f5843d
* Wed Nov  6 2019 yousaf.kaukab@suse.com
- config: arm64: enable nxp ls1028a (jsc#SLE-9263)
  Update supported.conf accordingly
- commit 3c653ff
* Wed Nov  6 2019 mkubecek@suse.cz
- series.conf: cleanup
- update upstream reference and move into sorted section:
  patches.suse/rtlwifi-Fix-potential-overflow-on-P2P-code.patch
- whitespace cleanup
  No effect on expanded tree.
- commit 913dbd6
* Wed Nov  6 2019 tiwai@suse.de
- rpm/kernel-source.spec.in: Fix dependency of kernel-devel (bsc#1154043)
- commit ceb9273
* Wed Nov  6 2019 jslaby@suse.cz
- rpm/kernel-binary.spec.in: add COMPRESS_VMLINUX (bnc#1155921)
  Let COMPRESS_VMLINUX determine the compression used for vmlinux. By
  default (historically), it is gz.
- commit c8b2d9f
* Wed Nov  6 2019 glin@suse.com
- selftests/bpf: More compatible nc options in test_lwt_ip_encap
  (bsc#1155518).
- selftests/bpf: Set rp_filter in test_flow_dissector
  (bsc#1155518).
- selftests/bpf: fix endianness issues in test_sysctl
  (bsc#1155518).
- selftests/bpf: improve unexpected success reporting in
  test_syctl (bsc#1155518).
- selftests/bpf: fix "ctx:write sysctl:write read ok" on s390
  (bsc#1155518).
- selftests/bpf: introduce bpf_cpu_to_be64 and bpf_be64_to_cpu
  (bsc#1155518).
- selftests/bpf: fix race in test_tcp_rtt test (bsc#1155518).
- tools: bpftool: move "__printf()" attributes to header file
  (bsc#1155518).
- tools: bpftool: fix format string for p_err() in
  detect_common_prefix() (bsc#1155518).
- tools: bpftool: fix format string for p_err() in
  query_flow_dissector() (bsc#1155518).
- tools: bpftool: fix argument for p_err() in BTF do_dump()
  (bsc#1155518).
- tools: bpftool: fix format strings and arguments for
  jsonw_printf() (bsc#1155518).
- tools: bpftool: fix arguments for p_err() in do_event_pipe()
  (bsc#1155518).
- commit 19d2eb7
* Wed Nov  6 2019 mgorman@suse.de
- series_sort: Move AMD-specific load balancing patch to sorted patch section
- commit c65ad73
* Tue Nov  5 2019 mkubecek@suse.cz
- Update upstream references:
  patches.suse/hugetlbfs-don-t-retry-when-pool-page-allocations-start-to-fail.patch
  patches.suse/mm-compaction-raise-compaction-priority-after-it-withdrawns.patch
  patches.suse/mm-compaction.c-remove-unnecessary-zone-parameter-in-isolate_migratepages.patch
  patches.suse/mm-filemap.c-don-t-initiate-writeback-if-mapping-has-no-dirty-pages.patch
  patches.suse/mm-filemap.c-rewrite-mapping_needs_writeback-in-less-fancy-manner.patch
  patches.suse/mm-mempolicy.c-remove-unnecessary-nodemask-check-in-kernel_migrate_pages.patch
  patches.suse/mm-reclaim-cleanup-should_continue_reclaim.patch
  patches.suse/mm-reclaim-make-should_continue_reclaim-perform-dryrun-detection.patch
  patches.suse/mm-replace-list_move_tail-with-add_page_to_lru_list_tail.patch
  patches.suse/mm-sl-aou-b-guarantee-natural-alignment-for-kmalloc-power-of-two.patch
  patches.suse/mm-sl-ou-b-improve-memory-accounting.patch
  patches.suse/mm-vmscan-do-not-share-cgroup-iteration-between-reclaimers.patch
  patches.suse/sched-topology-Improve-load-balancing-on-AMD-EPYC.patch
- commit 471d837
* Tue Nov  5 2019 tiwai@suse.de
- ALSA: hda/ca0132 - Fix possible workqueue stall (bsc#1155836).
- commit a383566
* Tue Nov  5 2019 tbogendoerfer@suse.de
- supported.conf: mark efa and siw as supported
- commit 6c0057f
* Tue Nov  5 2019 tbogendoerfer@suse.de
- net: fix installing orphaned programs (bsc#1154353).
- net: cls_bpf: fix NULL deref on offload filter removal
  (bsc#1154353).
- net: phylink: Fix phylink_dbg() macro (bsc#1154353).
- inet: stop leaking jiffies on the wire (bsc#1154353).
- ixgbe: Remove duplicate clear_bit() call (jsc#SLE-7979
  jsc#SLE-7981).
- e1000: fix memory leaks (jsc#SLE-8100).
- i40e: Fix receive buffer starvation for AF_XDP (jsc#SLE-8025).
- igb: Fix constant media auto sense switching when no cable is
  connected (jsc#SLE-7967 jsc#SLE-8010).
- igb: Enable media autosense for the i350 (jsc#SLE-7967
  jsc#SLE-8010).
- igb/igc: Don't warn on fatal read failures when the device is
  removed (jsc#SLE-7967 jsc#SLE-8010).
- tcp: increase tcp_max_syn_backlog max value (bsc#1154353).
- netdevsim: Fix use-after-free during device dismantle
  (bsc#1154353).
- cxgb4: fix panic when attaching to ULD fail (jsc#SLE-8389).
- net: annotate lockless accesses to sk->sk_napi_id (bsc#1154353).
- net: annotate accesses to sk->sk_incoming_cpu (bsc#1154353).
- mlxsw: core: Unpublish devlink parameters during reload
  (bsc#1154488).
- qed: Optimize execution time for nvm attributes configuration
  (jsc#SLE-8401).
- vxlan: fix unexpected failure of vxlan_changelink()
  (bsc#1154353).
- qed: fix spelling mistake "queuess" -> "queues" (jsc#SLE-8401).
- net/mlx5e: Initialize on stack link modes bitmap (jsc#SLE-8464).
- net/mlx5e: Fix ethtool self test: link speed (jsc#SLE-8464).
- net/mlx5e: Fix handling of compressed CQEs in case of low NAPI
  budget (jsc#SLE-8464).
- net/mlx5e: Don't store direct pointer to action's tunnel info
  (jsc#SLE-8464).
- net/mlx5: Fix NULL pointer dereference in extended destination
  (jsc#SLE-8464).
- net/mlx5: Fix rtable reference leak (jsc#SLE-8464).
- net/mlx5e: Only skip encap flows update when encap init failed
  (jsc#SLE-8464).
- net/mlx5e: Replace kfree with kvfree when free vhca stats
  (jsc#SLE-8464).
- net/mlx5e: Remove incorrect match criteria assignment line
  (jsc#SLE-8464).
- net/mlx5e: Determine source port properly for vlan push action
  (jsc#SLE-8464).
- net: rtnetlink: fix a typo fbd -> fdb (bsc#1154353).
- bonding: fix using uninitialized mode_lock (bsc#1154353).
- vxlan: check tun_info options_len properly (bsc#1154353).
- erspan: fix the tun_info options_len check for erspan
  (bsc#1154353).
- net: hisilicon: Fix ping latency when deal with high throughput
  (bsc#1154353).
- net/mlx4_core: Dynamically set guaranteed amount of counters
  per VF (jsc#SLE-8460).
- net: hisilicon: Fix "Trying to free already-free IRQ"
  (bsc#1154353).
- net: fix sk_page_frag() recursion from memory reclaim
  (bsc#1154353).
- udp: fix data-race in udp_set_dev_scratch() (bsc#1154353).
- net: add READ_ONCE() annotation in __skb_wait_for_more_packets()
  (bsc#1154353).
- net: use skb_queue_empty_lockless() in busy poll contexts
  (bsc#1154353).
- net: use skb_queue_empty_lockless() in poll() handlers
  (bsc#1154353).
- udp: use skb_queue_empty_lockless() (bsc#1154353).
- net: add skb_queue_empty_lockless() (bsc#1154353).
- ipvs: move old_secure_tcp into struct netns_ipvs (bsc#1154353).
- ipvs: don't ignore errors in case refcounting ip_vs module fails
  (bsc#1154353).
- netfilter: nft_payload: fix missing check for matching length
  in offloads (bsc#1154353).
- netfilter: nf_flow_table: set timeout before insertion into
  hashes (bsc#1154353).
- xsk: Fix registration of Rx-only sockets (bsc#1154353).
- xdp: Handle device unregister for devmap_hash map type
  (bsc#1154353).
- xdp: Prevent overflow in devmap_hash cost calculation for
  32-bit builds (bsc#1154353).
- bpf: lwtunnel: Fix reroute supplying invalid dst (bsc#1154353).
- ipv4: fix route update on metric change (bsc#1154353).
- net: Zeroing the structure ethtool_wolinfo in ethtool_get_wol()
  (bsc#1154353).
- cxgb4: request the TX CIDX updates to status page
  (jsc#SLE-8389).
- netns: fix GFP flags in rtnl_net_notifyid() (bsc#1154353).
- net: sch_generic: Use pfifo_fast as fallback scheduler for
  CAN hardware (bsc#1154353).
- net: remove unnecessary variables and callback (bsc#1154353).
- vxlan: add adjacent link to limit depth level (bsc#1154353).
- net: core: add ignore flag to netdev_adjacent structure
  (bsc#1154353).
- team: fix nested locking lockdep warning (bsc#1154353).
- bonding: use dynamic lockdep key instead of subclass
  (bsc#1154353).
- bonding: fix unexpected IFF_BONDING bit unset (bsc#1154353).
- net: core: add generic lockdep keys (bsc#1154353).
- net: core: limit nested device depth (bsc#1154353).
- keys: Fix memory leak in copy_net_ns (bsc#1154353).
- net/flow_dissector: switch to siphash (bsc#1154353).
- ipv6: include <net/addrconf.h> for missing declarations
  (bsc#1154353).
- bnxt_en: Avoid disabling pci device in bnxt_remove_one()
  for already disabled device (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Minor formatting changes in FW devlink_health_reporter
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Adjust the time to wait before polling firmware
  readiness (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix devlink NVRAM related byte order related issues
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Fix the size of devlink MSIX parameters (jsc#SLE-8371
  bsc#1153274).
- ipv4: fix IPSKB_FRAG_PMTU handling with fragmentation
  (bsc#1154353).
- net/mlx5: fix memory leak in mlx5_fw_fatal_reporter_dump
  (jsc#SLE-8464).
- net/mlx5: prevent memory leak in mlx5_fpga_conn_create_cq
  (jsc#SLE-8464).
- net/mlx5e: TX, Fix consumer index of error cqe dump
  (jsc#SLE-8464).
- net/mlx5e: kTLS, Enhance TX resync flow (jsc#SLE-8464).
- net/mlx5e: kTLS, Save a copy of the crypto info (jsc#SLE-8464).
- net/mlx5e: kTLS, Remove unneeded cipher type checks
  (jsc#SLE-8464).
- net/mlx5e: kTLS, Limit DUMP wqe size (jsc#SLE-8464).
- net/mlx5e: kTLS, Fix missing SQ edge fill (jsc#SLE-8464).
- net/mlx5e: kTLS, Fix page refcnt leak in TX resync error flow
  (jsc#SLE-8464).
- net/mlx5e: kTLS, Save by-value copy of the record frags
  (jsc#SLE-8464).
- net/mlx5e: kTLS, Save only the frag page to release at
  completion (jsc#SLE-8464).
- net/mlx5e: kTLS, Size of a Dump WQE is fixed (jsc#SLE-8464).
- net/mlx5e: kTLS, Release reference on DUMPed fragments in
  shutdown flow (jsc#SLE-8464).
- net/mlx5e: Tx, Zero-memset WQE info struct upon update
  (jsc#SLE-8464).
- net/mlx5e: Tx, Fix assumption of single WQEBB of NOP in cleanup
  flow (jsc#SLE-8464).
- SUNRPC: Destroy the back channel when we destroy the host
  transport (bsc#1154353).
- SUNRPC: The RDMA back channel mustn't disappear while requests
  are outstanding (bsc#1154353).
- SUNRPC: The TCP back channel mustn't disappear while requests
  are outstanding (bsc#1154353).
- RDMA/hns: Prevent memory leaks of eq->buf_list (jsc#SLE-8449).
- RDMA/iw_cxgb4: Avoid freeing skb twice in arp failure case
  (jsc#SLE-8392).
- RDMA/mlx5: Use irq xarray locking for mkey_table (jsc#SLE-8446).
- IB/core: Avoid deadlock during netlink message handling
  (jsc#SLE-8449).
- RDMA/nldev: Skip counter if port doesn't match (jsc#SLE-8449).
- RDMA/uverbs: Prevent potential underflow (jsc#SLE-8449).
- IB/core: Use rdma_read_gid_l2_fields to compare GID L2 fields
  (jsc#SLE-8449).
- RDMA/qedr: Fix reported firmware version (jsc#SLE-8215).
- RDMA/siw: free siw_base_qp in kref release routine
  (jsc#SLE-8381).
- RDMA/iwcm: move iw_rem_ref() calls out of spinlock
  (jsc#SLE-8449).
- iw_cxgb4: fix ECN check on the passive accept (jsc#SLE-8392).
- IB/hfi1: Use a common pad buffer for 9B and 16B packets
  (jsc#SLE-8449).
- IB/hfi1: Avoid excessive retry for TID RDMA READ request
  (jsc#SLE-8449).
- RDMA/mlx5: Clear old rate limit when closing QP (jsc#SLE-8446).
- net: reorder 'struct net' fields to avoid false sharing
  (bsc#1154353).
- net: netem: correct the parent's backlog when corrupted packet
  was dropped (bsc#1154353).
- net: netem: fix error path for corrupted GSO frames
  (bsc#1154353).
- net: hns3: fix mis-counting IRQ vector numbers issue
  (bsc#1154353).
- mlxsw: spectrum_trap: Push Ethernet header before reporting trap
  (bsc#1154488).
- net: ensure correct skb->tstamp in various fragmenters
  (bsc#1154353).
- tcp: fix a possible lockdep splat in tcp_done() (bsc#1154353).
- net: cavium: Use the correct style for SPDX License Identifier
  (bsc#1154353).
- tcp: annotate sk->sk_wmem_queued lockless reads (bsc#1154353).
- tcp: annotate sk->sk_sndbuf lockless reads (bsc#1154353).
- tcp: annotate sk->sk_rcvbuf lockless reads (bsc#1154353).
- tcp: annotate tp->urg_seq lockless reads (bsc#1154353).
- tcp: annotate tp->snd_nxt lockless reads (bsc#1154353).
- tcp: annotate tp->write_seq lockless reads (bsc#1154353).
- tcp: annotate tp->copied_seq lockless reads (bsc#1154353).
- tcp: annotate tp->rcv_nxt lockless reads (bsc#1154353).
- tcp: add rcu protection around tp->fastopen_rsk (bsc#1154353).
- net: silence KCSAN warnings about sk->sk_backlog.len reads
  (bsc#1154353).
- net: annotate sk->sk_rcvlowat lockless reads (bsc#1154353).
- net: silence KCSAN warnings around sk_add_backlog() calls
  (bsc#1154353).
- tcp: annotate lockless access to tcp_memory_pressure
  (bsc#1154353).
- net: add {READ|WRITE}_ONCE() annotations on ->rskq_accept_head
  (bsc#1154353).
- net: avoid possible false sharing in sk_leave_memory_pressure()
  (bsc#1154353).
- netfilter: conntrack: avoid possible false sharing
  (bsc#1154353).
- netns: fix NLM_F_ECHO mechanism for RTM_NEWNSID (bsc#1154353).
- sctp: add chunks to sk_backlog when the newsk sk_socket is
  not set (bsc#1154353).
- ip6erspan: remove the incorrect mtu limit for ip6erspan
  (bsc#1154353).
- net/mlx5: DR, Allow insertion of duplicate rules (jsc#SLE-8464).
- rxrpc: rxrpc_peer needs to hold a ref on the rxrpc_local record
  (bsc#1154353).
- rxrpc: Fix trace-after-put looking at the put call record
  (bsc#1154353).
- rxrpc: Fix trace-after-put looking at the put connection record
  (bsc#1154353).
- rxrpc: Fix trace-after-put looking at the put peer record
  (bsc#1154353).
- rxrpc: Fix call ref leak (bsc#1154353).
- commit ccf9a99
* Tue Nov  5 2019 mbrugger@suse.com
- rpm/mkspec-dtb: add mt76 based dtb package
- commit 8ff92d0
* Tue Nov  5 2019 tiwai@suse.de
- usb: dwc3: gadget: fix race when disabling ep with cancelled
  xfers (git-fixes).
- USB: serial: whiteheat: fix potential slab corruption
  (git-fixes).
- UAS: Revert commit 3ae62a42090f ("UAS: fix alignment of
  scatter/gather segments") (git-fixes).
- usb-storage: Revert commit 747668dbc061 ("usb-storage: Set
  virt_boundary_mask to avoid SG overflows") (git-fixes).
- usb: xhci: fix Immediate Data Transfer endianness (git-fixes).
- xhci: Fix use-after-free regression in xhci clear hub TT
  implementation (git-fixes).
- USB: ldusb: fix control-message timeout (git-fixes).
- USB: ldusb: fix ring-buffer locking (git-fixes).
- usb: dwc3: pci: prevent memory leak in dwc3_pci_probe
  (git-fixes).
- usb: gadget: udc: atmel: Fix interrupt storm in FIFO mode
  (git-fixes).
- usb: dwc3: select CONFIG_REGMAP_MMIO (git-fixes).
- hwmon: (ina3221) Fix read timeout issue (git-fixes).
- r8169: fix wrong PHY ID issue with RTL8168dp (git-fixes).
- mt76: dma: fix buffer unmap with non-linear skbs (git-fixes).
- nl80211: fix validation of mesh path nexthop (git-fixes).
- wimax: i2400: Fix memory leak in i2400m_op_rfkill_sw_toggle
  (git-fixes).
- virt_wifi: fix refcnt leak in module exit routine (git-fixes).
- macsec: fix refcnt leak in module exit routine (git-fixes).
- keys: Fix memory leak in copy_net_ns (git-fixes).
- drm/i915: Fix PCH reference clock for FDI on HSW/BDW
  (git-fixes).
- drm/v3d: Fix memory leak in v3d_submit_cl_ioctl (git-fixes).
- commit 7b0a0d1
* Tue Nov  5 2019 mgorman@suse.de
- mm, sl[aou]b: guarantee natural alignment for
  kmalloc(power-of-two) (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm, sl[ou]b: improve memory accounting (bnc#1155780 (VM/FS
  functional and performance backports)).
- hugetlbfs: don't retry when pool page allocations start to fail
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, compaction: raise compaction priority after it withdrawns
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm, reclaim: cleanup should_continue_reclaim() (bnc#1155780
  (VM/FS functional and performance backports)).
- mm, reclaim: make should_continue_reclaim perform dryrun
  detection (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm/mempolicy.c: remove unnecessary nodemask check in
  kernel_migrate_pages() (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm/compaction.c: remove unnecessary zone parameter in
  isolate_migratepages() (bnc#1155780 (VM/FS functional and
  performance backports)).
- mm: vmscan: do not share cgroup iteration between reclaimers
  (bnc#1155780 (VM/FS functional and performance backports)).
- mm/filemap.c: rewrite mapping_needs_writeback in less
  fancy manner (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm/filemap.c: don't initiate writeback if mapping has no
  dirty pages (bnc#1155780 (VM/FS functional and performance
  backports)).
- mm: replace list_move_tail() with add_page_to_lru_list_tail()
  (bnc#1155780 (VM/FS functional and performance backports)).
- commit d426df6
* Tue Nov  5 2019 jslaby@suse.cz
- stacktrace: Don't skip first entry on noncurrent tasks
  (bnc#1154866).
- commit cc9ff55
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0056-acpi-Disable-ACPI-table-override-if-the-kernel-is-lo.patch.
  This patch be replaced by 6ea0e815fc in v5.4-rc1. (jsc#SLE-9870)
- commit 76eea73
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0055-acpi-Ignore-acpi_rsdp-kernel-param-when-the-kernel-h.patch.
  This patch be replaced by 41fa1ee9c6 in v5.4-rc1. (jsc#SLE-9870)
- commit a511e8c
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0054-ACPI-Limit-access-to-custom_method-when-the-kernel-i.patch.
  This patch be replaced by f474e1486 in v5.4-rc1. (jsc#SLE-9870)
- commit 881b574
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0053-asus-wmi-Restrict-debugfs-interface-when-the-kernel-.patch.
  This patch be replaced by 5496197f9b in v5.4-rc1. (jsc#SLE-9870)
- commit 26e7156
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0052-x86-Restrict-MSR-access-when-the-kernel-is-locked-do.patch.
  This patch be replaced by 95f5e95f41 in v5.4-rc1. (jsc#SLE-9870)
- commit d5a4f81
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0051-x86-Lock-down-IO-port-access-when-the-kernel-is-lock.patch.
  This patch be replaced by 9b9d8dda1e in v5.4-rc1. (jsc#SLE-9870)
- commit a338a65
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0050-PCI-Lock-down-BAR-access-when-the-kernel-is-locked-d.patch.
  This patch be replaced by eb627e1772 in v5.4-rc1. (jsc#SLE-9870)
- commit 35fdce5
* Tue Nov  5 2019 jlee@suse.com
- Delete
  patches.suse/0048-hibernate-Disable-when-the-kernel-is-locked-down.patch.
  This patch be replaced by 38bd94b8a in v5.4-rc1. (jsc#SLE-9870)
- commit a36f246
* Tue Nov  5 2019 mkubecek@suse.cz
- update upstream references
- move to "almost mainline" section:
  patches.suse/autonuma-fix-watermark-checking-in-migrate_balanced_pgdat.patch
  patches.suse/autonuma-reduce-cache-footprint-when-scanning-page-tables.patch
- update patch-mainline:
  patches.suse/mm-slub.c-init_on_free-1-should-wipe-freelist-ptr-for-bulk-allocations.patch
  patches.suse/sched-fair-Scale-bandwidth-quota-and-period-without-losing-quota-period-ratio-precision.patch
  patches.suse/sched-vtime-Fix-guest-system-mis-accounting-on-task-switch.patch
  No effect on expanded tree.
- commit 509d57a
* Mon Nov  4 2019 mgorman@suse.de
- Refresh
  patches.suse/sched-topology-Improve-load-balancing-on-AMD-EPYC.patch.
- commit d1f7e6e
* Mon Nov  4 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: Mention debuginfo in the subpackage
  description (bsc#1149119).
- commit 525ec92
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0047-kexec_file-restrict-if-the-kernel-is-locked-down.patch.
  This patch be replaced by 155bdd30a in v5.4-rc1. (jsc#SLE-9870)
- commit 539b083
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0047-kexec_file-split-KEXEC_VERIFY_SIG.patch.
  This patch be replaced by 99d5cadfd in v5.4-rc1. (jsc#SLE-9870)
- commit b4392d9
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0046-Copy-secure_boot-flag-in-boot-params-across-kexec-re.patch.
  This patch be replaced by fef5dad987 in v5.4-rc1. (jsc#SLE-9870)
- commit 2ac33a1
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0045-kexec-Disable-at-runtime-if-the-kernel-is-locked-dow.patch.
  This patch be replaced by 7d31f4602f in v5.4-rc1. (jsc#SLE-9870)
- commit 6378a1f
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0043-Restrict-dev-mem-and-dev-kmem-when-the-kernel-is-loc.patch.
  This patch be replaced by 9b9d8dda1e in v5.4-rc1. (jsc#SLE-9870)
- commit 471bb54
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0042-Enforce-module-signatures-if-the-kernel-is-locked-do.patch.
  This patch be replaced by 49fcf732bd in v5.4-rc1. (jsc#SLE-9870)
- commit 0f1ab5f
* Mon Nov  4 2019 jlee@suse.com
- Delete
  patches.suse/0040-Add-the-ability-to-lock-down-access-to-the-running-k.patch.
  This patch be replaced by 9e47d31d6a and 000d388ed3 in v5.4-rc1. (jsc#SLE-9870)
- commit a3aff83
* Mon Nov  4 2019 jslaby@suse.cz
- powerpc/powernv: Fix CPU idle to be called with IRQs disabled
  (git-fixes).
- efi/tpm: Return -EINVAL when determining tpm final events log
  size fails (git-fixes).
- commit 0afb81a
* Mon Nov  4 2019 mgorman@suse.de
- autonuma: Reduce cache footprint when scanning page tables
  (bnc#1155756).
- autonuma: fix watermark checking in migrate_balanced_pgdat()
  (bnc#1155756).
- commit 92ab99b
* Mon Nov  4 2019 glin@suse.com
- bpf: Fix use after free in bpf_get_prog_name (bsc#1155518).
- bpf: Fix use after free in subprog's jited symbol removal
  (bsc#1155518).
- commit 0ffd4be
* Sun Nov  3 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream reference:
  patches.suse/scsi-lpfc-Check-queue-pointer-before-use.patch
  patches.suse/scsi-qla2xxx-Fix-partial-flash-write-of-MBI.patch
  patches.suse/scsi-qla2xxx-Initialized-mailbox-to-prevent-driver-l.patch
  patches.suse/scsi-qla2xxx-fixup-incorrect-usage-of-host_byte.patch
  patches.suse/scsi-qla2xxx-stop-timer-in-shutdown-path.patch
- no effect on expanded tree
- commit 37e310e
* Fri Nov  1 2019 tiwai@suse.de
- ALSA: timer: Fix mutex deadlock at releasing card (git-fixes).
- ALSA: hda - Fix mutex deadlock in HDMI codec driver (git-fixes).
- Revert "ALSA: hda: Flush interrupts on disabling" (git-fixes).
- ALSA: bebob: Fix prototype of helper function to return negative
  value (git-fixes).
- ALSA: hda/realtek - Fix 2 front mics of codec 0x623 (git-fixes).
- ALSA: hda/realtek - Add support for ALC623 (git-fixes).
- ALSA: usb-audio: Add DSD support for Gustard U16/X26 USB
  Interface (git-fixes).
- commit ed66481
* Fri Nov  1 2019 mkubecek@suse.cz
- Update upstream references:
  patches.suse/mm-meminit-Recalculate-pcpu-batch-and-high-limits-after-init-completes.patch.
  patches.suse/mm-pcp-Share-common-code-between-memory-hotplug-and-percpu-sysctl-handler.patch.
  patches.suse/mm-pcpu-Make-zone-pcp-updates-and-reset-internal-to-the-mm.patch.
- move these patches to "soon to be mainline" section
- commit 8b0a210
* Fri Nov  1 2019 mgorman@suse.de
- sched/vtime: Fix guest/system mis-accounting on task switch
  (git fixes (cputime accounting)).
- sched/fair: Scale bandwidth quota and period without losing
  quota/period ratio precision (git fixes (sched)).
- commit dc7f4dd
* Fri Nov  1 2019 mgorman@suse.de
- mm/slub.c: init_on_free=1 should wipe freelist ptr for bulk
  allocations (git fixes (mm/slub)).
- commit 1fe1553
* Fri Nov  1 2019 mgorman@suse.de
- mm, pcpu: Make zone pcp updates and reset internal to the mm
  (bnc#1155628).
- mm, pcp: Share common code between memory hotplug and percpu
  sysctl handler (bnc#1155628).
- mm, meminit: Recalculate pcpu batch and high limits after init
  completes (bnc#1155628).
- commit ca89c1c
* Thu Oct 31 2019 mkubecek@suse.cz
- refresh config files
  No functional change.
- commit b484ff3
* Thu Oct 31 2019 mkoutny@suse.com
- Update config files: Disable CONFIG_RT_GROUP_SCHED (jsc#SLE-10427)
- commit db9fda6
* Thu Oct 31 2019 jlee@suse.com
- MODSIGN: make new include file self contained (jsc#SLE-9870).
- commit 9916222
* Thu Oct 31 2019 glin@suse.com
- bpf: fix BTF limits (bsc#1155518).
- commit 97d5e03
* Thu Oct 31 2019 jlee@suse.com
- MODSIGN: Export module signature definitions (jsc#SLE-9870).
- Update config files.
- Refresh
  patches.suse/KEYS-Make-use-of-platform-keyring-for-module-signatu.patch.
- commit 10961d4
* Thu Oct 31 2019 mkubecek@suse.cz
- Update references (add CVE-2019-10220 bsc#1144903 bso#14072):
  patches.suse/Make-filldir-64-verify-the-directory-entry-filename-.patch
  patches.suse/filldir-64-remove-WARN_ON_ONCE-for-bad-directory-ent.patch
- commit e4c1e0f
* Wed Oct 30 2019 dwagner@suse.de
- scsi: qla2xxx: stop timer in shutdown path (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix partial flash write of MBI (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Initialized mailbox to prevent driver load
  failure (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: fixup incorrect usage of host_byte (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- commit 1cb635f
* Wed Oct 30 2019 dwagner@suse.de
- Refresh patches.suse/scsi-lpfc-Check-queue-pointer-before-use.patch
- commit 56420bc
* Wed Oct 30 2019 jslaby@suse.cz
- nbd: verify socket is supported during setup (git-fixes).
- commit 85aab98
* Wed Oct 30 2019 jlee@suse.com
- x86/boot/acpi: Move get_cmdline_acpi_rsdp() under #ifdef guard
  (jsc#SLE-9870).
- tracefs: Revert ccbd54ff54e8 ("tracefs: Restrict tracefs when
  the kernel is locked down") (jsc#SLE-9870).
- kexec: Fix file verification on S390 (jsc#SLE-9870).
- security: constify some arrays in lockdown LSM (jsc#SLE-9870).
- lockdown: Print current->comm in restriction messages
  (jsc#SLE-9870).
- efi: Restrict efivar_ssdt_load when the kernel is locked down
  (jsc#SLE-9870).
- tracefs: Restrict tracefs when the kernel is locked down
  (jsc#SLE-9870).
- debugfs: Restrict debugfs when the kernel is locked down
  (jsc#SLE-9870).
- kexec: Allow kexec_file() with appropriate IMA policy when
  locked down (jsc#SLE-9870).
- lockdown: Lock down perf when in confidentiality mode
  (jsc#SLE-9870).
- bpf: Restrict bpf when kernel lockdown is in confidentiality
  mode (jsc#SLE-9870).
- lockdown: Lock down tracing and perf kprobes when in
  confidentiality mode (jsc#SLE-9870).
- lockdown: Lock down /proc/kcore (jsc#SLE-9870).
- x86/mmiotrace: Lock down the testmmiotrace module
  (jsc#SLE-9870).
- lockdown: Lock down module params that specify hardware
  parameters (eg. ioport) (jsc#SLE-9870).
- lockdown: Lock down TIOCSSERIAL (jsc#SLE-9870).
- lockdown: Prohibit PCMCIA CIS storage when the kernel is locked
  down (jsc#SLE-9870).
- acpi: Disable ACPI table override if the kernel is locked down
  (jsc#SLE-9870).
- acpi: Ignore acpi_rsdp kernel param when the kernel has been
  locked down (jsc#SLE-9870).
- ACPI: Limit access to custom_method when the kernel is locked
  down (jsc#SLE-9870).
- x86/msr: Restrict MSR access when the kernel is locked down
  (jsc#SLE-9870).
- x86: Lock down IO port access when the kernel is locked down
  (jsc#SLE-9870).
- PCI: Lock down BAR access when the kernel is locked down
  (jsc#SLE-9870).
- hibernate: Disable when the kernel is locked down
  (jsc#SLE-9870).
- kexec_file: Restrict at runtime if the kernel is locked down
  (jsc#SLE-9870).
- kexec_file: split KEXEC_VERIFY_SIG into KEXEC_SIG and
  KEXEC_SIG_FORCE (jsc#SLE-9870).
- Update config files. (jsc#SLE-9870)
- lockdown: Copy secure_boot flag in boot params across kexec
  reboot (jsc#SLE-9870).
- kexec_load: Disable at runtime if the kernel is locked down
  (jsc#SLE-9870).
- lockdown: Restrict /dev/{mem,kmem,port} when the kernel is
  locked down (jsc#SLE-9870).
- lockdown: Enforce module signatures if the kernel is locked down
  (jsc#SLE-9870).
- security: Add a static lockdown policy LSM (jsc#SLE-9870).
- Update config files. (jsc#SLE-9870)
- security: Add a "locked down" LSM hook (jsc#SLE-9870).
- security: Support early LSMs (jsc#SLE-9870).
- commit f827a66
* Tue Oct 29 2019 dbueso@suse.de
- tasks, sched/core: RCUify the assignment of rq->curr
  (bsc#1155364).
- tasks, sched/core: With a grace period after
  finish_task_switch(), remove unnecessary code (bsc#1155364).
- tasks, sched/core: Ensure tasks are available for a grace
  period after leaving the runqueue (bsc#1155364).
- tasks: Add a count of task RCU users (bsc#1155364).
- commit 270b1d3
* Tue Oct 29 2019 tiwai@suse.de
- net: dsa: fix switch tree list (git-fixes).
- net: dsa: b53: Do not clear existing mirrored port mask
  (git-fixes).
- net: dsa: rtl8366rb: add missing of_node_put after calling
  of_get_child_by_name (git-fixes).
- net: dsa: qca8k: Use up to 7 ports for all operations
  (git-fixes).
- net: dsa: mv88e6xxx: fix SMI bit checking (git-fixes).
- commit 0fcc138
* Tue Oct 29 2019 tiwai@suse.de
- lib/vdso: Make clock_getres() POSIX compliant again (git-fixes).
- commit 88590ee
* Tue Oct 29 2019 tiwai@suse.de
- net: phy: bcm7xxx: define soft_reset for 40nm EPHY (git-fixes).
- net: phy: micrel: Discern KSZ8051 and KSZ8795 PHYs (git-fixes).
- net: phy: fix write to mii-ctrl1000 register (git-fixes).
- commit 904870e
* Tue Oct 29 2019 tiwai@suse.de
- dmaengine: iop-adma.c: fix printk format warning (git-fixes).
- commit bb35c8c
* Tue Oct 29 2019 tiwai@suse.de
- ASoC: core: use list_del_init and move it back to
  soc_cleanup_component (git-fixes).
- ASoC: core: delete component->card_list in soc_remove_component
  only (git-fixes).
- commit bb8cb13
* Tue Oct 29 2019 tiwai@suse.de
- Refresh patches.suse/ASoC-es8328-Fix-copy-paste-error-in-es8328_right_lin.patch
  Add a cherry-picked commit to ignore, too
- commit 758f004
* Tue Oct 29 2019 jslaby@suse.cz
- Linux 5.3.8 (bnc#1151927 5.3.8).
- lib/vdso: Make clock_getres() POSIX compliant again (bnc#1151927
  5.3.8).
- perf/aux: Fix AUX output stopping (bnc#1151927 5.3.8).
- CIFS: Fix use after free of file info structures (bnc#1151927
  5.3.8).
- cifs: Fix missed free operations (bnc#1151927 5.3.8).
- CIFS: avoid using MID 0xFFFF (bnc#1151927 5.3.8).
- MIPS: tlbex: Fix build_restore_pagemask KScratch restore
  (bnc#1151927 5.3.8).
- binder: Don't modify VMA bounds in ->mmap handler (bnc#1151927
  5.3.8).
- io_uring: fix bad inflight accounting for
  SETUP_IOPOLL|SETUP_SQTHREAD (bnc#1151927 5.3.8).
- io_uring: used cached copies of sq->dropped and cq->overflow
  (bnc#1151927 5.3.8).
- io_uring: Fix race for sqes with userspace (bnc#1151927 5.3.8).
- io_uring: Fix broken links with offloading (bnc#1151927 5.3.8).
- io_uring: Fix corrupted user_data (bnc#1151927 5.3.8).
- s390/kaslr: add support for R_390_GLOB_DAT relocation type
  (bnc#1151927 5.3.8).
- s390/zcrypt: fix memleak at release (bnc#1151927 5.3.8).
- fs/dax: Fix pmd vs pte conflict detection (bnc#1151927 5.3.8).
- scsi: core: try to get module before removing device
  (bnc#1151927 5.3.8).
- scsi: ch: Make it possible to open a ch device multiple times
  again (bnc#1151927 5.3.8).
- KVM: PPC: Book3S HV: XIVE: Ensure VP isn't already in use
  (bnc#1151927 5.3.8).
- drm/amdgpu/vce: fix allocation size in enc ring test
  (bnc#1151927 5.3.8).
- drm/amdgpu: user pages array memory leak fix (bnc#1151927
  5.3.8).
- drm/amdgpu/vcn: fix allocation size in enc ring test
  (bnc#1151927 5.3.8).
- drm/amdgpu/uvd7: fix allocation size in enc ring test (v2)
  (bnc#1151927 5.3.8).
- drm/amdgpu/uvd6: fix allocation size in enc ring test (v2)
  (bnc#1151927 5.3.8).
- mmc: cqhci: Commit descriptors before setting the doorbell
  (bnc#1151927 5.3.8).
- of: reserved_mem: add missing of_node_put() for proper
  ref-counting (bnc#1151927 5.3.8).
- opp: of: drop incorrect lockdep_assert_held() (bnc#1151927
  5.3.8).
- tracing: Fix race in perf_trace_buf initialization (bnc#1151927
  5.3.8).
- EDAC/ghes: Fix Use after free in ghes_edac remove path
  (bnc#1151927 5.3.8).
- Btrfs: fix qgroup double free after failure to reserve metadata
  for delalloc (bnc#1151927 5.3.8).
- btrfs: don't needlessly create extent-refs kernel thread
  (bnc#1151927 5.3.8).
- Btrfs: add missing extents release on file extent cluster
  relocation error (bnc#1151927 5.3.8).
- Refresh
  patches.suse/0001-btrfs-qgroup-Always-free-PREALLOC-META-reserve-in-bt.patch.
- x86/apic/x2apic: Fix a NULL pointer deref when handling a
  dying cpu (bnc#1151927 5.3.8).
- irqchip/sifive-plic: Switch to fasteoi flow (bnc#1151927 5.3.8).
- xen/netback: fix error path of xenvif_connect_data()
  (bnc#1151927 5.3.8).
- ipv4: fix race condition between route lookup and invalidation
  (bnc#1151927 5.3.8).
- ipv4: Return -ENETUNREACH if we can't create route but saddr
  is valid (bnc#1151927 5.3.8).
- net: phy: micrel: Update KSZ87xx PHY name (bnc#1151927 5.3.8).
- net: phy: micrel: Discern KSZ8051 and KSZ8795 PHYs (bnc#1151927
  5.3.8).
- net: stmmac: disable/enable ptp_ref_clk in suspend/resume flow
  (bnc#1151927 5.3.8).
- net: phy: Fix "link partner" information disappear issue
  (bnc#1151927 5.3.8).
- rxrpc: use rcu protection while reading sk->sk_user_data
  (bnc#1151927 5.3.8).
- net: i82596: fix dma_alloc_attr for sni_82596 (bnc#1151927
  5.3.8).
- sctp: change sctp_prot .no_autobind with true (bnc#1151927
  5.3.8).
- sched: etf: Fix ordering of packets with same txtime
  (bnc#1151927 5.3.8).
- net: avoid potential infinite loop in tc_ctl_action()
  (bnc#1151927 5.3.8).
- net/sched: fix corrupted L2 header with MPLS 'push' and 'pop'
  actions (bnc#1151927 5.3.8).
- net: avoid errors when trying to pop MLPS header on non-MPLS
  packets (bnc#1151927 5.3.8).
- iwlwifi: pcie: change qu with jf devices to use qu configuration
  (bnc#1151927 5.3.8).
- netdevsim: Fix error handling in nsim_fib_init and nsim_fib_exit
  (bnc#1151927 5.3.8).
- rxrpc: Fix possible NULL pointer access in ICMP handling
  (bnc#1151927 5.3.8).
- mac80211: Reject malformed SSID elements (bnc#1151927 5.3.8).
- net_sched: fix backward compatibility for TCA_ACT_KIND
  (bnc#1151927 5.3.8).
- net_sched: fix backward compatibility for TCA_KIND (bnc#1151927
  5.3.8).
- zram: fix race between backing_dev_show and backing_dev_store
  (bnc#1151927 5.3.8).
- ocfs2: fix panic due to ocfs2_wq is null (bnc#1151927 5.3.8).
- hugetlbfs: don't access uninitialized memmaps in
  pfn_range_valid_gigantic() (bnc#1151927 5.3.8).
- mm: memblock: do not enforce current limit for memblock_phys*
  family (bnc#1151927 5.3.8).
- mm: memcg: get number of pages on the LRU list in memcgroup
  base on lru_zone_size (bnc#1151927 5.3.8).
- mm: memcg/slab: fix panic in __free_slab() caused by premature
  memcg pointer release (bnc#1151927 5.3.8).
- mm/memunmap: don't access uninitialized memmap in
  memunmap_pages() (bnc#1151927 5.3.8).
- mm/page_owner: don't access uninitialized memmaps when reading
  /proc/pagetypeinfo (bnc#1151927 5.3.8).
- mm/memory-failure.c: don't access uninitialized memmaps in
  memory_failure() (bnc#1151927 5.3.8).
- fs/proc/page.c: don't access uninitialized memmaps in
  fs/proc/page.c (bnc#1151927 5.3.8).
- drivers/base/memory.c: don't access uninitialized memmaps in
  soft_offline_page_store() (bnc#1151927 5.3.8).
- nvme-pci: Set the prp2 correctly when using more than 4k page
  (bnc#1151927 5.3.8).
- blk-rq-qos: fix first node deletion of rq_qos_del() (bnc#1151927
  5.3.8).
- filldir: remove WARN_ON_ONCE() for bad directory entries
  (bnc#1151927 5.3.8).
- ceph: just skip unrecognized info in ceph_reply_info_extra
  (bnc#1151927 5.3.8).
- dm cache: fix bugs when a GFP_NOWAIT allocation fails
  (bnc#1151927 5.3.8).
- cpufreq: Avoid cpufreq_suspend() deadlock on system shutdown
  (bnc#1151927 5.3.8).
- arm64: Allow CAVIUM_TX2_ERRATUM_219 to be selected (bnc#1151927
  5.3.8).
- Update config files.
  CAVIUM_TX2_ERRATUM_219=y (the default)
- arm64: Avoid Cavium TX2 erratum 219 when switching TTBR
  (bnc#1151927 5.3.8).
- arm64: Enable workaround for Cavium TX2 erratum 219 when
  running SMT (bnc#1151927 5.3.8).
- arm64: KVM: Trap VM ops when ARM64_WORKAROUND_CAVIUM_TX2_219_TVM
  is set (bnc#1151927 5.3.8).
- xtensa: fix change_bit in exclusive access option (bnc#1151927
  5.3.8).
- xtensa: drop EXPORT_SYMBOL for outs*/ins* (bnc#1151927 5.3.8).
- drm/edid: Add 6 bpc quirk for SDC panel in Lenovo G50
  (bnc#1151927 5.3.8).
- drm/amdgpu/sdma5: fix mask value of POLL_REGMEM packet for
  pipe sync (bnc#1151927 5.3.8).
- drm/amdgpu: Bail earlier when amdgpu.cik_/si_support is not
  set to 1 (bnc#1151927 5.3.8).
- drm/i915/userptr: Never allow userptr into the mappable GGTT
  (bnc#1151927 5.3.8).
- Input: synaptics-rmi4 - avoid processing unknown IRQs
  (bnc#1151927 5.3.8).
- scsi: zfcp: fix reaction on bit error threshold notification
  (bnc#1151927 5.3.8).
- scsi: core: save/restore command resid for error handling
  (bnc#1151927 5.3.8).
- scsi: sd: Ignore a failure to sync cache due to lack of
  authorization (bnc#1151927 5.3.8).
- parisc: Fix vmap memory leak in ioremap()/iounmap() (bnc#1151927
  5.3.8).
- mm/memory-failure: poison read receives SIGKILL instead of
  SIGBUS if mmaped more than once (bnc#1151927 5.3.8).
- mm/slub: fix a deadlock in show_slab_objects() (bnc#1151927
  5.3.8).
- uaccess: implement a proper unsafe_copy_to_user() and switch
  filldir over to it (bnc#1151927 5.3.8).
- elf: don't use MAP_FIXED_NOREPLACE for elf executable mappings
  (bnc#1151927 5.3.8).
- ARM: dts: am4372: Set memory bandwidth limit for DISPC
  (bnc#1151927 5.3.8).
- ARM: OMAP2+: Fix warnings with broken omap2_set_init_voltage()
  (bnc#1151927 5.3.8).
- ARM: OMAP2+: Add missing LCDC midlemode for am335x (bnc#1151927
  5.3.8).
- ARM: OMAP2+: Fix missing reset done flag for am3 and am43
  (bnc#1151927 5.3.8).
- ARM: dts: Fix gpio0 flags for am335x-icev2 (bnc#1151927 5.3.8).
- ARM: dts: Fix wrong clocks for dra7 mcasp (bnc#1151927 5.3.8).
- namespace: fix namespace.pl script to support relative paths
  (bnc#1151927 5.3.8).
- scsi: megaraid: disable device when probe failed after enabled
  device (bnc#1151927 5.3.8).
- scsi: ufs: skip shutdown if hba is not powered (bnc#1151927
  5.3.8).
- Make filldir() verify the directory entry filename is valid
  (bnc#1151927 5.3.8).
- Convert filldir() from __put_user() to unsafe_put_user()
  (bnc#1151927 5.3.8).
- net: phy: fix write to mii-ctrl1000 register (bnc#1151927
  5.3.8).
- net: phy: allow for reset line to be tied to a sleepy GPIO
  controller (bnc#1151927 5.3.8).
- r8152: Set macpassthru in reset_resume callback (bnc#1151927
  5.3.8).
- netfilter: nft_connlimit: disable bh on garbage collection
  (bnc#1151927 5.3.8).
- net: ag71xx: fix mdio subnode support (bnc#1151927 5.3.8).
- net: stmmac: Do not stop PHY if WoL is enabled (bnc#1151927
  5.3.8).
- Refresh
  patches.suse/net-stmmac-Avoid-deadlock-on-suspend-resume.patch.
- net: stmmac: Correctly take timestamp for PTPv2 (bnc#1151927
  5.3.8).
- net: stmmac: dwmac4: Always update the MAC Hash Filter
  (bnc#1151927 5.3.8).
- net: stmmac: xgmac: Not all Unicast addresses may be available
  (bnc#1151927 5.3.8).
- net: dsa: rtl8366rb: add missing of_node_put after calling
  of_get_child_by_name (bnc#1151927 5.3.8).
- mac80211: fix txq null pointer dereference (bnc#1151927 5.3.8).
- nl80211: fix null pointer dereference (bnc#1151927 5.3.8).
- ieee802154: ca8210: prevent memory leak (bnc#1151927 5.3.8).
- net: dsa: qca8k: Use up to 7 ports for all operations
  (bnc#1151927 5.3.8).
- s390/mm: fix -Wunused-but-set-variable warnings (bnc#1151927
  5.3.8).
- mips: Loongson: Fix the link time qualifier of 'serial_exit()'
  (bnc#1151927 5.3.8).
- MIPS: dts: ar9331: fix interrupt-controller size (bnc#1151927
  5.3.8).
- riscv: Fix memblock reservation for device tree blob
  (bnc#1151927 5.3.8).
- RISC-V: Clear load reservations while restoring hart contexts
  (bnc#1151927 5.3.8).
- selftests: kvm: Fix libkvm build error (bnc#1151927 5.3.8).
- xen/efi: Set nonblocking callbacks (bnc#1151927 5.3.8).
- drm/komeda: prevent memory leak in komeda_wb_connector_add
  (bnc#1151927 5.3.8).
- drm: Clear the fence pointer when writeback job signaled
  (bnc#1151927 5.3.8).
- drm: Free the writeback_job when it with an empty fb
  (bnc#1151927 5.3.8).
- drm/amd/display: memory leak (bnc#1151927 5.3.8).
- drm/amdgpu: fix multiple memory leaks in acp_hw_init
  (bnc#1151927 5.3.8).
- loop: change queue block size to match when using DIO
  (bnc#1151927 5.3.8).
- nvme-rdma: fix possible use-after-free in connect timeout
  (bnc#1151927 5.3.8).
- nvme: allow 64-bit results in passthru commands (bnc#1151927
  5.3.8).
- nvme: Add quirk for Kingston NVME SSD running FW E8FK11.T
  (bnc#1151927 5.3.8).
- Added QUIRKs for ADATA XPG SX8200 Pro 512GB (bnc#1151927 5.3.8).
- nvme-rdma: Fix max_hw_sectors calculation (bnc#1151927 5.3.8).
- nvme: fix an error code in nvme_init_subsystem() (bnc#1151927
  5.3.8).
- nvme-pci: Save PCI state before putting drive into deepest state
  (bnc#1151927 5.3.8).
- nvme-tcp: fix wrong stop condition in io_work (bnc#1151927
  5.3.8).
- nvme-pci: Fix a race in controller removal (bnc#1151927 5.3.8).
- blk-mq: honor IO scheduler for multiqueue devices (bnc#1151927
  5.3.8).
- LSM: SafeSetID: Stop releasing uninitialized ruleset
  (bnc#1151927 5.3.8).
- commit 22f2089
* Tue Oct 29 2019 tiwai@suse.de
- blacklist.conf: Add an already cherry-picked i915 entry
- commit 43dfee5
* Tue Oct 29 2019 jslaby@suse.cz
- Update
  patches.suse/0001-btrfs-block-group-Fix-a-memory-leak-due-to-missing-b.patch
  (bsc#1155178 bnc#1151927 5.3.8).
- Update
  patches.suse/0001-btrfs-tracepoints-Fix-bad-entry-members-of-qgroup-ev.patch
  (bsc#1155186 bnc#1151927 5.3.8).
- Update
  patches.suse/0001-btrfs-tracepoints-Fix-wrong-parameter-order-for-qgro.patch
  (bsc#1155184 bnc#1151927 5.3.8).
- Update
  patches.suse/ACPI-CPPC-Set-pcc_data-pcc_ss_id-to-NULL-in-acpi_cpp.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ACPI-NFIT-Fix-unlock-on-error-in-scrub_show.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ALSA-hda-Force-runtime-PM-on-Nvidia-HDMI-codecs.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ALSA-hda-realtek-Add-support-for-ALC711.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ALSA-hda-realtek-Enable-headset-mic-on-Asus-MJ401TA.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ALSA-usb-audio-Disable-quirks-for-BOSS-Katana-amplif.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/ASoC-rsnd-Reinitialize-bit-clock-inversion-flag-for-.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/Btrfs-check-for-the-full-sync-flag-while-holding-the.patch
  (bsc#1153713 bnc#1151927 5.3.8).
- Update
  patches.suse/Input-da9063-fix-capability-and-drop-KEY_SLEEP.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/Input-st1232-fix-reporting-multitouch-coordinates.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/PCI-PM-Fix-pci_power_up.patch (git-fixes
  bnc#1151927 5.3.8).
- Update
  patches.suse/RDMA-cxgb4-Do-not-dma-memory-off-of-the-stack.patch
  (jsc#SLE-8392 bnc#1151927 5.3.8).
- Update
  patches.suse/Revert-Input-elantech-enable-SMBus-on-new-2018-syste.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/Revert-drm-radeon-Fix-EEH-during-kexec.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/USB-ldusb-fix-memleak-on-disconnect.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/USB-ldusb-fix-read-info-leaks.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/USB-legousbtower-fix-memleak-on-disconnect.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/USB-serial-ti_usb_3410_5052-fix-port-close-races.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/USB-usblp-fix-use-after-free-on-disconnect.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/cfg80211-wext-avoid-copying-malformed-SSIDs.patch
  (bsc#1153158 CVE-2019-17133 bnc#1151927 5.3.8).
- Update patches.suse/clk-ti-dra7-Fix-mcasp8-clock-bits.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/drm-i915-Favor-last-VBT-child-device-with-conflictin.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/drm-panfrost-Handle-resetting-on-timeout-better.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/drm-ttm-Restore-ttm-prefaulting.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/lib-textsearch-fix-escapes-in-example-code.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/libata-ahci-Fix-PCS-quirk-application.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/md-raid0-fix-warning-message-for-parameter-default_l.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/memstick-jmb38x_ms-Fix-an-error-handling-path-in-jmb.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/mm-compaction-fix-wrong-pfn-handling-in-_reset_isolation_pfn.patch
  (git-fixes (mm/compaction) bnc#1151927 5.3.8).
- Update
  patches.suse/mmc-mxs-fix-flags-passed-to-dmaengine_prep_slave_sg.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/mmc-sdhci-omap-Fix-Tuning-procedure-for-temperatures.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/msft-hv-1955-x86-hyperv-Make-vapic-support-x2apic-mode.patch
  (fate#323887 bnc#1151927 5.3.8).
- Update
  patches.suse/net-aquantia-correctly-handle-macvlan-and-multicast-.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-aquantia-do-not-pass-lro-session-with-invalid-tc.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/net-aquantia-temperature-retrieval-fix.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-aquantia-when-cleaning-hw-cache-it-should-be-tog.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-bcmgenet-Fix-RGMII_MODE_EN-value-for-GENET-v1-2-.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-bcmgenet-Set-phydev-dev_flags-only-for-internal-.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-ethernet-broadcom-have-drivers-select-DIMLIB-as-.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-hisilicon-Fix-usage-of-uninitialized-variable-in.patch
  (bsc#1154353 bnc#1151927 5.3.8).
- Update
  patches.suse/net-ibmvnic-Fix-EOI-when-running-in-XIVE-mode.patch
  (bsc#1089644, ltc#166495, ltc#165544, git-fixes bnc#1151927
  5.3.8).
- Update
  patches.suse/net-ipv6-fix-listify-ip6_rcv_finish-in-case-of-forwa.patch
  (bsc#1154353 bnc#1151927 5.3.8).
- Update
  patches.suse/net-mscc-ocelot-add-missing-of_node_put-after-callin.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/net-stmmac-Avoid-deadlock-on-suspend-resume.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/pinctrl-armada-37xx-fix-control-of-pins-32-and-up.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/pinctrl-armada-37xx-swap-polarity-on-LED-group.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/pinctrl-cherryview-restore-Strago-DMI-workaround-for.patch
  (git-fixes bnc#1151927 5.3.8).
- Update patches.suse/scsi-qla2xxx-Fix-N2N-link-reset.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.8).
- Update patches.suse/scsi-qla2xxx-Fix-N2N-link-up-fail.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.8).
- Update
  patches.suse/scsi-qla2xxx-Fix-stale-mem-access-on-driver-unload.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.8).
- Update
  patches.suse/scsi-qla2xxx-Fix-unbound-sleep-in-fcport-delete-path.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.8).
- Update
  patches.suse/scsi-qla2xxx-Silence-fwdump-template-message.patch
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334 bnc#1151927 5.3.8).
- Update
  patches.suse/staging-wlan-ng-fix-exit-return-when-sme-key_idx-NUM.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/usb-udc-lpc32xx-fix-bad-bit-shift-operation.patch
  (git-fixes bnc#1151927 5.3.8).
- Update
  patches.suse/x86-boot-64-Make-level2_kernel_pgt-pages-invalid-out.patch
  (bnc#1153969 bnc#1151927 5.3.8).
- commit dd1ea62
* Tue Oct 29 2019 jslaby@suse.cz
- x86/boot/64: Round memory hole size up to next PMD page
  (bnc#1153969).
- x86/boot/64: Make level2_kernel_pgt pages invalid outside
  kernel area (bnc#1153969).
- commit ec4e0e8
* Tue Oct 29 2019 mkubecek@suse.cz
- series.conf: refresh
  Update upstream references:
  patches.suse/scsi-lpfc-remove-left-over-BUILD_NVME-defines.patch
- commit b3990ad
* Mon Oct 28 2019 tiwai@suse.de
- HID: logitech-hidpp: do all FF cleanup in hidpp_ff_destroy()
  (git-fixes).
- HID: logitech-hidpp: rework device validation (git-fixes).
- HID: logitech-hidpp: split g920_get_config() (git-fixes).
- HID: fix error message in hid_open_report() (git-fixes).
- virtio_ring: fix stalls for packed rings (git-fixes).
- commit 211812f
* Mon Oct 28 2019 fdmanana@suse.com
- Refresh
  patches.suse/Btrfs-check-for-the-full-sync-flag-while-holding-the.patch.
- commit bee8076
* Mon Oct 28 2019 tiwai@suse.de
- 8250-men-mcb: fix error checking when get_num_ports returns
  - ENODEV (git-fixes).
- drm/komeda: Fix typos in komeda_splitter_validate (git-fixes).
- ACPI: NFIT: Fix unlock on error in scrub_show() (git-fixes).
- vfio/spapr_tce: Fix incorrect tce_iommu_group memory free
  (git-fixes).
- commit 707ac5a
* Mon Oct 28 2019 tiwai@suse.de
- drm/amdgpu: Add DC feature mask to disable fractional pwm
  (bsc#1154010).
- commit 619cd14
* Mon Oct 28 2019 dwagner@suse.de
- scsi: qla2xxx: fix a potential NULL pointer dereference
  (bsc#1150457 CVE-2019-16233).
- commit 0c213e5
* Mon Oct 28 2019 dwagner@suse.de
- Refresh series.conf
  Move patches.suse/scsi-lpfc-remove-left-over-BUILD_NVME-defines.patch
- commit c0faefe
* Mon Oct 28 2019 wqu@suse.com
- btrfs: tracepoints: Fix bad entry members of qgroup events
  (bsc#1155186).
- commit 442159a
* Mon Oct 28 2019 wqu@suse.com
- btrfs: tracepoints: Fix wrong parameter order for qgroup  events
  (bsc#1155184).
- commit 941375b
* Mon Oct 28 2019 wqu@suse.com
- btrfs: qgroup: Always free PREALLOC META reserve in
  btrfs_delalloc_release_extents() (bsc#1155179).
- commit 6d16367
* Mon Oct 28 2019 wqu@suse.com
- btrfs: block-group: Fix a memory leak due to missing
  btrfs_put_block_group() (bsc#1155178).
- commit c8620c7
* Mon Oct 28 2019 tiwai@suse.de
- staging: wlan-ng: fix exit return when sme->key_idx >=
  NUM_WEPKEYS (git-fixes).
- USB: ldusb: fix read info leaks (git-fixes).
- USB: serial: ti_usb_3410_5052: fix port-close races (git-fixes).
- USB: usblp: fix use-after-free on disconnect (git-fixes).
- usb: udc: lpc32xx: fix bad bit shift operation (git-fixes).
- USB: legousbtower: fix a signedness bug in tower_probe()
  (git-fixes).
- USB: legousbtower: fix memleak on disconnect (git-fixes).
- USB: ldusb: fix memleak on disconnect (git-fixes).
- i2c: stm32f7: remove warning when compiling with W=1
  (git-fixes).
- i2c: stm32f7: fix a race in slave mode with arbitration loss
  irq (git-fixes).
- i2c: stm32f7: fix first byte to send in slave mode (git-fixes).
- i2c: mt65xx: fix NULL ptr dereference (git-fixes).
- i2c: aspeed: fix master pending state handling (git-fixes).
- Input: st1232 - fix reporting multitouch coordinates
  (git-fixes).
- mmc: mxs: fix flags passed to dmaengine_prep_slave_sg
  (git-fixes).
- mmc: sdhci-omap: Fix Tuning procedure for temperatures < -20C
  (git-fixes).
- regulator: da9062: fix suspend_enable/disable preparation
  (git-fixes).
- regulator: of: fix suspend-min/max-voltage parsing (git-fixes).
- commit 8eae40b
* Mon Oct 28 2019 jlee@suse.com
- efi: Export Runtime Configuration Interface table to sysfs
  (jsc#SLE-7702).
- Update config files.
- commit da35ab6
* Mon Oct 28 2019 jlee@suse.com
- efi: x86: move efi_is_table_address() into arch/x86
  (jsc#SLE-7702).
- commit 7c42f38
* Fri Oct 25 2019 dbueso@suse.de
- x86/mm: Avoid redundant interrupt disable in load_mm_cr4() (bsc#1154772).
- commit a9a3f29
* Fri Oct 25 2019 jlee@suse.com
- ima: Fix use after free in ima_read_modsig() (jsc#SLE-9870).
- ima: Store the measurement again when appraising a modsig
  (jsc#SLE-9870).
- ima: Define ima-modsig template (jsc#SLE-9870).
- ima: Collect modsig (jsc#SLE-9870).
- ima: Implement support for module-style appended signatures
  (jsc#SLE-9870).
- ima: Factor xattr_verify() out of ima_appraise_measurement()
  (jsc#SLE-9870).
- commit 947fbd9
* Fri Oct 25 2019 jlee@suse.com
- ima: Add modsig appraise_type option for module-style appended
  signatures (jsc#SLE-9870).
- Update config files.
- commit 4fa2098
* Fri Oct 25 2019 jlee@suse.com
- integrity: Select CONFIG_KEYS instead of depending on it
  (jsc#SLE-9870).
- PKCS#7: Introduce pkcs7_get_digest() (jsc#SLE-9870).
- PKCS#7: Refactor verify_pkcs7_signature() (jsc#SLE-9870).
- commit 610313d
* Fri Oct 25 2019 mkubecek@suse.cz
- config: refresh ARM configs
- FB_TFT_FBTFT_DEVICE dropped
- commit d1fe9dc
* Thu Oct 24 2019 jeffm@suse.com
- Delete patches.suse/btrfs-use-spinlock-to-protect--caching_block_groups-list.patch.
  Qgroup rescan now uses the commit root and skips locking, so the deadlock
  this patch was intended to fix no longer exists.
- commit dc168d3
* Thu Oct 24 2019 msuchanek@suse.de
- Update cdrom autoclose to v4.
- cdrom: export autoclose logic as a separate function
  (bsc#1048585).
- scsi: blacklist: add VMware ESXi cdrom - broken tray emulation
  (bsc#1048585 bsc#1080813).
- Refresh patches.suse/cdrom-factor-out-common-open_for_-code.patch.
- Refresh patches.suse/cdrom-wait-for-the-tray-to-close.patch.
- Refresh patches.suse/scsi-sr-wait-for-the-medium-to-become-ready.patch.
- Delete patches.suse/cdrom-separate-autoclose-into-an-IOCTL.patch.
- Delete patches.suse/docs-cdrom-Add-autoclose-IOCTL.patch.
- Delete patches.suse/scsi-sr-workaround-VMware-ESXi-cdrom-emulation-bug.patch.
- commit 9bf0726
* Thu Oct 24 2019 jeffm@suse.com
- procfs: update and re-enable patch for /proc/sys/fs/procfs-drop-fd-dentries
  Refresh
  patches.suse/procfs-add-tunable-for-fd-fdinfo-dentry-retention.patch.
- commit 3f88bb6
* Thu Oct 24 2019 jeffm@suse.com
- Delete patches.suse/revert-btrfs-qgroup-move-half-of-the-qgroup-accounting-time-out-of-commit-trans.patch.
  It was replaced by setting the flag to skip locking while traversing the
  commit root.
- commit 304f8d0
* Thu Oct 24 2019 jeffm@suse.com
- reiserfs: fix extended attributes on the root directory
  (bsc#1151225).
- commit 90c4321
* Thu Oct 24 2019 jeffm@suse.com
- reiserfs: re-enable reiserfs patches
  Refresh
  patches.suse/reiserfs-mark-read-write-mode-unsupported.patch.
- commit ac1361a
* Thu Oct 24 2019 ggherdovich@suse.cz
- ACPI: acpi_pad: Do not launch acpi_pad threads on idle cpus
  (bsc#1113399).
- commit 1724b68
* Thu Oct 24 2019 tzimmermann@suse.de
- drm/i915/execlists: Always clear pending&inflight requests on reset (bsc#1152489)
- commit 21a0694
* Thu Oct 24 2019 tiwai@suse.de
- ALSA: hda: Add Tigerlake/Jasperlake PCI ID (git-fixes).
- ALSA: usb-audio: Fix copy&paste error in the validator
  (git-fixes).
- ASoC: rsnd: Reinitialize bit clock inversion flag for every
  format setting (git-fixes).
- ASoC: simple_card_utils.h: Fix potential multiple redefinition
  error (git-fixes).
- ASoc: rockchip: i2s: Fix RPM imbalance (git-fixes).
- ASoC: topology: Fix a signedness bug in
  soc_tplg_dapm_widget_create() (git-fixes).
- ALSA: hda/realtek - Add support for ALC711 (git-fixes).
- commit 4dad920
* Thu Oct 24 2019 tiwai@suse.de
- Add CVE reference to FIB security fix patch (CVE-2019-18198, bsc#1154617).
- commit 2b47bbd
* Thu Oct 24 2019 tiwai@suse.de
- net: usb: lan78xx: Connect PHY before registering MAC
  (git-fixes).
- net: ethernet: broadcom: have drivers select DIMLIB as needed
  (git-fixes).
- net: mscc: ocelot: add missing of_node_put after calling
  of_get_child_by_name (git-fixes).
- net: ethernet: stmmac: Fix signedness bug in
  ipq806x_gmac_of_parse() (git-fixes).
- net: nixge: Fix a signedness bug in nixge_probe() (git-fixes).
- net: axienet: fix a signedness bug in probe (git-fixes).
- net: socionext: Fix a signedness bug in ave_probe() (git-fixes).
- net: netsec: Fix signedness bug in netsec_probe() (git-fixes).
- net: broadcom/bcmsysport: Fix signedness in bcm_sysport_probe()
  (git-fixes).
- commit 242e8f9
* Thu Oct 24 2019 tiwai@suse.de
- net: bcmgenet: reset 40nm EPHY on energy detect (git-fixes).
- net: bcmgenet: soft reset 40nm EPHYs before MAC init
  (git-fixes).
- net: bcmgenet: don't set phydev->link from MAC (git-fixes).
- net: bcmgenet: Fix RGMII_MODE_EN value for GENET v1/2/3
  (git-fixes).
- net: bcmgenet: Set phydev->dev_flags only for internal PHYs
  (git-fixes).
- md/raid0: fix warning message for parameter default_layout
  (git-fixes).
- commit 87f7ca5
* Thu Oct 24 2019 tiwai@suse.de
- net: aquantia: correctly handle macvlan and multicast
  coexistence (git-fixes).
- net: aquantia: do not pass lro session with invalid tcp checksum
  (git-fixes).
- net: aquantia: when cleaning hw cache it should be toggled
  (git-fixes).
- net: aquantia: temperature retrieval fix (git-fixes).
- net: aquantia: Fix aq_vec_isr_legacy() return value (git-fixes).
- commit f106659
* Thu Oct 24 2019 tiwai@suse.de
- bus: ti-sysc: Remove unpaired sysc_clkdm_deny_idle()
  (git-fixes).
- commit 6fbfebc
* Thu Oct 24 2019 tiwai@suse.de
- ASoC: sun4i: Revert A83t description (git-fixes).
- ASoC: sunxi: Revert initial A83t support (git-fixes).
- ASoC: sun4i-i2s: Add support for DSP formats (git-fixes).
- ASoC: sun4i-i2s: Replace call to params_width by local variable
  (git-fixes).
- ASoC: sun4i-i2s: Use the actual format width instead of an
  hardcoded one (git-fixes).
- ASoC: sun4i-i2s: Use the physical / slot width for the clocks
  (git-fixes).
- ASoC: sun4i-i2s: Add support for TDM slots (git-fixes).
- ASoC: sun4i-i2s: Support more channels (git-fixes).
- ASoC: sun4i-i2s: Pass the channels number as an argument
  (git-fixes).
- ASoC: sun4i-i2s: Remove duplicated quirks structure (git-fixes).
- ASoC: sun4i-i2s: Register regmap and PCM before our component
  (git-fixes).
- commit 0c68de2
* Thu Oct 24 2019 tiwai@suse.de
- ASoC: sun4i-i2s: Rework MCLK divider calculation (git-fixes).
- Refresh
  patches.suse/ASoC-sun4i-i2s-Fix-the-MCLK-and-BCLK-dividers-on-new.patch.
- commit 65ed49e
* Thu Oct 24 2019 tiwai@suse.de
- ASoC: sun4i-i2s: Fix the LRCK period on A83t (git-fixes).
- ASoC: sun4i-i2s: Fix MCLK Enable bit offset on A83t (git-fixes).
- ASoC: sun4i-i2s: Fix WSS and SR fields for the A83t (git-fixes).
- ASoC: sun4i-i2s: Fix the LRCK polarity (git-fixes).
- ASoC: sun4i-i2s: Fix LRCK and BCLK polarity offsets on newer
  SoCs (git-fixes).
- ASoC: sun4i-i2s: RX and TX counter registers are swapped
  (git-fixes).
- ASoC: sun4i-i2s: Fix the MCLK and BCLK dividers on newer SoCs
  (git-fixes).
- ASoC: sun4i-i2s: Use module clock as BCLK parent on newer SoCs
  (git-fixes).
- ASoC: sun4i-i2s: Move the format configuration to a callback
  (git-fixes).
- ASoC: sun4i-i2s: Move the channel configuration to a callback
  (git-fixes).
- commit fd35f56
* Thu Oct 24 2019 tiwai@suse.de
- ASoC: imx-audmix: register the card on a proper dev (git-fixes).
- ASoC: wm8988: fix typo in wm8988_right_line_controls
  (git-fixes).
- ASoC: sunxi: fix a sound binding broken reference (git-fixes).
- ASoC: ams-delta: Take control over audio mute GPIO pins
  (git-fixes).
- ASoC: Intel: Baytrail: Fix implicit fallthrough warning
  (git-fixes).
- ASoC: meson: g12a-tohdmitx: require regmap mmio (git-fixes).
- ASoC: meson: axg-tdm-formatter: free reset on device removal
  (git-fixes).
- ASoC: wm8737: Fix copy-paste error in wm8737_snd_controls
  (git-fixes).
- ASoC: es8328: Fix copy-paste error in es8328_right_line_controls
  (git-fixes).
- commit d53947e
* Thu Oct 24 2019 tiwai@suse.de
- blacklist.conf: Add path entries for unsupported architectures
- commit cf0a6f3
* Thu Oct 24 2019 tiwai@suse.de
- scripts: setlocalversion: fix a bashism (git-fixes).
- xsk: Fix crash in poll when device does not support
  ndo_xsk_wakeup (git-fixes).
- NTB: fix IDT Kconfig typos/spellos (git-fixes).
- tools/power/x86/intel-speed-select: Fix a read overflow in
  isst_set_tdp_level_msr() (git-fixes).
- commit 9b4c74d
* Thu Oct 24 2019 tiwai@suse.de
- media: MAINTAINERS: hantro: Fix typo in a filepath (git-fixes).
- commit cd10c19
* Thu Oct 24 2019 tiwai@suse.de
- bonding: fix potential NULL deref in bond_update_slave_arr
  (git-fixes).
- llc: fix sk_buff refcounting in llc_conn_state_process()
  (git-fixes).
- llc: fix another potential sk_buff leak in llc_ui_sendmsg()
  (git-fixes).
- llc: fix sk_buff leak in llc_conn_service() (git-fixes).
- llc: fix sk_buff leak in llc_sap_state_process() (git-fixes).
- staging/fbtft: Remove fbtft_device (git-fixes).
- enetc: Fix a signedness bug in enetc_of_get_phy() (git-fixes).
- enetc: Clean up local mdio bus allocation (git-fixes).
- ACPI / property: Fix acpi_graph_get_remote_endpoint() name in
  kerneldoc (git-fixes).
- clocksource/drivers/npcm: Fix GENMASK and timer operation
  (git-fixes).
- commit b262b78
* Thu Oct 24 2019 tiwai@suse.de
- clk: ti: dra7: Fix mcasp8 clock bits (git-fixes).
- bus: ti-sysc: Fix handling of invalid clocks (git-fixes).
- bus: ti-sysc: Fix clock handling for no-idle quirks (git-fixes).
- checkpatch.pl: warn on invalid commit id (git-fixes).
- clk: at91: fix update bit maps on CFG_MOR write (git-fixes).
- clk: actions: Fix factor clk struct member access (git-fixes).
- clk: Evict unregistered clks from parent caches (git-fixes).
- clk: fix devm_platform_ioremap_resource.cocci warnings
  (git-fixes).
- clk: sunxi-ng: v3s: add the missing PLL_DDR1 (git-fixes).
- clk: imx: imx8mm: fix pll mux bit (git-fixes).
- clk: imx8mm: Fix incorrect parents (git-fixes).
- clk: imx8mq: Fix sys3 pll references (git-fixes).
- clk: imx8mm: GPT1 clock mux option #5 should be sys_pll1_80m
  (git-fixes).
- clk: imx8mm: Fix typo of pwm3 clock's mux option #4 (git-fixes).
- clk: qcom: fix QCS404 TuringCC regmap (git-fixes).
- clk: meson: g12a: fix hifi typo in mali parent_names
  (git-fixes).
- commit 989e4b0
* Thu Oct 24 2019 mkubecek@suse.cz
- supported.conf: drop gpio-tegra186 module
  It is built into vmlinux now, not a module.
- commit cc0ff86
* Wed Oct 23 2019 tiwai@suse.de
- mmc: sdhci-pci: Add another Id for Intel CML (jsc#SLE-7946).
- commit 06e352d
* Wed Oct 23 2019 tiwai@suse.de
- drm/i915/cml: Add Missing PCI IDs (jsc#SLE-7930, jsc#SLE-7953).
- commit 9b2cd64
* Wed Oct 23 2019 msuchanek@suse.de
- scsi: sr: wait for the medium to become ready (bsc#1048585).
- scsi: sr: workaround VMware ESXi cdrom emulation bug
  (bsc#1048585 bsc#1080813).
- bdev: add open_finish (bsc#1048585).
- docs: cdrom: Add autoclose IOCTL (bsc#1048585).
- cdrom: separate autoclose into an IOCTL (bsc#1048585).
- cdrom: wait for the tray to close (bsc#1048585).
- cdrom: factor out common open_for_* code (bsc#1048585).
- cdrom: add poll_event_interruptible (bsc#1048585).
- commit 79a9241
* Wed Oct 23 2019 ykaukab@suse.de
- arm64: config: statically link gpio-tegra186
  Driver doesn't load automatically. gpio-tegra already set to same.
- commit 8ae3edf
* Wed Oct 23 2019 ykaukab@suse.de
- cpufreq: tegra186: add CPUFREQ_NEED_INITIAL_FREQ_CHECK flag
  (bsc#1154776).
- commit e492e69
* Wed Oct 23 2019 msuchanek@suse.de
- Remove old cdrom autoclose patches.
- Refresh patches.suse/cdrom-turn-off-autoclose-by-default.patch.
- Delete patches.suse/cdrom-factor-out-common-open_for_-code.patch.
- Delete patches.suse/cdrom-wait-for-tray-to-close.patch.
- Delete patches.suse/delay-add-poll_event_interruptible.patch.
- Delete patches.suse/scsi-sr-wait-for-the-medium-to-become-ready.patch.
- Delete patches.suse/scsi-sr-workaround-VMware-ESXi-cdrom-emulation-bug.patch.
- commit 355491c
* Wed Oct 23 2019 tzimmermann@suse.de
- drm/i915: Don't mix srcu tag and negative error codes (bsc#1152489)
- commit 3b706cc
* Wed Oct 23 2019 tzimmermann@suse.de
- drm/i915/execlists: Process interrupted context on reset (bsc#1152489)
- commit 6dbca2a
* Wed Oct 23 2019 tiwai@suse.de
- fs/libfs.c: fix kernel-doc warning (git-fixes).
- fs/direct-io.c: fix kernel-doc warning (git-fixes).
- Documentation/infiniband: update name of some functions
  (git-fixes).
- docs: kbuild: remove cc-ldoption from document again
  (git-fixes).
- docs: kbuild: fix invalid ReST syntax (git-fixes).
- dmaengine: dw: platform: Switch to
  acpi_dma_controller_register() (git-fixes).
- Documentation: virt: Fix broken reference to virt tree's index
  (git-fixes).
- docs: packing: move it to core-api book and adjust markups
  (git-fixes).
- docs: ipmb: place it at driver-api and convert to ReST
  (git-fixes).
- docs: cgroup-v1/blkio-controller.rst: remove a CFQ left over
  (git-fixes).
- hwmon: (shtc1) fix shtc1 and shtw1 id mask (git-fixes).
- hwmon: (lm75) Fix write operations for negative temperatures
  (git-fixes).
- commit cf25ad9
* Wed Oct 23 2019 tiwai@suse.de
- tun: remove possible false sharing in tun_flow_update()
  (git-fixes).
- vhost/test: stop device before reset (git-fixes).
- xarray.h: fix kernel-doc warning (git-fixes).
- USB: usb-skeleton: fix use-after-free after driver unbind
  (git-fixes).
- usbip: vhci_hcd indicate failed message (git-fixes).
- watchdog: jz4740: Fix unused variable warning in
  jz4740_wdt_probe (git-fixes).
- wcn36xx: use dynamic allocation for large variables (git-fixes).
- mic: avoid statically declaring a 'struct device' (git-fixes).
- commit 03e4263
* Wed Oct 23 2019 tiwai@suse.de
- tty: n_hdlc: fix build on SPARC (git-fixes).
- tty: serial: rda: Fix the link time qualifier of
  'rda_uart_exit()' (git-fixes).
- tty: serial: owl: Fix the link time qualifier of
  'owl_uart_exit()' (git-fixes).
- tty: max310x: fix off-by-one buffer access when storing overrun
  (git-fixes).
- tty: serial: fsl_lpuart: Use appropriate lpuart32_* I/O funcs
  (git-fixes).
- commit 79097ee
* Wed Oct 23 2019 tiwai@suse.de
- serial: fix kernel-doc warning in comments (git-fixes).
- serial: stm32: Use __maybe_unused instead of #if CONFIG_PM_SLEEP
  (git-fixes).
- soc: amlogic: meson-gx-socinfo: Add of_node_put() before return
  (git-fixes).
- soc: renesas: rcar-sysc: Add goto to of_node_put() before return
  (git-fixes).
- spi: bcm-qspi: Fix BSPI QUAD and DUAL mode support when using
  flex mode (git-fixes).
- commit 6cf7966
* Wed Oct 23 2019 tiwai@suse.de
- pinctrl: berlin: as370: fix a typo s/spififib/spdifib
  (git-fixes).
- pinctrl: cherryview: restore Strago DMI workaround for all
  versions (git-fixes).
- pinctrl: intel: Allocate IRQ chip dynamic (git-fixes).
- pinctrl: armada-37xx: swap polarity on LED group (git-fixes).
- pinctrl: stmfx: fix null pointer on remove (git-fixes).
- pinctrl: ns2: Fix off by one bugs in ns2_pinmux_enable()
  (git-fixes).
- pinctrl: armada-37xx: fix control of pins 32 and up (git-fixes).
- commit 9b31ee5
* Wed Oct 23 2019 tiwai@suse.de
- iio: imu: st_lsm6dsx: fix waitime for st_lsm6dsx i2c controller
  (git-fixes).
- iio: adc: meson_saradc: Fix memory allocation order (git-fixes).
- kbuild: correct formatting of header in kbuild module docs
  (git-fixes).
- lib: textsearch: fix escapes in example code (git-fixes).
- lib: dimlib: fix help text typos (git-fixes).
- mtd: spi-nor: fix a memory leak bug (git-fixes).
- mtd: spi-nor: Fix an error code in spi_nor_read_raw()
  (git-fixes).
- mtd: spi-nor: Fix Cadence QSPI RCU Schedule Stall (git-fixes).
- mtd: rawnand: brcmnand: Fix ecc chunk calculation for erased
  page bitfips (git-fixes).
- mtd: rawnand: ingenic: fix devm_platform_ioremap_resource.cocci
  warnings (git-fixes).
- Revert "mwifiex: fix system hang problem after resume"
  (git-fixes).
- iio: dac: ad5380: fix incorrect assignment to val (git-fixes).
- iio: tsl2772: Use devm_add_action_or_reset for tsl2772_chip_off
  (git-fixes).
- media: MAINTAINERS: Remove zoran driver (git-fixes).
- gpio/aspeed: Fix incorrect number of banks (git-fixes).
- gpio: ftgpio: Fix an error handling path in
  'ftgpio_gpio_probe()' (git-fixes).
- gpio: Move gpiochip_lock/unlock_as_irq to gpio/driver.h
  (git-fixes).
- commit e950311
* Wed Oct 23 2019 tiwai@suse.de
- drm/panfrost: Handle resetting on timeout better (git-fixes).
- drm/ttm: Restore ttm prefaulting (git-fixes).
- drm/msm/dsi: Implement reset correctly (git-fixes).
- Revert "drm/radeon: Fix EEH during kexec" (git-fixes).
- drm/i915: Favor last VBT child device with conflicting AUX
  ch/DDC pin (git-fixes).
- drm/i915/cml: Add second PCH ID for CMP (git-fixes).
- drm/i915: Extend Haswell GT1 PSMI workaround to all (git-fixes).
- commit 28cf2c7
* Wed Oct 23 2019 bp@suse.de
- Update
  patches.suse/x86-cpu-add-comet-lake-to-the-intel-cpu-models-header.patch
  (jsc#SLE-7935).
- commit a71e408
* Wed Oct 23 2019 mkubecek@suse.cz
- config: refresh
- commit 3d308bb
* Wed Oct 23 2019 mkubecek@suse.cz
- series.conf: cleanup
  Move two submitted wireless patches to "on the way to mainline" section.
  No effect on expanded tree.
- commit 4d1b347
* Tue Oct 22 2019 tiwai@suse.de
- phylink: fix kernel-doc warnings (git-fixes).
- power: supply: ab8500: remove set but not used variables
  'vbup33_vrtcn' and 'bup_vch_range' (git-fixes).
- power: reset: gpio-restart: Fix typo when gpio reset is not
  found (git-fixes).
- power: supply: Init device wakeup after device_add()
  (git-fixes).
- remoteproc: qcom: q6v5-mss: fixup q6v5_pds_enable error handling
  (git-fixes).
- r8169: fix DMA issue on MIPS platform (git-fixes).
- PM: sleep: Fix possible overflow in pm_system_cancel_wakeup()
  (git-fixes).
- commit ed8c5e4
* Tue Oct 22 2019 tiwai@suse.de
- rt2x00: initialize last_reset (git-fixes).
- virt: vbox: fix memory leak in hgcm_call_preprocess_linaddr
  (git-fixes).
- staging: bcm2835-audio: Fix draining behavior regression
  (git-fixes).
- rtc: pcf2127: bugfix: read rtc disables watchdog (git-fixes).
- rtc: rv3029: revert error handling patch to
  rv3029_eeprom_write() (git-fixes).
- video: of: display_timing: Add of_node_put() in
  of_get_display_timing() (git-fixes).
- ath10k: adjust skb length in ath10k_sdio_mbox_rx_packet
  (git-fixes).
- rtw88: fix wrong rx power calculation (git-fixes).
- rtlwifi: Fix file release memory leak (git-fixes).
- rtw88: fix seq_file memory leak (git-fixes).
- rtlwifi: rtl8821ae: Fix incorrect returned values (git-fixes).
- rtlwifi: rtl8192cu: Fix value set in descriptor (git-fixes).
- rtw88: debug: dump tx power indexes in use (git-fixes).
- regulator: da9211: fix obtaining "enable" GPIO (git-fixes).
- regulator: max77686: fix obtaining "maxim,ena" GPIO (git-fixes).
- commit 39d4733
* Tue Oct 22 2019 tiwai@suse.de
- platform/x86: i2c-multi-instantiate: Fail the probe if no IRQ
  provided (git-fixes).
- platform/x86: classmate-laptop: remove unused variable
  (git-fixes).
- platform/x86: pmc_atom: Add Siemens SIMATIC IPC277E to
  critclk_systems DMI table (git-fixes).
- platform/x86: pmc_atom: Add Siemens SIMATIC IPC227E to
  critclk_systems DMI table (git-fixes).
- commit fb32f25
* Tue Oct 22 2019 tiwai@suse.de
- pinctrl: iproc-gpio: Fix incorrect pinconf configurations
  (git-fixes).
- pinctrl: qcom: sdm845: Fix UFS_RESET pin (git-fixes).
- pinctrl: intel: remap the pin number to gpio offset for irq
  enabled pin (git-fixes).
- commit 9e6b97e
* Tue Oct 22 2019 tiwai@suse.de
- nl80211: fix memory leak in nl80211_get_ftm_responder_stats
  (git-fixes).
- NFC: pn533: fix use-after-free and memleaks (git-fixes).
- PCI: PM: Fix pci_power_up() (git-fixes).
- of: mdio: Fix a signedness bug in of_phy_get_and_connect()
  (git-fixes).
- PCI: Correct pci=resource_alignment parameter example
  (git-fixes).
- phy: ti: am654-serdes: fix an use-after-free in
  serdes_am654_clk_register() (git-fixes).
- paride/pcd: need to set queue to NULL before put_disk
  (git-fixes).
- paride/pf: need to set queue to NULL before put_disk
  (git-fixes).
- commit 6c4192e
* Tue Oct 22 2019 tiwai@suse.de
- mt76: stop rx aggregation on station removal (git-fixes).
- mt76: mt7603: fix watchdog rescheduling in mt7603_set_channel
  (git-fixes).
- mt76: mt7615: fix MT7615_WATCHDOG_TIME definition (git-fixes).
- mt76: usb: fix endian in mt76u_copy (git-fixes).
- mt76: mt76u: fix typo in mt76u_fill_rx_sg (git-fixes).
- mt76: mt7615: fix sparse warnings: warning: restricted __le16
  degrades to integer (git-fixes).
- commit 36419e2
* Tue Oct 22 2019 tiwai@suse.de
- memstick: jmb38x_ms: Fix an error handling path in
  'jmb38x_ms_probe()' (git-fixes).
- staging: most: sound: Fix error path of audio_init (git-fixes).
- media: em28xx: Fix exception handling in em28xx_alloc_urbs()
  (git-fixes).
- media: atmel: atmel-isi: fix timeout value for stop streaming
  (git-fixes).
- media: ov8856: Check reading clock frequency succeeded
  (git-fixes).
- media: imx7.rst: Fix the references to the CSI multiplexer
  (git-fixes).
- media: marvell-ccic: mmp: add MODULE_DEVICE_TABLE (git-fixes).
- media: rcar-vin: Clean up correct notifier in error path
  (git-fixes).
- media: staging/imx: Fix NULL deref in find_pipeline_entity()
  (git-fixes).
- media: vivid: fix potential integer overflow on left shift
  (git-fixes).
- commit 67df550
* Tue Oct 22 2019 tiwai@suse.de
- mailbox: qcom-apcs: fix max_register value (git-fixes).
- commit b903159
* Tue Oct 22 2019 tiwai@suse.de
- mac80211: accept deauth frames in IBSS mode (git-fixes).
- mac80211: don't check if key is NULL in ieee80211_key_link()
  (git-fixes).
- mac80211: vht: add support VHT EXT NSS BW in parsing VHT
  (git-fixes).
- mac80211: minstrel_ht: fix per-group max throughput rate
  initialization (git-fixes).
- commit 53cbd53
* Tue Oct 22 2019 tiwai@suse.de
- leds: lm3532: Fix brightness control for i2c mode (git-fixes).
- Refresh
  patches.suse/leds-lm3532-Fixes-for-the-driver-for-stability.patch.
- commit 2348f20
* Tue Oct 22 2019 tiwai@suse.de
- libata/ahci: Fix PCS quirk application (git-fixes).
- libertas_tf: Use correct channel range in lbtf_geo_init
  (git-fixes).
- led: triggers: Fix dereferencing of null pointer (git-fixes).
- leds: trigger: gpio: GPIO 0 is valid (git-fixes).
- leds: ti-lmu-common: Fix coccinelle issue in TI LMU (git-fixes).
- commit 59a3bf5
* Tue Oct 22 2019 tiwai@suse.de
- iwlwifi: exclude GEO SAR support for 3168 (git-fixes).
- iwlwifi: pcie: fix memory leaks in iwl_pcie_ctxt_info_gen3_init
  (git-fixes).
- iwlwifi: mvm: fix race in sync rx queue notification
  (git-fixes).
- Revert "Input: elantech - enable SMBus on new (2018+) systems"
  (git-fixes).
- Input: da9063 - fix capability and drop KEY_SLEEP (git-fixes).
- ima: initialize the "template" field with the default template
  (git-fixes).
- Input: cros_ec_keyb - add back missing mask for event_type
  (git-fixes).
- iwlwifi: dbg_ini: remove periphery phy and aux regions handling
  (git-fixes).
- commit 5ba2a59
* Tue Oct 22 2019 tiwai@suse.de
- i2c: designware: assert reset when error happen at ->probe()
  (git-fixes).
- crypto: hisilicon - Matching the dma address for dma_pool_free()
  (git-fixes).
- dma-buf: fix stack corruption in dma_fence_chain_release
  (git-fixes).
- brcmfmac: get chip's default RAM info during PCIe setup
  (git-fixes).
- can: xilinx_can: xcan_probe(): skip error message on deferred
  probe (git-fixes).
- can: xilinx_can: xcan_chip_start(): fix failure with invalid
  bus (git-fixes).
- crypto: mediatek - fix uninitialized value of gctx->textlen
  (git-fixes).
- crypto: caam/qi - use print_hex_dump_debug function to print
  debug messages (git-fixes).
- crypto: caam/qi - execute library only on DPAA 1.x (git-fixes).
- crypto: caam - unregister algorithm only if the registration
  succeeded (git-fixes).
- crypto: caam - execute module exit point only if necessary
  (git-fixes).
- crypto: caam - free resources in case caam_rng registration
  failed (git-fixes).
- crypto: ccp - Clean up and exit correctly on allocation failure
  (git-fixes).
- crypto: ccp - Reduce maximum stack usage (git-fixes).
- commit 44f9d1d
* Tue Oct 22 2019 tiwai@suse.de
- ath10k: fix latency issue for QCA988x (git-fixes).
- ath9k: dynack: fix possible deadlock in ath_dynack_node_{de}init
  (git-fixes).
- Bluetooth: hidp: Fix assumptions on the return value of
  hidp_send_message (git-fixes).
- bcma: fix incorrect update of BCMA_CORE_PCI_MDIO_DATA
  (git-fixes).
- ASoC: SOF: Intel: hda: Initialize HDA controller after i915 init
  (git-fixes).
- ALSA: aoa: onyx: always initialize register read value
  (git-fixes).
- ahci: Do not export local variable ahci_em_messages (git-fixes).
- commit 2bdf3d5
* Tue Oct 22 2019 tiwai@suse.de
- act_mirred: Fix mirred_init_module error handling (git-fixes).
- commit 251206c
* Tue Oct 22 2019 tiwai@suse.de
- ACPI: CPPC: Set pcc_data[pcc_ss_id] to NULL in
  acpi_cppc_processor_exit() (git-fixes).
- commit e7cfc10
* Tue Oct 22 2019 tiwai@suse.de
- ALSA: usb-audio: Disable quirks for BOSS Katana amplifiers
  (git-fixes).
- commit 043c45c
* Tue Oct 22 2019 tiwai@suse.de
- ALSA: usb-audio: Update DSD support quirks for Oppo and Rotel
  (git-fixes).
- Refresh
  patches.suse/ALSA-usb-audio-Add-DSD-support-for-EVGA-NU-Audio.patch.
- Refresh
  patches.suse/ALSA-usb-audio-Add-Hiby-device-family-to-quirks-for-.patch.
- commit 468bbcd
* Tue Oct 22 2019 tiwai@suse.de
- ALSA: usb-audio: DSD auto-detection for Playback Designs
  (git-fixes).
- Refresh
  patches.suse/ALSA-usb-audio-Add-DSD-support-for-EVGA-NU-Audio.patch.
- Refresh
  patches.suse/ALSA-usb-audio-Add-Hiby-device-family-to-quirks-for-.patch.
- commit 81fa71f
* Tue Oct 22 2019 tiwai@suse.de
- ALSA: hda - Force runtime PM on Nvidia HDMI codecs (git-fixes).
- ALSA: hda/realtek - Enable headset mic on Asus MJ401TA
  (git-fixes).
- ALSA: hdac: clear link output stream mapping (git-fixes).
- ALSA: hda/realtek: Reduce the Headphone static noise on XPS
  9350/9360 (git-fixes).
- ALSA: hda/realtek - Fix alienware headset mic (git-fixes).
- Add Acer Aspire Ethos 8951G model quirk (git-fixes).
- ALSA: hda/hdmi: remove redundant assignment to variable pcm_idx
  (git-fixes).
- ALSA: hda - Allow runtime PM for controller if component
  notifier is used (git-fixes).
- ALSA: usb-audio: remove some dead code (git-fixes).
- ALSA: usb-audio: Fix possible NULL dereference at
  create_yamaha_midi_quirk() (git-fixes).
- ALSA: usb-audio: Clean up check_input_term() (git-fixes).
- ALSA: usb-audio: Remove superfluous bLength checks (git-fixes).
- ALSA: usb-audio: Unify the release of usb_mixer_elem_info
  objects (git-fixes).
- ALSA: usb-audio: Simplify parse_audio_unit() (git-fixes).
- ALSA: usb-audio: More validations of descriptor units
  (git-fixes).
- ALSA: hda/realtek - Check beep whitelist before assigning in
  all codecs (git-fixes).
- ALSA: hda - Define a fallback_pin_fixup_tbl for alc269 family
  (git-fixes).
- ALSA: hda - Expand pin_match function to match upcoming new tbls
  (git-fixes).
- ALSA: hda/sigmatel - remove unused variable 'stac9200_core_init'
  (git-fixes).
- ALSA: hda: Set fifo_size for both playback and capture streams
  (git-fixes).
- ALSA: hda - Inform too slow responses (git-fixes).
- ALSA: usb-audio: Add Pioneer DDJ-SX3 PCM quirck (git-fixes).
- ALSA: usb-audio: fix PCM device order (git-fixes).
- ALSA: usb-audio: Unify audioformat release code (git-fixes).
- ALSA: hda: Add support of Zhaoxin controller (git-fixes).
- ALSA: usb-audio: Scarlett Gen 2 mixer interface (git-fixes).
- ALSA: line6: sizeof (byte) is always 1, use that fact
  (git-fixes).
- ALSA: hda/hdmi - Allow audio component for AMD/ATI and Nvidia
  HDMI (git-fixes).
- commit 34822c0
* Tue Oct 22 2019 jslaby@suse.cz
- Linux 5.3.7 (bnc#1151927 5.3.7).
- tracing/hwlat: Don't ignore outer-loop duration when calculating
  max_latency (bnc#1151927 5.3.7).
- tracing/hwlat: Report total time spent in all NMIs during the
  sample (bnc#1151927 5.3.7).
- tracing: Get trace_array reference for available_tracers files
  (bnc#1151927 5.3.7).
- ftrace: Get a reference counter for the trace_array on filter
  files (bnc#1151927 5.3.7).
- hwmon: Fix HWMON_P_MIN_ALARM mask (bnc#1151927 5.3.7).
- mtd: rawnand: au1550nd: Fix au_read_buf16() prototype
  (bnc#1151927 5.3.7).
- firmware: google: increment VPD key_len properly (bnc#1151927
  5.3.7).
- mei: avoid FW version request on Ibex Peak and earlier
  (bnc#1151927 5.3.7).
- mei: me: add comet point (lake) LP device ids (bnc#1151927
  5.3.7).
- iio: light: opt3001: fix mutex unlock race (bnc#1151927 5.3.7).
- iio: adc: ad799x: fix probe error handling (bnc#1151927 5.3.7).
- iio: light: add missing vcnl4040 of_compatible (bnc#1151927
  5.3.7).
- iio: light: fix vcnl4000 devicetree hooks (bnc#1151927 5.3.7).
- iio: adc: axp288: Override TS pin bias current for some models
  (bnc#1151927 5.3.7).
- iio: adc: stm32-adc: fix a race when using several adcs with
  dma and irq (bnc#1151927 5.3.7).
- iio: adc: stm32-adc: move registers definitions (bnc#1151927
  5.3.7).
- iio: accel: adxl372: Perform a reset at start up (bnc#1151927
  5.3.7).
- iio: accel: adxl372: Fix push to buffers lost samples
  (bnc#1151927 5.3.7).
- iio: accel: adxl372: Fix/remove limitation for FIFO samples
  (bnc#1151927 5.3.7).
- iio: adc: hx711: fix bug in sampling of data (bnc#1151927
  5.3.7).
- staging: vt6655: Fix memory leak in vt6655_probe (bnc#1151927
  5.3.7).
- Staging: fbtft: fix memory leak in fbtft_framebuffer_alloc
  (bnc#1151927 5.3.7).
- staging: rtl8188eu: fix HighestRate check in
  odm_ARFBRefresh_8188E() (bnc#1151927 5.3.7).
- staging: bcm2835-audio: Fix draining behavior regression
  (bnc#1151927 5.3.7).
- staging/fbtft: Depend on OF (bnc#1151927 5.3.7).
- serial: uartps: Fix uartps_major handling (bnc#1151927 5.3.7).
- serial: uartlite: fix exit path null pointer (bnc#1151927
  5.3.7).
- USB: yurex: fix NULL-derefs on disconnect (bnc#1151927 5.3.7).
- USB: iowarrior: fix use-after-free after driver unbind
  (bnc#1151927 5.3.7).
- USB: iowarrior: fix use-after-free on release (bnc#1151927
  5.3.7).
- USB: iowarrior: fix use-after-free on disconnect (bnc#1151927
  5.3.7).
- USB: chaoskey: fix use-after-free on release (bnc#1151927
  5.3.7).
- USB: adutux: fix use-after-free on release (bnc#1151927 5.3.7).
- USB: ldusb: fix NULL-derefs on driver unbind (bnc#1151927
  5.3.7).
- USB: legousbtower: fix use-after-free on release (bnc#1151927
  5.3.7).
- USB: usb-skeleton: fix NULL-deref on disconnect (bnc#1151927
  5.3.7).
- USB: serial: keyspan: fix NULL-derefs on open() and write()
  (bnc#1151927 5.3.7).
- USB: serial: option: add support for Cinterion CLS8 devices
  (bnc#1151927 5.3.7).
- USB: serial: option: add Telit FN980 compositions (bnc#1151927
  5.3.7).
- USB: serial: ftdi_sio: add device IDs for Sienna and Echelon
  PL-20 (bnc#1151927 5.3.7).
- media: stkwebcam: fix runtime PM after driver unbind
  (bnc#1151927 5.3.7).
- USB: serial: fix runtime PM after driver unbind (bnc#1151927
  5.3.7).
- USB: usblp: fix runtime PM after driver unbind (bnc#1151927
  5.3.7).
- USB: usb-skeleton: fix runtime PM after driver unbind
  (bnc#1151927 5.3.7).
- usb: renesas_usbhs: gadget: Fix usb_ep_set_{halt,wedge}()
  behavior (bnc#1151927 5.3.7).
- usb: renesas_usbhs: gadget: Do not discard queues in
  usb_ep_set_{halt,wedge}() (bnc#1151927 5.3.7).
- xhci: Fix NULL pointer dereference in
  xhci_clear_tt_buffer_complete() (bnc#1151927 5.3.7).
- xhci: Increase STS_SAVE timeout in xhci_suspend() (bnc#1151927
  5.3.7).
- xhci: Prevent deadlock when xhci adapter breaks during init
  (bnc#1151927 5.3.7).
- usb: xhci: wait for CNR controller not ready bit in xhci resume
  (bnc#1151927 5.3.7).
- xhci: Fix USB 3.1 capability detection on early xHCI 1.1 spec
  based hosts (bnc#1151927 5.3.7).
- xhci: Check all endpoints for LPM timeout (bnc#1151927 5.3.7).
- xhci: Prevent device initiated U1/U2 link pm if exit latency
  is too long (bnc#1151927 5.3.7).
- xhci: Fix false warning message about wrong bounce buffer
  write length (bnc#1151927 5.3.7).
- USB: legousbtower: fix open after failed reset request
  (bnc#1151927 5.3.7).
- USB: legousbtower: fix potential NULL-deref on disconnect
  (bnc#1151927 5.3.7).
- USB: legousbtower: fix deadlock on disconnect (bnc#1151927
  5.3.7).
- USB: legousbtower: fix slab info leak at probe (bnc#1151927
  5.3.7).
- usb: typec: ucsi: displayport: Fix for the mode entering routine
  (bnc#1151927 5.3.7).
- usb: typec: ucsi: ccg: Remove run_isr flag (bnc#1151927 5.3.7).
- USB: usblcd: fix I/O after disconnect (bnc#1151927 5.3.7).
- usb: typec: tcpm: usb: typec: tcpm: Fix a signedness bug in
  tcpm_fw_get_caps() (bnc#1151927 5.3.7).
- USB: dummy-hcd: fix power budget for SuperSpeed mode
  (bnc#1151927 5.3.7).
- USB: yurex: Don't retry on unexpected errors (bnc#1151927
  5.3.7).
- USB: adutux: fix NULL-derefs on disconnect (bnc#1151927 5.3.7).
- USB: adutux: fix use-after-free on disconnect (bnc#1151927
  5.3.7).
- USB: microtek: fix info-leak at probe (bnc#1151927 5.3.7).
- USB: rio500: Remove Rio 500 kernel driver (bnc#1151927 5.3.7).
- perf inject jit: Fix JIT_CODE_MOVE filename (bnc#1151927 5.3.7).
- perf llvm: Don't access out-of-scope array (bnc#1151927 5.3.7).
- efi/tpm: Fix sanity check of unsigned tbl_size being less than
  zero (bnc#1151927 5.3.7).
- efi/tpm: Only set 'efi_tpm_final_log_size' after successful
  event log parsing (bnc#1151927 5.3.7).
- efi/tpm: Don't traverse an event log with no events (bnc#1151927
  5.3.7).
- efi/tpm: Don't access event->count when it isn't mapped
  (bnc#1151927 5.3.7).
- efivar/ssdt: Don't iterate over EFI vars if no SSDT override
  was specified (bnc#1151927 5.3.7).
- x86/asm: Fix MWAITX C-state hint value (bnc#1151927 5.3.7).
- MIPS: Disable Loongson MMI instructions for kernel build
  (bnc#1151927 5.3.7).
- MIPS: elf_hwcap: Export userspace ASEs (bnc#1151927 5.3.7).
- NFS: Fix O_DIRECT accounting of number of bytes read/written
  (bnc#1151927 5.3.7).
- CIFS: Force reval dentry if LOOKUP_REVAL flag is set
  (bnc#1151927 5.3.7).
- CIFS: Force revalidate inode when dentry is stale (bnc#1151927
  5.3.7).
- CIFS: Gracefully handle QueryInfo errors during open
  (bnc#1151927 5.3.7).
- cifs: use cifsInodeInfo->open_file_lock while iterating to
  avoid a panic (bnc#1151927 5.3.7).
- drm/i915: Mark contents as dirty on a write fault (bnc#1151927
  5.3.7).
- drm/i915: Bump skl+ max plane width to 5k for linear/x-tiled
  (bnc#1151927 5.3.7).
- drm/i915: Whitelist COMMON_SLICE_CHICKEN2 (bnc#1151927 5.3.7).
- drm/i915: Perform GGTT restore much earlier during resume
  (bnc#1151927 5.3.7).
- io_uring: only flush workqueues on fileset removal (bnc#1151927
  5.3.7).
- btrfs: fix uninitialized ret in ref-verify (bnc#1151927 5.3.7).
- btrfs: allocate new inode in NOFS context (bnc#1151927 5.3.7).
- btrfs: fix balance convert to single on 32-bit host CPUs
  (bnc#1151927 5.3.7).
- btrfs: fix incorrect updating of log root tree (bnc#1151927
  5.3.7).
- Btrfs: fix memory leak due to concurrent append writes with
  fiemap (bnc#1151927 5.3.7).
- Fix the locking in dcache_readdir() and friends (bnc#1151927
  5.3.7).
- arm64/sve: Fix wrong free for task->thread.sve_state
  (bnc#1151927 5.3.7).
- gpio: eic: sprd: Fix the incorrect EIC offset when toggling
  (bnc#1151927 5.3.7).
- gpio: fix getting nonexclusive gpiods from DT (bnc#1151927
  5.3.7).
- gpiolib: don't clear FLAG_IS_OUT when emulating
  open-drain/open-source (bnc#1151927 5.3.7).
- selinux: fix context string corruption in convert_context()
  (bnc#1151927 5.3.7).
- mm/vmpressure.c: fix a signedness bug in
  vmpressure_register_event() (bnc#1151927 5.3.7).
- mm/page_alloc.c: fix a crash in free_pages_prepare()
  (bnc#1151927 5.3.7).
- mm/z3fold.c: claim page in the beginning of free (bnc#1151927
  5.3.7).
- panic: ensure preemption is disabled during panic() (bnc#1151927
  5.3.7).
- commit fe06c63
* Tue Oct 22 2019 jslaby@suse.cz
- Update
  patches.suse/0001-btrfs-relocation-fix-use-after-free-on-dead-relocati.patch
  (bsc#1152972 bnc#1151927 5.3.7).
- Update
  patches.suse/0001-kernel-sysctl.c-do-not-override-max_threads-provided.patch
  (bnc#1150875 bnc#1151927 5.3.7).
- Update
  patches.suse/0002-drm-msm-Use-the-correct-dma_sync-calls-harder.patch
  (bsc#1152472 bnc#1151927 5.3.7).
- Update
  patches.suse/ACPI-PPTT-Add-support-for-ACPI-6.3-thread-flag.patch
  (jsc#SLE-10146 bnc#1151927 5.3.7).
- Update patches.suse/IB-core-Fix-wrong-iterating-on-ports.patch
  (jsc#SLE-8449 bnc#1151927 5.3.7).
- Update patches.suse/RDMA-vmw_pvrdma-Free-SRQ-only-once.patch
  (jsc#SLE-8449 bnc#1151927 5.3.7).
- Update
  patches.suse/arm64-topology-Use-PPTT-to-determine-if-PE-is-a-thre.patch
  (jsc#SLE-10146 bnc#1151927 5.3.7).
- Update
  patches.suse/blk-wbt-fix-performance-regression-in-wbt-scale_up-scale_down.patch
  (bsc#1152489 bnc#1151927 5.3.7).
- commit 942d26b
* Tue Oct 22 2019 msuchanek@suse.de
- kernel-binary.spec.in: Fix build of non-modular kernels (boo#1154578).
- commit 7f1e881
* Tue Oct 22 2019 jroedel@suse.de
- iommu/vt-d: Add Scalable Mode fault information (jsc#SLE-8032).
- iommu/vt-d: Add trace events for device dma map/unmap
  (jsc#SLE-8014).
- commit e17e39f
* Tue Oct 22 2019 acho@suse.com
- rtlwifi: Fix potential overflow on P2P code (bsc#1154372
  CVE-2019-17666).
- commit 6cf6227
* Tue Oct 22 2019 mkubecek@suse.cz
- series.conf: cleanup
  Update upstream references and move into sorted section:
  patches.suse/net-ath6kl-Fix-a-NULL-ptr-deref-bug.patch
  Move into "on the way" section:
  patches.suse/libertas-fix-a-potential-NULL-pointer-dereference.patch
- commit 5ebd03f
* Tue Oct 22 2019 mkubecek@suse.cz
- Fix Patch-mainline tag
  patches.suse/firmware-dmi-fix-unlikely-out-of-bounds-read.patch.
- commit a48c406
* Mon Oct 21 2019 tiwai@suse.de
- libertas: fix a potential NULL pointer dereference
  (CVE-2019-16232,bsc#1150465).
- commit 9f9e4f7
* Mon Oct 21 2019 tiwai@suse.de
- iwlwifi: pcie: fix rb_allocator workqueue allocation
  (CVE-2019-16234,bsc#1150452).
- commit 88957ce
* Mon Oct 21 2019 msuchanek@suse.de
- kernel-binary.spec.in: Obsolete kgraft packages only when not building
  them.
- commit 25f7690
* Mon Oct 21 2019 msuchanek@suse.de
- kernel-subpackage-build: create zero size ghost for uncompressed vmlinux
  (bsc#1154354).
  It is not strictly necessary to uncompress it so maybe the ghost file
  can be 0 size in this case.
- commit 4bf73c8
* Mon Oct 21 2019 jroedel@suse.de
- iommu/amd: Check PM_LEVEL_SIZE() condition in locked section
  (bsc#1154625).
- iommu/amd: Fix incorrect PASID decoding from event log
  (bsc#1154626).
- iommu/io-pgtable-arm: Support all Mali configurations
  (bsc#1154637).
- iommu/io-pgtable-arm: Correct Mali attributes (bsc#1154636).
- iommu/amd: Lock code paths traversing
  protection_domain->dev_list (bsc#1154629).
- iommu/amd: Lock dev_data in attach/detach code paths
  (bsc#1154630).
- iommu/amd: Check for busy devices earlier in attach_device()
  (bsc#1154624).
- iommu/amd: Take domain->lock for complete attach/detach path
  (bsc#1154633).
- iommu/amd: Remove amd_iommu_devtable_lock (bsc#1154631).
- iommu/amd: Remove domain->updated (bsc#1154632).
- iommu/amd: Wait for completion of IOTLB flush in attach_device
  (bsc#1154635).
- iommu/amd: Unmap all L7 PTEs when downgrading page-sizes
  (bsc#1154634).
- iommu/amd: Introduce first_pte_l7() helper (bsc#1154628).
- iommu/amd: Fix pages leak in free_pagetable() (bsc#1154627).
- commit 41aabfd
* Mon Oct 21 2019 pmladek@suse.com
- vsprintf: Prevent crash when dereferencing invalid pointers
  for %%pD (bsc#1154619).
- commit dffedfe
* Mon Oct 21 2019 dwagner@suse.de
- scsi: lpfc: Check queue pointer before use (bsc#1154242).
- commit 7553622
* Mon Oct 21 2019 ohering@suse.de
- x86/hyperv: Set pv_info.name to "Hyper-V" (fate#323887).
- x86/hyperv: Make vapic support x2apic mode (fate#323887).
- Drivers: hv: vmbus: Fix harmless building warnings without
  CONFIG_PM_SLEEP (fate#323887).
- HID: hyperv: Use in-place iterator API in the channel callback
  (fate#323887).
- commit bcf7984
* Mon Oct 21 2019 dwagner@suse.de
- Move patch to upstream section
  Refresh
  patches.suse/scsi-lpfc-remove-left-over-BUILD_NVME-defines.patch.
- commit 4bf6dec
* Mon Oct 21 2019 jdelvare@suse.de
- firmware: dmi: Fix unlikely out-of-bounds read in
  save_mem_devices (git-fixes).
- commit cf1b81f
* Mon Oct 21 2019 mkubecek@suse.cz
- series.conf: refresh
- update upstream references:
  patches.suse/cfg80211-wext-avoid-copying-malformed-SSIDs.patch.
  patches.suse/net-ibmvnic-Fix-EOI-when-running-in-XIVE-mode.patch.
- commit 863654c
* Mon Oct 21 2019 dbueso@suse.de
- hrtimer/treewide: Use hrtimer_sleeper_start_expires()
  (bsc#1149032).
- hrtimer: Provide hrtimer_sleeper_start_expires() (bsc#1149032).
- hrtimer: Consolidate hrtimer_init() +  hrtimer_init_sleeper()
  calls (bsc#1149032).
- hrtimer: Remove task argument from hrtimer_init_sleeper()
  (bsc#1149032).
- lib/timerqueue: Rely on rbtree semantics for next timer
  (bsc#1154536).
- x86/math64: Provide a sane mul_u64_u32_div() implementation
  for x86_64 (bsc#1149032).
- sched: Clean up active_mm reference counting (bsc#1149032).
- sched/core: Convert get_task_struct() to return the task
  (bsc#1149032).
- mutex: Fix up mutex_waiter usage (bsc#1149032).
- locking/mutex: Use mutex flags macro instead of hard code
  (bsc#1149032).
- locking/mutex: Make __mutex_owner static to mutex.c
  (bsc#1149032).
- locking/qspinlock,x86: Clarify virt_spin_lock_key (bsc#1149032).
- locking/rwsem: Check for operations on an uninitialized rwsem
  (bsc#1149032).
- locking/rwsem: Make handoff writer optimistically spin on owner
  (bsc#1149032).
- commit 2a492dc
* Sat Oct 19 2019 mkubecek@suse.cz
- Fix Patch-mainline:
  patches.suse/s390-zcrypt-add-base-code-for-cca-crypto-card-info-support
  patches.suse/s390-zcrypt-cex7s-exploitation-support
  patches.suse/s390-zcrypt-move-cca-misc-functions-to-new-code-file
  patches.suse/s390-zcrypt-new-sysfs-attributes-serialnr-and-mkvps
- commit 7dfd2cf
* Fri Oct 18 2019 tbogendoerfer@suse.de
- netdevsim: implement support for devlink region and snapshots
  (bsc#1154353).
- Refresh patches.suse/net-devlink-split-reload-op-into-two.patch.
- commit 8316be1
* Fri Oct 18 2019 tbogendoerfer@suse.de
- netdevsim: register couple of devlink params (bsc#1154353).
- Refresh patches.suse/net-devlink-split-reload-op-into-two.patch.
- commit f83adc1
* Fri Oct 18 2019 tbogendoerfer@suse.de
- SUNRPC: fix race to sk_err after xs_error_report (bsc#1154353).
- commit cf2c098
* Fri Oct 18 2019 tbogendoerfer@suse.de
- netdevsim: Add devlink-trap support (bsc#1154353).
- Refresh patches.suse/net-devlink-split-reload-op-into-two.patch.
- commit bd989c4
* Fri Oct 18 2019 tbogendoerfer@suse.de
- net: hisilicon: Fix usage of uninitialized variable in function
  mdio_sc_cfg_reg_write() (bsc#1154353).
- mlxsw: spectrum: Clear VLAN filters during port initialization
  (bsc#1154488).
- net: ena: clean up indentation issue (bsc#1154492).
- net: hisilicon: Fix signedness bug in hix5hd2_dev_probe()
  (bsc#1154353).
- net: ena: Select DIMLIB for ENA_ETHERNET (bsc#1154492).
- sunrpc: clean up indentation issue (bsc#1154353).
- sunrpc: add a new cache_detail operation for when a cache is
  flushed (bsc#1154353).
- svcrdma: Use llist for managing cache of recv_ctxts
  (jsc#SLE-8449).
- svcrdma: Remove svc_rdma_wq (jsc#SLE-8449).
- SUNRPC: Track writers of the 'channel' file to improve
  cache_listeners_exist (bsc#1154353).
- SUNRPC: Fix congestion window race with disconnect
  (bsc#1154353).
- SUNRPC: Rename xdr_buf_read_netobj to xdr_buf_read_mic
  (bsc#1154353).
- SUNRPC: Don't receive TCP data into a request buffer that has
  been reset (bsc#1154353).
- xprtrdma: Clear xprt->reestablish_timeout on close
  (jsc#SLE-8449).
- xprtrdma: Recycle MRs after disconnect (jsc#SLE-8449).
- xprtrdma: Optimize rpcrdma_post_recvs() (jsc#SLE-8449).
- xprtrdma: Inline XDR chunk encoder functions (jsc#SLE-8449).
- xprtrdma: Fix bc_max_slots return value (jsc#SLE-8449).
- xprtrdma: Clean up xprt_rdma_set_connect_timeout()
  (jsc#SLE-8449).
- xprtrdma: Use an llist to manage free rpcrdma_reps
  (jsc#SLE-8449).
- xprtrdma: Remove rpcrdma_buffer::rb_mrlock (jsc#SLE-8449).
- xprtrdma: Cache free MRs in each rpcrdma_req (jsc#SLE-8449).
- xprtrdma: Ensure creating an MR does not trigger FS writeback
  (jsc#SLE-8449).
- xprtrdma: Move rpcrdma_mr_get out of frwr_map (jsc#SLE-8449).
- xprtrdma: Combine rpcrdma_mr_put and rpcrdma_mr_unmap_and_put
  (jsc#SLE-8449).
- xprtrdma: Simplify rpcrdma_mr_pop (jsc#SLE-8449).
- xprtrdma: Rename rpcrdma_buffer::rb_all (jsc#SLE-8449).
- xprtrdma: Rename CQE field in Receive trace points
  (jsc#SLE-8449).
- xprtrdma: Boost maximum transport header size (jsc#SLE-8449).
- xprtrdma: Fix calculation of ri_max_segs again (jsc#SLE-8449).
- xprtrdma: Update obsolete comment (jsc#SLE-8449).
- xprtrdma: Refresh the documenting comment in frwr_ops.c
  (jsc#SLE-8449).
- SUNRPC: Inline xdr_commit_encode (bsc#1154353).
- SUNRPC: Remove rpc_wake_up_queued_task_on_wq() (bsc#1154353).
- RDMA/hns: Package operations of rq inline buffer into separate
  functions (jsc#SLE-8449).
- RDMA/hns: Optimize cmd init and mode selection for hip08
  (jsc#SLE-8449).
- RDMA/hns: Use devm_platform_ioremap_resource() to simplify code
  (jsc#SLE-8449).
- RDMA/hns: Fix wrong assignment of qp_access_flags
  (jsc#SLE-8449).
- RDMA/hns: Delete the not-used lines (jsc#SLE-8449).
- RDMA/hns: Remove if-else judgment statements for creating srq
  (jsc#SLE-8449).
- RDMA/hns: Add reset process for function-clear (jsc#SLE-8449).
- RDMA/hns: Fix cast from or to restricted __le32 for driver
  (jsc#SLE-8449).
- RDMA/hns: Remove the some magic number (jsc#SLE-8449).
- RDMA/hns: Modify the data structure of hns_roce_av
  (jsc#SLE-8449).
- RDMA/hns: Fix some white space check_mtu_validate()
  (jsc#SLE-8449).
- RDMA/hns: Remove unuseful member (jsc#SLE-8449).
- RDMA/hns: bugfix for slab-out-of-bounds when loading hip08
  driver (jsc#SLE-8449).
- RDMA/hns: Bugfix for slab-out-of-bounds when unloading hip08
  driver (jsc#SLE-8449).
- RDMA/hns: Modify pi vlaue when cq overflows (jsc#SLE-8449).
- RDMA/hns: Bugfix for creating qp attached to srq (jsc#SLE-8449).
- RDMA/hns: Logic optimization of wc_flags (jsc#SLE-8449).
- RDMA/hns: Use the new APIs for printing log (jsc#SLE-8449).
- RDMA/hns: Disable alw_lcl_lpbk of SSU (jsc#SLE-8449).
- RDMA/hns: Remove redundant print in hns_roce_v2_ceq_int()
  (jsc#SLE-8449).
- RDMA/hns: Refactor hns_roce_v2_set_hem for hip08 (jsc#SLE-8449).
- RDMA/hns: Remove unnecessary kzalloc (jsc#SLE-8449).
- RDMA/hns: Refactor irq request code (jsc#SLE-8449).
- RDMA/hns: Split bool statement and assign statement
  (jsc#SLE-8449).
- RDMA/hns: Handling the error return value of hem function
  (jsc#SLE-8449).
- RDMA/hns: Update some comments style (jsc#SLE-8449).
- RDMA/hns: Clean up unnecessary initial assignment
  (jsc#SLE-8449).
- RDMA/hns: Remove unnessary init for cmq reg (jsc#SLE-8449).
- RDMA/hns: Update the prompt message for creating and destroy qp
  (jsc#SLE-8449).
- RDMA/hns: Optimize hns_roce_modify_qp function (jsc#SLE-8449).
- RDMA/hns: Encapsulate some lines for setting sq size in user
  mode (jsc#SLE-8449).
- RDMA/hns: remove obsolete Kconfig comment (jsc#SLE-8449).
- RDMA/hns: Remove not used UAR assignment (jsc#SLE-8449).
- RDMA/hns: remove set but not used variable 'irq_num'
  (jsc#SLE-8449).
- RDMA/hns: Refactor eq table init for hip08 (jsc#SLE-8449).
- RDMA/hns: Refactor hem table mhop check and calculation
  (jsc#SLE-8449).
- RDMA/hns: Package for hns_roce_rereg_user_mr function
  (jsc#SLE-8449).
- RDMA/hns: Optimize hns_roce_mhop_alloc function (jsc#SLE-8449).
- RDMA/hns: optimize the duplicated code for qpc setting flow
  (jsc#SLE-8449).
- RDMA/hns: Use a separated function for setting extend sge
  paramters (jsc#SLE-8449).
- RDMA/hns: Refactor for hns_roce_v2_modify_qp function
  (jsc#SLE-8449).
- RDMA/hns: Refactor the code of creating srq (jsc#SLE-8449).
- RDMA/hns: Package the flow of creating cq (jsc#SLE-8449).
- net: ena: don't wake up tx queue when down (bsc#1154492).
- mlxsw: spectrum_buffers: Add the ability to query the CPU
  port's shared buffer (bsc#1154488).
- mlxsw: spectrum: Register CPU port with devlink (bsc#1154488).
- mlxsw: spectrum_buffers: Prevent changing CPU port's
  configuration (bsc#1154488).
- net: ena: fix incorrect update of intr_delay_resolution
  (bsc#1154492).
- net: ena: fix retrieval of nonadaptive interrupt moderation
  intervals (bsc#1154492).
- net: ena: fix update of interrupt moderation register
  (bsc#1154492).
- net: ena: remove all old adaptive rx interrupt moderation code
  from ena_com (bsc#1154492).
- net: ena: remove ena_restore_ethtool_params() and relevant
  fields (bsc#1154492).
- net: ena: remove old adaptive interrupt moderation code from
  ena_netdev (bsc#1154492).
- net: ena: remove code duplication in
  ena_com_update_nonadaptive_moderation_interval _*()
  (bsc#1154492).
- net: ena: enable the interrupt_moderation in
  driver_supported_features (bsc#1154492).
- net: ena: reimplement set/get_coalesce() (bsc#1154492).
- net: ena: switch to dim algorithm for rx adaptive interrupt
  moderation (bsc#1154492).
- net: ena: add intr_moder_rx_interval to struct ena_com_dev
  and use it (bsc#1154492).
- netdevsim: Set offsets to various protocol layers (bsc#1154353).
- net: hns3: add some DFX info for reset issue (bsc#1154353).
- net: hns3: check NULL pointer before use (bsc#1154353).
- net: hns3: modify some logs format (bsc#1154353).
- net: hns3: fix port setting handle for fibre port (bsc#1154353).
- net: hns3: fix shaper parameter algorithm (bsc#1154353).
- net: hns3: revert to old channel when setting new channel num
  fail (bsc#1154353).
- net: hns3: add ethtool_ops.set_channels support for HNS3 VF
  driver (bsc#1154353).
- net: hns3: make array spec_opcode static const, makes object
  smaller (bsc#1154353).
- net: hns3: make hclge_dbg_get_m7_stats_info static
  (bsc#1154353).
- net: hns3: disable loopback setting in hclge_mac_init
  (bsc#1154353).
- net: hns3: remove explicit conversion to bool (bsc#1154353).
- net: hns3: add client node validity judgment (bsc#1154353).
- net: hns3: fix mis-assignment to hdev->reset_level in
  hclge_reset (bsc#1154353).
- net: hns3: fix double free bug when setting ringparam
  (bsc#1154353).
- net: hns3: fix error VF index when setting VLAN offload
  (bsc#1154353).
- net: hns: Move static keyword to the front of declaration
  (bsc#1154353).
- sunrpc: Use kzfree rather than its implementation (bsc#1154353).
- mvpp2: percpu buffers (bsc#1154353).
- mvpp2: refactor BM pool functions (bsc#1154353).
- net: hns3: remove set but not used variable 'qos' (bsc#1154353).
- net: hns3: remove redundant assignment to pointer reg_info
  (bsc#1154353).
- net: bridge: Populate the pvid flag in br_vlan_get_info
  (bsc#1154353).
- net: hns3: not allow SSU loopback while execute ethtool -t dev
  (bsc#1154353).
- net: hns3: check reset interrupt status when reset fails
  (bsc#1154353).
- net: hns3: add phy selftest function (bsc#1154353).
- net: hns3: implement .process_hw_error for hns3 client
  (bsc#1154353).
- net: hns3: optimize waiting time for TQP reset (bsc#1154353).
- net: hns3: fix incorrect type in assignment (bsc#1154353).
- net: hns3: make some reusable codes into a function
  (bsc#1154353).
- net: hns3: optimize some log printings (bsc#1154353).
- net: hns3: reduce the parameters of some functions
  (bsc#1154353).
- net: hns3: modify base parameter of kstrtouint in
  hclge_dbg_dump_tm_map (bsc#1154353).
- net: hns3: use macro instead of magic number (bsc#1154353).
- net: hns3: code optimization for debugfs related to "dump reg"
  (bsc#1154353).
- mlxsw: spectrum_ptp: Add counters for GC events (bsc#1154488).
- mlxsw: Bump firmware version to 13.2000.1886 (bsc#1154488).
- mlxsw: spectrum: Prevent auto negotiation on number of lanes
  (bsc#1154488).
- mlxsw: Remove 56G speed support (bsc#1154488).
- net: hns3: Fix -Wunused-const-variable warning (bsc#1154353).
- selftests: mlxsw: Add a test case for devlink-trap
  (bsc#1154488).
- selftests: mlxsw: Add test cases for devlink-trap L2 drops
  (bsc#1154488).
- mlxsw: spectrum: Add devlink-trap support (bsc#1154488).
- mlxsw: Add trap group for layer 2 discards (bsc#1154488).
- mlxsw: Add layer 2 discard trap IDs (bsc#1154488).
- mlxsw: reg: Add new trap actions (bsc#1154488).
- mlxsw: core: Add API to set trap action (bsc#1154488).
- netdevsim: Fix build error without CONFIG_INET (bsc#1154353).
- net: hns: add phy_attached_info() to the hns driver
  (bsc#1154353).
- net: hns3: add phy_attached_info() to the hns3 driver
  (bsc#1154353).
- net: hns3: prevent unnecessary MAC TNL interrupt (bsc#1154353).
- net: hns3: change print level of RAS error log from warning
  to error (bsc#1154353).
- net: hns3: fix error and incorrect format (bsc#1154353).
- net: hns3: modify redundant initialization of variable
  (bsc#1154353).
- net: hns3: add or modify comments (bsc#1154353).
- Documentation: Add description of netdevsim traps (bsc#1154353).
- net: bridge: mdb: allow add/delete for host-joined groups
  (bsc#1154353).
- net: bridge: mdb: dump host-joined entries as well
  (bsc#1154353).
- net: bridge: mdb: factor out mdb filling (bsc#1154353).
- net: bridge: mdb: move vlan comments (bsc#1154353).
- net/mvpp2: Replace tasklet with softirq hrtimer (bsc#1154353).
- net: hns3: Make hclge_func_reset_sync_vf static (bsc#1154353).
- mvpp2: no need to check return value of debugfs_create functions
  (bsc#1154353).
- hns3: no need to check return value of debugfs_create functions
  (bsc#1154353).
- net: hns3: refine some macro definitions (bsc#1154353).
- net: hns3: add handshake with VF for PF reset (bsc#1154353).
- net: hns3: refine MAC pause statistics querying function
  (bsc#1154353).
- net: hns3: add function display NCL_CONFIG info (bsc#1154353).
- net: hns3: add check for max TX BD num for tso and non-tso case
  (bsc#1154353).
- net: hns3: add some statitics info to tx process (bsc#1154353).
- net: hns3: add DFX registers information for ethtool -d
  (bsc#1154353).
- net: hns3: modify how pause options is displayed (bsc#1154353).
- net: hns3: add input length check for debugfs write function
  (bsc#1154353).
- net: hns3: clean up for vlan handling in hns3_fill_desc_vtags
  (bsc#1154353).
- net: hns3: fix interrupt clearing error for VF (bsc#1154353).
- net: hns3: fix GFP flag error in hclge_mac_update_stats()
  (bsc#1154353).
- mlxsw: spectrum: Extend to support Spectrum-3 ASIC
  (bsc#1154488).
- net: hns3: activate reset timer when calling reset_event
  (bsc#1154353).
- net: hns3: clear reset interrupt status in hclge_irq_handle()
  (bsc#1154353).
- net: hns3: fix some reset handshake issue (bsc#1154353).
- net: hns3: rename a member in struct
  hclge_mac_ethertype_idx_rd_cmd (bsc#1154353).
- net: hns3: simplify hclge_cmd_query_error() (bsc#1154353).
- net: hns3: minior error handling change for
  hclge_tm_schd_info_init (bsc#1154353).
- net: hns3: minor cleanup in hns3_clean_rx_ring (bsc#1154353).
- net: hns3: remove unnecessary variable in
  hclge_get_mac_vlan_cmd_status() (bsc#1154353).
- net: hns3: refine for set ring parameters (bsc#1154353).
- net: hns3: do not query unsupported commands in debugfs
  (bsc#1154353).
- net: hns3: add handler for NCSI error mailbox (bsc#1154353).
- net: hns3: add link change event report (bsc#1154353).
- net: phy: xgene: use devm_platform_ioremap_resource() to
  simplify code (bsc#1154353).
- mvpp2: use devm_platform_ioremap_resource() to simplify code
  (bsc#1154353).
- net: bridge: mcast: add delete due to fast-leave mdb flag
  (bsc#1154353).
- selftests: mlxsw: Add a test for leftover DSCP rule
  (bsc#1154488).
- selftests: mlxsw: Fix local variable declarations in DSCP tests
  (bsc#1154488).
- net: Remove dev_err() usage after platform_get_irq()
  (bsc#1154353).
- net: hns3: use dev_info() instead of pr_info() (bsc#1154353).
- net: hns3: Add support for using order 1 pages with a 4K buffer
  (bsc#1154353).
- net: hns3: add interrupt affinity support for misc interrupt
  (bsc#1154353).
- net: hns3: make hclge_service use delayed workqueue
  (bsc#1154353).
- net: hns3: add debug messages to identify eth down cause
  (bsc#1154353).
- net: hns3: modify firmware version display format (bsc#1154353).
- net: hns3: change GFP flag during lock period (bsc#1154353).
- net: hns3: remove upgrade reset level when reset fail
  (bsc#1154353).
- net: hns3: add a check for get_reset_level (bsc#1154353).
- net: hns3: add reset checking before set channels (bsc#1154353).
- mlxsw: spectrum_flower: Forbid to offload match on reserved
  TCP flags bits (bsc#1154488).
- mlxsw: spectrum_acl: Track rules that forbid egress block bind
  (bsc#1154488).
- mlxsw: spectrum_flower: Forbid to offload mirred redirect on
  egress (bsc#1154488).
- drivers: net: xgene: Move status variable declaration into
  CONFIG_ACPI block (bsc#1154353).
- mlxsw: spectrum_router: Increase scale of IPv6 nexthop groups
  (bsc#1154488).
- mlxsw: spectrum: Expose KVD size for Spectrum-2 (bsc#1154488).
- drivers: net: xgene: Remove acpi_has_method() calls
  (bsc#1154353).
- platform/mellanox: mlxreg-hotplug: Remove dev_err() usage
  after platform_get_irq() (bsc#1154488).
- commit 25127c6
* Fri Oct 18 2019 ptesarik@suse.cz
- s390/zcrypt: new sysfs attributes serialnr and mkvps
  (jsc#SLE-9582 jsc#IBM-505 LTC#181532).
- Refresh patches.suse/s390-zcrypt-cex7s-exploitation-support.
- commit e3c6694
* Fri Oct 18 2019 ptesarik@suse.cz
- s390/zcrypt: add base code for cca crypto card info support
  (jsc#SLE-9582 jsc#IBM-505 LTC#181532).
- s390/zcrypt: move cca misc functions to new code file
  (jsc#SLE-9582 jsc#IBM-505 LTC#181532).
- commit ade3003
* Fri Oct 18 2019 ptesarik@suse.cz
- Update references in
  patches.suse/Revert-s390-dasd-Add-discard-support-for-ESE-volumes.patch
  (bnc#1151927 5.3.6 jsc#SLE-7885 jsc#IBM-463 LTC#178852).
- Update references in
  patches.suse/s390-dasd-Fix-error-handling-during-online-processin.patch
  (bnc#1151927 5.3.6 jsc#SLE-7885 jsc#IBM-463 LTC#178852).
- commit fae0452
* Fri Oct 18 2019 ptesarik@suse.cz
- s390/zcrypt: CEX7S exploitation support (jsc#SLE-7506
  jsc#IBM-458 LTC#178859).
- commit 99477f1
* Fri Oct 18 2019 tbogendoerfer@suse.de
- selftests/bpf: fix clearing buffered output between
  tests/subtests (bsc#1154353).
- commit 5178748
* Fri Oct 18 2019 tbogendoerfer@suse.de
- libbpf: convert libbpf code to use new btf helpers
  (bsc#1154353).
- Refresh
  patches.suse/libbpf-fix-false-uninitialized-variable-warning.patch.
- commit 234ecb1
* Fri Oct 18 2019 tbogendoerfer@suse.de
- Documentation: Clarify trap's description (bsc#1154353).
- libbpf: Teach btf_dumper to emit stand-alone anonymous enum
  definitions (bsc#1154353).
- libbpf: Remove getsockopt() check for XDP_OPTIONS (bsc#1154353).
- kcm: disable preemption in kcm_parse_func_strparser()
  (bsc#1154353).
- IB/mlx5: Use the original address for the page during free_pages
  (jsc#SLE-8446).
- RDMA/cma: Fix false error message (jsc#SLE-8449).
- kbuild: replace BASH-specific ${@:2} with shift and ${@}
  (bsc#1154353).
- libbpf: add flags to umem config (bsc#1154353).
- tools: bpftool: do not link twice against libbpf.a in Makefile
  (bsc#1154353).
- tools: bpf: account for generated feature/ and libbpf/
  directories (bsc#1154353).
- tools: bpftool: improve and check builds for different make
  invocations (bsc#1154353).
- tools: bpftool: ignore make built-in rules for getting kernel
  version (bsc#1154353).
- tools/bpf: sync bpf.h (bsc#1154353).
- btf: do not use CONFIG_OUTPUT_FORMAT (bsc#1154353).
- libbpf: use LFS (_FILE_OFFSET_BITS) instead of direct mmap2
  syscall (bsc#1154353).
- libbpf: add bpf_btf_get_next_id() to cycle through BTF objects
  (bsc#1154353).
- libbpf: refactor bpf_*_get_next_id() functions (bsc#1154353).
- tools: bpf: synchronise BPF UAPI header with tools
  (bsc#1154353).
- bpf: sync bpf.h to tools/ (bsc#1154353).
- libbpf: add support for need_wakeup flag in AF_XDP part
  (bsc#1154353).
- libbpf: make libbpf.map source of truth for libbpf version
  (bsc#1154353).
- tools: bpftool: compile with $(EXTRA_WARNINGS) (bsc#1154353).
- libbpf: attempt to load kernel BTF from sysfs first
  (bsc#1154353).
- tools: bpftool: add feature check for zlib (bsc#1154353).
- tools: bpftool: fix reading from /proc/config.gz (bsc#1154353).
- libbpf: implement BPF CO-RE offset relocation algorithm
  (bsc#1154353).
- libbpf: add .BTF.ext offset relocation section loading
  (bsc#1154353).
- libbpf: add helpers for working with BTF types (bsc#1154353).
- bpf: sync bpf.h to tools/ (bsc#1154353).
- tools: Add definitions for devmap_hash map type (bsc#1154353).
- tools/libbpf_probes: Add new devmap_hash type (bsc#1154353).
- tools/include/uapi: Add devmap_hash BPF map type (bsc#1154353).
- selftests/bpf: convert send_signal.c to use subtests
  (bsc#1154353).
- selftests/bpf: convert bpf_verif_scale.c to sub-tests API
  (bsc#1154353).
- selftests/bpf: add sub-tests support for test_progs
  (bsc#1154353).
- selftests/bpf: abstract away test log output (bsc#1154353).
- selftest/bpf: centralize libbpf logging management for
  test_progs (bsc#1154353).
- libbpf: return previous print callback from libbpf_set_print
  (bsc#1154353).
- selftests/bpf: add test selectors by number and name to
  test_progs (bsc#1154353).
- selftests/bpf: revamp test_progs to allow more control
  (bsc#1154353).
- selftests/bpf: prevent headers to be compiled as C code
  (bsc#1154353).
- selftests/bpf: support BPF_FLOW_DISSECTOR_F_STOP_AT_ENCAP
  (bsc#1154353).
- libbpf: provide more helpful message on uninitialized global
  var (bsc#1154353).
- tools headers: Grab copy of linux/const.h, needed by
  linux/bits.h (bsc#1154353).
- commit 0d4cc4a
* Fri Oct 18 2019 hare@suse.de
- scsi: lpfc: remove left-over BUILD_NVME defines (bsc#1154268).
- commit bde7b0f
* Fri Oct 18 2019 mkubecek@suse.cz
- rpm/config.sh: enable building DTBs (bsc#1153301)
- commit c58d61a
* Fri Oct 18 2019 mkubecek@suse.cz
- series.conf: move unsortable patch out of sorted section
  Move patches.suse/Btrfs-check-for-the-full-sync-flag-while-holding-the.patch
  out of sorted section; it does not have Git-commit tag (yet) so that it
  cannot be sorted without manual update anyway.
- commit dab15c2
* Fri Oct 18 2019 mkubecek@suse.cz
- series.conf: move queued patch into sorted section
  Update patches.suse/cfg80211-wext-avoid-copying-malformed-SSIDs.patch
  Git-repo tag and move it into sorted section.
- commit 9c78ce4
* Thu Oct 17 2019 tbogendoerfer@suse.de
- RDMA/mlx5: Add missing synchronize_srcu() for MW cases
  (jsc#SLE-8446).
- RDMA/mlx5: Put live in the correct place for ODP MRs
  (jsc#SLE-8446).
- RDMA/mlx5: Order num_pending_prefetch properly with
  synchronize_srcu (jsc#SLE-8446).
- RDMA/odp: Lift umem_mutex out of ib_umem_odp_unmap_dma_pages()
  (jsc#SLE-8449).
- RDMA/mlx5: Fix a race with mlx5_ib_update_xlt on an implicit MR
  (jsc#SLE-8446).
- RDMA/mlx5: Do not allow rereg of a ODP MR (jsc#SLE-8446).
- IB/core: Fix wrong iterating on ports (jsc#SLE-8449).
- RDMA/nldev: Reshuffle the code to avoid need to rebind QP in
  error path (jsc#SLE-8449).
- RDMA/cxgb4: Do not dma memory off of the stack (jsc#SLE-8392).
- RDMA/cm: Fix memory leak in cm_add/remove_one (jsc#SLE-8449).
- RDMA/core: Fix an error handling path in 'res_get_common_doit()'
  (jsc#SLE-8449).
- RDMA/i40iw: Associate ibdev to netdev before IB device
  registration (jsc#SLE-8449).
- RDMA/iwcm: Fix a lock inversion issue (jsc#SLE-8449).
- RDMA/iw_cxgb4: fix SRQ access from dump_qp() (jsc#SLE-8392).
- RDMA/hfi1: Prevent memory leak in sdma_init (jsc#SLE-8449).
- RDMA/core: Fix use after free and refcnt leak on ndev in_device
  in iwarp_query_port (jsc#SLE-8449).
- RDMA/siw: Fix serialization issue in write_space()
  (jsc#SLE-8381).
- RDMA/vmw_pvrdma: Free SRQ only once (jsc#SLE-8449).
- mlx5: avoid 64-bit division in dr_icm_pool_mr_create()
  (jsc#SLE-8464).
- devlink: Fix error handling in param and info_get dumpit cb
  (bsc#1154353).
- sk_buff: drop all skb extensions on free and skb scrubbing
  (bsc#1154353).
- bpf: Clean up indentation issue in BTF kflag processing
  (bsc#1154353).
- xsk: relax UMEM headroom alignment (bsc#1154353).
- bpf: fix BTF verification of enums (bsc#1154353).
- net: sched: sch_sfb: don't call qdisc_put() while holding tree
  lock (bsc#1154353).
- net: sched: multiq: don't call qdisc_put() while holding tree
  lock (bsc#1154353).
- net: sched: sch_htb: don't call qdisc_put() while holding tree
  lock (bsc#1154353).
- sch_netem: fix rcu splat in netem_enqueue() (bsc#1154353).
- cxgb4: Signedness bug in init_one() (jsc#SLE-8389).
- net/mlx5: DR, Allow matching on vport based on vhca_id
  (jsc#SLE-8464).
- net/mlx5: DR, Fix getting incorrect prev node in ste_free
  (jsc#SLE-8464).
- net/mlx5: DR, Remove redundant vport number from action
  (jsc#SLE-8464).
- net/mlx5: DR, Fix SW steering HW bits and definitions
  (jsc#SLE-8464).
- qede: qede_fp: simplify a bit 'qede_rx_build_skb()'
  (jsc#SLE-8401).
- IB/hfi1: remove unlikely() from IS_ERR*() condition
  (jsc#SLE-8449).
- mm/gup: add make_dirty arg to put_user_pages_dirty_lock()
  (jsc#SLE-8449).
- PCI/P2PDMA: Update pci_p2pdma_distance_many() documentation
  (jsc#SLE-8449).
- PCI/P2PDMA: Allow IOMMU for host bridge whitelist
  (jsc#SLE-8449).
- PCI/P2PDMA: dma_map() requests that traverse the host bridge
  (jsc#SLE-8449).
- PCI/P2PDMA: Store mapping method in an xarray (jsc#SLE-8449).
- PCI/P2PDMA: Factor out __pci_p2pdma_map_sg() (jsc#SLE-8449).
- PCI/P2PDMA: Introduce pci_p2pdma_unmap_sg() (jsc#SLE-8449).
- PCI/P2PDMA: Add attrs argument to pci_p2pdma_map_sg()
  (jsc#SLE-8449).
- PCI/P2PDMA: Whitelist some Intel host bridges (jsc#SLE-8449).
- PCI/P2PDMA: Factor out host_bridge_whitelist() (jsc#SLE-8449).
- PCI/P2PDMA: Apply host bridge whitelist for ACS (jsc#SLE-8449).
- PCI/P2PDMA: Factor out __upstream_bridge_distance()
  (jsc#SLE-8449).
- PCI/P2PDMA: Add constants for map type results to
  upstream_bridge_distance() (jsc#SLE-8449).
- PCI/P2PDMA: Add provider's pci_dev to pci_p2pdma_pagemap struct
  (jsc#SLE-8449).
- PCI/P2PDMA: Introduce private pagemap structure (jsc#SLE-8449).
- RDMA/efa: Fix incorrect error print (jsc#SLE-5640).
- RDMA/bnxt_re: Fix spelling mistake "missin_resp" ->
  "missing_resp" (jsc#SLE-8372 bsc#1153275).
- IB/{rdmavt, hfi1, qib}: Add a counter for credit waits
  (jsc#SLE-8449).
- IB/hfi1: Add traces for TID RDMA READ (jsc#SLE-8449).
- RDMA/siw: Relax from kmap_atomic() use in TX path
  (jsc#SLE-8381).
- IB/iser: Support up to 16MB data transfer in a single command
  (jsc#SLE-8449).
- RDMA/siw: Fix page address mapping in TX path (jsc#SLE-8381).
- RDMA: Fix goto target to release the allocated memory
  (jsc#SLE-8449).
- RDMA/usnic: Avoid overly large buffers on stack (jsc#SLE-8449).
- RDMA/odp: Add missing cast for 32 bit (jsc#SLE-8449).
- IB/mlx5: Add page fault handler for DC initiator WQE
  (jsc#SLE-8446).
- IB/mlx5: Remove check of FW capabilities in ODP page fault
  handling (jsc#SLE-8446).
- RDMA/iwpm: Delete unnecessary checks before the macro call
  "dev_kfree_skb" (jsc#SLE-8449).
- RDMA/efa: Use existing FIELD_SIZEOF macro (jsc#SLE-5640).
- RDMA/efa: Remove umem check on dereg MR flow (jsc#SLE-5640).
- RDMA/mlx5: RDMA_RX flow type support for user applications
  (jsc#SLE-8446).
- RDMA: Delete DEBUG code (jsc#SLE-8449).
- RDMA/mlx5: Annotate lock dependency in bind/unbind slave port
  (jsc#SLE-8446).
- IB/mlx5: Expose XRQ legacy commands over the DEVX interface
  (jsc#SLE-8446).
- IB/mlx5: Add legacy events to DEVX list (jsc#SLE-8446).
- RDMA/{cxgb3, cxgb4, i40iw}: Remove common code (jsc#SLE-8449).
- RDMA/core: Add common iWARP query port (jsc#SLE-8449).
- RDMA/cxgb3: Use ib_device_set_netdev() (jsc#SLE-8449).
- RDMA: Introduce ib_port_phys_state enum (jsc#SLE-8449).
- RDMA/efa: Rate limit admin queue error prints (jsc#SLE-5640).
- RDMA/core: Introduce ratelimited ibdev printk functions
  (jsc#SLE-8449).
- rdma: Enable ib_alloc_cq to spread work over a device's
  comp_vectors (jsc#SLE-8449).
- mlx5: Fix formats with line continuation whitespace
  (jsc#SLE-8464).
- RDMA/mlx5: Remove DEBUG ODP code (jsc#SLE-8446).
- RDMA/core: fix spelling mistake "Nelink" -> "Netlink"
  (jsc#SLE-8449).
- infiniband: Remove dev_err() usage after platform_get_irq()
  (jsc#SLE-8449).
- RDMA/efa: Expose device statistics (jsc#SLE-5640).
- IB/bnxt_re: Do not notifify GID change event (jsc#SLE-8372
  bsc#1153275).
- IB/mlx5: Support per device q counters in switchdev mode
  (jsc#SLE-8446).
- IB/mlx5: Refactor code for counters allocation (jsc#SLE-8446).
- qed*: Change dpi_addr to be denoted with __iomem (jsc#SLE-8401).
- IB/mlx5: Add CREATE_PSV/DESTROY_PSV for devx interface
  (jsc#SLE-8446).
- RDMA/core: Support netlink commands in non init_net net
  namespaces (jsc#SLE-8449).
- RDMA/mlx4: Annotate boolean arguments as bool and not int
  (jsc#SLE-8461).
- RDMA/mlx4: Separate creation of RWQ and QP (jsc#SLE-8461).
- IB/usnic: Use dev_get_drvdata (jsc#SLE-8449).
- RDMA/qedr: Remove Unneeded variable rc (jsc#SLE-8215).
- RDMA/qib: Unneeded variable ret (jsc#SLE-8449).
- IB/mlx5: Avoid unnecessary typecast (jsc#SLE-8446).
- RDMA/core: Annotate destroy of mutex to ensure that it is
  released as unlocked (jsc#SLE-8449).
- RDMA/hns: Fix comparison of unsigned long variable 'end'
  with less than zero (jsc#SLE-8449).
- RDMA/mlx4: Untag user pointers in mlx4_get_umem_mr
  (jsc#SLE-8461).
- IB/hfi1: Remove unused define (jsc#SLE-8449).
- RDMA/odp: remove ib_ucontext from ib_umem (jsc#SLE-8449).
- RDMA/odp: use mmu_notifier_get/put for 'struct
  ib_ucontext_per_mm' (jsc#SLE-8449).
- RDMA/mlx5: Use odp instead of mr->umem in pagefault_mr
  (jsc#SLE-8446).
- RDMA/mlx5: Use ib_umem_start instead of umem.address
  (jsc#SLE-8446).
- RDMA/core: Make invalidate_range a device operation
  (jsc#SLE-8449).
- RDMA/odp: Use kvcalloc for the dma_list and page_list
  (jsc#SLE-8449).
- RDMA/odp: Check for overflow when computing the umem_odp end
  (jsc#SLE-8449).
- RDMA/odp: Provide ib_umem_odp_release() to undo the allocs
  (jsc#SLE-8449).
- RDMA/odp: Split creating a umem_odp from ib_umem_get
  (jsc#SLE-8449).
- RDMA/odp: Make the three ways to create a umem_odp clear
  (jsc#SLE-8449).
- RMDA/odp: Consolidate umem_odp initialization (jsc#SLE-8449).
- RDMA/odp: Make it clearer when a umem is an implicit ODP umem
  (jsc#SLE-8449).
- RDMA/odp: Iterate over the whole rbtree directly (jsc#SLE-8449).
- RDMA/odp: Use the common interval tree library instead of
  generic (jsc#SLE-8449).
- refresh configs (INTERVAL_TREE=y on s390x)
- mm/mmu_notifiers: add a get/put scheme for the registration
  (jsc#SLE-8449).
- mm/mmu_notifiers: do not speculatively allocate a
  mmu_notifier_mm (jsc#SLE-8449).
- mm/mmu_notifiers: hoist do_mmu_notifier_register down_write
  to the caller (jsc#SLE-8449).
- infiniband: don't bother with d_delete() (jsc#SLE-8449).
- ethtool: implement Energy Detect Powerdown support via
  phy-tunable (bsc#1154353).
- drop_monitor: Better sanitize notified packets (bsc#1154353).
- tcp: Add snd_wnd to TCP_INFO (bsc#1154353).
- tcp: Add TCP_INFO counter for packets received out-of-order
  (bsc#1154353).
- bpf: fix accessing bpf_sysctl.file_pos on s390 (bsc#1154353).
- xdp: Fix race in dev_map_hash_update_elem() when replacing
  element (bsc#1154353).
- kcm: use BPF_PROG_RUN (bsc#1154353).
- net: sched: use get_dev() action API in flow_action infra
  (bsc#1154353).
- net: sched: take reference to psample group in flow_action infra
  (bsc#1154353).
- net: sched: extend flow_action_entry with destructor
  (bsc#1154353).
- qed: fix spelling mistake "fullill" -> "fulfill" (jsc#SLE-8401).
- net: devlink: move reload fail indication to devlink core and
  expose to user (bsc#1154353).
- net: devlink: split reload op into two (bsc#1154353).
- mlx4: Split restart_one into two functions (jsc#SLE-8460).
- cxgb4: Fix spelling typos (jsc#SLE-8389).
- nfp: read chip model from the PluDevice register (bsc#1154353).
- qed: Fix Config attribute frame format (jsc#SLE-8401).
- qed*: Fix size of config attribute dump (jsc#SLE-8401).
- nfp: devlink: set unknown fw_load_policy (bsc#1154353).
- devlink: add unknown 'fw_load_policy' value (bsc#1154353).
- net/mlx5: FWTrace, Reduce stack usage (jsc#SLE-8464).
- net/mlx5: Fix addr's type in mlx5dr_icm_dm (jsc#SLE-8464).
- net/mlx5: Fix rt's type in dr_action_create_reformat_action
  (jsc#SLE-8464).
- kdoc: fix nfp_fw_load documentation (bsc#1154353).
- nfp: devlink: add 'reset_dev_on_drv_probe' support
  (bsc#1154353).
- nfp: devlink: add 'fw_load_policy' support (bsc#1154353).
- nfp: add devlink param infrastructure (bsc#1154353).
- nfp: honor FW reset and loading policies (bsc#1154353).
- nfp: nsp: add support for hwinfo set operation (bsc#1154353).
- nfp: nsp: add support for optional hwinfo lookup (bsc#1154353).
- nfp: nsp: add support for fw_loaded command (bsc#1154353).
- devlink: add 'reset_dev_on_drv_probe' param (bsc#1154353).
- devlink: extend 'fw_load_policy' values (bsc#1154353).
- net/mlx4_en: ethtool: make array modes static const, makes
  object smaller (jsc#SLE-8460).
- net/tls: align non temporal copy to cache lines (bsc#1154353).
- net/tls: remove the record tail optimization (bsc#1154353).
- net/tls: use RCU for the adder to the offload record list
  (bsc#1154353).
- net/tls: unref frags in order (bsc#1154353).
- be2net: make two arrays static const, makes object smaller
  (jsc#SLE-8375).
- net/mlx5e: Add port buffer's congestion counters (jsc#SLE-8464).
- net/mlx5: Expose HW capability bits for port buffer per priority
  congestion counters (jsc#SLE-8464).
- net/mlx5: DR, Remove redundant dev_name print from err log
  (jsc#SLE-8464).
- net/mlx5: DR, Fix error return code in
  dr_domain_init_resources() (jsc#SLE-8464).
- net/mlx5: DR, Remove useless set memory to zero use memset()
  (jsc#SLE-8464).
- net/mlx5e: Remove unnecessary clear_bit()s (jsc#SLE-8464).
- net/mlx5e: kTLS, Remove unused function parameter
  (jsc#SLE-8464).
- net/mlx5: Use PTR_ERR_OR_ZERO rather than its implementation
  (jsc#SLE-8464).
- net/mlx5: fix missing assignment of variable err (jsc#SLE-8464).
- net/mlx5: fix spelling mistake "offlaods" -> "offloads"
  (jsc#SLE-8464).
- net/mlx5e: Remove leftover declaration (jsc#SLE-8464).
- net/mlx5e: Use ipv6_stub to avoid dependency with ipv6 being
  a module (jsc#SLE-8464).
- net/mlx5: Kconfig: Fix MLX5_CORE dependency with
  PCI_HYPERV_INTERFACE (jsc#SLE-8464).
- net/mlx5e: Fix static checker warning of potential pointer
  math issue (jsc#SLE-8464).
- tcp: ulp: fix possible crash in tcp_diag_get_aux_size()
  (bsc#1154353).
- net: fib_notifier: move fib_notifier_ops from struct net into
  per-net struct (bsc#1154353).
- xsk: lock the control mutex in sock_diag interface
  (bsc#1154353).
- xsk: avoid store-tearing when assigning umem (bsc#1154353).
- xsk: avoid store-tearing when assigning queues (bsc#1154353).
- net/mlx5e: Allow XSK frames smaller than a page (jsc#SLE-8464).
- mlx5e: modify driver for handling offsets (jsc#SLE-8464).
- bpf: fix error check in bpf_tcp_gen_syncookie (bsc#1154353).
- nfp: bpf: add simple map op cache (bsc#1154353).
- nfp: bpf: rework MTU checking (bsc#1154353).
- bpf: introduce verifier internal test flag (bsc#1154353).
- xdp: xdp_umem: replace kmap on vmap for umem map (bsc#1154353).
- bpf: add new BPF_BTF_GET_NEXT_ID syscall command (bsc#1154353).
- bpf: add BTF ids in procfs for file descriptors to BTF objects
  (bsc#1154353).
- bpf: Use PTR_ERR_OR_ZERO in xsk_map_inc() (bsc#1154353).
- xsk: support BPF_EXIST and BPF_NOEXIST flags in XSKMAP
  (bsc#1154353).
- bpf: support cloning sk storage on accept() (bsc#1154353).
- bpf: export bpf_map_inc_not_zero (bsc#1154353).
- net: Don't call XDP_SETUP_PROG when nothing is changed
  (bsc#1154353).
- net/mlx5e: Add AF_XDP need_wakeup support (jsc#SLE-8464).
- net/mlx5e: Move the SW XSK code from NAPI poll to a separate
  function (jsc#SLE-8464).
- btf: fix return value check in btf_vmlinux_init() (bsc#1154353).
- net_sched: act_police: add 2 new attributes to support police
  64bit rate and peakrate (bsc#1154353).
- nfp: Drop unnecessary continue in nfp_net_pf_alloc_vnics
  (bsc#1154353).
- net: qed: Move static keyword to the front of declaration
  (jsc#SLE-8401).
- net/tls: dedup the record cleanup (bsc#1154353).
- net/tls: clean up the number of #ifdefs for CONFIG_TLS_DEVICE
  (bsc#1154353).
- net/tls: narrow down the critical area of device_offload_lock
  (bsc#1154353).
- net/tls: don't jump to return (bsc#1154353).
- net/tls: use the full sk_proto pointer (bsc#1154353).
- net/sched: cbs: remove redundant assignment to variable
  port_rate (bsc#1154353).
- devlink: Add new info version tags for ASIC and FW
  (bsc#1154353).
- net/mlx5: Add devlink flow_steering_mode parameter
  (jsc#SLE-8464).
- net/mlx5: Add support to use SMFS in switchdev mode
  (jsc#SLE-8464).
- net/mlx5: Add API to set the namespace steering mode
  (jsc#SLE-8464).
- net/mlx5: Add direct rule fs_cmd implementation (jsc#SLE-8464).
- net/mlx5: DR, Add CONFIG_MLX5_SW_STEERING for software steering
  support (jsc#SLE-8464).
- update configs (MLX5_SW_STEERING=y)
- net/mlx5: DR, Expose APIs for direct rule managing
  (jsc#SLE-8464).
- net/mlx5: DR, Add required FW steering functionality
  (jsc#SLE-8464).
- net/mlx5: DR, Expose steering rule functionality (jsc#SLE-8464).
- net/mlx5: DR, Expose steering action functionality
  (jsc#SLE-8464).
- net/mlx5: DR, Expose steering matcher functionality
  (jsc#SLE-8464).
- net/mlx5: DR, Expose steering table functionality
  (jsc#SLE-8464).
- net/mlx5: DR, Expose steering domain functionality
  (jsc#SLE-8464).
- net/mlx5: DR, Add Steering entry (STE) utilities (jsc#SLE-8464).
- net/mlx5: DR, Expose an internal API to issue RDMA operations
  (jsc#SLE-8464).
- net/mlx5: DR, ICM pool memory allocator (jsc#SLE-8464).
- net/mlx5: DR, Add direct rule command utilities (jsc#SLE-8464).
- net/mlx5: DR, Add the internal direct rule types definitions
  (jsc#SLE-8464).
- net/mlx5: Add flow steering actions to fs_cmd shim layer
  (jsc#SLE-8464).
- net/mlx5: Set only stag for match untagged packets
  (jsc#SLE-8464).
- net/mlx5: Avoid disabling RoCE when uninitialized
  (jsc#SLE-8464).
- net/mlx5: Add HW bits and definitions required for SW steering
  (jsc#SLE-8464).
- net/mlx5: Move device memory management to mlx5_core
  (jsc#SLE-8464).
- mlx5: Add missing init_net check in FIB notifier (jsc#SLE-8464).
- devlink: Use switch-case instead of if-else (bsc#1154353).
- devlink: Make port index data type as unsigned int
  (bsc#1154353).
- net: tls: export protocol version, cipher, tx_conf/rx_conf to
  socket diag (bsc#1154353).
- tcp: ulp: add functions to dump ulp-specific information
  (bsc#1154353).
- net/tls: use RCU protection on icsk->icsk_ulp_data
  (bsc#1154353).
- qede: Add support for dumping the grc data (jsc#SLE-8401).
- qed: Add APIs for configuring grc dump config flags
  (jsc#SLE-8401).
- qede: Add support for reading the config id attributes
  (jsc#SLE-8401).
- qed: Add APIs for reading config id attributes (jsc#SLE-8401).
- udp: Remove unlikely() from IS_ERR*() condition (bsc#1154353).
- net/mlx5e: Remove unlikely() from WARN*() condition
  (jsc#SLE-8464).
- net/mlx5e: Move local var definition into ifdef block
  (jsc#SLE-8464).
- net: sched: cls_matchall: cleanup flow_action before
  deallocating (bsc#1154353).
- sched: act_vlan: implement stats_update callback (bsc#1154353).
- net/mlx5e: Support TSO and TX checksum offloads for IP-in-IP
  tunnels (jsc#SLE-8464).
- net/mlx5e: Improve stateless offload capability check
  (jsc#SLE-8464).
- net/mlx5e: Support RSS for IP-in-IP and IPv6 tunneled packets
  (jsc#SLE-8464).
- net/mlx5e: Change function's position to a more fitting file
  (jsc#SLE-8464).
- net/mlx5e: Add device out of buffer counter (jsc#SLE-8464).
- net/mlx5e: Support LAG TX port affinity distribution
  (jsc#SLE-8464).
- net/mlx5e: Expose new function for TIS destroy loop
  (jsc#SLE-8464).
- net/mlx5e: ethtool, Fix a typo in WOL function names
  (jsc#SLE-8464).
- net/mlx5: Set ODP capabilities for DC transport to max
  (jsc#SLE-8464).
- net/mlx5: fix a -Wstringop-truncation warning (jsc#SLE-8464).
- net/mlx5: Create bypass and loopback flow steering namespaces
  for RDMA RX (jsc#SLE-8464).
- net/mlx5: Add per-namespace flow table default miss action
  support (jsc#SLE-8464).
- net/mlx5: Add lag_tx_port_affinity capability bit
  (jsc#SLE-8464).
- net/mlx5: Expose IP-in-IP capability bit (jsc#SLE-8464).
- net/mlx5: Add support for VNIC_ENV internal rq counter
  (jsc#SLE-8464).
- net/mlx5: Improve functions documentation (jsc#SLE-8464).
- net/mlx5: Add missing include file to lib/crypto.c
  (jsc#SLE-8464).
- net/mlx5: Add XRQ legacy commands opcodes (jsc#SLE-8464).
- net/mlx5: Use debug message instead of warn (jsc#SLE-8464).
- mlx5: Use refcount_t for refcount (jsc#SLE-8464).
- net/mlx5: remove self-assignment on esw->dev (jsc#SLE-8464).
- IB/mlx5: Support MLX5_CMD_OP_QUERY_LAG as a DEVX general command
  (jsc#SLE-8446).
- net/mlx5: Fix mlx5_ifc_query_lag_out_bits (jsc#SLE-8464).
- nfp: add AMDA0058 boards to firmware list (bsc#1154353).
- net: sched: flower: don't take rtnl lock for cls hw offloads
  API (bsc#1154353).
- net: sched: copy tunnel info when setting flow_action
  entry->tunnel (bsc#1154353).
- net: sched: take reference to action dev before calling offloads
  (bsc#1154353).
- net: sched: take rtnl lock in tc_setup_flow_action()
  (bsc#1154353).
- net: sched: conditionally obtain rtnl lock in cls hw offloads
  API (bsc#1154353).
- net: sched: add API for registering unlocked offload block
  callbacks (bsc#1154353).
- net: sched: notify classifier on successful offload add/delete
  (bsc#1154353).
- net: sched: refactor block offloads counter usage (bsc#1154353).
- net: sched: change tcf block offload counter type to atomic_t
  (bsc#1154353).
- net: sched: protect block offload-related fields with
  rw_semaphore (bsc#1154353).
- =?UTF-8?q?net/core/skmsg:=20Delete=20an=20unnecessary=20c?=
  =?UTF-8?q?heck=20before=20the=20function=20call=20=E2=80=9Cconsume=5Fskb?=
  =?UTF-8?q?=E2=80=9D?= (bsc#1154353).
- net: use unlikely for dql_avail case (bsc#1154353).
- drop_monitor: Make timestamps y2038 safe (bsc#1154353).
- net/mlx5: Fix return code in case of hyperv wrong size read
  (jsc#SLE-8464).
- net: ipv6: fix listify ip6_rcv_finish in case of forwarding
  (bsc#1154353).
- net/mlx5e: Add mlx5e HV VHCA stats agent (jsc#SLE-8464).
- net/mlx5: Add HV VHCA control agent (jsc#SLE-8464).
- net/mlx5: Add HV VHCA infrastructure (jsc#SLE-8464).
- net/mlx5: Add wrappers for HyperV PCIe operations
  (jsc#SLE-8464).
- net/mlx5e: Add trace point for neigh update (jsc#SLE-8464).
- net/mlx5e: Add trace point for neigh used value update
  (jsc#SLE-8464).
- net/mlx5e: Add tc flower tracepoints (jsc#SLE-8464).
- net/mlx5e: Only access fully initialized flows in neigh update
  (jsc#SLE-8464).
- net/mlx5e: Refactor neigh update for concurrent execution
  (jsc#SLE-8464).
- net/mlx5e: Refactor neigh used value update for concurrent
  execution (jsc#SLE-8464).
- net/mlx5e: Protect neigh hash encap list with spinlock and rcu
  (jsc#SLE-8464).
- net/mlx5e: Refactor mlx5e_neigh_update_table->encap_lock
  (jsc#SLE-8464).
- net/mlx5e: Extend neigh hash entry with rcu (jsc#SLE-8464).
- net/mlx5e: Always take reference to neigh entry (jsc#SLE-8464).
- net/mlx5e: Extract code that queues neigh update work into
  function (jsc#SLE-8464).
- net/mlx5: Fix the order of fc_stats cleanup (jsc#SLE-8464).
- net/mlx5e: Fix deallocation of non-fully init encap entries
  (jsc#SLE-8464).
- net/mlx5e: Report and recover from CQE with error on RQ
  (jsc#SLE-8464).
- net/mlx5e: RX, Handle CQE with error at the earliest stage
  (jsc#SLE-8464).
- net/mlx5e: Report and recover from rx timeout (jsc#SLE-8464).
- net/mlx5e: Report and recover from CQE error on ICOSQ
  (jsc#SLE-8464).
- net/mlx5e: Split open/close ICOSQ into stages (jsc#SLE-8464).
- net/mlx5e: Add support to rx reporter diagnose (jsc#SLE-8464).
- net/mlx5e: Add helper functions for reporter's basics
  (jsc#SLE-8464).
- net/mlx5e: Add cq info to tx reporter diagnose (jsc#SLE-8464).
- net/mlx5e: Extend tx reporter diagnostics output (jsc#SLE-8464).
- net/mlx5e: Extend tx diagnose function (jsc#SLE-8464).
- net/mlx5e: Generalize tx reporter's functionality
  (jsc#SLE-8464).
- net/mlx5e: Change naming convention for reporter's functions
  (jsc#SLE-8464).
- net/mlx5e: Rename reporter header file (jsc#SLE-8464).
- net: flow_offload: convert block_ing_cb_list to regular list
  type (bsc#1154353).
- be2net: eliminate enable field from be_aic_obj (jsc#SLE-8375).
- Documentation: Add devlink-trap documentation (bsc#1154353).
- devlink: Add generic packet traps and groups (bsc#1154353).
- devlink: Add packet trap infrastructure (bsc#1154353).
- refresh configs
- drop_monitor: Allow user to start monitoring hardware drops
  (bsc#1154353).
- drop_monitor: Add support for summary alert mode for hardware
  drops (bsc#1154353).
- drop_monitor: Add support for packet alert mode for hardware
  drops (bsc#1154353).
- drop_monitor: Consider all monitoring states before performing
  configuration (bsc#1154353).
- drop_monitor: Add basic infrastructure for hardware drops
  (bsc#1154353).
- drop_monitor: Initialize hardware per-CPU data (bsc#1154353).
- drop_monitor: Move per-CPU data init/fini to separate functions
  (bsc#1154353).
- qed: Add driver API for flashing the config attributes
  (jsc#SLE-8401).
- qed: Add API for configuring NVM attributes (jsc#SLE-8401).
- page_pool: fix logic in __page_pool_get_cached (bsc#1154353).
- page_pool: remove unnecessary variable init (bsc#1154353).
- net: devlink: remove redundant rtnl lock assert (bsc#1154353).
- btf: rename /sys/kernel/btf/kernel into /sys/kernel/btf/vmlinux
  (bsc#1154353).
- btf: expose BTF info through sysfs (bsc#1154353).
- xdp: xdp_umem: fix umem pages mapping for 32bits systems
  (bsc#1154353).
- bpf: always allocate at least 16 bytes for setsockopt hook
  (bsc#1154353).
- bpf: add bpf_tcp_gen_syncookie helper (bsc#1154353).
- tcp: add skb-less helpers to retrieve SYN cookie (bsc#1154353).
- tcp: tcp_syn_flood_action read port from socket (bsc#1154353).
- xdp: Add devmap_hash map type for looking up devices by hashed
  index (bsc#1154353).
- xdp: Refactor devmap allocation code for reuse (bsc#1154353).
- include/bpf.h: Remove map_insert_ctx() stubs (bsc#1154353).
- bpf/flow_dissector: support ipv6 flow_label and
  BPF_FLOW_DISSECTOR_F_STOP_AT_FLOW_LABEL (bsc#1154353).
- selftests/bpf: support BPF_FLOW_DISSECTOR_F_PARSE_1ST_FRAG
  (bsc#1154353).
- tools/bpf: sync bpf_flow_keys flags (bsc#1154353).
- bpf/flow_dissector: support flags in BPF_PROG_TEST_RUN
  (bsc#1154353).
- bpf/flow_dissector: pass input flags to BPF flow dissector
  program (bsc#1154353).
- selftests/bpf: Add selftests for bpf_perf_event_output
  (bsc#1154353).
- bpf: Allow bpf_skb_event_output for a few prog types
  (bsc#1154353).
- selftests/bpf: remove perf buffer helpers (bsc#1154353).
- selftests/bpf: switch test_tcpnotify to perf_buffer API
  (bsc#1154353).
- selftests/bpf: convert test_get_stack_raw_tp to perf_buffer API
  (bsc#1154353).
- devlink: send notifications for deleted snapshots on region
  destroy (bsc#1154353).
- drop_monitor: Expose tail drop counter (bsc#1154353).
- drop_monitor: Make drop queue length configurable (bsc#1154353).
- drop_monitor: Add a command to query current configuration
  (bsc#1154353).
- drop_monitor: Allow truncation of dropped packets (bsc#1154353).
- drop_monitor: Add packet alert mode (bsc#1154353).
- drop_monitor: Add alert mode operations (bsc#1154353).
- drop_monitor: Require CAP_NET_ADMIN for drop monitor
  configuration (bsc#1154353).
- drop_monitor: Reset per-CPU data before starting to trace
  (bsc#1154353).
- drop_monitor: Initialize timer and work item upon tracing enable
  (bsc#1154353).
- drop_monitor: Split tracing enable / disable to different
  functions (bsc#1154353).
- nfp: no need to check return value of debugfs_create functions
  (bsc#1154353).
- cxgb4: no need to check return value of debugfs_create functions
  (jsc#SLE-8389).
- mlx5: no need to check return value of debugfs_create functions
  (jsc#SLE-8464).
- net/mlx5e: Use refcount_t for refcount (jsc#SLE-8464).
- net/mlx5e: Use vhca_id in generating representor port_index
  (jsc#SLE-8464).
- net/mlx5e: Simplify querying port representor parent id
  (jsc#SLE-8464).
- net/mlx5: E-switch, Removed unused hwid (jsc#SLE-8464).
- net/mlx5e: Allow concurrent creation of encap entries
  (jsc#SLE-8464).
- net/mlx5e: Protect encap hash table with mutex (jsc#SLE-8464).
- net/mlx5e: Extend encap entry with reference counter
  (jsc#SLE-8464).
- net/mlx5e: Allow concurrent creation of mod_hdr entries
  (jsc#SLE-8464).
- net/mlx5e: Protect mod_hdr hash table with mutex (jsc#SLE-8464).
- net/mlx5e: Protect mod header entry flows list with spinlock
  (jsc#SLE-8464).
- net/mlx5e: Extend mod header entry with reference counter
  (jsc#SLE-8464).
- net/mlx5e: Allow concurrent creation of hairpin entries
  (jsc#SLE-8464).
- net/mlx5e: Protect hairpin hash table with mutex (jsc#SLE-8464).
- net/mlx5e: Protect hairpin entry flows list with spinlock
  (jsc#SLE-8464).
- net/mlx5e: Extend hairpin entry with reference counter
  (jsc#SLE-8464).
- devlink: remove pointless data_len arg from region snapshot
  create (jsc#SLE-8460).
- fq_codel: remove set but not used variables 'prev_ecn_mark'
  and 'prev_drop_count' (bsc#1154353).
- flow_offload: support get multi-subsystem block (bsc#1154353).
- flow_offload: move tc indirect block to flow offload
  (bsc#1154353).
- cls_api: add flow_indr_block_call function (bsc#1154353).
- cls_api: remove the tcf_block cache (bsc#1154353).
- cls_api: modify the tc_indr_block_ing_cmd parameters
  (bsc#1154353).
- net: use listified RX for handling GRO_NORMAL skbs
  (bsc#1154353).
- sfc: falcon: don't score irq moderation points for GRO
  (jsc#SLE-8314).
- sfc: don't score irq moderation points for GRO (jsc#SLE-8314).
- qed: Add new ethtool supported port types based on media
  (jsc#SLE-8401).
- cxgb4: smt: Use normal int for refcount (jsc#SLE-8389).
- cxgb4: smt: Add lock for atomic_dec_and_test (jsc#SLE-8389).
- nfp: flower: encode mac indexes with pre-tunnel rule check
  (bsc#1154353).
- nfp: flower: remove offloaded MACs when reprs are applied to
  OvS bridges (bsc#1154353).
- nfp: flower: offload pre-tunnel rules (bsc#1154353).
- nfp: flower: verify pre-tunnel rules (bsc#1154353).
- nfp: flower: detect potential pre-tunnel rules (bsc#1154353).
- nfp: flower: push vlan after tunnel in merge (bsc#1154353).
- net: sched: add ingress mirred action to hardware IR
  (bsc#1154353).
- net: tc_act: add helpers to detect ingress mirred actions
  (bsc#1154353).
- net: sched: add skbedit of ptype action to hardware IR
  (bsc#1154353).
- net: tc_act: add skbedit_ptype helper functions (bsc#1154353).
- fq_codel: Kill useless per-flow dropped statistic (bsc#1154353).
- Increase fq_codel count in the bulk dropper (bsc#1154353).
- drop_monitor: Use pre_doit / post_doit hooks (bsc#1154353).
- drop_monitor: Add extack support (bsc#1154353).
- drop_monitor: Avoid multiple blank lines (bsc#1154353).
- drop_monitor: Document scope of spinlock (bsc#1154353).
- drop_monitor: Rename and document scope of mutex (bsc#1154353).
- drop_monitor: Use correct error code (bsc#1154353).
- net/mlx5e: Allow dropping specific tunnel packets
  (jsc#SLE-8464).
- net/mlx5e: TX reporter cleanup (jsc#SLE-8464).
- net/mlx5e: Set tx reporter only on successful creation
  (jsc#SLE-8464).
- net/mlx5e: Fix mlx5e_tx_reporter_create return value
  (jsc#SLE-8464).
- net/mlx5e: Rx, checksum handling refactoring (jsc#SLE-8464).
- net/mlx5e: Tx, Soften inline mode VLAN dependencies
  (jsc#SLE-8464).
- net/mlx5e: XDP, Slight enhancement for WQE fetch function
  (jsc#SLE-8464).
- net/mlx5e: XDP, Close TX MPWQE session when no room for inline
  packet left (jsc#SLE-8464).
- net/mlx5e: Tx, Strict the room needed for SQ edge NOPs
  (jsc#SLE-8464).
- net/mlx5: Add flow counter pool (jsc#SLE-8464).
- net/mlx5: Add flow counter bulk infrastructure (jsc#SLE-8464).
- net/mlx5: E-Switch, add ingress rate support (jsc#SLE-8464).
- net/mlx5: E-switch, Tide up eswitch config sequence
  (jsc#SLE-8464).
- net/mlx5: E-Switch, Remove redundant mc_promisc NULL check
  (jsc#SLE-8464).
- net/mlx5: E-Switch, remove redundant error handling
  (jsc#SLE-8464).
- net/mlx5: E-switch, Introduce helper function to enable/disable
  vports (jsc#SLE-8464).
- net/mlx5: E-switch, Initialize TSAR Qos hardware block before
  its user vports (jsc#SLE-8464).
- net/mlx5: E-switch, Combine metadata enable/disable
  functionality (jsc#SLE-8464).
- net/mlx5: E-Switch, Verify support QoS element type
  (jsc#SLE-8464).
- net/mlx5: Make load_one() and unload_one() symmetric
  (jsc#SLE-8464).
- net/mlx5: Fix offset of tisc bits reserved field (jsc#SLE-8464).
- net/mlx5: Add flow counter bulk allocation hardware bits and
  command (jsc#SLE-8464).
- net/mlx5: Refactor and optimize flow counter bulk query
  (jsc#SLE-8464).
- net/mlx5: fix -Wtype-limits compilation warnings (jsc#SLE-8464).
- net/mlx5e: Protect tc flow table with mutex (jsc#SLE-8464).
- net/mlx5e: Rely on rcu instead of rtnl lock when getting upper
  dev (jsc#SLE-8464).
- net/mlx5e: Eswitch, use state_lock to synchronize vlan change
  (jsc#SLE-8464).
- net/mlx5e: Eswitch, change offloads num_flows type to atomic64
  (jsc#SLE-8464).
- net/mlx5e: Protect unready flows with dedicated lock
  (jsc#SLE-8464).
- net/mlx5e: Protect tc flows hashtable with rcu (jsc#SLE-8464).
- net/mlx5e: Change flow flags type to unsigned long
  (jsc#SLE-8464).
- net/mlx5e: Extend tc flow struct with reference counter
  (jsc#SLE-8464).
- net/mlx5e: Simplify get_route_and_out_devs helper function
  (jsc#SLE-8464).
- net/mlx5e: Fix unnecessary flow_block_cb_is_busy call
  (jsc#SLE-8464).
- net/mlx5e: Improve ethtool rxnfc callback structure
  (jsc#SLE-8464).
- net/mlx5e: Avoid warning print when not required (jsc#SLE-8464).
- net/mlx5e: Print a warning when LRO feature is dropped or not
  allowed (jsc#SLE-8464).
- linux: Remove bvec page_offset, use bv_offset (bsc#1154353).
- mlx4/en_netdev: allow offloading VXLAN over VLAN (jsc#SLE-8460).
- net: neigh: remove redundant assignment to variable bucket
  (bsc#1154353).
- net: sfc: falcon: convert to i2c_new_dummy_device
  (jsc#SLE-8314).
- mlx4: avoid large stack usage in mlx4_init_hca() (jsc#SLE-8460).
- qed: reduce maximum stack frame size (jsc#SLE-8401).
- sfc-falcon: Use dev_get_drvdata where possible (jsc#SLE-8314).
- sfc: Use dev_get_drvdata where possible (jsc#SLE-8314).
- nfp: flower: offload MPLS set action (bsc#1154353).
- nfp: flower: offload MPLS pop action (bsc#1154353).
- nfp: flower: offload MPLS push action (bsc#1154353).
- net: sched: include mpls actions in hardware intermediate
  representation (bsc#1154353).
- net/mlx5e: xsk: dynamically allocate mlx5e_channel_param
  (jsc#SLE-8464).
- drivers: Introduce device lookup variants by fwnode
  (jsc#SLE-8449).
- drivers: Introduce device lookup variants by of_node
  (jsc#SLE-8449).
- drivers: Introduce device lookup variants by name
  (jsc#SLE-8449).
- commit 1851aa6
* Thu Oct 17 2019 yousaf.kaukab@suse.com
- ipmi_ssif: avoid registering duplicate ssif interface
  (jsc#SLE-10031).
- commit a68b3cc
* Thu Oct 17 2019 tbogendoerfer@suse.de
- tcp: fix slab-out-of-bounds in tcp_zerocopy_receive()
  (jsc#SLE-7979 jsc#SLE-7981).
- bpf/xskmap: Return ERR_PTR for failure case instead of NULL
  (jsc#SLE-8025).
- xsk: use state member for socket synchronization (jsc#SLE-8025).
- staging: octeon: Fix build failure due to typo (jsc#SLE-7979
  jsc#SLE-7981).
- ftgmac100: Fix build (jsc#SLE-7979 jsc#SLE-7981).
- commit 01068a7
* Thu Oct 17 2019 fdmanana@suse.com
- Btrfs: check for the full sync flag while holding the inode
  lock during fsync (bsc#1153713).
- commit 3467605
* Thu Oct 17 2019 acho@suse.com
- cfg80211: wext: avoid copying malformed SSIDs (bsc#1153158
  CVE-2019-17133).
- commit 3ac14b4
* Wed Oct 16 2019 tbogendoerfer@suse.de
- bnxt_en: Add a new BNXT_FW_RESET_STATE_POLL_FW_DOWN state
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Update firmware interface spec. to 1.10.0.100
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Increase timeout for HWRM_DBG_COREDUMP_XX commands
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Don't proceed in .ndo_set_rx_mode() when device is
  not in open state (jsc#SLE-8371 bsc#1153274).
- ixgbe: fix xdp handle calculations (jsc#SLE-7979 jsc#SLE-7981).
- i40e: fix xdp handle calculations (jsc#SLE-8025).
- ice: Bump version (jsc#SLE-7926).
- ice: Enable DDP package download (jsc#SLE-7926).
- ice: Initialize DDP package structures (jsc#SLE-7926).
- ice: Implement Dynamic Device Personalization (DDP) download
  (jsc#SLE-7926).
- ice: Fix FW version formatting in dmesg (jsc#SLE-7926).
- ice: send driver version to firmware (jsc#SLE-7926).
- i40e: fix potential RX buffer starvation for AF_XDP
  (jsc#SLE-8025).
- net/ixgbevf: make array api static const, makes object smaller
  (jsc#SLE-7979 jsc#SLE-7981).
- iavf: fix MAC address setting for VFs when filter is rejected
  (jsc#SLE-7940).
- i40e: clear __I40E_VIRTCHNL_OP_PENDING on invalid min Tx rate
  (jsc#SLE-8025).
- i40e: use BIT macro to specify the cloud filter field flags
  (jsc#SLE-8025).
- i40e: Fix message for other card without FEC (jsc#SLE-8025).
- i40e: fix missed "Negotiated" string in
  i40e_print_link_message() (jsc#SLE-8025).
- i40e: mark additional missing bits as reserved (jsc#SLE-8025).
- i40e: remove I40E_AQC_ADD_CLOUD_FILTER_OIP (jsc#SLE-8025).
- i40e: use ktime_get_real_ts64 instead of ktime_to_timespec64
  (jsc#SLE-8025).
- ixgbe: use skb_get_queue_mapping in tx path (jsc#SLE-7979
  jsc#SLE-7981).
- ixgbe: fix memory leaks (jsc#SLE-7979 jsc#SLE-7981).
- i40e: Add support for X710 device (jsc#SLE-8025).
- igc: Add tx_csum offload functionality (jsc#SLE-7966).
- ixgbe: sync the first fragment unconditionally (jsc#SLE-7979
  jsc#SLE-7981).
- i40e: Remove EMPR traces from debugfs facility (jsc#SLE-8025).
- i40e: Implement debug macro hw_dbg using dev_dbg (jsc#SLE-8025).
- i40e: fix hw_dbg usage in i40e_hmc_get_object_va (jsc#SLE-8025).
- igc: Remove unneeded PCI bus defines (jsc#SLE-7966).
- iavf: allow permanent MAC address to change (jsc#SLE-7940).
- igc: Add NVM checksum validation (jsc#SLE-7966).
- fm10k: use a local variable for the frag pointer (jsc#SLE-8009).
- igc: Remove useless forward declaration (jsc#SLE-7966).
- e1000e: Make speed detection on hotplugging cable more reliable
  (jsc#SLE-8100).
- ixgbevf: Link lost in VM on ixgbevf when restoring from freeze
  or suspend (jsc#SLE-7979 jsc#SLE-7981).
- iavf: remove unused debug function iavf_debug_d (jsc#SLE-7940).
- ice: Rework around device/function capabilities (jsc#SLE-7926).
- ice: change default number of receive descriptors
  (jsc#SLE-7926).
- ice: Minor refactor in queue management (jsc#SLE-7926).
- ice: Allow for delayed LLDP MIB change registration
  (jsc#SLE-7926).
- ice: update Tx context struct (jsc#SLE-7926).
- ice: Report VF link status with opcode to get resources
  (jsc#SLE-7926).
- ice: Check for DCB capability before initializing DCB
  (jsc#SLE-7926).
- ice: report link down for VF when PF's queues are not enabled
  (jsc#SLE-7926).
- ice: Reliably reset VFs (jsc#SLE-7926).
- ice: change work limit to a constant (jsc#SLE-7926).
- ice: small efficiency fixes (jsc#SLE-7926).
- ice: move code closer together (jsc#SLE-7926).
- ice: clean up arguments (jsc#SLE-7926).
- ice: Check root pointer for validity (jsc#SLE-7926).
- ice: Add ice_get_main_vsi to get PF/main VSI (jsc#SLE-7926).
- ice: Update fields in ice_vsi_set_num_qs when reconfiguring
  (jsc#SLE-7926).
- ixgbe: fix xdp handle calculations (jsc#SLE-7979 jsc#SLE-7981).
- i40e: fix xdp handle calculations (jsc#SLE-8025).
- ixgbe: modify driver for handling offsets (jsc#SLE-7979
  jsc#SLE-7981).
- i40e: modify driver for handling offsets (jsc#SLE-8025).
- xsk: add support to allow unaligned chunk placement
  (jsc#SLE-8025).
- ixgbe: simplify Rx buffer recycle (jsc#SLE-7979 jsc#SLE-7981).
- i40e: simplify Rx buffer recycle (jsc#SLE-8025).
- xsk: remove AF_XDP socket from map when the socket is released
  (jsc#SLE-8025).
- ixgbe: add support for AF_XDP need_wakeup feature (jsc#SLE-7979
  jsc#SLE-7981).
- i40e: add support for AF_XDP need_wakeup feature (jsc#SLE-8025).
- xsk: add support for need_wakeup flag in AF_XDP rings
  (jsc#SLE-8025).
- xsk: replace ndo_xsk_async_xmit with ndo_xsk_wakeup
  (jsc#SLE-7979 jsc#SLE-7981).
- ixgbe: Use kzfree() rather than its implementation (jsc#SLE-7979
  jsc#SLE-7981).
- ice: Only disable VLAN pruning for the VF when all VLANs are
  removed (jsc#SLE-7926).
- ice: Remove enable DCB when SW LLDP is activated (jsc#SLE-7926).
- ice: Report stats when VSI is down (jsc#SLE-7926).
- ice: Always notify FW of VF reset (jsc#SLE-7926).
- ice: Correctly handle return values for init DCB (jsc#SLE-7926).
- ice: Limit Max TCs on devices with more than 4 ports
  (jsc#SLE-7926).
- ice: Cleanup defines in ice_type.h (jsc#SLE-7926).
- ice: print extra message if topology issue (jsc#SLE-7926).
- ice: add print of autoneg state to link message (jsc#SLE-7926).
- ice: update driver unloading field for Queue Shutdown AQ command
  (jsc#SLE-7926).
- ice: add needed PFR during driver unload (jsc#SLE-7926).
- ice: Deduce TSA value from the priority value in the CEE mode
  (jsc#SLE-7926).
- ice: Report what the user set for coalesce [tx|rx]-usecs
  (jsc#SLE-7926).
- ice: Fix resource leak in ice_remove_rule_internal()
  (jsc#SLE-7926).
- ice: Fix EMP reset handling (jsc#SLE-7926).
- bnxt_en: Fix compile error regression with CONFIG_BNXT_SRIOV
  not set (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add FW fatal devlink_health_reporter (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Add bnxt_fw_exception() to handle fatal firmware errors
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add RESET_FW state logic to bnxt_fw_reset_task()
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Do not send firmware messages if firmware is in error
  state (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Retain user settings on a VF after RESET_NOTIFY event
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add devlink health reset reporter (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Handle firmware reset (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Handle RESET_NOTIFY async event from firmware
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add new FW devlink_health_reporter (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Add BNXT_STATE_IN_FW_RESET state (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Enable health monitoring (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Pre-map the firmware health monitoring registers
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Discover firmware error recovery capabilities
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Handle firmware reset status during IF_UP (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Register buffers for VFs before reserving resources
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor bnxt_sriov_enable() (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Prepare bnxt_init_one() to be called multiple times
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Suppress all error messages in hwrm_do_send_msg()
  in silent mode (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Simplify error checking in the SR-IOV message
  forwarding functions (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Convert error code in firmware message response to
  standard code (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Remove the -1 error return code from
  bnxt_hwrm_do_send_msg() (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Use a common function to print the same ethtool -f
  error message (jsc#SLE-8371 bsc#1153274).
- ice: fix adminq calls during remove (jsc#SLE-7926).
- ice: Rework ice_ena_msix_range (jsc#SLE-7926).
- ice: Fix VF configuration issues due to reset (jsc#SLE-7926).
- ice: Alloc queue management bitmaps and arrays dynamically
  (jsc#SLE-7926).
- ice: add support for virtchnl_queue_select.[tx|rx]_queues bitmap
  (jsc#SLE-7926).
- ice: add support for enabling/disabling single queues
  (jsc#SLE-7926).
- ice: fix potential infinite loop (jsc#SLE-7926).
- ice: fix ice_is_tc_ena (jsc#SLE-7926).
- ice: add validation in OP_CONFIG_VSI_QUEUES VF message
  (jsc#SLE-7926).
- ice: Don't clog kernel debug log with VF MDD events errors
  (jsc#SLE-7926).
- ice: Introduce a local variable for a VSI in the rebuild path
  (jsc#SLE-7926).
- ice: shorten local and add debug prints (jsc#SLE-7926).
- ice: Sanitize ice_ena_vsi and ice_dis_vsi (jsc#SLE-7926).
- ice: added sibling head to parse nodes (jsc#SLE-7926).
- ice: Fix ethtool port and PFC stats for 4x25G cards
  (jsc#SLE-7926).
- ice: Don't allow VSI to remove unassociated ucast filter
  (jsc#SLE-7926).
- ice: Fix issues updating VSI MAC filters (jsc#SLE-7926).
- ice: update ethtool stats on-demand (jsc#SLE-7926).
- ice: Add input handlers for virtual channel handlers
  (jsc#SLE-7926).
- ice: Don't clear auto_fec bit in ice_cfg_phy_fec()
  (jsc#SLE-7926).
- ice: Fix flag used for module query (jsc#SLE-7926).
- ice: silence some bogus error messages (jsc#SLE-7926).
- ice: Rename ethtool private flag for lldp (jsc#SLE-7926).
- ice: reject VF attempts to enable head writeback (jsc#SLE-7926).
- ice: Copy dcbx configuration only if mode is correct
  (jsc#SLE-7926).
- ice: Treat DCBx state NOT_STARTED as valid (jsc#SLE-7926).
- ice: Don't call synchronize_irq() for VF's from the host
  (jsc#SLE-7926).
- ice: Account for all states of FW DCBx and LLDP (jsc#SLE-7926).
- ice: Allow egress control packets from PF_VSI (jsc#SLE-7926).
- bnxt_en: Fix allocation of zero statistics block size regression
  (jsc#SLE-8371 bsc#1153274).
- =?UTF-8?q?ethernet:=20Delete=20unnecessary=20checks=20bef?=
  =?UTF-8?q?ore=20the=20macro=20call=20=E2=80=9Cdev=5Fkfree=5Fskb=E2=80=9D?=
  (jsc#SLE-7966).
- i40e: fix retrying in i40e_aq_get_phy_capabilities
  (jsc#SLE-8025).
- i40e: Persistent LLDP support (jsc#SLE-8025).
- i40e: allow reset in recovery mode (jsc#SLE-8025).
- i40e: Remove function i40e_update_dcb_config() (jsc#SLE-8025).
- i40e: Fix crash caused by stress setting of VF MAC addresses
  (jsc#SLE-8025).
- i40e: reset veb.tc_stats when resetting veb.stats
  (jsc#SLE-8025).
- i40e: Update FW API version to 1.9 (jsc#SLE-8025).
- i40e: check_recovery_mode had wrong if statement (jsc#SLE-8025).
- i40e: Add drop mode parameter to set mac config (jsc#SLE-8025).
- i40e: fix shifts of signed values (jsc#SLE-8025).
- i40e: add check on i40e_configure_tx_ring() return value
  (jsc#SLE-8025).
- i40e: Check if transceiver implements DDM before access
  (jsc#SLE-8025).
- i40e: reduce stack usage in i40e_set_fc (jsc#SLE-8025).
- ice: improve print for VF's when adding/deleting MAC filters
  (jsc#SLE-7926).
- ice: Change type for queue counts (jsc#SLE-7926).
- ice: Move VF resources definition to SR-IOV specific file
  (jsc#SLE-7926).
- ice: Increase size of Mailbox receive queue for many VFs
  (jsc#SLE-7926).
- ice: Reduce wait times during VF bringup/reset (jsc#SLE-7926).
- ice: update GLINT_DYN_CTL and GLINT_VECT2FUNC register access
  (jsc#SLE-7926).
- ice: Do not always bring up PF VSI in ice_ena_vsi()
  (jsc#SLE-7926).
- ice: allow empty Rx descriptors (jsc#SLE-7926).
- ice: Fix kernel hang with DCB reset in CEE mode (jsc#SLE-7926).
- ice: Set WB_ON_ITR when we don't re-enable interrupts
  (jsc#SLE-7926).
- ice: fix set pause param autoneg check (jsc#SLE-7926).
- ice: Restructure VFs initialization flows (jsc#SLE-7926).
- ice: Assume that more than one Rx queue is rare in ice_napi_poll
  (jsc#SLE-7926).
- ice: Use the software based tail when checking for hung Tx ring
  (jsc#SLE-7926).
- ixgbe: no need to check return value of debugfs_create functions
  (jsc#SLE-7979 jsc#SLE-7981).
- i40e: no need to check return value of debugfs_create functions
  (jsc#SLE-8025).
- fm10k: no need to check return value of debugfs_create functions
  (jsc#SLE-8009).
- bnxt: no need to check return value of debugfs_create functions
  (jsc#SLE-8371 bsc#1153274).
- i40e: Remove unicast log when VF is leaving multicast mode
  (jsc#SLE-8025).
- i40e: verify string count matches even on early return
  (jsc#SLE-8025).
- i40e: Log info when PF is entering and leaving Allmulti mode
  (jsc#SLE-8025).
- i40e: Update visual effect for advertised FEC mode
  (jsc#SLE-8025).
- i40e: fix code comments (jsc#SLE-8025).
- i40e: don't report link up for a VF who hasn't enabled queues
  (jsc#SLE-8025).
- i40e: Log disable-fw-lldp flag change by ethtool (jsc#SLE-8025).
- i40e: fix incorrect ethtool statistics veb and veb.tc_
  (jsc#SLE-8025).
- fm10k: fix fm10k_get_fault_pf to read correct address
  (jsc#SLE-8009).
- fm10k: convert NON_Q_VECTORS(hw) into NON_Q_VECTORS
  (jsc#SLE-8009).
- fm10k: mark unused parameters with __always_unused
  (jsc#SLE-8009).
- fm10k: cast page_addr to u8 * when incrementing it
  (jsc#SLE-8009).
- fm10k: explicitly return 0 on success path in function
  (jsc#SLE-8009).
- fm10k: remove needless initialization of size local variable
  (jsc#SLE-8009).
- fm10k: remove needless assignment of err local variable
  (jsc#SLE-8009).
- fm10k: remove unnecessary variable initializer (jsc#SLE-8009).
- fm10k: reduce scope of the ring variable (jsc#SLE-8009).
- fm10k: reduce the scope of the result local variable
  (jsc#SLE-8009).
- fm10k: reduce the scope of the local msg variable
  (jsc#SLE-8009).
- fm10k: reduce the scope of the local i variable (jsc#SLE-8009).
- fm10k: reduce the scope of the err variable (jsc#SLE-8009).
- fm10k: reduce the scope of the tx_buffer variable
  (jsc#SLE-8009).
- fm10k: reduce the scope of the q_idx local variable
  (jsc#SLE-8009).
- fm10k: reduce the scope of local err variable (jsc#SLE-8009).
- fm10k: reduce the scope of qv local variable (jsc#SLE-8009).
- fm10k: reduce scope of *p local variable (jsc#SLE-8009).
- fm10k: reduce scope of the err variable (jsc#SLE-8009).
- ice: Bump version number (jsc#SLE-7926).
- ice: Remove flag to track VF interrupt status (jsc#SLE-7926).
- ice: Remove unnecessary flag ICE_FLAG_MSIX_ENA (jsc#SLE-7926).
- ice: Don't return error for disabling LAN Tx queue that does
  exist (jsc#SLE-7926).
- ice: Remove duplicate code in ice_alloc_rx_bufs (jsc#SLE-7926).
- ice: Add stats for Rx drops at the port level (jsc#SLE-7926).
- ice: Update number of VF queue before setting VSI resources
  (jsc#SLE-7926).
- ice: Set up Tx scheduling tree based on alloc VSI Tx queues
  (jsc#SLE-7926).
- ice: Only bump Rx tail and release buffers once per napi_poll
  (jsc#SLE-7926).
- ice: Disable VFs until reset is completed (jsc#SLE-7926).
- ice: Do not configure port with no media (jsc#SLE-7926).
- ice: separate out control queue lock creation (jsc#SLE-7926).
- ice: Always set prefena when configuring an Rx queue
  (jsc#SLE-7926).
- ice: Move vector base setup to PF VSI (jsc#SLE-7926).
- ice: track hardware stat registers past rollover (jsc#SLE-7926).
- ice: add lp_advertising flow control support (jsc#SLE-7926).
- net: Use skb_frag_off accessors (jsc#SLE-7979 jsc#SLE-7981).
- linux: Add skb_frag_t page_offset accessors (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Add PCI IDs for 57500 series NPAR devices (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Support all variants of the 5750X chip family
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor bnxt_init_one() and turn on TPA support on
  57500 chips (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Support TPA counters on 57500 chips (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Allocate the larger per-ring statistics block for
  57500 chips (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor ethtool ring statistics logic (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Add hardware GRO setup function for 57500 chips
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add TPA ID mapping logic for 57500 chips (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Add fast path logic for TPA on 57500 chips
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Set TPA GRO mode flags on 57500 chips properly
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor tunneled hardware GRO logic (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Handle standalone RX_AGG completions (jsc#SLE-8371
  bsc#1153274).
- bnxt_en: Expand bnxt_tpa_info struct to support 57500 chips
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Refactor TPA logic (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Add TPA structure definitions for BCM57500 chips
  (jsc#SLE-8371 bsc#1153274).
- bnxt_en: Update firmware interface spec. to 1.10.0.89
  (jsc#SLE-8371 bsc#1153274).
- igc: Add more SKUs for i225 device (jsc#SLE-7966).
- igc: Update the MAC reset flow (jsc#SLE-7966).
- igc: Remove the unused field from a device specification
  structure (jsc#SLE-7966).
- igc: Remove the polarity field from a PHY information structure
  (jsc#SLE-7966).
- net/ixgbevf: fix a compilation error of skb_frag_t (jsc#SLE-7979
  jsc#SLE-7981).
- Build fixes for skb_frag_size conversion (jsc#SLE-7979
  jsc#SLE-7981).
- igb: Use dev_get_drvdata where possible (jsc#SLE-7967).
- i40e: Use dev_get_drvdata (jsc#SLE-8025).
- fm10k: Use dev_get_drvdata (jsc#SLE-8009).
- e1000e: Use dev_get_drvdata where possible (jsc#SLE-8100).
- net: broadcom: Use dev_get_drvdata (jsc#SLE-8371 bsc#1153274).
- net: Convert skb_frag_t to bio_vec (jsc#SLE-7979 jsc#SLE-7981).
- net: Rename skb_frag_t size to bv_len (jsc#SLE-7979
  jsc#SLE-7981).
- net: Rename skb_frag page to bv_page (jsc#SLE-7979
  jsc#SLE-7981).
- net: Reorder the contents of skb_frag_t (jsc#SLE-7979
  jsc#SLE-7981).
- net: Increase the size of skb_frag_t (jsc#SLE-7979
  jsc#SLE-7981).
- net: Use skb accessors in network core (jsc#SLE-7979
  jsc#SLE-7981).
- net: Use skb accessors in network drivers (jsc#SLE-8371
  bsc#1153274).
- commit b79d16a
* Wed Oct 16 2019 yousaf.kaukab@suse.com
- arm64: topology: Use PPTT to determine if PE is a thread
  (jsc#SLE-10146).
- ACPI/PPTT: Add support for ACPI 6.3 thread flag (jsc#SLE-10146).
- commit 72dbea4
* Wed Oct 16 2019 yousaf.kaukab@suse.com
- arm64: synquacer: enable spi driver
  References: jsc#SLE-9968
- commit 6756790
* Wed Oct 16 2019 jthumshirn@suse.de
- blk-wbt: fix performance regression in wbt scale_up/scale_down
  (bsc#1152489).
- commit 214a4b1
* Wed Oct 16 2019 mkubecek@suse.cz
- Update patches.suse/supported-flag references (add bsc#974406).
- commit 6b909a8
* Wed Oct 16 2019 pmladek@suse.com
- tracing: Initialize iter->seq after zeroing in
  tracing_read_pipe() (bsc#1151508).
- commit b84a6ef
* Wed Oct 16 2019 jroedel@suse.de
- kvm: x86, powerpc: do not allow clearing largepages debugfs
  entry (bsc#1117665).
- commit 8126faf
* Wed Oct 16 2019 ykaukab@suse.de
- pinctrl: rockchip: Mark expected switch fall-through
  (bsc#1154208).
- commit 284f3c9
* Wed Oct 16 2019 lpechacek@suse.com
- Refresh patches.suse/supported-flag.
- Delete
  patches.suse/module-Inform-user-when-loading-externally-supported.patch.
  Squash module-Inform-user-when-loading-externally-supported.patch (bsc#974406)
  into supported-flag.
- commit 5be4f6e
* Wed Oct 16 2019 dwagner@suse.de
- scsi: lpfc: Make function lpfc_defer_pt2pt_acc static
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.4.0.1 (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: cleanup: remove unused fcp_txcmlpq_cnt (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Complete removal of FCoE T10 PI support on SLI-4
  adapters (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Update async event logging (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix list corruption detected in
  lpfc_put_sgl_per_hdwq (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix hdwq sgl locks and irq handling (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix spinlock_irq issues in lpfc_els_flush_cmd()
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix list corruption in lpfc_sli_get_iocbq
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix host hang at boot or slow boot (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix coverity errors on NULL pointer checks
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix NVMe ABTS in response to receiving an ABTS
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix discovery failures when target device
  connectivity bounces (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix GPF on scsi command completion (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix locking on mailbox command completion
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix device recovery errors after PLOGI failures
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix rpi release when deleting vport (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix NVME io abort failures causing hangs
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix miss of register read failure check
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix premature re-enabling of interrupts in
  lpfc_sli_host_down (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix pt2pt discovery on SLI3 HBAs (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix reset recovery paths that are not recovering
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Convert existing %%pf users to %%ps (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: fix 12.4.0.0 GPF at boot (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Remove bg debugfs buffers (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Resolve checker warning for lpfc_new_io_buf()
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Update lpfc version to 12.4.0.0 (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Merge per-protocol WQ/CQ pairs into single per-cpu
  pair (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Add NVMe sequence level error recovery support
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Support dynamic unbounded SGL lists on G7 hardware
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Add MDS driver loopback diagnostics support
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Add first and second level hardware revisions to
  sysfs reporting (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Migrate to %%px and %%pf in kernel print calls
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Add simple unlikely optimizations to reduce NVME
  latency (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix coverity warnings (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix nvme first burst module parameter description
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix BlockGuard enablement on FCoE adapters
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix reported physical link speed on a disabled
  trunked link (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix Max Frame Size value shown in fdmishow output
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix upcall to bsg done in non-success cases
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix sli4 adapter initialization with MSI
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix nvme sg_seg_cnt display if HBA does not support
  NVME (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix nvme target mode ABTSing a received ABTS
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix hang when downloading fw on port enabled for
  nvme (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix too many sg segments spamming in kernel log
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix crash due to port reset racing vs adapter
  error handling (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix deadlock on host_lock during cable pulls
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix error in remote port address change
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix driver nvme rescan logging (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix sg_seg_cnt for HBAs that don't support NVME
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix propagation of devloss_tmo setting to nvme
  transport (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix loss of remote port after devloss due to lack
  of RPIs (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix devices that don't return after devloss followed
  by rediscovery (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix null ptr oops updating lpfc_devloss_tmo via
  sysfs attribute (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix FLOGI handling across multiple link up/down
  conditions (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix oops when fewer hdwqs than cpus (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix irq raising in lpfc_sli_hba_down (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix Oops in nvme_register with target logout/login
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix issuing init_vpi mbox on SLI-3 card
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix ADISC reception terminating login state if a
  NVME target (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix discovery when target has no GID_FT information
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix port relogin failure due to GID_FT interaction
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix leak of ELS completions on adapter reset
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix failure to clear non-zero eq_delay after io
  rate reduction (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Fix crash on driver unload in wq free (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix ELS field alignments (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: Fix PLOGI failure with high remoteport count
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Limit xri count for kdump environment (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: remove NULL check before some freeing functions
  (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: use spin_lock_irqsave in IRQ context (jsc#SLE-8284
  jsc#SLE-8654).
- scsi: lpfc: remove redundant code (jsc#SLE-8284 jsc#SLE-8654).
- scsi: lpfc: Remove unnecessary null check before kfree
  (jsc#SLE-8284 jsc#SLE-8654).
- commit d8bfc1f
* Wed Oct 16 2019 dwagner@suse.de
- series.conf: Update qla2xxx patches
  The qla2xxx patches have been added to jebj's queue.
- commit 1b97787
* Wed Oct 16 2019 mkubecek@suse.cz
- Fix Patch-mainline tags:
  patches.suse/0001-ACPI-property-Add-two-new-Thunderbolt-property-GUIDs.patch
  patches.suse/0001-thunderbolt-Add-support-for-Intel-Ice-Lake.patch
  patches.suse/0001-thunderbolt-Correct-path-indices-for-PCIe-tunnel.patch
  patches.suse/0001-thunderbolt-Do-not-fail-adding-switch-if-some-port-i.patch
  patches.suse/0001-thunderbolt-Expose-active-parts-of-NVM-even-if-upgra.patch
  patches.suse/0001-thunderbolt-Hide-switch-attributes-that-are-not-set.patch
  patches.suse/0001-thunderbolt-Move-NVM-upgrade-support-flag-to-struct-.patch
  patches.suse/0001-thunderbolt-Show-key-using-pE-not-pEp.patch
  patches.suse/0001-thunderbolt-Switch-to-use-device_property_count_uXX.patch
  patches.suse/0001-thunderbolt-Use-32-bit-writes-when-writing-ring-prod.patch
- commit 1318e50
* Wed Oct 16 2019 mkubecek@suse.cz
- config: refresh after dependency changes
- commit 4237191
* Wed Oct 16 2019 mkubecek@suse.cz
- series.conf: cleanup
  Update upstream references and resort:
  patches.suse/scsi-qla2xxx-Remove-WARN_ON_ONCE-in-qla2x00_status_c.patch
  Move unsortable
  patches.suse/scsi-qla2xxx-fix-wait-condition-in-loop.patch
  out of sorted section.
- commit 0133508
* Tue Oct 15 2019 dwagner@suse.de
- scsi: qedf: Add port_id getter (jsc#SLE-9711).
- scsi: qedf: Remove always false 'tmp_prio < 0' statement
  (jsc#SLE-9711).
- scsi: qedf: Update the version to 8.42.3.0 (jsc#SLE-9711).
- scsi: qedf: Fix race betwen fipvlan request and response path
  (jsc#SLE-9711).
- scsi: qedf: Use discovery list to traverse rports
  (jsc#SLE-9711).
- scsi: qedf: Decrease the LL2 MTU size to 2500 (jsc#SLE-9711).
- scsi: qedf: Check for module unloading bit before processing
  link update AEN (jsc#SLE-9711).
- scsi: qedf: Initiator fails to re-login to switch after link
  down (jsc#SLE-9711).
- scsi: qedf: Add debug information for unsolicited processing
  (jsc#SLE-9711).
- scsi: qedf: Add support for 20 Gbps speed (jsc#SLE-9711).
- scsi: qedf: Interpret supported caps value correctly
  (jsc#SLE-9711).
- scsi: qedf: Add shutdown callback handler (jsc#SLE-9711).
- scsi: qedf: Update module description string (jsc#SLE-9711).
- scsi: qedf: Fix crash during sg_reset (jsc#SLE-9711).
- scsi: qedf: Stop sending fipvlan request on unload
  (jsc#SLE-9711).
- scsi: qedf: Print message during bailout conditions
  (jsc#SLE-9711).
- commit 723fe3b
* Tue Oct 15 2019 bp@suse.de
- x86/cpu: Add Comet Lake to the Intel CPU models header
  (jsc#SLE-7946).
- commit e9d5845
* Tue Oct 15 2019 msuchanek@suse.de
- soundwire: depend on ACPI || OF (bsc#1148868).
- soundwire: depend on ACPI (bsc#1148868).
- commit 4ebb907
* Tue Oct 15 2019 nborisov@suse.com
- btrfs: Remove metadata_uuid patches
  They are already in upstream 5.0.
- Delete patches.suse/0001-btrfs-Introduce-support-for-FSID-change-without-meta.patch.
- Delete patches.suse/0002-btrfs-Remove-fsid-metadata_fsid-fields-from-btrfs_in.patch.
- Delete patches.suse/0003-btrfs-Add-handling-for-disk-split-brain-scenario-dur.patch.
- Delete patches.suse/0004-btrfs-Introduce-2-more-members-to-struct-btrfs_fs_de.patch.
- Delete patches.suse/0005-btrfs-Handle-one-more-split-brain-scenario-during-fs.patch.
- Delete patches.suse/0006-btrfs-Handle-final-split-brain-possibility-during-fs.patch.
- Delete patches.suse/btrfs-add-sysfs-support-for-metadata_uuid-feature.patch.
- commit 1a7c8f7
* Tue Oct 15 2019 jslaby@suse.cz
- Update
  patches.suse/sched-core-Fix-CPU-controller-for-RT_GROUP_SCHED.patch
  (bnc#1151927 5.3.4 bnc#1135646).
  Add a bnc reference.
- commit 05f45df
* Tue Oct 15 2019 ptesarik@suse.cz
- Delete patches.suse/0201-merge-tag-exynos-drm-fixes-for-v4-12.
- Delete
  patches.suse/0586-merge-branch-drm-next-4-13-into-drm-next.
- Delete
  patches.suse/0680-merge-tag-drm-for-v4-13-of-git-people-freedesktop-org-airlied-linux.
- Delete
  patches.suse/1312-merge-tag-drm-msm-next-2017-08-22-into-drm-next.
- Delete
  patches.suse/3619-merge-airlied-drm-next-into-drm-misc-next.
- Delete
  patches.suse/3625-merge-drm-misc-next-2017-11-30-into-drm-next.
- Delete
  patches.suse/3631-merge-tag-drm-intel-next-2017-11-17-1-into-drm-next.
- Delete
  patches.suse/4330-merge-drm-armada-devel-4-15-into-drm-next.
- Delete patches.suse/5994-backmerge-tag-v4-16-rc7-into-drm-next.
- Delete
  patches.suse/7627-merge-drm-upstream-drm-next-into-drm-misc-next.
- commit 1a3d42d
* Tue Oct 15 2019 vbabka@suse.cz
- Delete patches.suse/x86-mm-fix-fast-gup-paravirt.patch.
  (The problem was solved differently upstream between 4.12 and 5.3)
- commit 0329020
* Tue Oct 15 2019 yousaf.kaukab@suse.com
- arm64: cn99xx: enable patches for silicon revision Ax erratum
  References: PM-1408
  Systems with Ax silicon still in use.
- commit 012b115
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner: rename flag indicating that page is allocated
  (jsc#SLE-8959, bsc#1144653, VM Debug Functionality).
- commit 1a8c019
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner: decouple freeing stack trace from
  debug_pagealloc (jsc#SLE-8959, bsc#1144653, VM Debug Functionality).
- commit 0458b8c
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner: fix off-by-one error in
  __set_page_owner_handle() (jsc#SLE-8959, bsc#1144653, VM
  Debug Functionality).
- commit d9d2cb5
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner, debug_pagealloc: save and dump freeing stack
  trace (jsc#SLE-8959, bsc#1144653, VM Debug Functionality).
- commit 88a816e
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner: keep owner info when freeing the page (jsc#SLE-8959,
  bsc#1144653, VM Debug Functionality).
- commit 59689b6
* Tue Oct 15 2019 vbabka@suse.cz
- mm, page_owner: record page owner for each subpage (jsc#SLE-8959,
  bsc#1144653, VM Debug Functionality).
- commit 6920f27
* Tue Oct 15 2019 dwagner@suse.de
- qla2xxx: Enable T10-DIF with FC-NVMe enabled (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- commit f8cfc4e
* Tue Oct 15 2019 dwagner@suse.de
- scsi: qla2xxx: Fix wait condition in loop (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- commit 39bb1be
* Tue Oct 15 2019 dwagner@suse.de
- scsi: qla2xxx: Update driver version to 10.01.00.20-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Improve logging for scan thread (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Capture FW dump on MPI heartbeat stop event
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Check for MB timeout while capturing ISP27/28xx
  FW dump (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Set remove flag for all VP (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Add error handling for PLOGI ELS passthrough
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Dual FCP-NVMe target port support (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: remove redundant assignment to pointer host
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove WARN_ON_ONCE in
  qla2x00_status_cont_entry() (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Fix Nport ID display value (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix N2N link up fail (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Fix N2N link reset (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Optimize NPIV tear down process (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix stale mem access on driver unload
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix unbound sleep in fcport delete path
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Silence fwdump template message (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Update driver version to 10.01.00.19-k
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix stale session (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Fix stuck login session (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix driver reload for ISP82xx (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix flash read for Qlogic ISPs (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix message indicating vectors used by driver
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: fix spelling mistake "initializatin" ->
  "initialization" (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix a recently introduced kernel warning
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: cleanup trace buffer initialization (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: qla2x00_alloc_fw_dump: set ha->eft (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix a NULL pointer dereference (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Simplify qla24xx_async_abort_cmd() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove two superfluous if-tests (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Introduce qla2x00_els_dcmd2_free() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Inline the qla2x00_fcport_event_handler()
  function (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Report invalid mailbox status codes (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove superfluous sts_entry_* casts
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Let the compiler check the type of the
  SCSI command context pointer (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Complain if sp->done() is not called from the
  completion path (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Make sure that aborted commands are freed
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Introduce qla2xxx_get_next_handle() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Modify NVMe include directives (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Make qlt_handle_abts_completion() more robust
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix a race condition between aborting and
  completing a SCSI command (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Introduce the function qla2xxx_init_sp()
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Enable type checking for the SRB free and done
  callback functions (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Rework key encoding in qlt_find_host_by_d_id()
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Set the responder mode if appropriate for ELS
  pass-through IOCBs (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Make it explicit that ELS pass-through IOCBs
  use little endian (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Check secondary image if reading the primary
  image fails (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Change the return type of
  qla24xx_read_flash_data() (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Introduce the be_id_t and le_id_t data types
  for FC src/dst IDs (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Complain if a soft reset fails (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use memcpy() and strlcpy() instead of strcpy()
  and strncpy() (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Check the PCI info string output buffer size
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Complain if waiting for pending commands times
  out (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Declare fourth qla2x00_set_model_info() argument
  const (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Always check the qla2x00_wait_for_hba_online()
  return value (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Suppress multiple Coverity complaint
  about out-of-bounds accesses (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Suppress a Coveritiy complaint about integer
  overflow (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove unreachable code from qla83xx_idc_lock()
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix qla24xx_process_bidir_cmd() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Simplify a debug statement (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove dead code (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Complain if parsing the version string fails
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Complain if a mailbox command times out
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use strlcpy() instead of strncpy() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Do not corrupt vha->plogi_ack_list (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Report the firmware status code if a mailbox
  command fails (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Fix session lookup in qlt_abort_work()
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Simplify qla24xx_abort_sp_done() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove two superfluous tests (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove a superfluous pointer check (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Simplify qlt_lport_dump() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Reduce the number of casts in GID list code
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Verify locking assumptions at runtime
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Change data_dsd into an array (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Declare qla_tgt_cmd.cdb const (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Reduce the scope of three local variables
  in qla2xxx_queuecommand() (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- scsi: qla2xxx: Change the return type of
  qla2x00_update_ms_fdmi_iocb() into void (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Declare the fourth ql_dump_buffer() argument
  const (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove a superfluous forward declaration
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Remove an include directive from qla_mr.c
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Include the <asm/unaligned.h> header file from
  qla_dsd.h (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Use tabs instead of spaces for indentation
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Improve Linux kernel coding style conformance
  (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Really fix qla2xxx_eh_abort() (jsc#SLE-9714
  jsc#SLE-10327 jsc#SLE-10334).
- scsi: qla2xxx: Make qla2x00_abort_srb() again decrease the sp
  reference count (jsc#SLE-9714 jsc#SLE-10327 jsc#SLE-10334).
- qla2xxx: remove SGI SN2 support (jsc#SLE-9714 jsc#SLE-10327
  jsc#SLE-10334).
- commit 2a36545
* Tue Oct 15 2019 oneukum@suse.com
- ACPI / property: Add two new Thunderbolt property GUIDs to
  the list (jsc#SLE-8714).
- commit 11dee44
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Add support for Intel Ice Lake (jsc#SLE-8714).
- commit 815b577
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Expose active parts of NVM even if upgrade is
  not supported (jsc#SLE-8714).
- commit badef1c
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Hide switch attributes that are not set
  (jsc#SLE-8714).
- commit 5b9d6f9
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Do not fail adding switch if some port is not
  implemented (jsc#SLE-8714).
- commit d0e61eb
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Use 32-bit writes when writing ring
  producer/consumer (jsc#SLE-8714).
- commit df92f6a
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Move NVM upgrade support flag to struct icm
  (jsc#SLE-8714).
- commit 476237e
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Correct path indices for PCIe tunnel
  (jsc#SLE-8714).
- commit 0d8a0ac
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Show key using %%*pE not %%*pEp (jsc#SLE-8714).
- commit 2388d46
* Tue Oct 15 2019 oneukum@suse.com
- thunderbolt: Switch to use device_property_count_uXX()
  (jsc#SLE-8714).
- commit 51e1030
* Tue Oct 15 2019 dwagner@suse.de
- scsi: qla2xxx: Refresh patches ported from SLE15-SP1
- Refresh
  patches.suse/scsi-qla2xxx-Allow-NVMe-IO-to-resume-with-short-cabl.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Correct-error-handling-during-initializ.patch.
- Refresh patches.suse/scsi-qla2xxx-Fix-DMA-unmap-leak.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Fix-NVMe-port-discovery-after-a-short-d.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Fix-abort-timeout-race-condition.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Fix-different-size-DMA-Alloc-Unmap.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Fix-hang-in-fcport-delete-path.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Fix-premature-timer-expiration.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Reject-EH_-abort-device_reset-target_re.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Remove-unnecessary-null-check.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Replace-vmalloc-memset-with-vzalloc.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Retry-fabric-Scan-on-IOCB-queue-full.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Skip-FW-dump-on-LOOP-initialization-err.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.18-k.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Use-Correct-index-for-Q-Pair-array.patch.
- Refresh
  patches.suse/scsi-qla2xxx-Use-common-update-firmware-options-rout.patch.
- commit 44af015
* Tue Oct 15 2019 jslaby@suse.cz
- Linux 5.3.6 (bnc#1151927 5.3.6).
- DTS: ARM: gta04: introduce legacy spi-cs-high to make display
  work again (bnc#1151927 5.3.6).
- mac80211: keep BHs disabled while calling drv_tx_wake_queue()
  (bnc#1151927 5.3.6).
- cfg80211: initialize on-stack chandefs (bnc#1151927 5.3.6).
- cfg80211: validate SSID/MBSSID element ordering assumption
  (bnc#1151927 5.3.6).
- nl80211: validate beacon head (bnc#1151927 5.3.6).
- ieee802154: atusb: fix use-after-free at disconnect (bnc#1151927
  5.3.6).
- KVM: s390: fix __insn32_query() inline assembly (bnc#1151927
  5.3.6).
- KVM: nVMX: Fix consistency check on injected exception error
  code (bnc#1151927 5.3.6).
- KVM: X86: Fix userspace set invalid CR4 (bnc#1151927 5.3.6).
- xen/xenbus: fix self-deadlock after killing user process
  (bnc#1151927 5.3.6).
- xen/balloon: Set pages PageOffline() in balloon_add_region()
  (bnc#1151927 5.3.6).
- selftests: pidfd: Fix undefined reference to pthread_create()
  (bnc#1151927 5.3.6).
- sched: Add __ASSEMBLY__ guards around struct clone_args
  (bnc#1151927 5.3.6).
- drm/omap: fix max fclk divider for omap36xx (bnc#1151927 5.3.6).
- drm/amd/powerplay: change metrics update period from 1ms to
  100ms (bnc#1151927 5.3.6).
- Revert "s390/dasd: Add discard support for ESE volumes"
  (bnc#1151927 5.3.6).
- s390/dasd: Fix error handling during online processing
  (bnc#1151927 5.3.6).
- vfs: Fix EOVERFLOW testing in put_compat_statfs64 (bnc#1151927
  5.3.6).
- tick: broadcast-hrtimer: Fix a race in bc_set_next (bnc#1151927
  5.3.6).
- Btrfs: fix selftests failure due to uninitialized i_mode in
  test inodes (bnc#1151927 5.3.6).
- mmc: tegra: Implement ->set_dma_mask() (bnc#1151927 5.3.6).
- mmc: sdhci: Let drivers define their DMA mask (bnc#1151927
  5.3.6).
- mmc: sdhci-of-esdhc: set DMA snooping based on DMA coherence
  (bnc#1151927 5.3.6).
- mmc: sdhci: improve ADMA error reporting (bnc#1151927 5.3.6).
- libnvdimm: prevent nvdimm from requesting key when security
  is disabled (bnc#1151927 5.3.6).
- libnvdimm/region: Initialize bad block for volatile namespaces
  (bnc#1151927 5.3.6).
- libnvdimm/nfit_test: Fix acpi_handle redefinition (bnc#1151927
  5.3.6).
- =?UTF-8?q?libnvdimm:=20Fix=20endian=20conversion=20issues=C2=A0?=
  (bnc#1151927 5.3.6).
- i2c: qcom-geni: Disable DMA processing on the Lenovo Yoga C630
  (bnc#1151927 5.3.6).
- iommu/amd: Fix downgrading default page-sizes in alloc_pte()
  (bnc#1151927 5.3.6).
- nfp: abm: fix memory leak in nfp_abm_u32_knode_replace
  (bnc#1151927 5.3.6).
- mlxsw: spectrum_flower: Fail in case user specifies multiple
  mirror actions (bnc#1151927 5.3.6).
- net: dsa: microchip: Always set regmap stride to 1 (bnc#1151927
  5.3.6).
- netfilter: nf_tables: allow lookups in dynamic sets (bnc#1151927
  5.3.6).
- bpf: Fix bpf_event_output re-entry issue (bnc#1151927 5.3.6).
- selftests/bpf: adjust strobemeta loop to satisfy latest clang
  (bnc#1151927 5.3.6).
- libbpf: fix false uninitialized variable warning (bnc#1151927
  5.3.6).
- powerpc/mm: Fix an Oops in kasan_mmu_init() (bnc#1151927 5.3.6).
- powerpc/mm: Add a helper to select PAGE_KERNEL_RO or
  PAGE_READONLY (bnc#1151927 5.3.6).
- x86/purgatory: Disable the stackleak GCC plugin for the
  purgatory (bnc#1151927 5.3.6).
- sched/core: Fix migration to invalid CPU in
  __set_cpus_allowed_ptr() (bnc#1151927 5.3.6).
- sched/membarrier: Call sync_core only before usermode for same
  mm (bnc#1151927 5.3.6).
- sched/membarrier: Fix private expedited registration check
  (bnc#1151927 5.3.6).
- ima: fix freeing ongoing ahash_request (bnc#1151927 5.3.6).
- ima: always return negative code for error (bnc#1151927 5.3.6).
- 9p: Transport error uninitialized (bnc#1151927 5.3.6).
- 9p: avoid attaching writeback_fid on mmap with type PRIVATE
  (bnc#1151927 5.3.6).
- riscv: Avoid interrupts being erroneously enabled in
  handle_exception() (bnc#1151927 5.3.6).
- Revert "locking/pvqspinlock: Don't wait if vCPU is preempted"
  (bnc#1151927 5.3.6).
- pwm: stm32-lp: Add check in case requested period cannot be
  achieved (bnc#1151927 5.3.6).
- blk-mq: move lockdep_assert_held() into elevator_exit
  (bnc#1151927 5.3.6).
- drivers: thermal: qcom: tsens: Fix memory leak from qfprom read
  (bnc#1151927 5.3.6).
- thermal: Fix use-after-free when unregistering thermal zone
  device (bnc#1151927 5.3.6).
- thermal_hwmon: Sanitize thermal_zone type (bnc#1151927 5.3.6).
- watchdog: aspeed: Add support for AST2600 (bnc#1151927 5.3.6).
- watchdog: imx2_wdt: fix min() calculation in
  imx2_wdt_set_timeout (bnc#1151927 5.3.6).
- drm/amdgpu: Check for valid number of registers to read
  (bnc#1151927 5.3.6).
- drm/radeon: Bail earlier when radeon.cik_/si_support=0 is passed
  (bnc#1151927 5.3.6).
- drm/atomic: Reject FLIP_ASYNC unconditionally (bnc#1151927
  5.3.6).
- drm/atomic: Take the atomic toys away from X (bnc#1151927
  5.3.6).
- ntb: point to right memory window index (bnc#1151927 5.3.6).
- timer: Read jiffies once when forwarding base clk (bnc#1151927
  5.3.6).
- perf unwind: Fix libunwind build failure on i386 systems
  (bnc#1151927 5.3.6).
- perf build: Add detection of java-11-openjdk-devel package
  (bnc#1151927 5.3.6).
- perf probe: Fix to clear tev->nargs in clear_probe_trace_event()
  (bnc#1151927 5.3.6).
- perf tools: Fix segfault in cpu_cache_level__read() (bnc#1151927
  5.3.6).
- perf stat: Fix a segmentation fault when using repeat forever
  (bnc#1151927 5.3.6).
- perf stat: Reset previous counts on repeat with interval
  (bnc#1151927 5.3.6).
- usercopy: Avoid HIGHMEM pfn warning (bnc#1151927 5.3.6).
- selftests/seccomp: fix build on older kernels (bnc#1151927
  5.3.6).
- pNFS: Ensure we do clear the return-on-close layout stateid
  on fatal errors (bnc#1151927 5.3.6).
- SUNRPC: Don't try to parse incomplete RPC messages (bnc#1151927
  5.3.6).
- SUNRPC: RPC level errors should always set task->tk_rpc_status
  (bnc#1151927 5.3.6).
- xprtrdma: Send Queue size grows after a reconnect (bnc#1151927
  5.3.6).
- xprtrdma: Toggle XPRT_CONGESTED in xprtrdma's slot methods
  (bnc#1151927 5.3.6).
- fs: nfs: Fix possible null-pointer dereferences in
  encode_attrs() (bnc#1151927 5.3.6).
- s390/cio: exclude subchannels with no parent from pseudo check
  (bnc#1151927 5.3.6).
- s390/cio: avoid calling strlen on null pointer (bnc#1151927
  5.3.6).
- s390/topology: avoid firing events before kobjs are created
  (bnc#1151927 5.3.6).
- xen/pci: reserve MCFG areas earlier (bnc#1151927 5.3.6).
- include/trace/events/writeback.h: fix -Wstringop-truncation
  warnings (bnc#1151927 5.3.6).
- kernel/elfcore.c: include proper prototypes (bnc#1151927 5.3.6).
- ceph: reconnect connection if session hang in opening state
  (bnc#1151927 5.3.6).
- ceph: fetch cap_gen under spinlock in ceph_add_cap (bnc#1151927
  5.3.6).
- ceph: fix directories inode i_blkbits initialization
  (bnc#1151927 5.3.6).
- fuse: fix memleak in cuse_channel_open (bnc#1151927 5.3.6).
- fuse: fix request limit (bnc#1151927 5.3.6).
- selftests/tpm2: Add the missing TEST_FILES assignment
  (bnc#1151927 5.3.6).
- power: supply: sbs-battery: only return health when battery
  present (bnc#1151927 5.3.6).
- power: supply: sbs-battery: use correct flags field (bnc#1151927
  5.3.6).
- MIPS: Treat Loongson Extensions as ASEs (bnc#1151927 5.3.6).
- powerpc/603: Fix handling of the DIRTY flag (bnc#1151927 5.3.6).
- powerpc/32s: Fix boot failure with DEBUG_PAGEALLOC without KASAN
  (bnc#1151927 5.3.6).
- powerpc/kasan: Fix shadow area set up for modules (bnc#1151927
  5.3.6).
- powerpc/kasan: Fix parallel loading of modules (bnc#1151927
  5.3.6).
- powerpc/ptdump: Fix addresses display on PPC32 (bnc#1151927
  5.3.6).
- tracing: Make sure variable reference alias has correct
  var_ref_idx (bnc#1151927 5.3.6).
- drm/nouveau/kms/nv50-: Don't create MSTMs for eDP connectors
  (bnc#1151927 5.3.6).
- drm/i915: to make vgpu ppgtt notificaiton as atomic operation
  (bnc#1151927 5.3.6).
- drm/i915/gvt: update vgpu workload head pointer correctly
  (bnc#1151927 5.3.6).
- can: mcp251x: mcp251x_hw_reset(): allow more time after a reset
  (bnc#1151927 5.3.6).
- crypto: cavium/zip - Add missing single_release() (bnc#1151927
  5.3.6).
- crypto: skcipher - Unmap pages after an external error
  (bnc#1151927 5.3.6).
- crypto: caam/qi - fix error handling in ERN handler (bnc#1151927
  5.3.6).
- crypto: caam - fix concurrency issue in givencrypt descriptor
  (bnc#1151927 5.3.6).
- crypto: ccree - use the full crypt length value (bnc#1151927
  5.3.6).
- crypto: qat - Silence smp_processor_id() warning (bnc#1151927
  5.3.6).
- crypto: ccree - account for TEE not ready to report (bnc#1151927
  5.3.6).
- coresight: etm4x: Use explicit barriers on enable/disable
  (bnc#1151927 5.3.6).
- staging: erofs: detect potential multiref due to corrupted
  images (bnc#1151927 5.3.6).
- staging: erofs: avoid endless loop of invalid lookback distance
  0 (bnc#1151927 5.3.6).
- staging: erofs: add two missing erofs_workgroup_put for
  corrupted images (bnc#1151927 5.3.6).
- staging: erofs: some compressed cluster should be submitted
  for corrupted images (bnc#1151927 5.3.6).
- staging: erofs: fix an error handling in erofs_readdir()
  (bnc#1151927 5.3.6).
- KVM: s390: Test for bad access register and size at the start
  of S390_MEM_OP (bnc#1151927 5.3.6).
- PM / devfreq: tegra: Fix kHz to Hz conversion (bnc#1151927
  5.3.6).
- ASoC: sgtl5000: Improve VAG power and mute control (bnc#1151927
  5.3.6).
- ASoC: Define a set of DAPM pre/post-up events (bnc#1151927
  5.3.6).
- nbd: fix max number of supported devs (bnc#1151927 5.3.6).
- s390/sclp: Fix bit checked for has_sipl (bnc#1151927 5.3.6).
- s390/process: avoid potential reading of freed stack
  (bnc#1151927 5.3.6).
- tools lib traceevent: Do not free tep->cmdlines in
  add_new_comm() on failure (bnc#1151927 5.3.6).
- tools lib traceevent: Fix "robust" test of
  do_generate_dynamic_list_file (bnc#1151927 5.3.6).
- commit 09e8239
* Tue Oct 15 2019 vbabka@suse.cz
- mm, compaction: fix wrong pfn handling in
  __reset_isolation_pfn() (git-fixes (mm/compaction)).
- commit b7593ee
* Tue Oct 15 2019 jslaby@suse.cz
- Update
  patches.suse/0001-drm-msm-dsi-Fix-return-value-check-for-clk_get_paren.patch
  (bsc#1152472 bnc#1151927 5.3.6).
- Update
  patches.suse/0002-drm-mali-dp-Mark-expected-switch-fall-through.patch
  (bsc#1152472 bnc#1151927 5.3.6).
- Update
  patches.suse/0003-drm-i915-dp-Fix-dsc-bpp-calculations-v5.patch
  (bsc#1152472 bnc#1151927 5.3.6).
- Update
  patches.suse/0004-drm-amdgpu-Fix-KFD-related-kernel-oops-on-Hawaii.patch
  (bsc#1152472 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-Enable-XIVE-native-capability-only-if.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-HV-Check-for-MMU-ready-on-piggybacked.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-HV-Don-t-lose-pending-doorbell-reques.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-HV-Don-t-push-XIVE-context-when-not-u.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-HV-Fix-race-in-re-enabling-XIVE-escal.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/KVM-PPC-Book3S-HV-XIVE-Free-escalation-interrupts-be.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/PCI-Restore-Resizable-BAR-size-bits-correctly-for-1M.patch
  (bsc#1143841 bnc#1151927 5.3.6).
- Update
  patches.suse/PCI-vmd-Fix-config-addressing-when-using-bus-offsets.patch
  (git-fixes bnc#1151927 5.3.6).
- Update
  patches.suse/PCI-vmd-Fix-shadow-offsets-to-reflect-spec-changes.patch
  (git-fixes bnc#1151927 5.3.6).
- Update
  patches.suse/libnvdimm-altmap-track-namespace-boundaries-in-altmap.patch
  (bsc#1150305 bnc#1151927 5.3.6).
- Update
  patches.suse/msft-hv-1911-PCI-hv-Avoid-use-of-hv_pci_dev-pci_slot-after-freein.patch
  (bsc#1142701 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-book3s64-mm-Don-t-do-tlbie-fixup-for-some-ha.patch
  (bsc#1152161 ltc#181664 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-book3s64-radix-Rename-CPU_FTR_P9_TLBIE_BUG-f.patch
  (bsc#1152161 ltc#181664 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-mce-Fix-MCE-handling-for-huge-pages.patch
  (jsc#SLE-7730 jsc#SLE-8330 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-mce-Schedule-work-from-irq_work.patch
  (jsc#SLE-7730 jsc#SLE-8330 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-mm-Fixup-tlbie-vs-mtpidr-mtlpidr-ordering-is.patch
  (bsc#1152161 ltc#181664 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-powernv-Restrict-OPAL-symbol-map-to-only-be-.patch
  (bsc#1152885 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-powernv-ioda-Fix-race-in-TCE-level-allocatio.patch
  (bsc#1061840 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-pseries-Fix-cpu_hotplug_lock-acquisition-in-.patch
  (bsc#1065729 bnc#1151927 5.3.6).
- Update
  patches.suse/powerpc-xive-Implement-get_irqchip_state-method-for-.patch
  (bsc#1065729 bnc#1151927 5.3.6).
- commit e5cdb69
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: move local to extent inode logging into bmap helper
  (bsc#1153965).
- commit f0be3ee
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: remove broken error handling on failed attr sf to leaf
  change (bsc#1153964).
- commit 82cbfae
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: log the inode on directory sf to block format change
  (bsc#1153963).
- commit 09a957a
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: get allocation alignment from the buftarg (bsc#1153962).
- commit a48cb33
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: assure zeroed memory buffers for certain kmem allocations
  (bsc#1153957).
- commit 077c951
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: add kmem_alloc_io() (bsc#1153956).
- commit ef9a9c2
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: add kmem allocation trace points (bsc#1153955).
- commit 2ee9365
* Mon Oct 14 2019 ailiopoulos@suse.com
- fs: xfs: Remove KM_NOSLEEP and KM_SLEEP (bsc#1153954).
- commit 5c16078
* Mon Oct 14 2019 msuchanek@suse.de
- KVM: PPC: Book3S HV: use smp_mb() when setting/clearing host_ipi
  flag (bsc#1061840).
- commit 5c3f332
* Mon Oct 14 2019 msuchanek@suse.de
- net/ibmvnic: Fix EOI when running in XIVE mode (bsc#1089644,
  ltc#166495, ltc#165544, git-fixes).
- commit 7298d5a
* Mon Oct 14 2019 ailiopoulos@suse.com
- xfs: Fix tail rounding in xfs_alloc_file_space() (bsc#1153917).
- commit 9a4ea01
* Mon Oct 14 2019 mkubecek@suse.cz
- series.conf: refresh sorted section
  Update upstream reference:
  patches.suse/powerpc-pseries-Remove-confusing-warning-message.patch
- commit dcc4e8b
* Sat Oct 12 2019 msuchanek@suse.de
- Refresh patches.suse/powerpc-papr_scm-Fix-an-off-by-one-check-in-papr_scm.patch
- commit 2e48c74
* Fri Oct 11 2019 msuchanek@suse.de
- powerpc/pseries: Remove confusing warning message (bsc#1109158).
- commit 1ec9a94
* Thu Oct 10 2019 mkubecek@suse.cz
- supported.conf: sort
  No functional change, fix order only.
- commit 624292b
* Wed Oct  9 2019 jack@suse.cz
- patches.suse/jbd2-flush_descriptor-Do-not-decrease-buffer-head-s-ref-count.patch:
  Update tags.
- commit 7a9890d
* Wed Oct  9 2019 yousaf.kaukab@suse.com
- arm64: enable Nvidia Jetson TX2
  References: SLE-9388
- commit 4c4ee96
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/amd/display: support "dummy pstate" (bsc#1152472)
- commit f26d6de
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/i915: Trust programmed MCR in read_subslice_reg (bsc#1152472)
- commit ceae560
* Wed Oct  9 2019 jslaby@suse.cz
- net: stmmac: Avoid deadlock on suspend/resume (git-fixes).
- commit 9c4865d
* Wed Oct  9 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: hide another #warning'
- commit 57d5b16
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/amdgpu: revert "disable bulk moves for now" (bsc#1152472)
- commit 0df34be
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/amd/display: Embed DCN2 SOC bounding box (bsc#1152472)
- commit 095c537
* Wed Oct  9 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Allow sharing the idle-barrier from other kernel requests'
- commit fdee26c
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/i915: Fix g4x sprite scaling stride check with GTT remapping (bsc#1152472)
- commit 2cb06d6
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/i915/dp: Fix dsc bpp calculations, v5. (bsc#1152472)
- commit def17f6
* Wed Oct  9 2019 tzimmermann@suse.de
- drm/i915: Fix and improve MCR selection logic (bsc#1152472)
- commit f2d1229
* Wed Oct  9 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm: Fix kerneldoc warns in connector-related docs'
- commit a7d220e
* Wed Oct  9 2019 jslaby@suse.cz
- PCI: vmd: Fix shadow offsets to reflect spec changes
  (git-fixes).
- PCI: vmd: Fix config addressing when using bus offsets
  (git-fixes).
- commit d1eff9d
* Wed Oct  9 2019 jslaby@suse.cz
- Refresh
  patches.suse/PCI-Restore-Resizable-BAR-size-bits-correctly-for-1M.patch.
  Update upstream status and sort.
- commit 586dc90
* Wed Oct  9 2019 jslaby@suse.cz
- blacklist.conf: add 0df3e42167ca
- commit eb1317e
* Wed Oct  9 2019 mkubecek@suse.cz
- config: enable PCIE_BW also on armv7hl (jsc#SLE-9858)
  Refresh armv7hl configs.
- commit 23f34d5
* Wed Oct  9 2019 mkubecek@suse.cz
- config: refresh configs
- commit 26e5ee3
* Wed Oct  9 2019 mkubecek@suse.cz
- Fix references (v5.4-rc2 -> v5.4-rc3)
  patches.suse/0001-kernel-sysctl.c-do-not-override-max_threads-provided.patch.
- Update references and move into sorted section
  patches.suse/PCI-mobiveil-Fix-the-CPU-base-address-setup-in-inbou.patch.
  patches.suse/scsi-qla2xxx-Fix-Relogin-to-prevent-modifying-scan_s.patch.
- commit 6fdd32d
* Tue Oct  8 2019 hare@suse.de
- config: enable CONFIG_PCIE_BW (jsc#SLE-9858)
- commit 4f573d4
* Tue Oct  8 2019 jslaby@suse.cz
- blacklist.conf: add a91bcc2b6537
- commit 4ff0ba8
* Tue Oct  8 2019 jslaby@suse.cz
- Linux 5.3.5 (bnc#1151927 5.3.5).
- net: qlogic: Fix memory leak in ql_alloc_large_buffers
  (bnc#1151927 5.3.5).
- nfc: fix memory leak in llcp_sock_bind() (bnc#1151927 5.3.5).
- sch_dsmark: fix potential NULL deref in dsmark_init()
  (bnc#1151927 5.3.5).
- ipv6: Handle missing host route in __ipv6_ifa_notify
  (bnc#1151927 5.3.5).
- net: ipv4: avoid mixed n_redirects and rate_tokens usage
  (bnc#1151927 5.3.5).
- cxgb4:Fix out-of-bounds MSI-X info array access (bnc#1151927
  5.3.5).
- rxrpc: Fix rxrpc_recvmsg tracepoint (bnc#1151927 5.3.5).
- qmi_wwan: add support for Cinterion CLS8 devices (bnc#1151927
  5.3.5).
- udp: only do GSO if # of segs > 1 (bnc#1151927 5.3.5).
- udp: fix gso_segs calculations (bnc#1151927 5.3.5).
- ipv6: drop incoming packets having a v4mapped source address
  (bnc#1151927 5.3.5).
- ptp_qoriq: Initialize the registers' spinlock before calling
  ptp_qoriq_settime (bnc#1151927 5.3.5).
- net: dsa: sja1105: Fix sleeping while atomic in
  .port_hwtstamp_set (bnc#1151927 5.3.5).
- net: dsa: sja1105: Initialize the meta_lock (bnc#1151927 5.3.5).
- net/rds: Fix error handling in rds_ib_add_one() (bnc#1151927
  5.3.5).
- net: dsa: rtl8366: Check VLAN ID and not ports (bnc#1151927
  5.3.5).
- tipc: fix unlimited bundling of small messages (bnc#1151927
  5.3.5).
- xen-netfront: do not use ~0U as error return value for
  xennet_fill_frags() (bnc#1151927 5.3.5).
- tcp: adjust rto_base in retransmits_timed_out() (bnc#1151927
  5.3.5).
- vsock: Fix a lockdep warning in __vsock_release() (bnc#1151927
  5.3.5).
- hso: fix NULL-deref on tty open (bnc#1151927 5.3.5).
- net: sched: cbs: Avoid division by zero when calculating the
  port rate (bnc#1151927 5.3.5).
- net: sched: taprio: Avoid division by zero on invalid link speed
  (bnc#1151927 5.3.5).
- net: socionext: netsec: always grab descriptor lock (bnc#1151927
  5.3.5).
- net: sched: taprio: Fix potential integer overflow in
  taprio_set_picos_per_byte (bnc#1151927 5.3.5).
- net: dsa: sja1105: Prevent leaking memory (bnc#1151927 5.3.5).
- net: dsa: sja1105: Ensure PTP time for rxtstamp reconstruction
  is not in the past (bnc#1151927 5.3.5).
- net: Unpublish sk from sk_reuseport_cb before call_rcu
  (bnc#1151927 5.3.5).
- erspan: remove the incorrect mtu limit for erspan (bnc#1151927
  5.3.5).
- sch_cbq: validate TCA_CBQ_WRROPT to avoid crash (bnc#1151927
  5.3.5).
- 9p/cache.c: Fix memory leak in v9fs_cache_session_get_cookie
  (bnc#1151927 5.3.5).
- kexec: bail out upon SIGKILL when allocating memory (bnc#1151927
  5.3.5).
- i2c: tegra: Move suspend handling to NOIRQ phase (bnc#1151927
  5.3.5).
- i2c-cht-wc: Fix lockdep warning (bnc#1151927 5.3.5).
- pktcdvd: remove warning on attempting to register
  non-passthrough dev (bnc#1151927 5.3.5).
- block, bfq: push up injection only after setting service time
  (bnc#1151927 5.3.5).
- mips: properly account for stack randomization and stack guard
  gap (bnc#1151927 5.3.5).
- arm: use STACK_TOP when computing mmap base address (bnc#1151927
  5.3.5).
- arm: properly account for stack randomization and stack guard
  gap (bnc#1151927 5.3.5).
- arm64: consider stack randomization for mmap base only when
  necessary (bnc#1151927 5.3.5).
- kmemleak: increase DEBUG_KMEMLEAK_EARLY_LOG_SIZE default to 16K
  (bnc#1151927 5.3.5).
- ocfs2: wait for recovering done after direct unlock request
  (bnc#1151927 5.3.5).
- kbuild: clean compressed initramfs image (bnc#1151927 5.3.5).
- mm: add dummy can_do_mlock() helper (bnc#1151927 5.3.5).
- fat: work around race with userspace's read via blockdev while
  mounting (bnc#1151927 5.3.5).
- tools/power/x86/intel-speed-select: Fix high priority core
  mask over count (bnc#1151927 5.3.5).
- hypfs: Fix error number left in struct pointer member
  (bnc#1151927 5.3.5).
- mfd: intel-lpss: Remove D3cold delay (bnc#1151927 5.3.5).
- PCI: tegra: Fix OF node reference leak (bnc#1151927 5.3.5).
- PCI: histb: Propagate errors for optional regulators
  (bnc#1151927 5.3.5).
- PCI: imx6: Propagate errors for optional regulators (bnc#1151927
  5.3.5).
- PCI: exynos: Propagate errors for optional PHYs (bnc#1151927
  5.3.5).
- PCI: rockchip: Propagate errors for optional regulators
  (bnc#1151927 5.3.5).
- PCI: layerscape: Add the bar_fixed_64bit property to the
  endpoint driver (bnc#1151927 5.3.5).
- PCI: pci-hyperv: Fix build errors on non-SYSFS config
  (bnc#1151927 5.3.5).
- PCI: Use static const struct, not const static struct
  (bnc#1151927 5.3.5).
- PCI: Add pci_info_ratelimited() to ratelimit PCI separately
  (bnc#1151927 5.3.5).
- smack: use GFP_NOFS while holding inode_smack::smk_lock
  (bnc#1151927 5.3.5).
- security: smack: Fix possible null-pointer dereferences in
  smack_socket_sock_rcv_skb() (bnc#1151927 5.3.5).
- Smack: Don't ignore other bprm->unsafe flags if
  LSM_UNSAFE_PTRACE is set (bnc#1151927 5.3.5).
- HID: wacom: Fix several minor compiler warnings (bnc#1151927
  5.3.5).
- HID: apple: Fix stuck function keys when using FN (bnc#1151927
  5.3.5).
- selinux: fix residual uses of current_security() for the
  SELinux blob (bnc#1151927 5.3.5).
- crypto: hisilicon - Fix double free in sec_free_hw_sgl()
  (bnc#1151927 5.3.5).
- power: supply: register HWMON devices with valid names
  (bnc#1151927 5.3.5).
- rtc: pcf85363/pcf85263: fix regmap error in set_time
  (bnc#1151927 5.3.5).
- rtc: snvs: fix possible race condition (bnc#1151927 5.3.5).
- rtc: bd70528: fix driver dependencies (bnc#1151927 5.3.5).
- soundwire: intel: fix channel number reported by hardware
  (bnc#1151927 5.3.5).
- ARM: 8905/1: Emit __gnu_mcount_nc when using Clang 10.0.0 or
  newer (bnc#1151927 5.3.5).
- ARM: 8903/1: ensure that usable memory in bank 0 starts from
  a PMD-aligned address (bnc#1151927 5.3.5).
- ARM: 8898/1: mm: Don't treat faults reported from cache
  maintenance as writes (bnc#1151927 5.3.5).
- ARM: 8875/1: Kconfig: default to AEABI w/ Clang (bnc#1151927
  5.3.5).
- mips/atomic: Fix smp_mb__{before,after}_atomic() (bnc#1151927
  5.3.5).
- mips/atomic: Fix loongson_llsc_mb() wreckage (bnc#1151927
  5.3.5).
- MIPS: tlbex: Explicitly cast _PAGE_NO_EXEC to a boolean
  (bnc#1151927 5.3.5).
- MIPS: Don't use bc_false uninitialized in __mm_isBranchInstr
  (bnc#1151927 5.3.5).
- MIPS: Ingenic: Disable broken BTB lookup optimization
  (bnc#1151927 5.3.5).
- f2fs: fix to drop meta/node pages during umount (bnc#1151927
  5.3.5).
- ext4: fix potential use after free after remounting with
  noblock_validity (bnc#1151927 5.3.5).
- scsi: core: Reduce memory required for SCSI logging (bnc#1151927
  5.3.5).
- dm raid: fix updating of max_discard_sectors limit (bnc#1151927
  5.3.5).
- dm zoned: fix invalid memory access (bnc#1151927 5.3.5).
- ARM: dts: dir685: Drop spi-cpol from the display (bnc#1151927
  5.3.5).
- clk: sprd: add missing kfree (bnc#1151927 5.3.5).
- clk: at91: select parent if main oscillator or bypass is enabled
  (bnc#1151927 5.3.5).
- clk: Make clk_bulk_get_all() return a valid "id" (bnc#1151927
  5.3.5).
- clk: renesas: cpg-mssr: Set GENPD_FLAG_ALWAYS_ON for clock
  domain (bnc#1151927 5.3.5).
- clk: renesas: mstp: Set GENPD_FLAG_ALWAYS_ON for clock domain
  (bnc#1151927 5.3.5).
- clk: sunxi-ng: v3s: add missing clock slices for MMC2 module
  clocks (bnc#1151927 5.3.5).
- clk: imx: clk-pll14xx: unbypass PLL by default (bnc#1151927
  5.3.5).
- clk: imx: pll14xx: avoid glitch when set rate (bnc#1151927
  5.3.5).
- clk: imx8mq: Mark AHB clock as critical (bnc#1151927 5.3.5).
- clk: sunxi: Don't call clk_hw_get_name() on a hw that isn't
  registered (bnc#1151927 5.3.5).
- clk: zx296718: Don't reference clk_init_data after registration
  (bnc#1151927 5.3.5).
- clk: sprd: Don't reference clk_init_data after registration
  (bnc#1151927 5.3.5).
- clk: sirf: Don't reference clk_init_data after registration
  (bnc#1151927 5.3.5).
- clk: meson: axg-audio: Don't reference clk_init_data after
  registration (bnc#1151927 5.3.5).
- clk: actions: Don't reference clk_init_data after registration
  (bnc#1151927 5.3.5).
- clk: ingenic/jz4740: Fix "pll half" divider not read/written
  properly (bnc#1151927 5.3.5).
- clk: qcom: gcc-sdm845: Use floor ops for sdcc clks (bnc#1151927
  5.3.5).
- clk: qoriq: Fix -Wunused-const-variable (bnc#1151927 5.3.5).
- vfio_pci: Restore original state on release (bnc#1151927 5.3.5).
- powerpc/eeh: Clean up EEH PEs after recovery finishes
  (bnc#1151927 5.3.5).
- selftests/powerpc: Retry on host facility unavailable
  (bnc#1151927 5.3.5).
- powerpc/eeh: Clear stale EEH_DEV_NO_HANDLER flag (bnc#1151927
  5.3.5).
- powerpc/perf: fix imc allocation failure handling (bnc#1151927
  5.3.5).
- powerpc/futex: Fix warning: 'oldval' may be used uninitialized
  in this function (bnc#1151927 5.3.5).
- powerpc/ptdump: fix walk_pagetables() address mismatch
  (bnc#1151927 5.3.5).
- PCI: rpaphp: Avoid a sometimes-uninitialized warning
  (bnc#1151927 5.3.5).
- arm64: fix unreachable code issue with cmpxchg (bnc#1151927
  5.3.5).
- kbuild: Do not enable -Wimplicit-fallthrough for clang for now
  (bnc#1151927 5.3.5).
- drm/amdgpu/si: fix ASIC tests (bnc#1151927 5.3.5).
- drm/amd/display: fix trigger not generated for freesync
  (bnc#1151927 5.3.5).
- drm/amd/display: support spdif (bnc#1151927 5.3.5).
- drm/amd/display: fix MPO HUBP underflow with Scatter Gather
  (bnc#1151927 5.3.5).
- drm/amd/powerpaly: fix navi series custom peak level value error
  (bnc#1151927 5.3.5).
- drm/amdgpu/sdma5: fix number of sdma5 trap irq types for navi1x
  (bnc#1151927 5.3.5).
- drm/amd/display: Register VUPDATE_NO_LOCK interrupts for DCN2
  (bnc#1151927 5.3.5).
- drm/amd/display: reprogram VM config when system resume
  (bnc#1151927 5.3.5).
- drm/amd/display: Fix frames_to_insert math (bnc#1151927 5.3.5).
- drm/amd/display: fix issue where 252-255 values are clipped
  (bnc#1151927 5.3.5).
- drm/nouveau/volt: Fix for some cards having 0 maximum voltage
  (bnc#1151927 5.3.5).
- drm/nouveau/kms/tu102-: disable input lut when input is already
  FP16 (bnc#1151927 5.3.5).
- dma-buf/sw_sync: Synchronize signal vs syncpt free (bnc#1151927
  5.3.5).
- gpu: drm: radeon: Fix a possible null-pointer dereference in
  radeon_connector_set_property() (bnc#1151927 5.3.5).
- drm/radeon: Fix EEH during kexec (bnc#1151927 5.3.5).
- drm/amdgpu: Fix hard hang for S/G display BOs (bnc#1151927
  5.3.5).
- drm/amd/display: Copy GSL groups when committing a new context
  (bnc#1151927 5.3.5).
- drm/amd/display: Clear FEC_READY shadow register if DPCD write
  fails (bnc#1151927 5.3.5).
- drm/amd/display: fix not calling ppsmu to trigger PME
  (bnc#1151927 5.3.5).
- drm/amd/display: Power-gate all DSCs at driver init time
  (bnc#1151927 5.3.5).
- drm/amd/display: add monitor patch to add T7 delay (bnc#1151927
  5.3.5).
- drm/rockchip: Check for fast link training before enabling psr
  (bnc#1151927 5.3.5).
- drm/panel: check failure cases in the probe func (bnc#1151927
  5.3.5).
- drm/stm: attach gem fence to atomic state (bnc#1151927 5.3.5).
- drm/tinydrm/Kconfig: drivers: Select BACKLIGHT_CLASS_DEVICE
  (bnc#1151927 5.3.5).
- drm/panel: simple: fix AUO g185han01 horizontal blanking
  (bnc#1151927 5.3.5).
- drm/vkms: Avoid assigning 0 for possible_crtc (bnc#1151927
  5.3.5).
- drm/bridge: tc358767: Increase AUX transfer length limit
  (bnc#1151927 5.3.5).
- drm/vkms: Fix crc worker races (bnc#1151927 5.3.5).
- drm/mcde: Fix uninitialized variable (bnc#1151927 5.3.5).
- pinctrl: meson-gxbb: Fix wrong pinning definition for uart_c
  (bnc#1151927 5.3.5).
- pinctrl: amd: disable spurious-firing GPIO IRQs (bnc#1151927
  5.3.5).
- pinctrl: tegra: Fix write barrier placement in pmx_writel
  (bnc#1151927 5.3.5).
- pinctrl: stmfx: update pinconf settings (bnc#1151927 5.3.5).
- ipmi_si: Only schedule continuously in the thread in maintenance
  mode (bnc#1151927 5.3.5).
- mbox: qcom: add APCS child device for QCS404 (bnc#1151927
  5.3.5).
- mailbox: mediatek: cmdq: clear the event in cmdq initial flow
  (bnc#1151927 5.3.5).
- pstore: fs superblock limits (bnc#1151927 5.3.5).
- vfs: set fs_context::user_ns for reconfigure (bnc#1151927
  5.3.5).
- NFC: fix attrs checks in netlink interface (bnc#1151927 5.3.5).
- commit 3f4d1b8
* Tue Oct  8 2019 jslaby@suse.cz
- Update
  patches.suse/0001-video-ssd1307fb-Start-page-range-at-page_offset.patch
  (bsc#1152472 bnc#1151927 5.3.5).
- Update
  patches.suse/0003-drm-amd-display-Use-proper-enum-conversion-functions.patch
  (bsc#1152472 bnc#1151927 5.3.5).
- Update
  patches.suse/0005-drm-bridge-sii902x-fix-missing-reference-to-mclk-clo.patch
  (bsc#1152472 bnc#1151927 5.3.5).
- Update
  patches.suse/PCI-mobiveil-Fix-the-CPU-base-address-setup-in-inbou.patch
  (fate#326572 bnc#1151927 5.3.5).
- Update
  patches.suse/livepatch-nullify-obj-mod-in-klp_module_coming-s-error-path.patch
  (bsc#1071995 fate#323487 bnc#1151927 5.3.5).
- Update
  patches.suse/msft-hv-1950-KVM-hyperv-Fix-Direct-Synthetic-timers-assert-an-int.patch
  (fate#323887 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-64s-exception-machine-check-use-correct-cfar.patch
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-64s-radix-Fix-memory-hotplug-section-page-ta.patch
  (bsc#1065729 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-dump-kernel-log-before-carrying-out-fadump-o.patch
  (bsc#1149940 ltc#179958 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-powernv-ioda2-Allocate-TCE-table-levels-on-d.patch
  (bsc#1061840 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-pseries-correctly-track-irq-state-in-default.patch
  (bsc#1150727 ltc#178925 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-pseries-mobility-use-cond_resched-when-updat.patch
  (bsc#1153112 ltc#181778 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-rtas-use-device-model-APIs-and-serialization.patch
  (bsc#1144123 ltc#178840 bnc#1151927 5.3.5).
- Update
  patches.suse/powerpc-xmon-Check-for-HV-mode-when-dumping-XIVE-inf.patch
  (bsc#1142019 bnc#1151927 5.3.5).
- commit 37e2aaf
* Tue Oct  8 2019 jslaby@suse.cz
- Update
  patches.suse/0001-btrfs-Fix-a-regression-which-we-can-t-convert-to-SIN.patch
  (bsc#1152973 bnc#1151927 5.3.4).
- Update
  patches.suse/0001-btrfs-qgroup-Fix-the-wrong-target-io_tree-when-freei.patch
  (bsc#1152974 bnc#1151927 5.3.4).
- Update
  patches.suse/0001-ipmi-move-message-error-checking-to-avoid-deadlock.patch
  (bsc#1152489 bnc#1151927 5.3.4).
- Update
  patches.suse/0002-btrfs-qgroup-Fix-reserved-data-space-leak-if-we-have.patch
  (bsc#1152975 bnc#1151927 5.3.4).
- Update
  patches.suse/0002-drm-fix-module-name-in-edid_firmware-log-message.patch
  (bsc#1152472 bnc#1151927 5.3.4).
- Update
  patches.suse/alarmtimer-Use-EOPNOTSUPP-instead-of-ENOTSUPP.patch
  (bsc#1151680 bnc#1151927 5.3.4).
- Update
  patches.suse/edac-amd64-decode-syndrome-before-translating-address.patch
  (bsc#1152489 bnc#1151927 5.3.4).
- Update
  patches.suse/edac-amd64-recognize-dram-device-type-ecc-capability.patch
  (bsc#1152489 bnc#1151927 5.3.4).
- Update
  patches.suse/hwmon-k10temp-Add-support-for-AMD-family-17h-model-7.patch
  (bsc#1153137 bnc#1151927 5.3.4).
- Update
  patches.suse/iommu-iova-avoid-false-sharing-on-fq_timer_on
  (bsc#1151675 bnc#1151927 5.3.4).
- Update
  patches.suse/iommu-vt-d-fix-wrong-analysis-whether-devices-share-the-same-bus
  (bsc#1151679 bnc#1151927 5.3.4).
- Update
  patches.suse/scsi-qla2xxx-Fix-Relogin-to-prevent-modifying-scan_s.patch
  (bsc#1082635 bsc#1141340 bsc#1143706 bnc#1151927 5.3.4).
- Update
  patches.suse/scsi-scsi_dh_rdac-zero-cdb-in-send_mode_select.patch
  (bsc#1149313 bnc#1151927 5.3.4).
- Update
  patches.suse/tpm_tis_core-Set-TPM_CHIP_FLAG_IRQ-before-probing-fo.patch
  (bsc#1082555 bnc#1151927 5.3.4).
- Update
  patches.suse/x86-amd_nb-Add-PCI-device-IDs-for-family-17h-model-7.patch
  (bsc#1153137 bnc#1151927 5.3.4).
- commit 78212b5
* Tue Oct  8 2019 jslaby@suse.cz
- Linux 5.3.4 (bnc#1151927 5.3.4).
- Btrfs: fix race setting up and completing qgroup rescan workers
  (bnc#1151927 5.3.4).
- btrfs: adjust dirty_metadata_bytes after writeback failure of
  extent buffer (bnc#1151927 5.3.4).
- ARM: dts: am3517-evm: Fix missing video (bnc#1151927 5.3.4).
- ARM: dts: logicpd-torpedo-baseboard: Fix missing video
  (bnc#1151927 5.3.4).
- ARM: omap2plus_defconfig: Fix missing video (bnc#1151927 5.3.4).
- CIFS: Fix oplock handling for SMB 2.1+ protocols (bnc#1151927
  5.3.4).
- CIFS: fix max ea value size (bnc#1151927 5.3.4).
- smb3: fix leak in "open on server" perf counter (bnc#1151927
  5.3.4).
- i2c: riic: Clear NACK in tend isr (bnc#1151927 5.3.4).
- tcp: better handle TCP_USER_TIMEOUT in SYN_SENT state
  (bnc#1151927 5.3.4).
- tcp_bbr: fix quantization code to not raise cwnd if not probing
  bandwidth (bnc#1151927 5.3.4).
- net: phy: micrel: add Asym Pause workaround for KSZ9021
  (bnc#1151927 5.3.4).
- nfp: flower: fix memory leak in nfp_flower_spawn_vnic_reprs
  (bnc#1151927 5.3.4).
- nfp: flower: prevent memory leak in nfp_flower_spawn_phy_reprs
  (bnc#1151927 5.3.4).
- vrf: Do not attempt to create IPv6 mcast rule if IPv6 is
  disabled (bnc#1151927 5.3.4).
- net/rds: Check laddr_check before calling it (bnc#1151927
  5.3.4).
- iwlwifi: fw: don't send GEO_TX_POWER_LIMIT command to FW
  version 36 (bnc#1151927 5.3.4).
- mt76: mt7615: fix mt7615 firmware path definitions (bnc#1151927
  5.3.4).
- ipv6: do not free rt if FIB_LOOKUP_NOREF is set on suppress rule
  (bnc#1151927 5.3.4).
- openvswitch: change type of UPCALL_PID attribute to NLA_UNSPEC
  (bnc#1151927 5.3.4).
- net: stmmac: Fix page pool size (bnc#1151927 5.3.4).
- macsec: drop skb sk before calling gro_cells_receive
  (bnc#1151927 5.3.4).
- net/mlx5e: Fix matching on tunnel addresses type (bnc#1151927
  5.3.4).
- net/mlx5e: Fix traffic duplication in ethtool steering
  (bnc#1151927 5.3.4).
- net/mlx5: Add device ID of upcoming BlueField-2 (bnc#1151927
  5.3.4).
- net/sched: cbs: Fix not adding cbs instance to list (bnc#1151927
  5.3.4).
- ppp: Fix memory leak in ppp_write (bnc#1151927 5.3.4).
- skge: fix checksum byte order (bnc#1151927 5.3.4).
- arcnet: provide a buffer big enough to actually receive packets
  (bnc#1151927 5.3.4).
- nfc: enforce CAP_NET_RAW for raw sockets (bnc#1151927 5.3.4).
- ieee802154: enforce CAP_NET_RAW for raw sockets (bnc#1151927
  5.3.4).
- ax25: enforce CAP_NET_RAW for raw sockets (bnc#1151927 5.3.4).
- appletalk: enforce CAP_NET_RAW for raw sockets (bnc#1151927
  5.3.4).
- mISDN: enforce CAP_NET_RAW for raw sockets (bnc#1151927 5.3.4).
- net: sched: fix possible crash in tcf_action_destroy()
  (bnc#1151927 5.3.4).
- net_sched: add policy validation for action attributes
  (bnc#1151927 5.3.4).
- net_sched: add max len check for TCA_KIND (bnc#1151927 5.3.4).
- net: qrtr: Stop rx_worker before freeing node (bnc#1151927
  5.3.4).
- net/phy: fix DP83865 10 Mbps HDX loopback disable function
  (bnc#1151927 5.3.4).
- usbnet: ignore endpoints with invalid wMaxPacketSize
  (bnc#1151927 5.3.4).
- cdc_ncm: fix divide-by-zero caused by invalid wMaxPacketSize
  (bnc#1151927 5.3.4).
- ipv6: fix a typo in fib6_rule_lookup() (bnc#1151927 5.3.4).
- sch_netem: fix a divide by zero in tabledist() (bnc#1151927
  5.3.4).
- ipv4: Revert removal of rt_uses_gateway (bnc#1151927 5.3.4).
- selftests: Update fib_nexthop_multiprefix to handle missing
  ping6 (bnc#1151927 5.3.4).
- selftests: Update fib_tests to handle missing ping6 (bnc#1151927
  5.3.4).
- net/sched: act_sample: don't push mac header on ip6gre ingress
  (bnc#1151927 5.3.4).
- usbnet: sanity checking of packet sizes and device mtu
  (bnc#1151927 5.3.4).
- kvm: x86: Add "significant index" flag to a few CPUID leaves
  (bnc#1151927 5.3.4).
- KVM: x86/mmu: Use fast invalidate mechanism to zap MMIO sptes
  (bnc#1151927 5.3.4).
- block: fix null pointer dereference in blk_mq_rq_timed_out()
  (bnc#1151927 5.3.4).
- drm/amdgpu/display: fix 64 bit divide (bnc#1151927 5.3.4).
- drm/amd/display: Restore backlight brightness after system
  resume (bnc#1151927 5.3.4).
- drm/amd/display: Add missing HBM support and raise Vega20's uclk
  (bnc#1151927 5.3.4).
- drm/amd/display: dce11.x /dce12 update formula input
  (bnc#1151927 5.3.4).
- SUNRPC: Fix buffer handling of GSS MIC without slack
  (bnc#1151927 5.3.4).
- SUNRPC: Dequeue the request from the receive queue while we're
  re-encoding (bnc#1151927 5.3.4).
- binfmt_elf: Do not move brk for INTERP-less ET_EXEC (bnc#1151927
  5.3.4).
- lib/lzo/lzo1x_compress.c: fix alignment bug in lzo-rle
  (bnc#1151927 5.3.4).
- memcg, kmem: do not fail __GFP_NOFAIL charges (bnc#1151927
  5.3.4).
- fuse: fix beyond-end-of-page access in fuse_parse_cache()
  (bnc#1151927 5.3.4).
- fuse: fix missing unlock_page in fuse_writepage() (bnc#1151927
  5.3.4).
- fuse: fix deadlock with aio poll and fuse_iqueue::waitq.lock
  (bnc#1151927 5.3.4).
- tpm: Wrap the buffer from the caller to tpm_buf in tpm_send()
  (bnc#1151927 5.3.4).
- KEYS: trusted: correctly initialize digests and fix locking
  issue (bnc#1151927 5.3.4).
- ALSA: hda/realtek - PCI quirk for Medion E4254 (bnc#1151927
  5.3.4).
- memcg, oom: don't require __GFP_FS when invoking memcg OOM
  killer (bnc#1151927 5.3.4).
- mm/compaction.c: clear total_{migrate,free}_scanned before
  scanning a new zone (bnc#1151927 5.3.4).
- z3fold: fix memory leak in kmem cache (bnc#1151927 5.3.4).
- z3fold: fix retry mechanism in page reclaim (bnc#1151927 5.3.4).
- hwrng: core - don't wait on add_early_randomness() (bnc#1151927
  5.3.4).
- gfs2: clear buf_in_tr when ending a transaction in
  sweep_bh_for_rgrps (bnc#1151927 5.3.4).
- quota: fix wrong condition in is_quota_modification()
  (bnc#1151927 5.3.4).
- ext4: fix punch hole for inline_data file systems (bnc#1151927
  5.3.4).
- ext4: fix warning inside ext4_convert_unwritten_extents_endio
  (bnc#1151927 5.3.4).
- mtd: rawnand: stm32_fmc2: avoid warnings when building with
  W=1 option (bnc#1151927 5.3.4).
- RDMA: Fix double-free in srq creation error flow (bnc#1151927
  5.3.4).
- IB/mlx5: Free mpi in mp_slave mode (bnc#1151927 5.3.4).
- IB/hfi1: Define variables as unsigned long to fix KASAN warning
  (bnc#1151927 5.3.4).
- IB/hfi1: Do not update hcrc for a KDETH packet during fault
  injection (bnc#1151927 5.3.4).
- randstruct: Check member structs in is_pure_ops_struct()
  (bnc#1151927 5.3.4).
- printk: Do not lose last line in kmsg buffer dump (bnc#1151927
  5.3.4).
- ARM: samsung: Fix system restart on S3C6410 (bnc#1151927 5.3.4).
- powerpc/imc: Dont create debugfs files for cpu-less nodes
  (bnc#1151927 5.3.4).
- drm/amd/powerplay/smu7: enforce minimal VBITimeout (v2)
  (bnc#1151927 5.3.4).
- efifb: BGRT: Improve efifb_bgrt_sanity_check (bnc#1151927
  5.3.4).
- platform/chrome: cros_ec_rpmsg: Fix race with host command
  when probe failed (bnc#1151927 5.3.4).
- smb3: fix unmount hang in open_shroot (bnc#1151927 5.3.4).
- smb3: allow disabling requesting leases (bnc#1151927 5.3.4).
- xfs: Fix stale data exposure when readahead races with hole
  punch (bnc#1151927 5.3.4).
- fs: Export generic_fadvise() (bnc#1151927 5.3.4).
- mm: Handle MADV_WILLNEED through vfs_fadvise() (bnc#1151927
  5.3.4).
- ovl: filter of trusted xattr results in audit (bnc#1151927
  5.3.4).
- ovl: Fix dereferencing possible ERR_PTR() (bnc#1151927 5.3.4).
- btrfs: Relinquish CPUs in btrfs_compare_trees (bnc#1151927
  5.3.4).
- btrfs: fix allocation of free space cache v1 bitmap pages
  (bnc#1151927 5.3.4).
- btrfs: Detect unbalanced tree with empty leaf before crashing
  btree operations (bnc#1151927 5.3.4).
- Btrfs: fix use-after-free when using the tree modification log
  (bnc#1151927 5.3.4).
- btrfs: tree-checker: Add ROOT_ITEM check (bnc#1151927 5.3.4).
- btrfs: extent-tree: Make sure we only allocate extents from
  block groups with the same type (bnc#1151927 5.3.4).
- btrfs: delayed-inode: Kill the BUG_ON() in
  btrfs_delete_delayed_dir_index() (bnc#1151927 5.3.4).
- ath10k: fix channel info parsing for non tlv target (bnc#1151927
  5.3.4).
- i40e: check __I40E_VF_DISABLE bit in i40e_sync_filters_subtask
  (bnc#1151927 5.3.4).
- cfg80211: Purge frame registrations on iftype change
  (bnc#1151927 5.3.4).
- mt76: mt7615: always release sem in mt7615_load_patch
  (bnc#1151927 5.3.4).
- mt76: round up length on mt76_wr_copy (bnc#1151927 5.3.4).
- zd1211rw: remove false assertion from zd_mac_clear()
  (bnc#1151927 5.3.4).
- rtw88: pci: Use DMA sync instead of remapping in RX ISR
  (bnc#1151927 5.3.4).
- rtw88: pci: Rearrange the memory usage for skb in RX ISR
  (bnc#1151927 5.3.4).
- libertas: Add missing sentinel at end of if_usb.c fw_table
  (bnc#1151927 5.3.4).
- e1000e: add workaround for possible stalled packet (bnc#1151927
  5.3.4).
- /dev/mem: Bail out upon SIGKILL (bnc#1151927 5.3.4).
- staging: erofs: cannot set EROFS_V_Z_INITED_BIT if
  fill_inode_lazy fails (bnc#1151927 5.3.4).
- kvm: Nested KVM MMUs need PAE root too (bnc#1151927 5.3.4).
- KVM: x86: set ctxt->have_exception in x86_decode_insn()
  (bnc#1151927 5.3.4).
- KVM: x86: always stop emulation on page fault (bnc#1151927
  5.3.4).
- KVM: x86: Manually calculate reserved bits when loading PDPTRS
  (bnc#1151927 5.3.4).
- KVM: x86: Disable posted interrupts for non-standard IRQs
  delivery modes (bnc#1151927 5.3.4).
- ACPI / LPSS: Save/restore LPSS private registers also on
  Lynxpoint (bnc#1151927 5.3.4).
- ACPI / PCI: fix acpi_pci_irq_enable() memory leak (bnc#1151927
  5.3.4).
- ACPI: custom_method: fix memory leaks (bnc#1151927 5.3.4).
- ACPI / processor: don't print errors for processorIDs == 0xff
  (bnc#1151927 5.3.4).
- ACPI / APEI: Release resources if gen_pool_add() fails
  (bnc#1151927 5.3.4).
- ACPI / CPPC: do not require the _PSD method (bnc#1151927 5.3.4).
- PM / devfreq: passive: fix compiler warning (bnc#1151927 5.3.4).
- PM / devfreq: passive: Use non-devm notifiers (bnc#1151927
  5.3.4).
- PM / devfreq: exynos-bus: Correct clock enable sequence
  (bnc#1151927 5.3.4).
- PM / devfreq: Fix kernel oops on governor module load
  (bnc#1151927 5.3.4).
- cpufreq: imx-cpufreq-dt: Add i.MX8MN support (bnc#1151927
  5.3.4).
- cpufreq: ap806: Add NULL check after kcalloc (bnc#1151927
  5.3.4).
- sched/cpufreq: Align trace event behavior of fast switching
  (bnc#1151927 5.3.4).
- cpuidle: teo: Allow tick to be stopped if PM QoS is used
  (bnc#1151927 5.3.4).
- dmaengine: ti: edma: Do not reset reserved paRAM slots
  (bnc#1151927 5.3.4).
- dmaengine: bcm2835: Print error in case setting DMA mask fails
  (bnc#1151927 5.3.4).
- leds: lm3532: Fixes for the driver for stability (bnc#1151927
  5.3.4).
- led: triggers: Fix a memory leak bug (bnc#1151927 5.3.4).
- leds: leds-lp5562 allow firmware files up to the maximum length
  (bnc#1151927 5.3.4).
- media: videobuf-core.c: poll_wait needs a non-NULL buf pointer
  (bnc#1151927 5.3.4).
- media: ov9650: add a sanity check (bnc#1151927 5.3.4).
- media: aspeed-video: address a protential usage of an
  unitialized var (bnc#1151927 5.3.4).
- media: saa7134: fix terminology around
  saa7134_i2c_eeprom_md7134_gate() (bnc#1151927 5.3.4).
- media: sn9c20x: Add MSI MS-1039 laptop to flip_dmi_table
  (bnc#1151927 5.3.4).
- media: saa7146: add cleanup in hexium_attach() (bnc#1151927
  5.3.4).
- media: cpia2_usb: fix memory leaks (bnc#1151927 5.3.4).
- media: cec-notifier: clear cec_adap in cec_notifier_unregister
  (bnc#1151927 5.3.4).
- media: ttusb-dec: Fix info-leak in ttusb_dec_send_command()
  (bnc#1151927 5.3.4).
- media: dvb-core: fix a memory leak bug (bnc#1151927 5.3.4).
- media: mceusb: fix (eliminate) TX IR signal length limit
  (bnc#1151927 5.3.4).
- media: dvb-frontends: use ida for pll number (bnc#1151927
  5.3.4).
- media: gspca: zero usb_buf on error (bnc#1151927 5.3.4).
- media: hdpvr: add terminating 0 at end of string (bnc#1151927
  5.3.4).
- media: radio/si470x: kill urb on error (bnc#1151927 5.3.4).
- media: imx: mipi csi-2: Don't fail if initial state times-out
  (bnc#1151927 5.3.4).
- media: i2c: ov5645: Fix power sequence (bnc#1151927 5.3.4).
- media: omap3isp: Don't set streaming state on random subdevs
  (bnc#1151927 5.3.4).
- media: omap3isp: Set device on omap3isp subdevs (bnc#1151927
  5.3.4).
- media: vsp1: fix memory leak of dl on error return path
  (bnc#1151927 5.3.4).
- media: rc: imon: Allow iMON RC protocol for ffdc 7e device
  (bnc#1151927 5.3.4).
- media: em28xx: modules workqueue not inited for 2nd device
  (bnc#1151927 5.3.4).
- media: fdp1: Reduce FCP not found message level to debug
  (bnc#1151927 5.3.4).
- media: i2c: tda1997x: prevent potential NULL pointer access
  (bnc#1151927 5.3.4).
- media: mtk-mdp: fix reference count on old device tree
  (bnc#1151927 5.3.4).
- media: media/platform: fsl-viu.c: fix build for MICROBLAZE
  (bnc#1151927 5.3.4).
- media: staging: tegra-vde: Fix build error (bnc#1151927 5.3.4).
- media: iguanair: add sanity checks (bnc#1151927 5.3.4).
- media: don't drop front-end reference count for ->detach
  (bnc#1151927 5.3.4).
- media: hantro: Set DMA max segment size (bnc#1151927 5.3.4).
- media: i2c: ov5640: Check for devm_gpiod_get_optional() error
  (bnc#1151927 5.3.4).
- media: vivid: fix device init when no_error_inj=1 and fb
  disabled (bnc#1151927 5.3.4).
- media: hdpvr: Add device num check and handling (bnc#1151927
  5.3.4).
- media: exynos4-is: fix leaked of_node references (bnc#1151927
  5.3.4).
- media: vivid: work around high stack usage with clang
  (bnc#1151927 5.3.4).
- media: vivid:add sanity check to avoid divide error and set
  value to 1 if 0 (bnc#1151927 5.3.4).
- media: vb2: reorder checks in vb2_poll() (bnc#1151927 5.3.4).
- media: dib0700: fix link error for dibx000_i2c_set_speed
  (bnc#1151927 5.3.4).
- media: mtk-cir: lower de-glitch counter for rc-mm protocol
  (bnc#1151927 5.3.4).
- ASoC: dt-bindings: sun4i-spdif: Fix dma-names warning
  (bnc#1151927 5.3.4).
- ASoC: Intel: Haswell: Adjust machine device private context
  (bnc#1151927 5.3.4).
- ASoC: sun4i-i2s: Don't use the oversample to calculate BCLK
  (bnc#1151927 5.3.4).
- ASoC: SOF: reset DMA state in prepare (bnc#1151927 5.3.4).
- ASoC: SOF: pci: mark last_busy value at runtime PM init
  (bnc#1151927 5.3.4).
- ASoC: sgtl5000: Fix charge pump source assignment (bnc#1151927
  5.3.4).
- ASoC: sgtl5000: Fix of unmute outputs on probe (bnc#1151927
  5.3.4).
- ASoC: tlv320aic31xx: suppress error message for EPROBE_DEFER
  (bnc#1151927 5.3.4).
- ASoC: SOF: Intel: hda: Make hdac_device device-managed
  (bnc#1151927 5.3.4).
- ASoC: dmaengine: Make the pcm->name equal to pcm->id if the
  name is not set (bnc#1151927 5.3.4).
- ASoC: fsl_ssi: Fix clock control issue in master mode
  (bnc#1151927 5.3.4).
- ASoC: es8316: fix headphone mixer volume table (bnc#1151927
  5.3.4).
- ASoC: Intel: NHLT: Fix debug print format (bnc#1151927 5.3.4).
- ASoC: Intel: Fix use of potentially uninitialized variable
  (bnc#1151927 5.3.4).
- ASoC: Intel: Skylake: Use correct function to access iomem space
  (bnc#1151927 5.3.4).
- ASoC: mchp-i2s-mcc: Wait for RX/TX RDY only if controller is
  running (bnc#1151927 5.3.4).
- ASoC: mchp-i2s-mcc: Fix unprepare of GCLK (bnc#1151927 5.3.4).
- ASoC: uniphier: Fix double reset assersion when transitioning
  to suspend state (bnc#1151927 5.3.4).
- ASoC: hdac_hda: fix page fault issue by removing race
  (bnc#1151927 5.3.4).
- ASoC: rsnd: don't call clk_get_rate() under atomic context
  (bnc#1151927 5.3.4).
- ALSA: firewire-motu: add support for MOTU 4pre (bnc#1151927
  5.3.4).
- ALSA: hda/realtek - Blacklist PC beep for Lenovo ThinkCentre
  M73/93 (bnc#1151927 5.3.4).
- ALSA: hda - Drop unsol event handler for Intel HDMI codecs
  (bnc#1151927 5.3.4).
- ALSA: hda - Add a quirk model for fixing Huawei Matebook X
  right speaker (bnc#1151927 5.3.4).
- ALSA: usb-audio: Skip bSynchAddress endpoint check if it is
  invalid (bnc#1151927 5.3.4).
- ALSA: i2c: ak4xxx-adda: Fix a possible null pointer dereference
  in build_adc_controls() (bnc#1151927 5.3.4).
- ALSA: hda - Show the fatal CORB/RIRB error more clearly
  (bnc#1151927 5.3.4).
- ALSA: hda/hdmi - Don't report spurious jack state changes
  (bnc#1151927 5.3.4).
- ALSA: hda: Flush interrupts on disabling (bnc#1151927 5.3.4).
- ALSA: firewire-tascam: check intermediate state of clock status
  and retry (bnc#1151927 5.3.4).
- ALSA: firewire-tascam: handle error code when getting current
  source of clock (bnc#1151927 5.3.4).
- mmc: core: Clarify sdio_irq_pending flag for
  MMC_CAP2_SDIO_IRQ_NOTHREAD (bnc#1151927 5.3.4).
- mmc: mtk-sd: Re-store SDIO IRQs mask at system resume
  (bnc#1151927 5.3.4).
- mmc: dw_mmc: Re-store SDIO IRQs mask at system resume
  (bnc#1151927 5.3.4).
- mmc: core: Add helper function to indicate if SDIO IRQs is
  enabled (bnc#1151927 5.3.4).
- mmc: sdhci: Fix incorrect switch to HS mode (bnc#1151927 5.3.4).
- block: make rq sector size accessible for block stats
  (bnc#1151927 5.3.4).
- md/raid0: avoid RAID0 data corruption due to layout confusion
  (bnc#1151927 5.3.4).
- raid5: don't set STRIPE_HANDLE to stripe which is in batch list
  (bnc#1151927 5.3.4).
- raid5: don't increment read_errors on EILSEQ return (bnc#1151927
  5.3.4).
- md/raid1: fail run raid1 array when active disk less than one
  (bnc#1151927 5.3.4).
- closures: fix a race on wakeup from closure_sync (bnc#1151927
  5.3.4).
- block: mq-deadline: Fix queue restart handling (bnc#1151927
  5.3.4).
- nvme-multipath: fix ana log nsid lookup when nsid is not found
  (bnc#1151927 5.3.4).
- nvmet: fix data units read and written counters in SMART log
  (bnc#1151927 5.3.4).
- md: don't report active array_state until after
  revalidate_disk() completes (bnc#1151927 5.3.4).
- md: only call set_in_sync() when it is expected to succeed
  (bnc#1151927 5.3.4).
- nbd: add missing config put (bnc#1151927 5.3.4).
- blk-mq: Fix memory leak in blk_mq_init_allocated_queue error
  handling (bnc#1151927 5.3.4).
- loop: Add LOOP_SET_DIRECT_IO to compat ioctl (bnc#1151927
  5.3.4).
- md: don't call spare_active in md_reap_sync_thread if all
  member devices can't work (bnc#1151927 5.3.4).
- md: don't set In_sync if array is frozen (bnc#1151927 5.3.4).
- md/raid1: end bio when the device faulty (bnc#1151927 5.3.4).
- md/raid6: Set R5_ReadError when there is read failure on parity
  disk (bnc#1151927 5.3.4).
- scsi: implement .cleanup_rq callback (bnc#1151927 5.3.4).
- blk-mq: add callback of .cleanup_rq (bnc#1151927 5.3.4).
- libata/ahci: Drop PCS quirk for Denverton and beyond
  (bnc#1151927 5.3.4).
- io_uring: fix wrong sequence setting logic (bnc#1151927 5.3.4).
- s390/crypto: xts-aes-s390 fix extra run-time crypto self tests
  finding (bnc#1151927 5.3.4).
- s390/kasan: provide uninstrumented __strlen (bnc#1151927 5.3.4).
- posix-cpu-timers: Sanitize bogus WARNONS (bnc#1151927 5.3.4).
- x86/apic/vector: Warn when vector space exhaustion breaks
  affinity (bnc#1151927 5.3.4).
- x86/apic: Make apic_pending_intr_clear() more robust
  (bnc#1151927 5.3.4).
- x86/apic: Soft disable APIC before initializing it (bnc#1151927
  5.3.4).
- x86/reboot: Always use NMI fallback when shutdown via reboot
  vector IPI fails (bnc#1151927 5.3.4).
- irqchip/gic-v3-its: Fix LPI release for Multi-MSI devices
  (bnc#1151927 5.3.4).
- x86/mm/pti: Do not invoke PTI functions when PTI is disabled
  (bnc#1151927 5.3.4).
- x86/mm/pti: Handle unaligned address gracefully in
  pti_clone_pagetable() (bnc#1151927 5.3.4).
- tools/power/x86/intel-speed-select: Fix memory leak (bnc#1151927
  5.3.4).
- platform/x86: intel_int0002_vgpio: Fix wakeups not working on
  Cherry Trail (bnc#1151927 5.3.4).
- platform/x86: intel_pmc_core_pltdrv: Module removal warning fix
  (bnc#1151927 5.3.4).
- platform/x86: intel_pmc_core: Do not ioremap RAM (bnc#1151927
  5.3.4).
- x86/platform/intel/iosf_mbi Rewrite locking (bnc#1151927 5.3.4).
- x86/mm: Fix cpumask_of_node() error condition (bnc#1151927
  5.3.4).
- x86/cpu: Add Tiger Lake to Intel family (bnc#1151927 5.3.4).
- sched/psi: Correct overly pessimistic size calculation
  (bnc#1151927 5.3.4).
- sched/fair: Use rq_lock/unlock in online_fair_sched_group
  (bnc#1151927 5.3.4).
- rcu/tree: Fix SCHED_FIFO params (bnc#1151927 5.3.4).
- sched/core: Fix CPU controller for !RT_GROUP_SCHED (bnc#1151927
  5.3.4).
- rcu/tree: Call setschedule() gp ktread to SCHED_FIFO outside
  of atomic region (bnc#1151927 5.3.4).
- sched/deadline: Fix bandwidth accounting at all levels after
  offline migration (bnc#1151927 5.3.4).
- time/tick-broadcast: Fix tick_broadcast_offline() lockdep
  complaint (bnc#1151927 5.3.4).
- sched/fair: Fix imbalance due to CPU affinity (bnc#1151927
  5.3.4).
- kprobes: Prohibit probing on BUG() and WARN() address
  (bnc#1151927 5.3.4).
- libtraceevent: Change users plugin directory (bnc#1151927
  5.3.4).
- perf evlist: Use unshare(CLONE_FS) in sb threads to let
  setns(CLONE_NEWNS) work (bnc#1151927 5.3.4).
- perf script: Fix memory leaks in list_scripts() (bnc#1151927
  5.3.4).
- perf report: Fix --ns time sort key output (bnc#1151927 5.3.4).
- perf trace beauty ioctl: Fix off-by-one error in cmd->string
  table (bnc#1151927 5.3.4).
- libperf: Fix alignment trap with xyarray contents in 'perf stat'
  (bnc#1151927 5.3.4).
- tools headers: Fixup bitsperlong per arch includes (bnc#1151927
  5.3.4).
- perf unwind: Fix libunwind when tid != pid (bnc#1151927 5.3.4).
- perf record: Support aarch64 random socket_id assignment
  (bnc#1151927 5.3.4).
- perf tools: Fix paths in include statements (bnc#1151927 5.3.4).
- perf test vfs_getname: Disable ~/.perfconfig to get default
  output (bnc#1151927 5.3.4).
- perf config: Honour $PERF_CONFIG env var to specify alternate
  .perfconfig (bnc#1151927 5.3.4).
- efi: cper: print AER info of PCIe fatal error (bnc#1151927
  5.3.4).
- idle: Prevent late-arriving interrupts from disrupting offline
  (bnc#1151927 5.3.4).
- rcu: Add destroy_work_on_stack() to match INIT_WORK_ONSTACK()
  (bnc#1151927 5.3.4).
- arm64: dts: rockchip: limit clock rate of MMC controllers for
  RK3328 (bnc#1151927 5.3.4).
- ARM: dts: exynos: Mark LDO10 as always-on on Peach Pit/Pi
  Chromebooks (bnc#1151927 5.3.4).
- arm64: dts: qcom: qcs404-evb: Mark WCSS clocks protected
  (bnc#1151927 5.3.4).
- arm64: dts: meson: fix boards regulators states format
  (bnc#1151927 5.3.4).
- arm64: dts: imx8mq: Correct OPP table according to latest
  datasheet (bnc#1151927 5.3.4).
- ARM: dts: imx7-colibri: disable HS400 (bnc#1151927 5.3.4).
- ARM: dts: imx7d: cl-som-imx7: make ethernet work again
  (bnc#1151927 5.3.4).
- base: soc: Export soc_device_register/unregister APIs
  (bnc#1151927 5.3.4).
- firmware: qcom_scm: Use proper types for dma mappings
  (bnc#1151927 5.3.4).
- soc: amlogic: meson-clk-measure: protect measure with a mutex
  (bnc#1151927 5.3.4).
- soc: renesas: Enable ARM_ERRATA_754322 for affected Cortex-A9
  (bnc#1151927 5.3.4).
- soc: renesas: rmobile-sysc: Set GENPD_FLAG_ALWAYS_ON for
  always-on domain (bnc#1151927 5.3.4).
- firmware: arm_scmi: Check if platform has released shmem before
  using (bnc#1151927 5.3.4).
- ARM: zynq: Use memcpy_toio instead of memcpy on smp bring-up
  (bnc#1151927 5.3.4).
- ARM: OMAP2+: move platform-specific asm-offset.h to
  arch/arm/mach-omap2 (bnc#1151927 5.3.4).
- ARM: at91: move platform-specific asm-offset.h to
  arch/arm/mach-at91 (bnc#1151927 5.3.4).
- net: lpc-enet: fix printk format strings (bnc#1151927 5.3.4).
- ARM: xscale: fix multi-cpu compilation (bnc#1151927 5.3.4).
- dmaengine: iop-adma: use correct printk format strings
  (bnc#1151927 5.3.4).
- parisc: Disable HP HSC-PCI Cards to prevent kernel crash
  (bnc#1151927 5.3.4).
- ia64:unwind: fix double free for mod->arch.init_unw_table
  (bnc#1151927 5.3.4).
- irqchip/sifive-plic: set max threshold for ignored handlers
  (bnc#1151927 5.3.4).
- m68k: Prevent some compiler warnings in Coldfire builds
  (bnc#1151927 5.3.4).
- arm64: Use correct ll/sc atomic constraints (bnc#1151927 5.3.4).
- jump_label: Don't warn on __exit jump entries (bnc#1151927
  5.3.4).
- arm64: tlb: Ensure we execute an ISB following walk cache
  invalidation (bnc#1151927 5.3.4).
- kasan/arm64: fix CONFIG_KASAN_SW_TAGS && KASAN_INLINE
  (bnc#1151927 5.3.4).
- arm64: kpti: ensure patched kernel text is fetched from PoU
  (bnc#1151927 5.3.4).
- arm64: entry: Move ct_user_exit before any other exception
  (bnc#1151927 5.3.4).
- powerpc/Makefile: Always pass --synthetic to nm if supported
  (bnc#1151927 5.3.4).
- arm64/efi: Move variable assignments after SECTIONS (bnc#1151927
  5.3.4).
- arm64/prefetch: fix a -Wtype-limits warning (bnc#1151927 5.3.4).
- arm64: mm: free the initrd reserved memblock in a aligned manner
  (bnc#1151927 5.3.4).
- iommu/amd: Silence warnings under memory pressure (bnc#1151927
  5.3.4).
- iommu/amd: Override wrong IVRS IOAPIC on Raven Ridge systems
  (bnc#1151927 5.3.4).
- iommu/arm-smmu-v3: Disable detection of ATS and PRI (bnc#1151927
  5.3.4).
- gpio: madera: Add support for Cirrus Logic CS47L92 (bnc#1151927
  5.3.4).
- gpio: madera: Add support for Cirrus Logic CS47L15 (bnc#1151927
  5.3.4).
- spi: ep93xx: Repair SPI CS lookup tables (bnc#1151927 5.3.4).
- spi: dw-mmio: Clock should be shut when error occurs
  (bnc#1151927 5.3.4).
- spi: bcm2835: Work around DONE bit erratum (bnc#1151927 5.3.4).
- spi: spi-fsl-dspi: Exit the ISR with IRQ_NONE when it's not ours
  (bnc#1151927 5.3.4).
- regulator: Defer init completion for a while after late_initcall
  (bnc#1151927 5.3.4).
- regulator: lm363x: Fix n_voltages setting for lm36274
  (bnc#1151927 5.3.4).
- regulator: lm363x: Fix off-by-one n_voltages for lm3632
  ldo_vpos/ldo_vneg (bnc#1151927 5.3.4).
- hwmon: (acpi_power_meter) Change log level for 'unsafe software
  power cap' (bnc#1151927 5.3.4).
- RAS: Build debugfs.o only when enabled in Kconfig (bnc#1151927
  5.3.4).
- EDAC/amd64: Support more than two controllers for chip selects
  handling (bnc#1151927 5.3.4).
- EDAC, pnd2: Fix ioremap() size in dnv_rd_reg() (bnc#1151927
  5.3.4).
- EDAC/altera: Use the proper type for the IRQ status bits
  (bnc#1151927 5.3.4).
- EDAC/mc: Fix grain_bits calculation (bnc#1151927 5.3.4).
- tpm_tis_core: Turn on the TPM before probing IRQ's (bnc#1151927
  5.3.4).
- Update patches.suse/tpm_tis_core-Set-TPM_CHIP_FLAG_IRQ-before-probing-fo.patch
- commit 44d74c4
* Tue Oct  8 2019 mhocko@suse.com
- kernel/sysctl.c: do not override max_threads provided by
  userspace (bnc#1150875).
- commit c8680bd
* Mon Oct  7 2019 msuchanek@suse.de
- powerpc/pseries/mobility: use cond_resched when updating device
  tree (bsc#1153112 ltc#181778).
- powerpc/rtas: allow rescheduling while changing cpu states
  (bsc#1153112 ltc#181778).
- commit 6d0719a
* Mon Oct  7 2019 msuchanek@suse.de
- powerpc/64s/pseries: radix flush translations before MMU is
  enabled at boot (bsc#1055186).
- commit 90a9436
* Mon Oct  7 2019 martin.wilck@suse.com
- block: drop device references in bsg_queue_rq() (bsc#1153217).
- commit b02e448
* Mon Oct  7 2019 tbogendoerfer@suse.de
- Re-activated still not upstream mvpp2 patch (bsc#1117016)
- commit 6e10d56
* Mon Oct  7 2019 tbogendoerfer@suse.de
- Delete
  patches.suse/lustre-Simplify-ib_post_-send-recv-srq_recv-calls.patch.
  No longer needed.
- commit 8d0fb6b
* Mon Oct  7 2019 jthumshirn@suse.de
- libnvdimm/altmap: Track namespace boundaries in altmap
  (bsc#1150305).
- commit 458a137
* Mon Oct  7 2019 jslaby@suse.cz
- Linux 5.3.3 (bnc#1151927 5.3.3).
- commit d0d68ea
* Mon Oct  7 2019 pvorel@suse.cz
- alarmtimer: Use EOPNOTSUPP instead of ENOTSUPP (bsc#1151680).
- commit 87f78af
* Mon Oct  7 2019 ohering@suse.de
- scsi: storvsc: setup 1:1 mapping between hardware queue and
  CPU queue (fate#323887).
- commit 96ad9b0
* Sun Oct  6 2019 mkubecek@suse.cz
- hwmon: (k10temp) Add support for AMD family 17h, model 70h CPUs
  (bsc#1153137).
- x86/amd_nb: Add PCI device IDs for family 17h, model 70h
  (bsc#1153137).
- commit 6e407a5
* Fri Oct  4 2019 msuchanek@suse.de
- powerpc/64s/radix: tidy up TLB flushing code (bsc#1152885).
- powerpc/64s: remove register_process_table callback
  (bsc#1152885).
- commit 33f6003
* Fri Oct  4 2019 mkubecek@suse.cz
- Linux 5.3.2 (bnc#1151927 5.3.2).
- ALSA: usb-audio: Add DSD support for EVGA NU Audio (bnc#1151927
  5.3.2).
- ALSA: hda - Add laptop imic fixup for ASUS M9V laptop
  (bnc#1151927 5.3.2).
- ALSA: hda - Apply AMD controller workaround for Raven platform
  (bnc#1151927 5.3.2).
- ALSA: usb-audio: Add Hiby device family to quirks for native
  DSD support (bnc#1151927 5.3.2).
- ALSA: dice: fix wrong packet parameter for Alesis iO26
  (bnc#1151927 5.3.2).
- Revert "mm/z3fold.c: fix race between migration and destruction"
  (bnc#1151927 5.3.2).
- platform/x86: i2c-multi-instantiate: Derive the device name
  from parent (bnc#1151927 5.3.2).
- HID: Add quirk for HP X500 PIXART OEM mouse (bnc#1151927 5.3.2).
- HID: prodikeys: Fix general protection fault during probe
  (bnc#1151927 5.3.2).
- HID: sony: Fix memory corruption issue on cleanup (bnc#1151927
  5.3.2).
- HID: logitech-dj: Fix crash when initial
  logi_dj_recv_query_paired_devices fails (bnc#1151927 5.3.2).
- HID: logitech: Fix general protection fault caused by Logitech
  driver (bnc#1151927 5.3.2).
- HID: hidraw: Fix invalid read in hidraw_ioctl (bnc#1151927
  5.3.2).
- crypto: talitos - fix missing break in switch statement
  (bnc#1151927 5.3.2).
- mtd: cfi_cmdset_0002: Use chip_good() to retry in
  do_write_oneword() (bnc#1151927 5.3.2).
- clk: imx: imx8mm: fix audio pll setting (bnc#1151927 5.3.2).
- drm/amd/display: Don't replace the dc_state for fast updates
  (bnc#1151927 5.3.2).
- drm/amd/display: Skip determining update type for async updates
  (bnc#1151927 5.3.2).
- drm/amd/display: Allow cursor async updates for framebuffer
  swaps (bnc#1151927 5.3.2).
- drm/amd/display: readd -msse2 to prevent Clang from emitting
  libcalls to undefined SW FP routines (bnc#1151927 5.3.2).
- netfilter: add missing IS_ENABLED(CONFIG_NF_TABLES) check to
  header-file (bnc#1151927 5.3.2).
- clocksource/drivers: Do not warn on probe defer (bnc#1151927
  5.3.2).
- clocksource/drivers/timer-of: Do not warn on deferred probe
  (bnc#1151927 5.3.2).
- objtool: Clobber user CFLAGS variable (bnc#1151927 5.3.2).
- commit 8866153
* Fri Oct  4 2019 mkubecek@suse.cz
- Update references (add bnc#1151927 5.3.2) and refresh
  patches.suse/powerpc-xive-Fix-bogus-error-code-returned-by-OPAL.patch
- commit cf3b8a7
* Fri Oct  4 2019 wqu@suse.com
- btrfs: qgroup: Fix reserved data space leak if we have  multiple
  reserve calls (bsc#1152975).
- commit 453d0eb
* Fri Oct  4 2019 wqu@suse.com
- btrfs: qgroup: Fix the wrong target io_tree when freeing
  reserved data space (bsc#1152974).
- commit f48e436
* Fri Oct  4 2019 wqu@suse.com
- btrfs: Fix a regression which we can't convert to SINGLE
  profile (bsc#1152973).
- commit eee41e6
* Fri Oct  4 2019 wqu@suse.com
- btrfs: relocation: fix use-after-free on dead relocation  roots
  (bsc#1152972).
- commit 39b83a8
* Thu Oct  3 2019 msuchanek@suse.de
- powerpc: add machine check safe copy_to_user (jsc#SLE-7730
  jsc#SLE-8330).
  Update config files.
- powerpc/memcpy: Add memcpy_mcsafe for pmem (jsc#SLE-7730
  jsc#SLE-8330).
- powerpc/mce: Handle UE event for memcpy_mcsafe (jsc#SLE-7730
  jsc#SLE-8330).
- extable: Add function to search only kernel exception table
  (jsc#SLE-7730 jsc#SLE-8330).
- powerpc/mce: Make machine_check_ue_event() static (jsc#SLE-7730
  jsc#SLE-8330).
- powerpc/mce: Fix MCE handling for huge pages (jsc#SLE-7730
  jsc#SLE-8330).
- powerpc/mce: Schedule work from irq_work (jsc#SLE-7730
  jsc#SLE-8330).
- commit 12b3809
* Thu Oct  3 2019 msuchanek@suse.de
- powerpc/powernv: Restrict OPAL symbol map to only be readable
  by root (bsc#1152885).
- powerpc/rtas: Unexport rtas_online_cpus_mask,
  rtas_offline_cpus_mask (bsc#1152885).
- commit a002009
* Thu Oct  3 2019 msuchanek@suse.de
- KVM: PPC: Book3S: Enable XIVE native capability only if OPAL
  has required functions (bsc#1061840).
- commit c8b5967
* Thu Oct  3 2019 msuchanek@suse.de
- dma-mapping: explicitly wire up ->mmap and ->get_sgtable
  (bsc#1152879).
- commit 4e5b600
* Thu Oct  3 2019 msuchanek@suse.de
- powerpc/powernv/ioda2: Allocate TCE table levels on demand
  for default DMA window (bsc#1061840).
- commit af7925a
* Thu Oct  3 2019 msuchanek@suse.de
- powerpc/pseries: Call H_BLOCK_REMOVE when supported
  (bsc#1109158).
- powerpc/pseries: Read TLB Block Invalidate Characteristics
  (bsc#1109158).
- commit 4883057
* Thu Oct  3 2019 mkubecek@suse.cz
- config: refresh configs
- commit b8eafb3
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/xive: Fix bogus error code returned by OPAL
  (bsc#1065729).
- commit 9e22168
* Wed Oct  2 2019 msuchanek@suse.de
- blacklist.conf: Add duplicate commit id.
- commit f9863f0
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/papr_scm: Fix an off-by-one check in papr_scm_meta_{get,
  set} (bsc#1152243 ltc#181472).
- net/ibmvnic: prevent more than one thread from running in reset
  (bsc#1152457 ltc#174432).
- net/ibmvnic: unlock rtnl_lock in reset so linkwatch_event can
  run (bsc#1152457 ltc#174432).
- powerpc/mm: Fixup tlbie vs mtpidr/mtlpidr ordering issue on
  POWER9 (bsc#1152161 ltc#181664).
- powerpc/book3s64/radix: Rename CPU_FTR_P9_TLBIE_BUG feature flag
  (bsc#1152161 ltc#181664).
- powerpc/book3s64/mm: Don't do tlbie fixup for some hardware
  revisions (bsc#1152161 ltc#181664).
- commit 4d9184c
* Wed Oct  2 2019 ohering@suse.de
- irqdomain: Add the missing assignment of domain->fwnode for
  named fwnode (fate#323887).
- commit e4b9c3f
* Wed Oct  2 2019 ohering@suse.de
- KVM: vmx: fix build warnings in hv_enable_direct_tlbflush()
  on i386 (fate#323887).
- KVM: x86: announce KVM_CAP_HYPERV_ENLIGHTENED_VMCS support
  only when it is available (fate#323887).
- KVM/Hyper-V: Add new KVM capability
  KVM_CAP_HYPERV_DIRECT_TLBFLUSH (fate#323887).
- commit 68b44d1
* Wed Oct  2 2019 ohering@suse.de
- cpu/SMT: create and export cpu_smt_possible() (fate#323887).
- smp/hotplug: Track booted once CPUs in a cpumask (fate#323887).
- commit 48d9519
* Wed Oct  2 2019 ohering@suse.de
- KVM: x86: hyper-v: set NoNonArchitecturalCoreSharing CPUID
  bit when SMT is impossible (fate#323887).
- commit 231241b
* Wed Oct  2 2019 ohering@suse.de
- KVM: hyperv: Fix Direct Synthetic timers assert an interrupt
  w/o lapic_in_kernel (fate#323887).
- commit 8f924d6
* Wed Oct  2 2019 ohering@suse.de
- KVM/Hyper-V/VMX: Add direct tlb flush support (fate#323887).
- commit ef750e3
* Wed Oct  2 2019 ohering@suse.de
- x86/Hyper-V: Fix definition of struct hv_vp_assist_page
  (fate#323887).
- commit 1239e74
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Resume after fixing up old primary channels
  (fate#323887).
- commit 9e12e34
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Suspend after cleaning up hv_sock and sub
  channels (fate#323887).
- commit 36c8dd5
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Clean up hv_sock channels by force upon
  suspend (fate#323887).
- commit 9f06b05
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Suspend/resume the vmbus itself for
  hibernation (fate#323887).
- commit 4bd7f09
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Ignore the offers when resuming from
  hibernation (fate#323887).
- commit fe8f660
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Implement suspend/resume for VSC drivers
  for hibernation (fate#323887).
- commit 344d3ff
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Add a helper function is_sub_channel()
  (fate#323887).
- commit 3b1ed7d
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Suspend/resume the synic for hibernation
  (fate#323887).
- commit 121172c
* Wed Oct  2 2019 ohering@suse.de
- Drivers: hv: vmbus: Break out synic enable and disable
  operations (fate#323887).
- commit 561f047
* Wed Oct  2 2019 ohering@suse.de
- HID: hv: Remove dependencies on PAGE_SIZE for ring buffer
  (fate#323887).
- commit 60e6c9f
* Wed Oct  2 2019 ohering@suse.de
- Tools: hv: move to tools buildsystem (fate#323887).
- commit a3f0abd
* Wed Oct  2 2019 ohering@suse.de
- hv_balloon: Reorganize the probe function (fate#323887).
- commit 8480408
* Wed Oct  2 2019 ohering@suse.de
- hv_balloon: Use a static page for the balloon_up send buffer
  (fate#323887).
- commit 9e12837
* Wed Oct  2 2019 ohering@suse.de
- PCI: hv: Use bytes 4 and 5 from instance ID as the PCI domain
  numbers (fate#323887).
- commit 113e837
* Wed Oct  2 2019 ohering@suse.de
- PCI: hv: Detect and fix Hyper-V PCI domain number collision
  (fate#323887, bsc#1150423).
- commit a0e547e
* Wed Oct  2 2019 ohering@suse.de
- hv_netvsc: Sync offloading features to VF NIC (fate#323887).
- commit 392e859
* Wed Oct  2 2019 ohering@suse.de
- hv_netvsc: Allow scatter-gather feature to be tunable
  (fate#323887).
- commit 0aa9a52
* Wed Oct  2 2019 ohering@suse.de
- PCI: hv: Add a Hyper-V PCI interface driver for software
  backchannel interface (fate#323887).
- commit 381f060
* Wed Oct  2 2019 ohering@suse.de
- PCI: hv: Add a paravirtual backchannel in software
  (fate#323887).
- commit 9b88ba8
* Wed Oct  2 2019 ohering@suse.de
- x86/hyperv: Hide pv_ops access for CONFIG_PARAVIRT=n
  (fate#323887).
- commit 334c380
* Wed Oct  2 2019 ohering@suse.de
- clocksource/drivers/hyperv: Enable TSC page clocksource on 32bit
  (fate#323887).
- commit ddf471b
* Wed Oct  2 2019 ohering@suse.de
- clocksource/drivers/hyperv: Add Hyper-V specific sched clock
  function (fate#323887).
- commit 0442bbf
* Wed Oct  2 2019 ohering@suse.de
- clocksource/drivers/hyperv: Allocate Hyper-V TSC page statically
  (fate#323887).
- commit 8fc74ac
* Wed Oct  2 2019 ohering@suse.de
- PCI: hv: Allocate a named fwnode instead of an address-based
  one (fate#323887).
- commit 38fe080
* Wed Oct  2 2019 ohering@suse.de
- drivers: hv: vmbus: Replace page definition with Hyper-V
  specific one (fate#323887).
- commit a1e5f69
* Wed Oct  2 2019 ohering@suse.de
- x86/hyperv: Add functions to allocate/deallocate page for
  Hyper-V (fate#323887).
- commit 357181d
* Wed Oct  2 2019 ohering@suse.de
- x86/hyperv: Create and use Hyper-V page definitions
  (fate#323887).
- commit 0a58e81
* Wed Oct  2 2019 ohering@suse.de
- add mainline tag to a hyperv patch
- commit 994aada
* Wed Oct  2 2019 mkubecek@suse.cz
- series.conf: cleanup
  Move unsortable patch out of sorted section.
- commit 636b696
* Tue Oct  1 2019 mwilck@suse.com
- scsi: scsi_dh_rdac: zero cdb in send_mode_select()
  (bsc#1149313).
- commit e7cd81e
* Tue Oct  1 2019 lduncan@suse.com
- Removed guarded st driver patch: already upstream
- commit b34f3cb
* Tue Oct  1 2019 yousaf.kaukab@suse.com
- arm64: mmc: remove patches already applied to v5.3
  Both patches landed in v5.0
- commit 075db4d
* Tue Oct  1 2019 yousaf.kaukab@suse.com
- arm64: remove 0001-irqchip-gic-v3-its-fix-build-warnings.patch
  Not required on v5.3
- commit db9714b
* Tue Oct  1 2019 yousaf.kaukab@suse.com
- config: arm64: lx2160: enable mobiveil pcie controller driver
- commit 21c2539
* Tue Oct  1 2019 yousaf.kaukab@suse.com
- PCI: mobiveil: Add PCIe Gen4 RC driver for NXP Layerscape SoCs
  (fate#326572).
- PCI: mobiveil: Add 8-bit and 16-bit CSR register accessors
  (fate#326572).
- PCI: mobiveil: Make mobiveil_host_init() can be used to re-init
  host (fate#326572).
- PCI: mobiveil: Refactor Mobiveil PCIe Host Bridge IP driver
  (fate#326572).
- PCI: mobiveil: Fix the CPU base address setup in inbound window
  (fate#326572).
- commit 1e982e0
* Tue Oct  1 2019 ykaukab@suse.de
- arm64: lx2160: remove mobiveil PCIe driver v5
  Preparing to bring in v8. Most of the patches are already included in
  v5.3.
- commit 136f3e5
* Tue Oct  1 2019 ykaukab@suse.de
- PCI: Add quirk to disable MSI-X support for Amazon's Annapurna
  Labs Root Port (bsc#1152187,bsc#1152525).
- PCI/VPD: Prevent VPD access for Amazon's Annapurna Labs Root
  Port (bsc#1152187,bsc#1152525).
- PCI: Add ACS quirk for Amazon Annapurna Labs root ports
  (bsc#1152187,bsc#1152525).
- PCI: Add Amazon's Annapurna Labs vendor ID
  (bsc#1152187,bsc#1152525).
- commit cb75ccf
* Tue Oct  1 2019 oneukum@suse.com
- usb: typec: tps6598x: Fix build error without CONFIG_REGMAP_I2C
  (bsc#1152489).
- commit 50acd22
* Tue Oct  1 2019 oneukum@suse.com
- usb: dwc3: meson-g12a: fix suspend resume regulator unbalanced
  disables (bsc#1152489).
- commit f417fe7
* Tue Oct  1 2019 oneukum@suse.com
- b2c2-flexcop-usb: add sanity checking (bsc#1146540
  CVE-2019-15291).
- commit 300993f
* Tue Oct  1 2019 oneukum@suse.com
- ipmi: move message error checking to avoid deadlock
  (bsc#1152489).
- commit 78528fd
* Tue Oct  1 2019 bp@suse.de
- x86/cpufeatures: Enable a new AVX512 CPU feature (jsc#SLE-7925).
- commit 400d642
* Tue Oct  1 2019 jslaby@suse.cz
- Update config files.
  Enable CONFIG_X86_5LEVEL (jsc#SLE-9308).
- commit fad1d7e
* Tue Oct  1 2019 tzimmermann@suse.de
- drm/mgag200: Don't unpin the current cursor image's buffer. (bsc#1152472)
- commit 6389bb6
* Tue Oct  1 2019 tzimmermann@suse.de
- drm/mgag200: Set cursor scanout address to correct BO (bsc#1152472)
- commit fba11f2
* Tue Oct  1 2019 tzimmermann@suse.de
- drm/mgag200: Pin displayed cursor BO to video memory (bsc#1152472)
- commit 1cd88ec
* Tue Oct  1 2019 tzimmermann@suse.de
- drm/mgag200: add in missing { } around if block (bsc#1152472)
- commit 5ad6864
* Tue Oct  1 2019 mkubecek@suse.cz
- series.conf: cleanup
  Let's keep the number of top level sections reasonable.
  Update tags (do not use "Patch-mainline: no"):
  patches.suse/printk-console-Correctly-mark-console-that-is-used-w.patch
  patches.suse/printk-panic-Avoid-deadlock-in-printk-after-stopping-CPUs-by-NMI.patch
- commit 9121df0
* Mon Sep 30 2019 bp@suse.de
- EDAC/amd64: Recognize DRAM device type ECC capability
  (bsc#1152489).
- commit abc7ef1
* Mon Sep 30 2019 bp@suse.de
- EDAC/amd64: Decode syndrome before translating address
  (bsc#1152489).
- commit 3c4a52a
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/amdgpu: Fix KFD-related kernel oops on Hawaii (bsc#1152472)
- commit 3c6a999
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/amdkfd: fix a use after free race with mmu_notifer unregister (bsc#1152472)
- commit 792d1c5
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/mcde: Fix DSI transfers (bsc#1152472)
- commit a87cce0
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/msm: Use the correct dma_sync calls harder (bsc#1152472)
- commit 33411e0
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/msm/dsi: Fix return value check for clk_get_parent (bsc#1152472)
- commit b591595
* Mon Sep 30 2019 pmladek@suse.com
- Refresh
  patches.suse/printk-console-Correctly-mark-console-that-is-used-w.patch
- commit d007d29
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu: fix GFXOFF on Picasso and Raven2'
- commit 0b48ba5
* Mon Sep 30 2019 tzimmermann@suse.de
- Revert "drm/amdgpu: free up the first paging queue v2" (bsc#1152472)
- commit beca648
* Mon Sep 30 2019 tzimmermann@suse.de
- Revert "drm/amd/display: Fix underscan not using proper scaling" (bsc#1152472)
- commit 6bc7400
* Mon Sep 30 2019 tzimmermann@suse.de
- Revert "drm/amd/display: add global master update lock for DCN2" (bsc#1152472)
- commit 13bba8c
* Mon Sep 30 2019 tzimmermann@suse.de
- Revert "drm/amd/display: navi10 bring up skip dsc encoder config" (bsc#1152472)
- commit f5b512e
* Mon Sep 30 2019 tzimmermann@suse.de
- Revert "drm/amd/display: skip dsc config for navi10 bring up" (bsc#1152472)
- commit e06dd1d
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/display: Calculate bpc based on max_requested_bpc'
- commit ba7e6fb
* Mon Sep 30 2019 vbabka@suse.cz
- Update config files. Enable CONFIG_DEBUG_PAGEALLOC.
- commit c9d1113
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amdgpu/gfx9: update pg_flags after determining if gfx off is possible'
- commit 1687748
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/amdgpu: fix transform feedback GDS hang on gfx10 (v2)"'
- commit 1b720a9
* Mon Sep 30 2019 tzimmermann@suse.de
- drm: fix module name in edid_firmware log message (bsc#1152472)
- commit b1ccfe7
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/imx: Drop unused imx-ipuv3-crtc.o build (bsc#1152472)
- commit c76be29
* Mon Sep 30 2019 vbabka@suse.cz
- x86/kconfig: Remove X86_DIRECT_GBPAGES dependency on
  !DEBUG_PAGEALLOC (PM-1168, bsc#1144653, VM Debug Functionality).
- commit bebf778
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Do not create a new max_bpc prop for MST connectors'
- commit 2f54da8
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix HW readout for crtc_clock in HDMI mode'
- commit d17d39c
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix wrong escape clock divisor init for GLK'
- commit de225fb
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: fix possible memory leak in intel_hdcp_auth_downstream()'
- commit 81e8a9e
* Mon Sep 30 2019 tzimmermann@suse.de
- drm: rcar-du: lvds: Fix bridge_to_rcar_lvds (bsc#1152472)
- commit 7243441
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/amd/display: Use proper enum conversion functions (bsc#1152472)
- commit 8362493
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/amd/display: Support uclk switching for DCN2 (bsc#1152472)
- commit 4b2f15b
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/rockchip: fix VOP_WIN_GET macro (bsc#1152472)
- commit 6dccec7
* Mon Sep 30 2019 tzimmermann@suse.de
- drm: mali-dp: Mark expected switch fall-through (bsc#1152472)
- commit d5b02fc
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/syncobj: fix leaking dma_fence in drm_syncobj_query_ioctl (bsc#1152472)
- commit f87cd1c
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/connector: Fix warning in debug message'
- commit 99fb862
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/bridge: sii902x: fix missing reference to mclk clock (bsc#1152472)
- commit 33a37f2
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/panel: make drm_panel.h self-contained (bsc#1152472)
- commit 24e6b1f
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/lima: Reduce the amount of logs on deferred probe (bsc#1152472)
- commit 7fc211d
* Mon Sep 30 2019 tzimmermann@suse.de
- drm/lima: Mark 64-bit number as ULL (bsc#1152472)
- commit a47d898
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix GEN8_MCR_SELECTOR programming'
- commit 7f9b12e
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/vbt: Fix VBT parsing for the PSR section'
- commit d8eb2fd
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Lock the engine while dumping the active request'
- commit eaa408b
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/perf: add missing delay for OA muxes configuration'
- commit 3e3bf58
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/perf: ensure we keep a reference on the driver'
- commit 2030c79
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gtt: Mark the freed page table entries with scratch'
- commit 1cbd1c3
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gtt: Defer the free for alloc error paths'
- commit 68741a8
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Deal with machines that expose less than three QGV points'
- commit 984d843
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix memleak in runtime wakeref tracking'
- commit e990311
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: fix whitelist selftests with readonly registers'
- commit 8c63a7c
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix the TBT AUX power well enabling'
- commit e962027
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Lift intel_engines_resume() to callers'
- commit b42e83a
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Only recover active engines'
- commit 562ba01
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix various tracepoints for gen2'
- commit 53b1384
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/perf: fix ICL perf register offsets'
- commit f94a6d1
* Mon Sep 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Keep rings pinned while the context is active'
- commit ddd1ccc
* Mon Sep 30 2019 tzimmermann@suse.de
- video: backlight: Drop default m for {LCD,BACKLIGHT_CLASS_DEVICE} (bsc#1152472)
- commit 85cda2a
* Mon Sep 30 2019 tzimmermann@suse.de
- video: ssd1307fb: Start page range at page_offset (bsc#1152472)
- commit 8809ebe
* Mon Sep 30 2019 pmladek@suse.com
- printk/panic: Avoid deadlock in printk() after stopping CPUs
  by NMI (bsc#1148712).
- commit dd62e61
* Mon Sep 30 2019 pvorel@suse.cz
- blacklist.conf: blacklist 34cd83bb8a46
- commit e519fc0
* Mon Sep 30 2019 mkubecek@suse.cz
- series.conf: cleanup
- commit 56e35ef
* Mon Sep 30 2019 jlee@suse.com
- KEYS: Make use of platform keyring for module signature verify
  (FATE#314508, FATE#316531).
- commit 0722d07
* Fri Sep 27 2019 mkubecek@suse.cz
- config.conf: disable vanilla flavour on armv7hl
  With stable backports being handled the same way as other mainline
  backports, we no longer build kernel-vanilla. Disable vanilla flavor also
  on armv7hl architecture.
- commit 2628641
* Fri Sep 27 2019 mbenes@suse.cz
- livepatch: Nullify obj->mod in klp_module_coming()'s error path
  (bsc#1071995 fate#323487).
- commit a28c007
* Thu Sep 26 2019 jlee@suse.com
- Delete
  patches.suse/0006-modsign-Use-secondary-trust-keyring-for-module-signi.patch.
  This patch be replaced by e84cd7ee63 in v5.0-rc1.
- commit e937c06
* Thu Sep 26 2019 jlee@suse.com
- Delete
  patches.suse/0001-KEYS-Allow-unrestricted-boot-time-addition-of-keys-t.patch.
  This patch be replaced by 60740accf78 in v5.0-rc1. The UEFI keys will be add
  to platform keyring instead of secondary certificates keyring.
- commit bc249e1
* Thu Sep 26 2019 jlee@suse.com
- Delete
  patches.suse/0005-MODSIGN-Allow-the-db-UEFI-variable-to-be-suppressed.patch.
  This patch be replaced by 386b49f51dc in v5.0-rc1
- commit 58a4a2d
* Thu Sep 26 2019 jlee@suse.com
- Delete
  patches.suse/0003-efi-Add-an-EFI-signature-blob-parser.patch.
  This patch be replaced by 0bc9ae395b in v5.0-rc1.
- commit 1c1cc93
* Thu Sep 26 2019 jlee@suse.com
- Delete patches.suse/0002-efi-Add-EFI-signature-data-types.patch.
  This patch be replaced by 5c126ba22f in v5.0-rc1.
- commit 3868a56
* Wed Sep 25 2019 ailiopoulos@suse.com
- Delete patches.suse/squashfs-3.4.patch.
  Deprecate squashfs-3.4 legacy fs format support (jsc#SLE-9416)
- commit e1d0aab
* Wed Sep 25 2019 jlee@suse.com
- Delete
  patches.suse/0004-MODSIGN-Import-certificates-from-UEFI-Secure-Boot.patch.
  This patch be replaced by 15ea0e1e3e in v5.0-rc1.
- commit d558f60
* Wed Sep 25 2019 fvogt@suse.com
- config: Enable dual-role modes for DWC on arm64 as well
- CONFIG_USB_DWC2_DUAL_ROLE=y and CONFIG_USB_DWC3_DUAL_ROLE=y
- Previously that was only enabled on armv6/armv7
- commit a9c5486
* Wed Sep 25 2019 mkubecek@suse.cz
- supported.conf: cleanup
- drop obsolete mask sound/oss/*
- drop removed module nf_conntrack_slp
- commit 30def80
* Wed Sep 25 2019 jslaby@suse.cz
- config.conf: disable vanilla flavour
  As was discussed on the labs conf 2019, vanilla flavour is barely
  used. Given we are not going to use stable patches when building
  kernel-vanilla, it becomes a yet bit more useless. So disable it for
  now only. If nobody cares, we can drop also the configs later.
- commit 4223115
* Wed Sep 25 2019 jslaby@suse.cz
- Linux 5.3.1 (bnc#1151927 5.3.1).
- ovl: fix regression caused by overlapping layers detection
  (bnc#1151927 5.3.1).
- xen-netfront: do not assume sk_buff_head list is empty in
  error handling (bnc#1151927 5.3.1).
- net: stmmac: Hold rtnl lock in suspend/resume callbacks
  (bnc#1151927 5.3.1).
- ip6_gre: fix a dst leak in ip6erspan_tunnel_xmit (bnc#1151927
  5.3.1).
- udp: correct reuseport selection with connected sockets
  (bnc#1151927 5.3.1).
- net_sched: let qdisc_put() accept NULL pointer (bnc#1151927
  5.3.1).
- net: dsa: Fix load order between DSA drivers and taggers
  (bnc#1151927 5.3.1).
- net/sched: fix race between deactivation and dequeue for NOLOCK
  qdisc (bnc#1151927 5.3.1).
- nl80211: Fix possible Spectre-v1 for CQM RSSI thresholds
  (bnc#1151927 5.3.1).
- firmware: google: check if size is valid when decoding VPD data
  (bnc#1151927 5.3.1).
- phy: qcom-qmp: Correct ready status, again (bnc#1151927 5.3.1).
- phy: renesas: rcar-gen3-usb2: Disable clearing VBUS in
  over-current (bnc#1151927 5.3.1).
- serial: sprd: correct the wrong sequence of arguments
  (bnc#1151927 5.3.1).
- tty/serial: atmel: reschedule TX after RX was started
  (bnc#1151927 5.3.1).
- USB: usbcore: Fix slab-out-of-bounds bug during device reset
  (bnc#1151927 5.3.1).
- KVM: coalesced_mmio: add bounds checking (bnc#1151927 5.3.1).
- media: tm6000: double free if usb disconnect while streaming
  (bnc#1151927 5.3.1).
- media: technisat-usb2: break out of loop at end of buffer
  (bnc#1151927 5.3.1).
- floppy: fix usercopy direction (bnc#1151927 5.3.1).
- Documentation: sphinx: Add missing comma to list of strings
  (bnc#1151927 5.3.1).
- Revert "arm64: Remove unnecessary ISBs from set_{pte,pmd,pud}"
  (bnc#1151927 5.3.1).
- commit af71771
* Tue Sep 24 2019 msuchanek@suse.de
- enable VFIO-CCW and CCW IOMMU (bsc#1151192 jsc#SLE-6138)
- config changes (s390x only)
  - VFIO_CCW=m
  - S390_CCW_IOMMU=y
- supported.conf: add vfio_ccw as externally supported (by IBM)
  supported.conf: Add vfio_ccw (bsc#1151192 jsc#SLE-6138).
- commit bbfc15f
* Tue Sep 24 2019 hare@suse.de
- Compile nvme.ko as module (bsc#1150846, bsc#1150850, bsc#1161889)
- commit 12cab35
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/64s/radix: Fix memory hotplug section page table
  creation (bsc#1065729).
- commit 431bc28
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/pseries: Fix cpu_hotplug_lock acquisition in
  resize_hpt() (bsc#1065729).
- commit e574522
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/xive: Implement get_irqchip_state method for XIVE to
  fix shutdown race (bsc#1065729).
- commit a9647b9
* Mon Sep 23 2019 msuchanek@suse.de
- tpm_tis_core: Set TPM_CHIP_FLAG_IRQ before probing for
  interrupts (bsc#1082555).
- commit d3b1602
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/64s/radix: Fix memory hot-unplug page table split
  (bsc#1065729).
- powerpc/powernv/ioda: Fix race in TCE level allocation
  (bsc#1061840).
- KVM: PPC: Book3S HV: Don't lose pending doorbell request on
  migration on P9 (bsc#1061840).
- KVM: PPC: Book3S HV: Check for MMU ready on piggybacked virtual
  cores (bsc#1061840).
- KVM: PPC: Book3S HV: Don't push XIVE context when not using
  XIVE device (bsc#1061840).
- KVM: PPC: Book3S HV: Fix race in re-enabling XIVE escalation
  interrupts (bsc#1061840).
- KVM: PPC: Book3S HV: XIVE: Free escalation interrupts before
  disabling the VP (bsc#1061840).
- commit 3411cdc
* Mon Sep 23 2019 jroedel@suse.de
- iommu/dma: Fix for dereferencing before null checking
  (bsc#1151674).
- iommu/iova: Avoid false sharing on fq_timer_on (bsc#1151675).
- iommu/vt-d: Fix wrong analysis whether devices share the same
  bus (bsc#1151679).
- iommu/ipmmu-vmsa: Move IMTTBCR_SL0_TWOBIT_* to restore sort
  order (bsc#1151676).
- iommu/mediatek: Fix VLD_PA_RNG register backup when suspend
  (bsc#1151678).
- iommu/mediatek: Fix iova_to_phys PA start for 4GB mode
  (bsc#1151677).
- commit 6809156
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/64s/exception: reduce page fault unnecessary loads
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Remove pointless KVM handler name
  bifurcation (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: program check handler do not branch
  into a macro (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: move interrupt entry code above the
  common handler (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: INT_COMMON add DAR, DSISR, reconcile
  options (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Expand EXCEPTION_PROLOG_COMMON_1 and
  2 into caller (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Expand EXCEPTION_COMMON macro into caller
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Add INT_COMMON gas macro to generate
  common exception code (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Merge EXCEPTION_PROLOG_COMMON_2/3
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: KVM_HANDLER reorder arguments to match
  other macros (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Add INT_KVM_HANDLER gas macro
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: INT_HANDLER support HDAR/HDSISR and
  use it in HDSI (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Add the virt variant of the denorm
  interrupt handler (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: remove EXCEPTION_PROLOG_0/1, rename _2
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exceptions: Use keyword params to shorten arg lists
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Replace PROLOG macros and EXC helpers
  with a gas macro (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: remove 0xb00 handler (jsc#PM-1334
  jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Fix performance monitor virt handler
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Add EXC_HV_OR_STD, which selects HSRR
  if HVMODE (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: move head-64.h exception code to
  exception-64s.S (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: Fix DAR load for handle_page_fault
  error case (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check improve labels and comments
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: untangle early machine check handler
  branch (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check move unrecoverable handling
  out of line (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: simplify machine check early path
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check move tramp code
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check restructure to reuse
  common macros (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check pseries should skip
  the late handler for kernel MCEs (jsc#PM-1334 jsc#SLE-9246
  jsc#SLE-9251).
- powerpc/64s/pseries: machine check convert to use common event
  code (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/powernv: machine check dump SLB contents
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check use correct cfar for late
  handler (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check remove
  machine_check_pSeries_0 branch (jsc#PM-1334 jsc#SLE-9246
  jsc#SLE-9251).
- powerpc/64s/exception: machine check pseries should always
  run the early handler (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check adjust RFI target
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check fix KVM guest test
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check remove bitrotted comment
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- powerpc/64s/exception: machine check fwnmi remove HV case
  (jsc#PM-1334 jsc#SLE-9246 jsc#SLE-9251).
- commit 0e08ffb
* Mon Sep 23 2019 msuchanek@suse.de
- kexec_elf: support 32 bit ELF files (jsc#PM-1333 jsc#SLE-9255
  jsc#SLE-9527).
- kexec_elf: remove unused variable in kexec_elf_load()
  (jsc#PM-1333 jsc#SLE-9255 jsc#SLE-9527).
- kexec_elf: remove Elf_Rel macro (jsc#PM-1333 jsc#SLE-9255
  jsc#SLE-9527).
- kexec_elf: remove PURGATORY_STACK_SIZE (jsc#PM-1333 jsc#SLE-9255
  jsc#SLE-9527).
- kexec_elf: remove parsing of section headers (jsc#PM-1333
  jsc#SLE-9255 jsc#SLE-9527).
- kexec_elf: change order of elf_*_to_cpu() functions (jsc#PM-1333
  jsc#SLE-9255 jsc#SLE-9527).
- kexec: add KEXEC_ELF (jsc#PM-1333 jsc#SLE-9255 jsc#SLE-9527).
- new config options:
  - KEXEC_ELF=y (ppc64le only, autoselected)
- commit 2985288
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/fadump: support holes in kernel boot memory area
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: remove RMA_START and RMA_END macros (jsc#PM-1318
  jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: update documentation about option to release
  opalcore (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: consider f/w load area (jsc#PM-1318 jsc#SLE-9099
  jsc#SLE-9176).
- powerpc/opalcore: provide an option to invalidate
  /sys/firmware/opal/core file (jsc#PM-1318 jsc#SLE-9099
  jsc#SLE-9176).
- powerpc/opalcore: export /sys/firmware/opal/core for analysing
  opal crashes (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- new config options:
  - OPAL_CORE=n (ppc64le only)
- powerpc/fadump: update documentation about
  CONFIG_PRESERVE_FA_DUMP (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: add support to preserve crash data on FADUMP
  disabled kernel (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: improve how crashed kernel's memory is reserved
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: consider reserved ranges while releasing memory
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: make crash memory ranges array allocation
  generic (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: process architected register state data provided
  by firmware (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: make use of memblock's bottom up allocation mode
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: Update documentation about OPAL platform support
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: handle invalidation of crashdump and
  re-registraion (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: Warn before processing partial crashdump
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: process the crashdump by exporting it as
  /proc/vmcore (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: support copying multiple kernel boot memory
  regions (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: define OPAL register/un-register callback
  functions (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: reset metadata address during clean up
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: register kernel metadata address with opal
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: improve fadump_reserve_mem() (jsc#PM-1318
  jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: add fadump support on powernv (jsc#PM-1318
  jsc#SLE-9099 jsc#SLE-9176).
- powerpc/opal: add MPIPL interface definitions (jsc#PM-1318
  jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: use FADump instead of fadump for how it is
  pronounced (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- pseries/fadump: move out platform specific support from generic
  code (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- Refresh patches.suse/powerpc-fadump-when-fadump-is-supported-register-the.patch.
- powerpc/fadump: release all the memory above boot memory size
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: add source info while displaying region contents
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- pseries/fadump: define RTAS register/un-register callback
  functions (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- Refresh patches.suse/powerpc-fadump-when-fadump-is-supported-register-the.patch.
- powerpc/fadump: introduce callbacks for platform specific
  operations (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: move rtas specific definitions to platform code
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: use helper functions to reserve/release cpu
  notes buffer (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: Improve fadump documentation (jsc#PM-1318
  jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: declare helper functions in internal header file
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- powerpc/fadump: add helper functions (jsc#PM-1318 jsc#SLE-9099
  jsc#SLE-9176).
- powerpc/fadump: move internal macros/definitions to a new header
  (jsc#PM-1318 jsc#SLE-9099 jsc#SLE-9176).
- commit deefc64
* Mon Sep 23 2019 msuchanek@suse.de
- Refresh sorted section.
- Refresh patches.suse/powerpc-dump-kernel-log-before-carrying-out-fadump-o.patch with upstream status.
- commit 9991920
* Wed Sep 18 2019 jroedel@suse.de
- Update config files.
  Disable CONFIG_ARM_SMMU_DISABLE_BYPASS_BY_DEFAULT. Not all drivers are
  ready for this yet, so enabling this config option causes regressions.
  See bsc#1150577 for an example.
- commit 76ac02e
* Mon Sep 16 2019 jroedel@suse.de
- Delete patches.suse/0001-iommu-vt-d-Fix-race-condition-in-add_unmap.patch.
- commit b0363d2
* Mon Sep 16 2019 mkubecek@suse.cz
- Update to 5.3 final
- Eliminated 3 patches
- Refresh configs
  - NF_CONNTRACK_SLP is gone
- commit 6baef36
* Fri Sep 13 2019 tonyj@suse.de
- Move guarded patch into it's own out of tree section
- commit 081b55b
* Fri Sep 13 2019 msuchanek@suse.de
- powerpc/pseries: correctly track irq state in default idle
  (bsc#1150727 ltc#178925).
- commit 97a4665
* Wed Sep 11 2019 mgorman@suse.de
- series.conf: Add note on why pcc-cpufreq patch is being held for evaluation
- commit a514b48
* Tue Sep 10 2019 mkubecek@suse.cz
- Delete patches.suse/netfilter-ip_conntrack_slp.patch (FATE#324143 jsc#SLE-8944 bsc#1127886).
  This veteran out of tree patch is no longer needed since the userspace
  conntrack helper (in conntrack-tools / conntrackd) has reached Factory.
- commit d6f0b71
* Tue Sep 10 2019 mkubecek@suse.cz
- Update and reenable
  patches.suse/Revert-netfilter-conntrack-remove-helper-hook-again.patch
  (FATE#324143 jsc#SLE-8944 bsc#1127886).
- commit 029452e
* Tue Sep 10 2019 msuchanek@suse.de
- powerpc: dump kernel log before carrying out fadump or kdump
  (bsc#1149940 ltc#179958).
- commit 4b365d2
* Tue Sep 10 2019 msuchanek@suse.de
- Refresh patches.suse/net-ibmvnic-Fix-missing-in-__ibmvnic_reset.patch.
- commit 0ebba63
* Tue Sep 10 2019 mkubecek@suse.cz
- series.conf: update sorted section banner
  Make the commit above sorted section less ambiguous. In particular, state
  clearly that patches without Git-commit which cannot be handled by git-sort
  do not belong in it.
- commit 1506bb8
* Tue Sep 10 2019 mkubecek@suse.cz
- series.conf: move unsortable patch out of sorted section
  Patch without Git-commit cannot be sorted so that there is no point having
  it into the sorted section.
- commit f18376e
* Mon Sep  9 2019 msuchanek@suse.de
- net/ibmvnic: Fix missing { in __ibmvnic_reset (bsc#1149652
  ltc#179635).
- commit a3cd2bf
* Mon Sep  9 2019 msuchanek@suse.de
- net/ibmvnic: free reset work of removed device from queue
  (bsc#1149652 ltc#179635).
- commit e64984b
* Mon Sep  9 2019 ailiopoulos@suse.com
- Refresh
  patches.suse/xfs-repair-malformed-inode-items-during-log-recovery.patch.
- commit cbb6da0
* Mon Sep  9 2019 mgorman@suse.de
- config: enable SLAB_FREELIST_HARDENED (bsc#1127808)
  Enable SLAB_FREELIST_HARDENED on all architectures. This obscures the
  free object pointer on a per-cache basis making it more difficult to
  locate kernel objects via exploits probing the cache metadata.
  This change was requested by the upstream openSUSE community to make
  the kernel more resistent to slab freelist attacks. Tests conducted
  by the kernel performance teams confirmed that the performance impact
  is detectable but negligible.
- commit 39e9013
* Mon Sep  9 2019 guillaume.gardet@arm.com
- rpm/constraints.in: lower disk space required for ARM
  With a requirement of 35GB, only 2 slow workers are usable for ARM.
  Current aarch64 build requires 27G and armv6/7 requires 14G.
  Set requirements respectively to 30GB and 20GB.
- commit f84c163
* Mon Sep  9 2019 mkubecek@suse.cz
- Update to 5.3-rc8
- refresh armv6hl configs (IXP4xx drivers no longer visible)
- commit 3dea797
* Mon Sep  9 2019 mkubecek@suse.cz
- config: enable STACKPROTECTOR_STRONG also on armv6hl
  Recently reenabled armv6hl architecture has STACKPROTECTOR_STRONG disabled,
  enable it here as well.
- commit 8c0677d
* Fri Sep  6 2019 msuchanek@suse.de
- powerpc/tm: Fix restoring FP/VMX facility incorrectly on
  interrupts (CVE-2019-15031 bsc#1149713).
- powerpc/tm: Fix FP/VMX unavailable exceptions inside a
  transaction (CVE-2019-15030 bsc#1149713).
- commit ca72e89
* Fri Sep  6 2019 mkubecek@suse.cz
- series.conf: move unsortable patch out of sorted section
- commit 8a360b5
* Thu Sep  5 2019 msuchanek@suse.de
- powerpc/xmon: Add a dump of all XIVE interrupts (bsc#1142019).
- powerpc/xive: Fix dump of XIVE interrupt under pseries
  (bsc#1142019).
- powerpc/xmon: Check for HV mode when dumping XIVE info from OPAL
  (bsc#1142019).
- commit 68e4d5a
* Wed Sep  4 2019 mbenes@suse.cz
- Enable klp-convert patches
  Enable patches.suse/livepatch-create-and-include-UAPI-headers.patch
  Enable and refresh patches.suse/livepatch-modpost-ignore-unresolved-symbols.patch
  Still not in upstream. Submitted though. It seems the final upstream
  version will be a bit different, but we need these two patches for our
  use case.
- commit f385ff2
* Wed Sep  4 2019 mbenes@suse.cz
- Enable patches.suse/livepatch-mark-the-kernel-unsupported-when-disabling.patch
  Still SUSE-specific and still needed.
- commit cd16e71
* Tue Sep  3 2019 msuchanek@suse.de
- powerpc/fadump: when fadump is supported register the fadump
  sysfs files (bsc#1146352).
- commit da248a6
* Tue Sep  3 2019 mkubecek@suse.cz
- config: enable STACKPROTECTOR_STRONG (jsc#SLE-9120 bsc#1130365)
  Enable CONFIG_STACKPROTECTOR_STRONG on all architectures except s390x
  (where the feature is not available). This extends the number of functions
  which are protected by "stack canary" check to catch functions writing past
  their stack frame.
  This change was requested by SUSE security to make our kernels more
  resistant to some types of stack overflow attacks. Tests performed by
  kernel performance teams confirmed that performance impact is acceptable.
- commit 4c43fab
* Tue Sep  3 2019 neilb@suse.com
- Refresh
  patches.suse/0001-NFS-flush-out-dirty-data-on-file-fput.patch.
- Refresh
  patches.suse/0001-NFSv4-don-t-let-hanging-mounts-block-other-mounts.patch.
- NFS: Allow multiple connections to NFSv4.0 servers
  (fate#322786).
- Refresh patches.suse/nfs-set-acl-perm.patch.
- Delete
  patches.suse/0001-NFSv4-handle-EINVAL-from-EXCHANGE_ID-better.patch.
- Delete
  patches.suse/0001-SUNRPC-Allow-creation-of-RPC-clients-with-multiple-c.patch.
- Delete
  patches.suse/0001-sunrpc-include-sup-groups-in-hash.patch.
- Delete
  patches.suse/0002-NFS-Add-a-mount-option-to-specify-number-of-TCP-conn.patch.
- Delete
  patches.suse/0003-NFSv4-Allow-multiple-connections-to-NFSv4.x-x-0-serv.patch.
- Delete
  patches.suse/0004-pNFS-Allow-multiple-connections-to-the-DS.patch.
- Delete
  patches.suse/0005-NFS-Display-the-nconnect-mount-option-if-it-is-set.patch.
- Delete
  patches.suse/0007-SUNRPC-Mask-XIDs-to-prevent-replay-cache-collision.patch.
- Delete patches.suse/NFS-optional-NFSv4_2-fix.patch.
- Delete patches.suse/NFS-optional-NFSv4_2.patch.
- Delete patches.suse/d-lookup-fairness.fix.
- Delete
  patches.suse/getcwd-close-race-with-d_move-called-by-lustre.patch.
- Delete
  patches.suse/sunrpc-cache-handle-missing-listeners-better.patch.
- Delete
  patches.suse/vfs-use-synchronize_rcu_expedited-in-namespace_unlock.patch.
- commit 4685373
* Mon Sep  2 2019 mkubecek@suse.cz
- Update to 5.3-rc7
- Refresh configs
  - IXP4xx SoC drivers not visible
  - gcc 9.2.1
- commit 9bff5f9
* Sun Sep  1 2019 mkubecek@suse.cz
- config: armv7hl: Enable cadence watchdog
  CONFIG_CADENCE_WATCHDOG is required for Zynq-7000 based MIYR Zturn board.
- commit 64fda45
* Fri Aug 30 2019 mkubecek@suse.cz
- config: enable armv7hl
  Import armv7hl configs from master branch, update them for Leap 15.2 and
  enable in config.conf.
- commit f85f2d7
* Fri Aug 30 2019 jthumshirn@suse.de
- Delete patches.suse/nvdimm-testing-provide-SZ_4G.patch.
  The patch was SLE15{,-SP1} specific to provide a constant already
  contained in kernel 5.3.
- commit 4ea3f92
* Fri Aug 30 2019 dmueller@suse.com
- config.conf: Update ARMv6 config files
- commit c17167d
* Fri Aug 30 2019 dmueller@suse.com
- config.conf: Reenable ARMv7 config for Kernel 5.3
  All modules plus errata's enabled. Reused other
  values from x86_64 update.
- commit b1c627e
* Fri Aug 30 2019 tzimmermann@suse.de
- Add "drm/ttm: Remove warning about inconsistent mapping information"
  This patch removes a warning that causes bug reports unnecessarily.
- commit 4a7bc21
* Fri Aug 30 2019 tzimmermann@suse.de
- Add "Reserve 64MiB of CMA for RPi3's VC4"
  Taking this patch from SLE15-SP1 with updates for v5.3. Enables display
  when booting RPi3 installer.
- commit 9fab830
* Fri Aug 30 2019 tzimmermann@suse.de
- Remove "drm/msm: fix address space warning"
  The respective code was removed in v4.20.
- commit 3d7e3d1
* Fri Aug 30 2019 jslaby@suse.cz
- Refresh
  patches.suse/0003-kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
  Add more placeholders to device.h. In particular, to structs bus_type,
  device_driver, class, and device.
- commit c4220a5
* Thu Aug 29 2019 msuchanek@suse.de
- scsi: cxlflash: Mark expected switch fall-throughs
  (bsc#1148868).
- commit ea514bf
* Wed Aug 28 2019 tiwai@suse.de
- mwifiex: Fix three heap overflow at
  parsing element in cfg80211_ap_settings
  (CVE-2019-14814,bsc#1146512,CVE-2019-14815,bsc#1146514,CVE-2019-14816,bsc#1146516).
- commit 528fd68
* Wed Aug 28 2019 mkubecek@suse.cz
- supported.conf: drop obsolete entries
  Drop supported.conf entries not matching any module built on any
  supported architecture. This commit mostly drops entries for modules
  built in master branch but not SLE15-SP2. Moved and no longer existing
  modules were handled in previous commits in master branch.
- commit 97fd102
* Wed Aug 28 2019 mkubecek@suse.cz
- supported.conf: mark more core networking modules supported
  Two more netfilter modules and one more *_diag should be supported too.
- commit bee2dd8
* Wed Aug 28 2019 mkubecek@suse.cz
- supported.conf: update status of some networking core modules
  This marks new networking modules which should be supported as such; it is
  mostly netfilter and traffic control modules which have been following the
  "support all of them" policy for some time.
- commit 65e1131
* Wed Aug 28 2019 mkubecek@suse.cz
- supported.conf: obsolete paths cleanup
  Update paths for existing modules which were moved, clean up duplicate
  entries and drop entries for modules which no longer exist (either not
  built any more or built into the image now).
- commit 3bb142a
* Wed Aug 28 2019 msuchanek@suse.de
- powerpc/64s: support nospectre_v2 cmdline option (bsc#1131107).
- commit 9cef94b
* Tue Aug 27 2019 mkubecek@suse.cz
- series.conf: add section for SUSE kabi padding patches
  Leave "kABI consistency patches" only for patches.kabi/*
- commit 81c3a75
* Tue Aug 27 2019 mkubecek@suse.cz
- series.conf: move unguarded patches from review section
- commit 6de2b58
* Tue Aug 27 2019 mkubecek@suse.cz
- rpm: raise required disk space for binary packages
  Current disk space constraints (10 GB on s390x, 25 GB on other
  architectures) no longer suffice for 5.3 kernel builds. The statistics
  show ~30 GB of disk consumption on x86_64 and ~11 GB on s390x so raise
  the constraints to 35 GB in general and 14 GB on s390x.
- commit 527cb66
* Tue Aug 27 2019 mhocko@suse.com
- enable and refresh
  patches.suse/memcg-deprecate-memory.force_empty-knob.patch.
- enable patches.suse/mm-inform-about-enabling-mirrored-memory.patch
  both patches are minimal and still useful to identify future
  supportability problems.
- commit 93500e8
* Tue Aug 27 2019 jack@suse.cz
- Update patches.suse/ext4-unsupported-features.patch
  (fate#317919, SLE-8615).
- commit 3b1bc66
* Tue Aug 27 2019 jack@suse.cz
- Refresh and enable valid patches from SLE15-SP1:
- Refresh patches.suse/ext4-dont-warn-when-enabling-DAX.patch.
- Refresh patches.suse/ext4-unsupported-features.patch.
- Refresh patches.suse/unsupported-features.patch.
- commit 9ef1a75
* Tue Aug 27 2019 jack@suse.cz
- Remove patches obsoleted by upstream changes:
- Delete
  patches.suse/arch-powerpc-dax-Add-MAP_SYNC-mmap-flag.patch.
- Delete
  patches.suse/block-Don-t-revalidate-bdev-of-hidden-gendisk.patch.
- Delete patches.suse/fs-speedup-clean-bdev-aliases.patch.
- Delete
  patches.suse/mm-migrate-Fix-reference-check-race-between-__find_get_block-and-migration.patch.
- Delete patches.suse/powerpc-Add-pmem.h.patch.
- commit 21008fb
* Tue Aug 27 2019 bpoirier@suse.com
- Refresh patches.suse/qlge-Deduplicate-lbq_buf_size.patch.
- Refresh
  patches.suse/qlge-Deduplicate-rx-buffer-queue-management.patch.
- Refresh patches.suse/qlge-Remove-bq_desc.maplen.patch.
- Refresh
  patches.suse/qlge-Remove-useless-dma-synchronization-calls.patch.
  Reenable qlge patch series for bsc#1106061
- commit b2971c6
* Mon Aug 26 2019 mgorman@suse.de
- sched: Further improve spurious CPU_IDLE active migrations
  (bnc# 986383).
- Update
  patches.suse/cpufreq-ondemand-set-default-up_threshold-to-30-on-multi-core-systems.patch
  (bnc#464461,bnc#981838,bnc#1064414,bnc#1144943).
- Refresh
  patches.suse/mm-Warn-users-of-node-memory-hot-remove-if-the-memory-ratio-is-a-high-risk.patch.
- Update
  patches.suse/sched-Fix-up-proc-sched_debug-to-print-only-runnable-tasks-again.patch
  (none, should be posted upstream).
- Update
  patches.suse/sched-fair-Enable-SIS_AVG_CPU-by-default.patch
  (bsc#1061593,bsc#1148030).
- Refresh
  patches.suse/sched-topology-Improve-load-balancing-on-AMD-EPYC.patch.
- Delete
  patches.suse/0001-Revert-mm-vmacache-optimize-overflow-system-wide-flu.patch.
- Delete
  patches.suse/0001-sched-wake_q-Reduce-reference-counting-for-special-u.patch.
- Delete
  patches.suse/cpufreq-intel_pstate-Ramp-up-frequency-faster-when-utilisation-reaches-setpoint.patch.
- Delete
  patches.suse/cpufreq-intel_pstate-Temporarily-boost-P-state-when-exiting-from-idle.patch.
- Delete
  patches.suse/cpufreq-intel_pstate-Update-setpoint-for-unspecified-ACPI-profile.patch.
- Delete
  patches.suse/cpufreq-intel_pstate-Use-load-based-policy-by-default-but-allow-PID-to-be-used.patch.
- Delete
  patches.suse/mm-Adjust-watermark-boost-factor-tunable.patch.
- Delete
  patches.suse/mm-migrate-Fix-reference-check-race-between-__find_get_block-and-migration.patch.
- Delete
  patches.suse/mm-page_alloc.c-use-a-single-function-to-free-page.patch.
- commit 9de058d
* Mon Aug 26 2019 jgross@suse.com
- usb: Introduce Xen pvUSB frontend (xen hcd) (fate#315712).
- Update config files.
- usb: Add Xen pvUSB protocol description (fate#315712).
- commit b32b2bd
* Mon Aug 26 2019 mhocko@suse.com
- Delete
  patches.suse/mm-sparse-do-not-swamp-log-with-huge-vmemmap-allocat-fix.patch.
  not applicable as explained in the patch description.
- commit fbed5c2
* Mon Aug 26 2019 mhocko@suse.com
- Delete
  patches.suse/mm-__init_single_page-do-not-zero-core-struct-pages.patch.
  Not applicable because it was a fallout of a partial backport as noted
  in the changelog.
- commit 1e8b220
* Mon Aug 26 2019 mhocko@suse.com
- Delete
  patches.suse/0001-memory_hotplug-add-missing-newlines-to-debugging-out.patch.
  merged as 1ecc07fd0a6d350bbf4dc176e0d654661b304a30 in 5.0
- commit 5aa2923
* Mon Aug 26 2019 mhocko@suse.com
- Delete
  patches.suse/0001-x86-speculation-Prepare-entry-code-for-Spectre-v1-sw.patch.
- Delete
  patches.suse/0002-x86-speculation-Enable-Spectre-v1-swapgs-mitigations.patch.
- Delete
  patches.suse/x86-speculation-swapgs-exclude-ATOMs-from-speculating-through-SWAPGS.patch.
  swapgs fixes have been merged in 5.3-rc3.
- commit 24d8d43
* Mon Aug 26 2019 oneukum@suse.com
- Delete
  patches.suse/0049-commit-833689044e13a3fb8c6c03ad868375670d97010b.patch.
  No longer needed in SP2
- commit 13a1350
* Mon Aug 26 2019 oneukum@suse.com
- Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
  Shifted kABI placeholders back where they belong
- commit 2d913e0
* Mon Aug 26 2019 tiwai@suse.de
- Update reference for ath6kl fix (CVE-2019-15290,bsc#1146543).
- commit b08d3d5
* Mon Aug 26 2019 tiwai@suse.de
- Fix a NULL-ptr-deref bug in ath6kl_usb_alloc_urb_from_pipe
  (CVE-2019-15098,bsc#1146378).
- Fix a NULL-ptr-deref bug in ath10k_usb_alloc_urb_from_pipe
  (CVE-2019-15099,bsc#1146368).
- commit 758e216
* Mon Aug 26 2019 jslaby@suse.cz
- Delete patches.suse/tty-make-R3964-line-discipline-fail.patch.
  We no longer build (and support) R3964.
- commit 85b2e98
* Mon Aug 26 2019 jslaby@suse.cz
- Delete
  patches.suse/mlxsw-spectrum-Forbid-linking-to-devices-fix.patch.
  This was a fix for a bad commit in 4.12.* stable.
- commit e8f9b29
* Mon Aug 26 2019 jslaby@suse.cz
- Refresh
  patches.suse/0003-kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
  Enable it and add one more placeholder to mm_context_t.
- commit 00e7e80
* Mon Aug 26 2019 jslaby@suse.cz
- Delete
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Delete
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Delete
  patches.suse/0003-x86-idle-Control-Indirect-Branch-Speculation-in-idle.patch.
- Delete
  patches.suse/0004-x86-enter-Create-macros-to-restrict-unrestrict-Indir.patch.
- Delete
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Delete patches.suse/IBRS-forbid-shooting-in-foot.patch.
- Delete patches.suse/do-not-default-to-ibrs-on-skl.patch.
  Drop IBRS as we disabled it later anyway.
- commit c03b8fa
* Mon Aug 26 2019 bpoirier@suse.com
- Fix a double free bug in rsi_91x_deinit (bnc#1147116
  CVE-2019-15504).
- commit 8ae43d1
* Sun Aug 25 2019 mkubecek@suse.cz
- Update to 5.3-rc6
- commit 2831011
* Sun Aug 25 2019 ailiopoulos@suse.com
- Delete
  patches.suse/0001-module-warn-if-module-init-probe-takes-long.patch.
- commit f81e033
* Sun Aug 25 2019 ailiopoulos@suse.com
- Delete
  patches.suse/xfs-add-option-to-mount-with-barrier-0-or-barrier-1.patch.
  Since v4.10-rc1 xfs has deprecated all options that explicitly control
  barriers with commit 4cf4573d899c ("xfs: deprecate barrier/nobarrier
  mount option").
  Drop backwards-compat patch for parsing the obsolete barrier=[0|1]
  syntax of the option, since supporting this causes more confusion and
  gives the false impression that disabling barriers is still a
  possibility.
- commit 0ac0c38
* Sun Aug 25 2019 ailiopoulos@suse.com
- xfs: remove experimental tag for dax support (FATE#324503).
- commit f13a4a4
* Sun Aug 25 2019 ailiopoulos@suse.com
- Delete patches.suse/xfs-unsupported-features.patch.
  Drop unsupported features patch which was marking reflink and rmap
  as unsupported. The experimental tags were dropped for both features
  and thus marked stable upstream on v4.16-rc1, with the two following
  commits:
  commit 1e369b0e199b ("xfs: remove experimental tag for reflinks")
  commit 76883f7988e6 ("xfs: remove experimental tag for reverse mapping")
  While we follow upstream here, SLE15.2 xfsprogs/mkfs.xfs will not be
  switching on reflink/rmap by default for newly created filesystems.
  Regarding dax, contrary to upstream we have been supporting it for a
  while and removing the experimental tag, and we will continue doing so.
  The related patch for DAX will be posted as a separate commit for
  clarity.
- commit f84ab02
* Fri Aug 23 2019 ohering@suse.de
- remove stale SLE15-SP1 patches, keep a pci-hyperv patch (bsc#1142701)
- commit b0bbc9a
* Fri Aug 23 2019 msuchanek@suse.de
- Fix livepatch build.
- commit b7e78e8
* Fri Aug 23 2019 tiwai@suse.de
- Move a PCI fix patch to the-stairway-to-heaven section
- commit 3c94e42
* Fri Aug 23 2019 tiwai@suse.de
- Drop downstream DRM mgag200 patches
  Some of them are no longer applicable, some are invalid, and the rest
  won't be taken by upstream.  Let's rip them off.
- commit 1108d1d
* Fri Aug 23 2019 mbrugger@suse.com
- Delete patches.suse/irq-stub-affinity.patch.
- commit f5fe3d1
* Fri Aug 23 2019 mkubecek@suse.cz
- series.conf: move submitted patch out of sorted section
  Move
  patches.suse/ibmveth-Update-ethtool-settings-to-reflect-virtual-p.patch
  from sorted section to "soon to be mainline" section.
  For SLE15-SP2, we only want patches which git_sort can do something with in
  sorted section. Moreover, upstream discussion suggests that this patch is
  unlikely to be accepted in this form.
- commit 46df5db
* Fri Aug 23 2019 msuchanek@suse.de
- Remove obsolete build fix.
  Delete patches.suse/Fix-build-error-in-drmem.c.patch.
- commit 39eb823
* Fri Aug 23 2019 msuchanek@suse.de
- Restore ibmveth patch.
  Refresh patches.suse/ibmveth-Update-ethtool-settings-to-reflect-virtual-p.patch.
- commit d129c25
* Fri Aug 23 2019 msuchanek@suse.de
- Remove obsolete kABI padding in paca.
  Delete patches.suse/powerpc-KABI-add-aux_ptr-to-hole-in-paca_struct-to-e.patch.
- commit ae6527d
* Fri Aug 23 2019 msuchanek@suse.de
- Restore s390 crash KMP export.
- commit 2850611
* Fri Aug 23 2019 msuchanek@suse.de
- Delete obsolete pkey and bcm2835 patches.
- commit 7f76e58
* Fri Aug 23 2019 hare@suse.de
- Delete
  patches.suse/qla2xxx-Enable-T10-DIF-with-FC-NVMe-enabled.patch.
- Delete patches.suse/s390-sles15-03-01-rwlock.patch.
- Delete
  patches.suse/scsi-qla2xxx-do-not-crash-on-uninitialized-pool-list.patch.
- Delete
  patches.suse/scsi-qla2xxx-qla2x00_alloc_fw_dump-set-ha-eft.patch.
- commit 9c5d24e
* Fri Aug 23 2019 hare@suse.de
- Refresh patches.suse/md-display-timeout-error.patch.
- commit 83d69fe
* Fri Aug 23 2019 hare@suse.de
- Delete patches.suse/nvme-multipath-round-robin-I-O-policy.patch.
- commit cb248a3
* Fri Aug 23 2019 hare@suse.de
- Delete patches.suse/qla2xxx-always-allocate-qla_tgt_wq.patch.
- commit 7005228
* Fri Aug 23 2019 hare@suse.de
- Delete
  patches.suse/block-Fix-a-NULL-pointer-dereference-in-generic_make.patch.
- commit 5284ba5
* Fri Aug 23 2019 hare@suse.de
- Delete
  patches.suse/dasd_fba-Display-00000000-for-zero-page-when-dumping.patch.
- Delete patches.suse/s390-sles15-message-catalog.patch.
- commit 6885922
* Fri Aug 23 2019 tiwai@suse.de
- Revive some downstream DRM patches and delete obsoleted patches
  Refreshed for 5.3:
  patches.suse/drm-i915-Disable-tv-output-on-i9x5gm
  patches.suse/drm-mgag200-Implement-basic-PM-support
  Deleted, as no longer needed for 5.3:
  patches.suse/HID-quirks-fix-support-for-Apple-Magic-Keyboards.patch
  patches.suse/Input-synaptics-Add-intertouch-blacklist-for-Thinkpa.patch
  patches.suse/drm-i915-CVE-2018-20669-access-check.patch
  patches.suse/kernel-Export-mm_access.patch
  patches.suse/mmc-version-check-printk-downgrade
  patches.suse/tpm-Downgrade-error-level
  patches.suse/tty-Don-t-return-EAGAIN-in-blocking-read.patch
- commit d9bc0ec
* Fri Aug 23 2019 mkubecek@suse.cz
- Delete
  patches.suse/irda-Fix-memory-leak-caused-by-repeated-binds-of-ird.patch
  patches.suse/irda-Only-insert-new-objects-into-the-global-databas.patch
  These are CVE fixes for a driver dropped in mainline 4.17.
- commit 2f68f7e
* Fri Aug 23 2019 mkubecek@suse.cz
- import non-mainline SLE15-SP1 patches
  Import all SLE15-SP1 (kernel-source commit 0181a93c80e7) patches which are
  not in mainline yet (as of commit 59c36bc8d377). All patches are added at
  the end of series.conf with a guard indicating who is/was responsible for
  them (using first of From:, Signed-off-by:, Acked-by:, Reviewed-by: and
  commiter with address containing '@suse.' or '@novell.').
  Some of non-mainline patches in SLE15-SP1 branch match existing SLE15-SP2
  patches. For these, SLE15-SP2 version (inherited from master branch) is
  preserved.
  This commit has no effect on expanded tree.
- commit ec8941d
* Fri Aug 23 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Fix kernel-livepatch description typo.
- commit 36acf91
* Fri Aug 23 2019 mkubecek@suse.cz
- update branch metadata
- fix OBS build project (15.1 -> 15.2)
- set BUGZILLA_PRODUCT to "openSUSE Distribution"
- commit faed656
* Thu Aug 22 2019 msuchanek@suse.de
- Pull packaging cleanup from mkubecek.
- Parametrize kgraft vs livepatch.
- commit 16f6816
* Thu Aug 22 2019 msuchanek@suse.de
- rpm/config.sh: Enable livepatch.
- commit e001776
* Thu Aug 22 2019 mkubecek@suse.cz
- config: import configs from master branch
  Copy Tumbleweed configs from master branch, adjust CONFIG_SUSE_* options
  for openSUSE Leap 15.2 and refresh the configs with gcc 7.4.
- commit 5a5dbd7
* Thu Aug 22 2019 mkubecek@suse.cz
- update branch metadata
- update README.BRANCH text
- update build project in rpm/config.sh
- commit 6408d97
* Thu Aug 22 2019 mkubecek@suse.cz
- config: restore correct PHYSICAL_START and PHYSICAL_ALIGN on x86_64
  These were already fixed in master by kernel-source commit baa2434a5ab6 but
  old (and wrong) values were restored by merge of SLE15-SP1 config. Fix them
  also in SLE15-SP2 now.
- commit 9b6f95a
* Thu Aug 22 2019 mkubecek@suse.cz
- config: update from SLE15-SP2
  In general, we want features and drivers from SLE also in openSUSE unless
  we have a good reason not to. Enable most config options which were
  disabled in master but enabled in SLE15-SP2 (inherited from SLE15-SP1).
- commit 769684a
* Wed Aug 21 2019 msuchanek@suse.de
- powerpc/rtas: use device model APIs and serialization during
  LPM (bsc#1144123 ltc#178840).
- commit 9f79b99
* Wed Aug 21 2019 mkubecek@suse.cz
- series.conf: reorganize sections
  With ~40 patches in master branch, we have accumulated way too many
  sections in series.conf, some of them being very specific. While new SLE
  and Leap branches are going to have more patches, vast majority of them is
  going to end up in the sorted section (e.g. less than 1%% of SLE15-SP1
  patches are neither sorted nor stable baskports right now - and that
  includes quite a few which would actually belong into the sorted section
  but are left outside for historical reasons).
  After the reorganization, series.conf is ordered like this:
  - stable backports (patches.kernel.org/*)
  - tweaks applied to vanilla (patches.rpmify/*)
  - sorted section (not in master)
  - unsorted patches expected to get into mainline soon
  - permanent and longterm non-upstream patches
  - kabi hacks (not in master)
  This commit has no effect on expanded tree.
- commit 8ac1895
* Wed Aug 21 2019 mkubecek@suse.cz
- series.conf: cleanup
  Only whitespace and comments, no efect on expanded tree.
- commit bf21808
* Tue Aug 20 2019 mkubecek@suse.cz
- config: import SLE15-SP1 configs
  Replace configs inherited from master branch by proper SLE ones. With few
  obvious exceptions, the initial SLE15-SP2 configs were created using these
  rules (for each option, use first rule which applies):
  - use value explicitly changed with reference to a feature or a bug
  - use value from SLE15-SP1 if the option exists there
  - use value from master if the option exists there
  - use upstream default
  The configs will need review by people responsible for specific kernel
  subsystems and architectures.
  Also update supported.conf with new modules:
  - add intel_pmc_core_pltdrv as unsupported
  - fix cfb{copyarea,fillrect,imgblt} path and mark "+base" as virtio-gpu
    depends on them
- commit dded633
* Mon Aug 19 2019 bp@suse.de
- Update config files.
  As per https://jira.suse.com/browse/SLE-7041
  Factory first!
- commit 126cef1
* Mon Aug 19 2019 mkubecek@suse.cz
- Update README.BRANCH
- drop Jeff Mahoney (inherited from master)
- add Miroslav Benes as comaintainer
- drop misleading paragraph left from master branch
- commit 4300e4e
* Mon Aug 19 2019 mkubecek@suse.cz
- Update to 5.3-rc5
- Refresh configs
  - RDMA_SIW available on i386 (=m)
  - clean up unavailable options
- commit cadbe00
* Sun Aug 18 2019 afaerber@suse.de
- config: arm64: Enable I2C_IMX (boo#1146026)
  Needed for Google Coral board.
- commit 8803b04
* Thu Aug 15 2019 msuchanek@suse.de
- Revert "Workaround gcc regression on ppc64 (bko#204125)."
  This reverts commit 8b84d1d46ff90146bb6ba5b760a54ddd87a1a680.
  Works for me 5.3-rc4-65-g329120423947
- commit d8f9e6c
* Mon Aug 12 2019 msuchanek@suse.de
- config.conf: syms should not depend on kernel-zfcpdump
  Kernel-zfcpdump is not modular so kernel-zfcpdump-devel does not make
  sense and is not built. kernel-syms cannot depend on it.
- commit 473ac28
* Mon Aug 12 2019 msuchanek@suse.de
- rpm/mkspec: Correct tarball URL for rc kernels.
- commit c4ef18d
* Sun Aug 11 2019 mkubecek@suse.cz
- config: refresh with gcc7
  Unlike master branch, SLE15-SP2 is supposed to be built with gcc7. At
  the moment, this only makes a significant difference on aarch64 (which
  we already refreshed with gcc 7.4.0 for this reason) but let's refresh
  all configs to make it more visible.
- commit 67e1879
* Sun Aug 11 2019 mkubecek@suse.cz
- Update to 5.3-rc4
- Refresh
  - patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
- commit 5402233
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/config.sh: Enable building DTBs.
- commit 7de292a
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/mkspec: Make building DTBs optional.
- commit 7c057c8
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: fix supported modules depending on unsupported on non-x86_64 architectures
  Some more "unsupported module needed by supported one" errors were reported
  on aarch64 and ppc64le.
- commit 6b609de
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: drop obsolete entry for hyperv_fb
  The module moved to a different directory, the obsolete entry causes
  file conflict betwen kernel-default and kernel-default-extra.
- commit 6b112e5
* Fri Aug  9 2019 msuchanek@suse.de
- rpm/modflist: Simplify compression support.
- commit fd135a6
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: close with respect to dependencies
  Modules which some supported module depends on must be supported as well.
  Also drop obsolete entries for rtsx_pci and rtsx_usb which were moved
  between 4.12 and 5.3.
- commit b781c36
* Fri Aug  9 2019 mkubecek@suse.cz
- rpm: support compressed modules
  Some of our scripts and scriptlets in rpm/ do not expect module files not
  ending with ".ko" which currently leads to failure in preuninstall
  scriptlet of cluster-md-kmp-default (and probably also other subpackages).
  Let those which could be run on compressed module files recognize ".ko.xz"
  in addition to ".ko".
- commit 18fcdff
* Fri Aug  9 2019 msuchanek@suse.de
- Bring back MODVERDIR to Makefile.modpost (bsc#1066369).
- commit 6cc69f5
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: sort again
  Make the order compatible with scripts/supported-conf-fixup (LC_ALL=C).
- commit 4a4b5dd
* Fri Aug  9 2019 msuchanek@suse.de
- supported.conf: Sort alphabetically, align comments.
- commit 5189766
* Fri Aug  9 2019 mkubecek@suse.cz
- series.conf: cleanup
  Move patches.suse/0001-oracleasm-4.0-compat-changes.patch
  to more appropriate place.
- commit 2080902
* Fri Aug  9 2019 mkubecek@suse.cz
- supported.conf: drop extensions
  To make things more consistent, drop all ".ko" extensions.
- commit 398461b
* Fri Aug  9 2019 mkubecek@suse.cz
- Update patches.suse/supported-flag.
  Fix ReST table.
- commit 0692bf4
* Thu Aug  8 2019 msuchanek@suse.de
- Use upstream TAINT_AUX for TAINT_EXTERNAL_SUPPORT.
  Refresh patches.suse/supported-flag.
- commit a4999e0
* Thu Aug  8 2019 dmueller@suse.com
- rpm/kernel-obs-build.spec.in: add dm-crypt for building with cryptsetup
  Co-Authored-By: Adam Spiers <aspiers@suse.com>
- commit 7cf5b9e
* Thu Aug  8 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Enable supported.conf check.
- commit 96adf4d
* Thu Aug  8 2019 msuchanek@suse.de
- Update arm64 config files.
- commit 1e7a157
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: add missing entries for all architectures
  As list of built modules depends on architecture, we must also add entries
  for modules which are not built (or do not even exist) on x86_64 but are
  built on other architectures (aarch64, ppc64le, s390x).
- commit 8f74082
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: add missing entries
  Add all modules currently built but not listed in supported.conf.
  Another update will be necessary once we replace configs inherited from
  master with true SLE15-SP2 configs. This is also why entries for modules
  not built are left in the file for now.
- commit 0f5033c
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: sort
  Also remove one commented out line.
- commit b539157
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: cleanup
  Remove duplicate and shadowed entries.
- commit 25e91ec
* Thu Aug  8 2019 mkubecek@suse.cz
- supported.conf: update from SLE15-SP1
  Differences from current SLE15-SP1 supported.conf:
  - f71808e_wdt and it87_wdt supported (jdelvare)
  - bpfilter marked +base (tiwai, bsc#1106751)
  - unified indentation
- commit 02162e4
* Wed Aug  7 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: support partial rt debug config.
- commit af37821
* Wed Aug  7 2019 msuchanek@suse.de
- rpm/config.sh: Update OBS build project to 15 SP1.
- commit 03e63ed
* Wed Aug  7 2019 afaerber@suse.de
- config: arm64: Update to 5.3-rc3
- commit f1f49f3
* Wed Aug  7 2019 mkubecek@suse.cz
- config: disable preemption
  Full update to configs based on SLE15-SP1 will follow later.
- commit 84c63fb
* Wed Aug  7 2019 afaerber@suse.de
- config: Enable SENSORS_GPIO_FAN for all of Arm (boo#1144723)
  We already had it for armv6hl but were lacking it on arm64.
  Add it on armv7hl for consistency while at it.
- commit 607ebeb
* Wed Aug  7 2019 mkubecek@suse.cz
- series.conf: add sorted section
  Also mark kabi section on top explicitly as intended only for kabi patches
  related to stable backports and add kabi section for the rest at the end of
  the file (so that these can be dropped easily).
- commit 3df2daa
* Wed Aug  7 2019 msuchanek@suse.de
- README.BRANCH: Change branch name to 15 SP2
- commit 5135437
* Wed Aug  7 2019 msuchanek@suse.de
- config.conf: Remove non-SLE configs.
- Update config files with SLE product number.
- commit f002b36
* Wed Aug  7 2019 msuchanek@suse.de
- rpm/config.sh: Update to 15 SP2
  - update IBS project
  - update bugzilla product
  - sort series
- commit 41fafbc
* Mon Aug  5 2019 mkubecek@suse.cz
- Update to 5.3-rc3
- Eliminated 1 patch
- Refresh
  - patches.suse/supported-flag
  - patches.suse/supported-flag-external
- Refresh configs
- commit 571863b
* Fri Aug  2 2019 bwiedemann@suse.de
- kernel-binary: Drop .kernel-binary.spec.buildenv (boo#1154578).
  Without this patch,
  /usr/src/linux-@VERSION@-@RELEASE_SHORT@-obj/x86_64/vanilla/.kernel-binary.spec.buildenv
  contained rpm %%_smp_mflags in a line like
  export MAKE_ARGS=" --output-sync -j4"
  This made it hard to produce bit-identical builds.
- commit 789d131
* Thu Aug  1 2019 mkubecek@suse.cz
- config: refresh x86_64/default
  With HBMC_AM654 disabled, nothing selects MULTIPLEXER any more.
- commit 07a1a73
* Wed Jul 31 2019 jdelvare@suse.de
- Update config files: CONFIG_HBMC_AM654=n
  The TI AM654 is an ARM64 SoC, so disable the driver on all other
  architectures.
- commit 042f63f
* Tue Jul 30 2019 schwab@suse.de
- packaging: add support for riscv64
- commit c2885ea
* Sun Jul 28 2019 mkubecek@suse.cz
- Update to 5.3-rc2
- Eliminated 1 patch
  - patches.suse/dma-mapping-use-dma_get_mask-in-dma_addressing_limit.patch
- Refresh
  - patches.suse/netfilter-ip_conntrack_slp.patch
- Config changes
  - NF_TABLES_BRIDGE=m (was =y)
- commit fc5ebf3
* Sat Jul 27 2019 msuchanek@suse.de
- rpm/macros.kernel-source: KMPs should depend on kmod-compat to build.
  kmod-compat links are used in find-provides.ksyms, find-requires.ksyms,
  and find-supplements.ksyms in rpm-config-SUSE.
- commit f97ca49
* Sat Jul 27 2019 msuchanek@suse.de
- scripts/run_oldconfig.sh: Fix update-vanilla
  When CC is set we want to use it for native only. Cross-compilation
  still needs the crosscompilers.
- commit 3b9fcdb
* Wed Jul 24 2019 msuchanek@suse.de
- dma-mapping: use dma_get_mask in dma_addressing_limited
  (https://lore.kernel.org/lkml/cda1952f-0265-e055-a3ce-237c59069a3f@suse.com/T/#u).
- commit c584343
* Wed Jul 24 2019 msuchanek@suse.de
- scripts/arch-symbols: add missing link.
- commit ee7c635
* Tue Jul 23 2019 tiwai@suse.de
- rpm/config.sh: enable kernel module compression (bsc#1135854)
- commit b333e24
* Tue Jul 23 2019 tiwai@suse.de
- Add kernel module compression support (bsc#1135854)
  For enabling the kernel module compress, add the item COMPRESS_MODULES="xz"
  in config.sh, then mkspec will pass it to the spec file.
- commit cdf5806
* Tue Jul 23 2019 msuchanek@suse.de
- Workaround gcc regression on ppc64 (bko#204125).
- commit 8b84d1d
* Tue Jul 23 2019 msuchanek@suse.de
- config.conf: Add ppc64 kvmsmall config (bsc#1137361).
- Remove superfluous i2c drivers from ppc64 config
  - CONFIG_I2C_ALGOPCA=m
  - CONFIG_I2C_AMD8111=m
  - CONFIG_I2C_CBUS_GPIO=m
  - CONFIG_I2C_DESIGNWARE_CORE=y
  - CONFIG_I2C_DESIGNWARE_PLATFORM=y
  - CONFIG_I2C_DESIGNWARE_PCI=m
  - CONFIG_I2C_OCORES=m
  - CONFIG_I2C_PCA_PLATFORM=m
  Can't get rid of i2c in kvmsmall anyway but at least the DW i2c is gone.
- commit 3d0102c
* Tue Jul 23 2019 jeffm@suse.com
- config: enable PPPoE for kvmsmall (bsc#1133945).
- commit 39d218a
* Mon Jul 22 2019 jeffm@suse.com
- config: remove unnecessary drivers from kvmsmall
  The initial merge was incomplete and needed revisiting, which didn't really
  happen.  Since then, new options have been added and not removed from
  kvmsmall, leading to grow in size.
  This commit uses the following blacklist:
  _(BT|CHARGER|CHROMEOS|CROS|DVB|DW|EDAC|FPGA|GPIO|GNSS|HID|INFINIBAND|IR|JOYSTICK|LEDS|MFD|PINCTRL|REGULATOR|RTC|SENSORS|SND_SOC|STAGING|TOUCHSCREEN|VIDEO|XEN|XILINX)[_=]
  ... along with some manual removal of NET_VENDORs with no relevant drivers.
- commit e850d85
* Mon Jul 22 2019 mkubecek@suse.cz
- rpm/klp-symbols: update to work with kernel >= 5.3
  Since mainline commit b7dca6dd1e59 ("kbuild: create *.mod with full
  directory path and remove MODVERDIR") in v5.3-rc1, *.mod files are created
  in the build tree rather than in a single directory .tmp_versions
  ($MODVERDIR). They also do not provide path to the *.ko module file on
  their first line as the path is the same (except for the suffix).
  Update klp-symbols script to handle this new layout and format of *.mod
  files to fix build of 5.3-rc1 and newer kernel.
  Note: this is a quick band-aid to fix master branch build without risk of
  breaking any other branch. A more proper cleanup will follow.
- commit c32f8e7
* Mon Jul 22 2019 mkubecek@suse.cz
- Update to 5.3-rc1
- Eliminated 89 patches (83 stable, 6 other)
- ARM configs need update
- Refresh
  patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/netfilter-ip_conntrack_slp.patch
  patches.suse/rpm-kernel-config
  patches.suse/supported-flag
  patches.suse/vfs-add-super_operations-get_inode_dev
- replace patches.rpmify/BPF-UMH-do-not-detect-if-compiler-can-link-userspace.patch
  with patches.rpmify/Kconfig-make-CONFIG_CC_CAN_LINK-always-true.patch
- New config options:
  - General setup
  - HEADER_TEST=y
  - KERNEL_HEADER_TEST=y
  - PREEMPT_LL=n
  - UCLAMP_TASK=y
  - UCLAMP_BUCKETS_COUNT=5
  - Processor type and features
  - ACRN_GUEST=y
  - LEGACY_VSYSCALL_XONLY=y
  - IO Schedulers
  - BFQ_CGROUP_DEBUG=n (=y in */debug)
  - Networking
  - NFT_SYNPROXY=m
  - NFT_BRIDGE_META=m
  - NF_CONNTRACK_BRIDGE=m
  - NET_ACT_MPLS=m
  - NET_ACT_CTINFO=m
  - NET_ACT_CT=m
  - BT_HCIBTUSB_MTK=y
  - GVE=m
  - MLX5_FPGA_IPSEC=y
  - MLX5_FPGA_TLS=y
  - MLX5_TLS=y
  - STMMAC_SELFTESTS=n
  - XILINX_AXI_EMAC=m
  - SFP=m
  - NXP_TJA11XX_PHY=m
  - PHY_MIXEL_MIPI_DPHY=m
  - File systems
  - UBIFS_FS_ZSTD=y
  - SUNRPC_DISABLE_INSECURE_ENCTYPES=n
  - CEPH_FS_SECURITY_LABEL=y
  - Generic driver options
  - FW_LOADER_COMPRESS=y
  - Storage
  - SCSI_FDOMAIN_PCI=m
  - SCSI_FDOMAIN_ISA=n
  - PCMCIA_FDOMAIN=n
  - Input
  - KEYBOARD_APPLESPI=m
  - Power supply and hardware monitoring
  - POWER_SUPPLY_HWMON=y
  - CHARGER_WILCO=m
  - SENSORS_IRPS5401=m
  - SENSORS_PXE1610=m
  - REGULATOR_ARIZONA_LDO1=m
  - REGULATOR_ARIZONA_MICSUPP=m
  - REGULATOR_SLG51000=m
  - Multimedia
  - DVB_USB_CXUSB_ANALOG=y
  - VIDEO_TDA1997X=m
  - VIDEO_TLV320AIC23B=m
  - VIDEO_ADV7180=m
  - VIDEO_ADV7183=m
  - VIDEO_ADV7604=m
  - VIDEO_ADV7604_CEC=y
  - VIDEO_ADV7842=m
  - VIDEO_ADV7842_CEC=y
  - VIDEO_BT819=m
  - VIDEO_BT856=m
  - VIDEO_BT866=m
  - VIDEO_KS0127=m
  - VIDEO_ML86V7667=m
  - VIDEO_SAA7110=m
  - VIDEO_TC358743=m
  - VIDEO_TC358743_CEC=y
  - VIDEO_TVP514X=m
  - VIDEO_TVP7002=m
  - VIDEO_TW9910=m
  - VIDEO_VPX3220=m
  - VIDEO_SAA7185=m
  - VIDEO_ADV7170=m
  - VIDEO_ADV7175=m
  - VIDEO_ADV7343=m
  - VIDEO_ADV7393=m
  - VIDEO_ADV7511=m
  - VIDEO_ADV7511_CEC=y
  - VIDEO_AD9389B=m
  - VIDEO_AK881X=m
  - VIDEO_THS8200=m
  - VIDEO_IMX214=m
  - VIDEO_IMX258=m
  - VIDEO_IMX274=m
  - VIDEO_IMX319=m
  - VIDEO_IMX355=m
  - VIDEO_OV2659=m
  - VIDEO_OV2680=m
  - VIDEO_OV2685=m
  - VIDEO_OV5647=m
  - VIDEO_OV6650=m
  - VIDEO_OV5670=m
  - VIDEO_OV5695=m
  - VIDEO_OV7251=m
  - VIDEO_OV772X=m
  - VIDEO_OV7740=m
  - VIDEO_OV8856=m
  - VIDEO_OV9640=m
  - VIDEO_OV9650=m
  - VIDEO_OV13858=m
  - VIDEO_VS6624=m
  - VIDEO_MT9M001=m
  - VIDEO_MT9M032=m
  - VIDEO_MT9M111=m
  - VIDEO_MT9P031=m
  - VIDEO_MT9T001=m
  - VIDEO_MT9T112=m
  - VIDEO_MT9V032=m
  - VIDEO_MT9V111=m
  - VIDEO_SR030PC30=m
  - VIDEO_NOON010PC30=m
  - VIDEO_M5MOLS=m
  - VIDEO_RJ54N1=m
  - VIDEO_S5K6AA=m
  - VIDEO_S5K6A3=m
  - VIDEO_S5K4ECGX=m
  - VIDEO_S5K5BAF=m
  - VIDEO_SMIAPP=m
  - VIDEO_ET8EK8=m
  - VIDEO_S5C73M3=m
  - VIDEO_AD5820=m
  - VIDEO_AK7375=m
  - VIDEO_DW9714=m
  - VIDEO_DW9807_VCM=m
  - VIDEO_ADP1653=m
  - VIDEO_LM3560=m
  - VIDEO_LM3646=m
  - SDR_MAX2175=m
  - VIDEO_THS7303=m
  - VIDEO_I2C=m
  - VIDEO_ST_MIPID02=n
  - VIDEO_GS1662=m
  - DVB_S5H1432=m
  - DVB_DIB9000=m
  - DVB_CXD2880=m
  - DVB_MN88443X=m
  - DVB_LNBH29=m
  - DVB_LGS8GL5=m
  - Graphics
  - DRM_AMD_DC_DCN2_0=y
  - DRM_AMD_DC_DSC_SUPPORT=y
  - DRM_I915_FORCE_PROBE=""
  - DRM_I915_DEBUG_MMIO=n
  - DRM_I915_USERFAULT_AUTOSUSPEND=250
  - DRM_I915_SPIN_REQUEST=5
  - DRM_PANEL_OSD_OSD101T2587_53TS=m
  - DRM_PANEL_SAMSUNG_S6E63M0=m
  - Sound
  - SND_SOC_INTEL_CML_H=m
  - SND_SOC_INTEL_CML_LP=m
  - SND_SOC_INTEL_BYT_CHT_CX2072X_MACH=m
  - SND_SOC_SOF_COMETLAKE_LP_SUPPORT=y
  - SND_SOC_SOF_COMETLAKE_H_SUPPORT=y
  - SND_SOC_CX2072X=m
  - InfiniBand
  - RDMA_SIW=m
  - Platform specific drivers
  - XIAOMI_WMI=m
  - ACPI_CMPC=m
  - SAMSUNG_Q10=m
  - INTEL_SPEED_SELECT_INTERFACE=m
  - CROS_EC_ISHTP=m
  - WILCO_EC_EVENTS=m
  - WILCO_EC_TELEMETRY=m
  - Industrial I/O
  - XILINX_XADC=n
  - ADF4371=n
  - DPS310=n
  - LEDs
  - LEDS_SPI_BYTE=m
  - LEDS_TI_LMU_COMMON=m
  - LEDS_LM3697=m
  - LEDS_LM36274=m
  - Other drivers
  - MTD_HYPERBUS=m
  - HBMC_AM654=m
  - XILINX_SDFEC=n
  - GPIO_XILINX=m
  - WATCHDOG_OPEN_TIMEOUT=0
  - MFD_CS47L15=y
  - MFD_CS47L92=y
  - MFD_ROHM_BD70528=n
  - RTC_DRV_BD70528=m
  - DW_EDMA=m
  - DW_EDMA_PCIE=m
  - COMMON_CLK_SI5341=m
  - EXTCON_FSA9480=m
  - NTB_MSI=y
  - NTB_MSI_TEST=n
  - RAS_CEC_DEBUG=n
  - AL_FIC=n
  - Virtualization
  - VIRTIO_PMEM=m
  - Security options
  - KEYS_REQUEST_CACHE=y
  - Kernel hardening options
  - INIT_ON_ALLOC_DEFAULT_ON=n
  - INIT_ON_FREE_DEFAULT_ON=n
  - Cryptographic API
  - CRYPTO_XXHASH=n
  - CRYPTO_DEV_ATMEL_ECC=m
  - CRYPTO_DEV_ATMEL_SHA204A=m
  - Kernel hacking
  - HEADERS_INSTALL=n
  - REED_SOLOMON_TEST=n
  - TEST_BLACKHOLE_DEV=n
  - TEST_MEMINIT=n
- commit 0a6d0d9
* Sun Jul 21 2019 mkubecek@suse.cz
- Revert "netfilter: conntrack: remove helper hook again"
  (http://lkml.kernel.org/r/20190718092128.zbw4qappq6jsb4ja@breakpoint.cc).
- commit 8e9a006
* Sun Jul 21 2019 jslaby@suse.cz
- Linux 5.2.2 (bnc#1012628).
- x86/entry/32: Fix ENDPROC of common_spurious (bnc#1012628).
- crypto/NX: Set receive window credits to max number of CRBs
  in RxFIFO (bnc#1012628).
- crypto: talitos - fix hash on SEC1 (bnc#1012628).
- crypto: talitos - move struct talitos_edesc into talitos.h
  (bnc#1012628).
- s390/qdio: don't touch the dsci in tiqdio_add_input_queues()
  (bnc#1012628).
- s390/qdio: (re-)initialize tiqdio list entries (bnc#1012628).
- s390: fix stfle zero padding (bnc#1012628).
- s390/ipl: Fix detection of has_secure attribute (bnc#1012628).
- ARC: hide unused function unw_hdr_alloc (bnc#1012628).
- x86/irq: Seperate unused system vectors from spurious entry
  again (bnc#1012628).
- x86/irq: Handle spurious interrupt after shutdown gracefully
  (bnc#1012628).
- x86/ioapic: Implement irq_get_irqchip_state() callback
  (bnc#1012628).
- genirq: Add optional hardware synchronization for shutdown
  (bnc#1012628).
- genirq: Fix misleading synchronize_irq() documentation
  (bnc#1012628).
- genirq: Delay deactivation in free_irq() (bnc#1012628).
- firmware: improve LSM/IMA security behaviour (bnc#1012628).
- drivers: base: cacheinfo: Ensure cpu hotplug work is done
  before Intel RDT (bnc#1012628).
- nilfs2: do not use unexported cpu_to_le32()/le32_to_cpu()
  in uapi header (bnc#1012628).
- Input: synaptics - enable SMBUS on T480 thinkpad trackpad
  (bnc#1012628).
- e1000e: start network tx queue only when link is up
  (bnc#1012628).
- Revert "e1000e: fix cyclic resets at link up with active tx"
  (bnc#1012628).
- commit 93f0a54
* Tue Jul 16 2019 lpechacek@suse.com
- rpm/kernel-binary.spec.in: build kernel-*-kgraft only for default SLE kernel
  RT and Azure variants are excluded for the moment. (bsc#1141600)
- commit 620816f
* Sun Jul 14 2019 jslaby@suse.cz
- Linux 5.2.1 (bnc#1012628).
- staging: rtl8712: reduce stack usage, again (bnc#1012628).
- staging: bcm2835-camera: Handle empty EOS buffers whilst
  streaming (bnc#1012628).
- staging: bcm2835-camera: Remove check of the number of buffers
  supplied (bnc#1012628).
- staging: bcm2835-camera: Ensure all buffers are returned on
  disable (bnc#1012628).
- staging: bcm2835-camera: Replace spinlock protecting context_map
  with mutex (bnc#1012628).
- staging: fsl-dpaa2/ethsw: fix memory leak of switchdev_work
  (bnc#1012628).
- staging: vchiq: revert "switch to wait_for_completion_killable"
  (bnc#1012628).
- staging: vchiq: make wait events interruptible (bnc#1012628).
- staging: vchiq_2835_arm: revert "quit using custom
  down_interruptible()" (bnc#1012628).
- VMCI: Fix integer overflow in VMCI handle arrays (bnc#1012628).
- Revert "x86/build: Move _etext to actual end of .text"
  (bnc#1012628).
- carl9170: fix misuse of device driver API (bnc#1012628).
- coresight: tmc-etf: Do not call smp_processor_id from
  preemptible (bnc#1012628).
- coresight: tmc-etr: alloc_perf_buf: Do not call smp_processor_id
  from preemptible (bnc#1012628).
- coresight: tmc-etr: Do not call smp_processor_id() from
  preemptible (bnc#1012628).
- coresight: etb10: Do not call smp_processor_id from preemptible
  (bnc#1012628).
- coresight: Potential uninitialized variable in probe()
  (bnc#1012628).
- iio: adc: stm32-adc: add missing vdda-supply (bnc#1012628).
- binder: return errors from buffer copy functions (bnc#1012628).
- binder: fix memory leak in error path (bnc#1012628).
- lkdtm: support llvm-objcopy (bnc#1012628).
- HID: Add another Primax PIXART OEM mouse quirk (bnc#1012628).
- staging: mt7621-pci: fix PCIE_FTS_NUM_LO macro (bnc#1012628).
- staging: comedi: amplc_pci230: fix null pointer deref on
  interrupt (bnc#1012628).
- staging: bcm2835-camera: Restore return behavior of
  ctrl_set_bitrate() (bnc#1012628).
- staging: wilc1000: fix error path cleanup in
  wilc_wlan_initialize() (bnc#1012628).
- staging: comedi: dt282x: fix a null pointer deref on interrupt
  (bnc#1012628).
- p54: fix crash during initialization (bnc#1012628).
- drivers/usb/typec/tps6598x.c: fix 4CC cmd write (bnc#1012628).
- drivers/usb/typec/tps6598x.c: fix portinfo width (bnc#1012628).
- usb: renesas_usbhs: add a workaround for a race condition of
  workqueue (bnc#1012628).
- usb: dwc2: use a longer AHB idle timeout in dwc2_core_reset()
  (bnc#1012628).
- usb: gadget: ether: Fix race between gether_disconnect and
  rx_submit (bnc#1012628).
- usb: gadget: f_fs: data_len used before properly set
  (bnc#1012628).
- p54usb: Fix race between disconnect and firmware loading
  (bnc#1012628).
- Revert "serial: 8250: Don't service RX FIFO if interrupts are
  disabled" (bnc#1012628).
- USB: serial: option: add support for GosunCn ME3630 RNDIS mode
  (bnc#1012628).
- USB: serial: ftdi_sio: add ID for isodebug v1 (bnc#1012628).
- mwifiex: Don't abort on small, spec-compliant vendor IEs
  (bnc#1012628).
- Documentation/admin: Remove the vsyscall=native documentation
  (bnc#1012628).
- Documentation: Add section about CPU vulnerabilities for Spectre
  (bnc#1012628).
- x86/tls: Fix possible spectre-v1 in do_get_thread_area()
  (bnc#1012628).
- x86/ptrace: Fix possible spectre-v1 in ptrace_get_debugreg()
  (bnc#1012628).
- perf header: Assign proper ff->ph in
  perf_event__synthesize_features() (bnc#1012628).
- perf thread-stack: Fix thread stack return from kernel for
  kernel-only case (bnc#1012628).
- perf pmu: Fix uncore PMU alias list for ARM64 (bnc#1012628).
- perf intel-pt: Fix itrace defaults for perf script intel-pt
  documentation (bnc#1012628).
- perf auxtrace: Fix itrace defaults for perf script
  (bnc#1012628).
- perf intel-pt: Fix itrace defaults for perf script
  (bnc#1012628).
- block, bfq: NULL out the bic when it's no longer valid
  (bnc#1012628).
- block: fix .bi_size overflow (bnc#1012628).
- tpm: Fix TPM 1.2 Shutdown sequence to prevent future TPM
  operations (bnc#1012628).
- tpm: Actually fail on TPM errors during "get random"
  (bnc#1012628).
- ALSA: hda/realtek - Headphone Mic can't record after S3
  (bnc#1012628).
- ALSA: usb-audio: Fix parse of UAC2 Extension Units
  (bnc#1012628).
- media: stv0297: fix frequency range limit (bnc#1012628).
- udf: Fix incorrect final NOT_ALLOCATED (hole) extent length
  (bnc#1012628).
- fscrypt: don't set policy for a dead directory (bnc#1012628).
- crypto: talitos - rename alternative AEAD algos (bnc#1012628).
- crypto: lrw - use correct alignmask (bnc#1012628).
- commit 51ca500
* Thu Jul 11 2019 glin@suse.com
- net: bpfilter: print umh messages to /dev/kmsg (bsc#1140221).
- commit 139acc9
* Wed Jul 10 2019 jslaby@suse.cz
- rpm/kernel-binary.spec.in: handle modules.builtin.modinfo
  It was added in 5.2.
- commit eb88df3
* Tue Jul  9 2019 rgoldwyn@suse.com
- Disable CONFIG_OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW in config (bsc#1140494)
- commit 8d950e4
* Mon Jul  8 2019 mkubecek@suse.cz
- Update to 5.2 final
- Eliminated 1 patch
- commit b36439f
* Sun Jul  7 2019 msuchanek@suse.de
- Refresh tpm: tpm_ibm_vtpm: Fix unallocated banks (boo#1139244).
- commit 99f9469
* Fri Jul  5 2019 tiwai@suse.de
- config: align CONFIG_PHYSICAL_START and CONFIG_PHYSICAL_ALIGN to default values
  As suggested in bsc#1067593, our kconfig keeps the old default values
  while the upstream took different (actually swapped) values for x86
  CONFIG_PHYSICAL_START and CONFIG_PHYSICAL_ALIGN.   Let's follow the
  upstream default now.
- commit baa2434
* Fri Jul  5 2019 mkubecek@suse.cz
- Rename patches.suse/[PATCH]_tpm:_fixes_uninitialized_allocated_banks_for_IBM_vtpm_driver
  to patches.suse/tpm-fixes-uninitialized-allocated-banks-for-IBM-vtpm-driver.patch
  Let's not risk some tool somewhere does not handle special characters correctly.
- commit 8a3fff9
* Thu Jul  4 2019 msuchanek@suse.de
- tpm: fixes uninitialized allocated banks for IBM vtpm driver
  (boo#1139244).
- Delete patches.suse/Revert-tpm-pass-an-array-of-tpm_extend_digest-struct.patch.
- commit 43ec0a5
* Wed Jul  3 2019 msuchanek@suse.de
- crypto: user - prevent operating on larval algorithms
  (bsc#1133401).
- Delete patches.suse/crypto-algapi-guard-against-uninitialized-spawn-list.patch.
- commit 90eea5d
* Wed Jul  3 2019 schwab@suse.de
- rpm/dtb.spec.in.in: don't make dtb directory inaccessible
  There is no reason to lock down the dtb directory for ordinary users.
- commit a69437a
* Wed Jul  3 2019 jslaby@suse.cz
- Update config files.
  Set CONFIG_SCSI_SCAN_ASYNC=y (bnc#1137686).
- commit a156b11
* Wed Jul  3 2019 mkubecek@suse.cz
- config: switch to SLUB allocator (Jira:PM-1158)
- new config options:
  - SLUB=y
  - SLUB_DEBUG=y
  - SLUB_MEMCG_SYSFS_ON=y
  - SLAB_FREELIST_HARDENED=n
  - SLUB_CPU_PARTIAL=y
  - SLUB_DEBUG_ON=n
  - SLUB_STATS=n
- commit 0ab8cfd
* Sun Jun 30 2019 mkubecek@suse.cz
- Update to 5.2-rc7
- Refresh configs
- commit 2d405cc
* Sun Jun 30 2019 msuchanek@suse.de
- Delete patches.rpmify/BPF-UMH-do-not-detect-if-compiler-can-link-userspace.patch.
  Obsoleted by the gcc9 cross-compilers with libc.
- commit 0e0679b
* Sun Jun 30 2019 msuchanek@suse.de
- Revert "tpm: pass an array of tpm_extend_digest structures to
  tpm_pcr_extend()" (boo#1139244).
- commit b09a129
* Fri Jun 28 2019 msuchanek@suse.de
- Refresh patches.suse/supported-flag.
  Supported kernel does not build with the patch in master so imported
  patch from SLE15.
- commit 10d9b2c
* Thu Jun 27 2019 msuchanek@suse.de
- Update config files
  - Add core options from SLE15 which are not enabled on master for no
  obvious reason
  - Add core option from x86 which are not enabled on non-x86 for no
  obvious reason
  - Enable fadump
  Changes:
  Scheduling:
    +CONFIG_CONTEXT_TRACKING=y
  - CONFIG_TICK_CPU_ACCOUNTING=y
    +CONFIG_VIRT_CPU_ACCOUNTING_GEN=y
    +CONFIG_VIRT_CPU_ACCOUNTING=y
    +CONFIG_IRQ_TIME_ACCOUNTING=y
    +CONFIG_TASKS_RCU=y
    +CONFIG_RT_GROUP_SCHED=y
  mm:
    +# CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS is not set
    +CONFIG_TRANSPARENT_HUGEPAGE_MADVISE=y
    +CONFIG_FRONTSWAP=y
    +CONFIG_ZSWAP=y
  arc/ppc:
    +CONFIG_FA_DUMP=y
  fs:
    +CONFIG_9P_FSCACHE=y
  net:
    +CONFIG_TIPC=m
    +CONFIG_TIPC_DIAG=m
    +CONFIG_TIPC_MEDIA_UDP=y
  misc:
  - CONFIG_SERIAL_SIFIVE=m
    +CONFIG_SYSCTL_SYSCALL=y
  debug&test:
    +CONFIG_PAGE_EXTENSION=y
    +CONFIG_PAGE_OWNER=y
    +CONFIG_DEBUG_MISC=y
    +CONFIG_RCU_TRACE=y
    +CONFIG_KGDB_SERIAL_CONSOLE=y
    +CONFIG_SCOM_DEBUGFS=y
    +CONFIG_CRYPTO_TEST=m
    +CONFIG_RCU_TORTURE_TEST=m
    +CONFIG_TEST_FIRMWARE=m
    +CONFIG_TEST_LIVEPATCH=m
    +CONFIG_TEST_LKM=m
    +CONFIG_TEST_SYSCTL=m
    +CONFIG_TORTURE_TEST=m
- commit ce08519
* Mon Jun 24 2019 msuchanek@suse.de
- crypto: algapi - guard against uninitialized spawn list in
  crypto_remove_spawns (bsc#1133401).
- commit 543f67d
* Mon Jun 24 2019 tiwai@suse.de
- fonts: Prefer a bigger font for high resolution screens
  (bsc#1138496).
- fonts: Use BUILD_BUG_ON() for checking empty font table
  (bsc#1138496).
- fonts: Fix coding style (bsc#1138496).
- commit f99f70b
* Sun Jun 23 2019 mkubecek@suse.cz
- Update to 5.2-rc6
- Eliminated 5 patches
  - patches.suse/net-phy-rename-Asix-Electronics-PHY-driver.patch
  - patches.suse/tcp-limit-payload-size-of-sacked-skbs.patch
  - patches.suse/tcp-tcp_fragment-should-apply-sane-memory-limits.patch
  - patches.suse/tcp-add-tcp_min_snd_mss-sysctl.patch
  - patches.suse/tcp-enforce-tcp_min_snd_mss-in-tcp_mtu_probing.patch
- Refresh
  - patches.suse/apparmor-compatibility-with-v2.x-net.patch
- commit 75acedc
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: rpm does not support multiline condition
- commit aceae50
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: Use -c grep option in klp project detection.
- commit 5def2a2
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: fix missing \
- commit 8325214
* Wed Jun 19 2019 mkubecek@suse.cz
- config: refresh i386/default
- commit a562f5a
* Wed Jun 19 2019 jslaby@suse.cz
- Update config files.
  Enable SECURITY_YAMA to allow protection against ptrace attacks
  (bnc#1128245).
- commit f841e66
* Tue Jun 18 2019 jslaby@suse.cz
- Update config files.
  Set HARDENED_USERCOPY=y (bnc#1127808). This can be disabled on the
  commandline using hardened_usercopy=n.
- commit 3b85d22
* Tue Jun 18 2019 tiwai@suse.de
- config: enable CONFIG_FONT_TER16x32 for HiDPI monitors (boo#1138496)
- commit 073136d
* Mon Jun 17 2019 mkubecek@suse.cz
- tcp: enforce tcp_min_snd_mss in tcp_mtu_probing()
  (CVE-2019-11479 bsc#1137586).
- tcp: add tcp_min_snd_mss sysctl (CVE-2019-11479 bsc#1137586).
- tcp: tcp_fragment() should apply sane memory limits
  (CVE-2019-11478 bsc#1137586).
- tcp: limit payload size of sacked skbs (CVE-2019-11477
  bsc#1137586).
- commit ab45ff3
* Sun Jun 16 2019 mkubecek@suse.cz
- Update to 5.2-rc5
- Config changes:
  - Sound:
  - SND_SOC_SOF_NOCODEC_SUPPORT=n on x86, =y on ARM
  - Storage:
  - MQ_IOSCHED_DEADLINE m -> y on arm64
- commit b5857f8
* Thu Jun 13 2019 msuchanek@suse.de
- Build klp-symbols in kernel devel projects.
- commit ffd0ed9
* Thu Jun 13 2019 jdelvare@suse.de
- supported.conf: Enable it87_wdt and f71808e_wdt
  Both drivers are for watchdog devices included in Super-I/O chipsets
  which are popular on x86 PC mainboards. Code is clean and simple,
  so supporting them isn't a problem.
- commit b818771
* Mon Jun 10 2019 lduncan@suse.com
- scsi: mpt3sas_ctl: fix double-fetch bug in _ctl_ioctl_main()
  (bsc#1136922 cve-2019-12456).
- commit 42064d5
* Mon Jun 10 2019 mkubecek@suse.cz
- Update to 5.2-rc4
- Eliminated 1 patch
  - patches.rpmify/mlx5-avoid-64-bit-division.patch
- Refresh configs
  - IKHEADERS_PROC -> IKHEADERS
- commit c8bdb02
* Fri Jun  7 2019 mvedovati@suse.com
- rpm/post.sh: correct typo in err msg (bsc#1137625)
- commit 9fe85cc
* Thu Jun  6 2019 jslaby@suse.cz
- s390: drop meaningless 'targets' from tools Makefile (s390
  kmp build fix).
- commit b4eda05
* Wed Jun  5 2019 mvedovati@suse.com
- Enhance kvmsmall configuration (bsc#1137361)
  Add a minimal set of modules to  kvmsmall, to make this config usable
  to set up guest VMs interacting with the host.
- commit 34c4eab
* Wed Jun  5 2019 mkubecek@suse.cz
- config: refresh configs
  No functional change.
- commit cbc8b7e
* Tue Jun  4 2019 jslaby@suse.cz
- Update config files.
  Enable CRASH_DUMP and RELOCATABLE on ppc64le to be on par with the
  other archs and to allow for kdump (bnc#1135217).
- commit a6a9f0e
* Mon Jun  3 2019 mkubecek@suse.cz
- Update to 5.2-rc3
- Eliminated 1 patch
  - patches.suse/kvm-memunmap-also-needs-HAS_IOMEM.patch
- commit 038ee83
* Wed May 29 2019 mkubecek@suse.cz
- config: refresh vanilla configs
- commit cbe6c1c
* Wed May 29 2019 mkubecek@suse.cz
- reenable ARM architectures
- commit 194828b
* Wed May 29 2019 mkubecek@suse.cz
- refresh configs after Tumbleweed switch to gcc9 as default
- commit 3b7ae7e
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv7hl: lpae: Update to v5.2.0-rc2
- commit 38ac345
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv7hl: Update to v5.2.0-rc2
- commit 737b08e
* Wed May 29 2019 yousaf.kaukab@suse.com
- config: armv6hl: Update to v5.2.0-rc2
- commit c7bc712
* Tue May 28 2019 yousaf.kaukab@suse.com
- config: arm64: Update to v5.2.0-rc2
- commit 18d0586
* Mon May 27 2019 mkubecek@suse.cz
- Update to 5.2-rc2
- Eliminated 4 patches
  - patches.suse/dm-make-sure-to-obey-max_io_len_target_boundary.patch
  - patches.suse/kvm-make-kvm_vcpu_-un-map-dependency-on-CONFIG_HAS_I.patch
  - patches.suse/vfio_pci-Add-local-source-directory-as-include.patch
  - patches.suse/x86-kvm-pmu-Set-AMD-s-virt-PMU-version-to-1.patch
- add s390x/zfcpdump build fix
  - patches.suse/kvm-memunmap-also-needs-HAS_IOMEM.patch
- commit b02c459
* Wed May 22 2019 msuchanek@suse.de
- Delete patches.suse/Revert-Bluetooth-btusb-driver-to-enable-the-usb-wake.patch (boo#1130448).
  Should be fixed in 5.1-rc5
  commit 771acc7e4a6e5dba779cb1a7fd851a164bc81033
  Author: Brian Norris <briannorris@chromium.org>
  Date:   Tue Apr 9 11:49:17 2019 -0700
    Bluetooth: btusb: request wake pin with NOAUTOEN
- commit b225e5a
* Wed May 22 2019 jslaby@suse.cz
- dm: make sure to obey max_io_len_target_boundary (bnc#1135868).
- commit dbeb07c
* Mon May 20 2019 mkubecek@suse.cz
- kvm: make kvm_vcpu_(un)map dependency on CONFIG_HAS_IOMEM
  explicit.
  Fixes build of s390x/zfcpdump.
- commit b33dbfc
* Mon May 20 2019 mkubecek@suse.cz
- config: refresh vanilla configs
- commit 4c41263
* Mon May 20 2019 mkubecek@suse.cz
- net: phy: rename Asix Electronics PHY driver.
  Fix duplicate module name asix by renaming phy driver to ax88796b.
- Update config files.
- commit df18320
* Mon May 20 2019 mkubecek@suse.cz
- mlx5: avoid 64-bit division.
  Fix i386 build.
- commit 89c5a47
* Mon May 20 2019 mkubecek@suse.cz
- Update to 5.2-rc1
- Eliminated 106 patches (105 stable, 1 other)
- ARM configs need update
- Refresh
  patches.rpmify/scripts-mkmakefile-honor-second-argument.patch
  patches.suse/dm-mpath-leastpending-path-update
  patches.suse/supported-flag
  patches.suse/supported-flag-external
  patches.suse/vfs-add-super_operations-get_inode_dev
- New config options:
  - General setup
  - IKHEADERS_PROC=n
  - SHUFFLE_PAGE_ALLOCATOR=y
  - Security
  - SECURITY_TOMOYO_INSECURE_BUILTIN_SETTING=n
  - Filesystems
  - UNICODE=y
  - UNICODE_NORMALIZATION_SELFTEST=n
  - Crypto
  - CRYPTO_ECRDSA=m
  - Networking
  - BATMAN_ADV_SYSFS=y
  - BT_MTKSDIO=m
  - XILINX_LL_TEMAC=m
  - MT7615E=m
  - RTW88=m
  - RTW88_8822BE=y
  - RTW88_8822CE=y
  - RTW88_DEBUG=n
  - RTW88_DEBUGFS=n
  - INFINIBAND_EFA=m
  - Storage
  - DM_DUST=m
  - MTD drivers
  - MTD_RAW_NAND=m
  - MTD_NAND_ECC_SW_BCH=y
  - MTD_NAND_ECC_SW_HAMMING_SMC=n
  - Input
  - KEYBOARD_QT1050=m
  - TOUCHSCREEN_IQS5XX=m
  - INPUT_GPIO_VIBRA=n
  - INPUT_REGULATOR_HAPTIC=m
  - HID_MACALLY=m
  - HID_U2FZERO=m
  - INPUT_MAX77650_ONKEY=m
  - Serial
  - NULL_TTY=m
  - SERIAL_SIFIVE=m
  - Power management
  - CHARGER_MANAGER=y
  - CHARGER_LT3651=m
  - CHARGER_UCS1002=m
  - SENSORS_IR38064=m
  - SENSORS_ISL68137=m
  - SENSORS_LTC2978_REGULATOR=y
  - THERMAL_MMIO=m
  - MFD_MAX77650=m
  - MFD_STMFX=m
  - REGULATOR_DEBUG=n
  - REGULATOR_FIXED_VOLTAGE=m
  - REGULATOR_VIRTUAL_CONSUMER=m
  - REGULATOR_USERSPACE_CONSUMER=m
  - REGULATOR_88PG86X=m
  - REGULATOR_ACT8865=m
  - REGULATOR_AD5398=m
  - REGULATOR_AXP20X=m
  - REGULATOR_DA9062=m
  - REGULATOR_DA9210=m
  - REGULATOR_DA9211=m
  - REGULATOR_FAN53555=m
  - REGULATOR_GPIO=m
  - REGULATOR_ISL9305=m
  - REGULATOR_ISL6271A=m
  - REGULATOR_LM363X=m
  - REGULATOR_LP3971=m
  - REGULATOR_LP3972=m
  - REGULATOR_LP872X=m
  - REGULATOR_LP8755=m
  - REGULATOR_LTC3589=m
  - REGULATOR_LTC3676=m
  - REGULATOR_MAX1586=m
  - REGULATOR_MAX77650=m
  - REGULATOR_MAX8649=m
  - REGULATOR_MAX8660=m
  - REGULATOR_MAX8907=m
  - REGULATOR_MAX8952=m
  - REGULATOR_MAX8973=m
  - REGULATOR_MCP16502=m
  - REGULATOR_MT6311=m
  - REGULATOR_PFUZE100=m
  - REGULATOR_PV88060=m
  - REGULATOR_PV88080=m
  - REGULATOR_PV88090=m
  - REGULATOR_PWM=m
  - REGULATOR_QCOM_SPMI=m
  - REGULATOR_SY8106A=m
  - REGULATOR_TPS51632=m
  - REGULATOR_TPS62360=m
  - REGULATOR_TPS65023=m
  - REGULATOR_TPS6507X=m
  - REGULATOR_TPS65132=m
  - REGULATOR_TPS6524X=m
  - REGULATOR_VCTRL=m
  - CHARGER_MAX77650=m
  - Media
  - MEDIA_CONTROLLER_REQUEST_API=y
  - VIDEO_V4L2_SUBDEV_API=y
  - V4L2_FLASH_LED_CLASS=m
  - VIDEO_COBALT=n
  - VIDEO_IPU3_CIO2=m
  - VIDEO_CADENCE_CSI2RX=m
  - VIDEO_CADENCE_CSI2TX=m
  - VIDEO_MUX=m
  - VIDEO_XILINX=m
  - VIDEO_XILINX_TPG=m
  - VIDEO_VIMC=m
  - VIDEO_IPU3_IMGU=m
  - DRM
  - NOUVEAU_LEGACY_CTX_SUPPORT=n
  - DRM_PANEL_FEIYANG_FY07024DI26A30D=n
  - DRM_PANEL_ROCKTECH_JH057N00900=n
  - DRM_PANEL_RONBO_RB070D30=n
  - Sound
  - SND_SOC_FSL_AUDMIX=n
  - SND_SOC_SOF_TOPLEVEL=y
  - SND_SOC_SOF_PCI=m
  - SND_SOC_SOF_ACPI=m
  - SND_SOC_SOF_NOCODEC=n
  - SND_SOC_SOF_STRICT_ABI_CHECKS=n
  - SND_SOC_SOF_DEBUG=n
  - SND_SOC_SOF_INTEL_TOPLEVEL=y
  - SND_SOC_SOF_BAYTRAIL_SUPPORT=y
  - SND_SOC_SOF_BROADWELL_SUPPORT=y
  - SND_SOC_SOF_MERRIFIELD_SUPPORT=y
  - SND_SOC_SOF_APOLLOLAKE_SUPPORT=y
  - SND_SOC_SOF_GEMINILAKE_SUPPORT=y
  - SND_SOC_SOF_CANNONLAKE_SUPPORT=y
  - SND_SOC_SOF_COFFEELAKE_SUPPORT=y
  - SND_SOC_SOF_ICELAKE_SUPPORT=y
  - SND_SOC_SOF_HDA_LINK=y
  - SND_SOC_SOF_HDA_AUDIO_CODEC=y
  - SND_SOC_INTEL_SOF_RT5682_MACH=m
  - USB
  - TYPEC_NVIDIA_ALTMODE=m
  - LEDS
  - LEDS_LM3532=m
  - LEDS_REGULATOR=m
  - LEDS_MAX77650=m
  - Platform
  - CROS_EC_RPMSG=m
  - CROS_USBPD_LOGGER=m
  - CLK_SIFIVE=n
  - IXP4XX_QMGR=n
  - IXP4XX_NPE=m
  - IIO
  - CC10001_ADC=n
  - TI_ADS8344=n
  - FXAS21002C=n
  - MB1232=n
  - MAX31856=m
  - Misc drivers
  - I2C_AMD_MP2=m
  - PINCTRL_STMFX=n
  - FIELDBUS_DEV=n
  - KPC2000=n
  - NVMEM_SYSFS=y
  - COUNTER=n
  - GPIO_MAX77650=m
  - Library
  - PACKING=n
  - Debugging and testing
  - DEBUG_INFO_BTF=n
  - DEBUG_MISC=n
  - DEBUG_PLIST=n
  - TEST_STRSCPY=n
  - x86
  - ACPI_HMAT=y
  - INTEL_CHT_INT33FE=m
  - INTEL_ISH_FIRMWARE_DOWNLOADER=m
  - i386
  - MEMORY_HOTPLUG=y
  - MEMORY_HOTPLUG_DEFAULT_ONLINE=n
  - MEMORY_HOTREMOVE
  - XEN_BALLOON_MEMORY_HOTPLUG=y
  - XEN_BALLOON_MEMORY_HOTPLUG_LIMIT=4
  - DEV_DAX_KMEM=m
  - MEMORY_NOTIFIER_ERROR_INJECT=m
  - ACPI_HOTPLUG_MEMORY=y
  - ppc64 / ppc64le
  - PPC_KUEP=y
  - PPC_KUAP=y
  - PPC_KUAP_DEBUG=n
  - MTD_NAND_DENALI_PCI=m
  - MTD_NAND_CAFE=m
  - MTD_NAND_GPIO=m
  - MTD_NAND_PLATFORM=m
  - MTD_NAND_NANDSIM=m
  - MTD_NAND_RICOH=m
  - MTD_NAND_DISKONCHIP=m
  - MTD_NAND_DISKONCHIP_PROBE_ADVANCED=n
  - MTD_NAND_DISKONCHIP_BBTWRITE=n
  - INTEGRITY_PLATFORM_KEYRING=y
  - OPTIMIZE_INLINING=y
  - XMON_DEFAULT_RO_MODE=y
  - s390x
  - KEXEC_VERIFY_SIG=n
  - RELOCATABLE=y
  - RANDOMIZE_BASE=y
  - PROTECTED_VIRTUALIZATION_GUEST=y
  - LCD_CLASS_DEVICE=n
  - BACKLIGHT_CLASS_DEVICE=n
  - INTEGRITY_PLATFORM_KEYRING=y
  - OPTIMIZE_INLINING=n
- commit c8b1101
* Fri May 17 2019 jslaby@suse.cz
- Revert "selinux: do not report error on connect(AF_UNSPEC)"
  (git-fixes).
- Revert "Don't jump to compute_result state from check_result
  state" (git-fixes).
- commit 3d34296
* Fri May 17 2019 jslaby@suse.cz
- Linux 5.1.3 (bnc#1012628).
- f2fs: Fix use of number of devices (bnc#1012628).
- PCI: hv: Add pci_destroy_slot() in pci_devices_present_work(),
  if necessary (bnc#1012628).
- PCI: hv: Add hv_pci_remove_slots() when we unload the driver
  (bnc#1012628).
- PCI: hv: Fix a memory leak in hv_eject_device_work()
  (bnc#1012628).
- virtio_ring: Fix potential mem leak in
  virtqueue_add_indirect_packed (bnc#1012628).
- powerpc/booke64: set RI in default MSR (bnc#1012628).
- powerpc/powernv/idle: Restore IAMR after idle (bnc#1012628).
- powerpc/book3s/64: check for NULL pointer in pgd_alloc()
  (bnc#1012628).
- drivers/virt/fsl_hypervisor.c: prevent integer overflow in ioctl
  (bnc#1012628).
- drivers/virt/fsl_hypervisor.c: dereferencing error pointers
  in ioctl (bnc#1012628).
- isdn: bas_gigaset: use usb_fill_int_urb() properly
  (bnc#1012628).
- flow_dissector: disable preemption around BPF calls
  (bnc#1012628).
- net: phy: fix phy_validate_pause (bnc#1012628).
- tuntap: synchronize through tfiles array instead of
  tun->numqueues (bnc#1012628).
- tuntap: fix dividing by zero in ebpf queue selection
  (bnc#1012628).
- vrf: sit mtu should not be updated when vrf netdev is the link
  (bnc#1012628).
- vlan: disable SIOCSHWTSTAMP in container (bnc#1012628).
- tipc: fix hanging clients using poll with EPOLLOUT flag
  (bnc#1012628).
- selinux: do not report error on connect(AF_UNSPEC)
  (bnc#1012628).
- packet: Fix error path in packet_init (bnc#1012628).
- net: ucc_geth - fix Oops when changing number of buffers in
  the ring (bnc#1012628).
- net: seeq: fix crash caused by not set dev.parent (bnc#1012628).
- net: macb: Change interrupt and napi enable order in open
  (bnc#1012628).
- net: ethernet: stmmac: dwmac-sun8i: enable support of unicast
  filtering (bnc#1012628).
- net: dsa: Fix error cleanup path in dsa_init_module
  (bnc#1012628).
- ipv4: Fix raw socket lookup for local traffic (bnc#1012628).
- fib_rules: return 0 directly if an exactly same rule exists
  when NLM_F_EXCL not supplied (bnc#1012628).
- dpaa_eth: fix SG frame cleanup (bnc#1012628).
- bridge: Fix error path for kobject_init_and_add() (bnc#1012628).
- bonding: fix arp_validate toggling in active-backup mode
  (bnc#1012628).
- Don't jump to compute_result state from check_result state
  (bnc#1012628).
- rtlwifi: rtl8723ae: Fix missing break in switch statement
  (bnc#1012628).
- mwl8k: Fix rate_idx underflow (bnc#1012628).
- USB: serial: fix unthrottle races (bnc#1012628).
- virt: vbox: Sanity-check parameter types for hgcm-calls coming
  from userspace (bnc#1012628).
- kernfs: fix barrier usage in __kernfs_new_node() (bnc#1012628).
- i2c: core: ratelimit 'transfer when suspended' errors
  (bnc#1012628).
- selftests/seccomp: Handle namespace failures gracefully
  (bnc#1012628).
- hwmon: (occ) Fix extended status bits (bnc#1012628).
- hwmon: (pwm-fan) Disable PWM if fetching cooling data fails
  (bnc#1012628).
- platform/x86: dell-laptop: fix rfkill functionality
  (bnc#1012628).
- platform/x86: thinkpad_acpi: Disable Bluetooth for some machines
  (bnc#1012628).
- platform/x86: sony-laptop: Fix unintentional fall-through
  (bnc#1012628).
- commit 073196d
* Thu May 16 2019 mwilck@suse.com
- Update config files: disable CONFIG_IDE for ppc64/ppc64le (bsc#1135333)
- commit 012b7ed
* Wed May 15 2019 mkubecek@suse.cz
- x86/kvm/pmu: Set AMD's virt PMU version to 1
  (https://patchwork.kernel.org/patch/10936271/).
- commit d737fc7
* Tue May 14 2019 jslaby@suse.cz
- Linux 5.1.2 (bnc#1012628).
- x86/speculation/mds: Fix documentation typo (bnc#1012628).
- Documentation: Correct the possible MDS sysfs values
  (bnc#1012628).
- x86/mds: Add MDSUM variant to the MDS documentation
  (bnc#1012628).
- x86/speculation/mds: Add 'mitigations=' support for MDS
  (bnc#1012628).
- s390/speculation: Support 'mitigations=' cmdline option
  (bnc#1012628).
- powerpc/speculation: Support 'mitigations=' cmdline option
  (bnc#1012628).
- x86/speculation: Support 'mitigations=' cmdline option
  (bnc#1012628).
- cpu/speculation: Add 'mitigations=' cmdline option
  (bnc#1012628).
- x86/speculation/mds: Print SMT vulnerable on MSBDS with
  mitigations off (bnc#1012628).
- x86/speculation/mds: Fix comment (bnc#1012628).
- x86/speculation/mds: Add SMT warning message (bnc#1012628).
- x86/speculation: Move arch_smt_update() call to after mitigation
  decisions (bnc#1012628).
- x86/speculation/mds: Add mds=full,nosmt cmdline option
  (bnc#1012628).
- Documentation: Add MDS vulnerability documentation
  (bnc#1012628).
- Documentation: Move L1TF to separate directory (bnc#1012628).
- x86/speculation/mds: Add mitigation mode VMWERV (bnc#1012628).
- x86/speculation/mds: Add sysfs reporting for MDS (bnc#1012628).
- x86/speculation/mds: Add mitigation control for MDS
  (bnc#1012628).
- x86/speculation/mds: Conditionally clear CPU buffers on idle
  entry (bnc#1012628).
- x86/kvm/vmx: Add MDS protection when L1D Flush is not active
  (bnc#1012628).
- x86/speculation/mds: Clear CPU buffers on exit to user
  (bnc#1012628).
- x86/speculation/mds: Add mds_clear_cpu_buffers() (bnc#1012628).
- x86/kvm: Expose X86_FEATURE_MD_CLEAR to guests (bnc#1012628).
- x86/speculation/mds: Add BUG_MSBDS_ONLY (bnc#1012628).
- x86/speculation/mds: Add basic bug infrastructure for MDS
  (bnc#1012628).
- x86/speculation: Consolidate CPU whitelists (bnc#1012628).
- x86/msr-index: Cleanup bit defines (bnc#1012628).
- commit 5a8c05f
* Tue May 14 2019 mkubecek@suse.cz
- config: keep LSM empty in s390x/zfcpdump
  This config doesn't really build AppArmor and always had
  DEFAULT_SECURITY_DAC so it seems more consistent to keep LSM list empty.
- commit 3073856
* Tue May 14 2019 mkubecek@suse.cz
- config: enable AppArmor by default again (bsc#1134906)
  AppArmor used to be enabled in kernel by default by after the recent
  introduction of CONFIG_LSM, we disabled all LSM modules. Enable AppArmor
  again.
- commit 953db35
* Tue May 14 2019 mkubecek@suse.cz
- Update upstream reference:
  patches.suse/efifb-Omit-memory-map-check-on-legacy-boot.patch
- commit 133a780
* Sat May 11 2019 jslaby@suse.cz
- Linux 5.1.1 (bnc#1012628).
- arm64: futex: Bound number of LDXR/STXR loops in FUTEX_WAKE_OP
  (bnc#1012628).
- locking/futex: Allow low-level atomic operations to return
  - EAGAIN (bnc#1012628).
- i3c: Fix a shift wrap bug in i3c_bus_set_addr_slot_status()
  (bnc#1012628).
- ASoC: Intel: avoid Oops if DMA setup fails (bnc#1012628).
- UAS: fix alignment of scatter/gather segments (bnc#1012628).
- Bluetooth: hci_bcm: Fix empty regulator supplies for Intel Macs
  (bnc#1012628).
- Bluetooth: Fix not initializing L2CAP tx_credits (bnc#1012628).
- Bluetooth: Align minimum encryption key size for LE and BR/EDR
  connections (bnc#1012628).
- Bluetooth: hidp: fix buffer overflow (bnc#1012628).
- scsi: qla2xxx: Fix device staying in blocked state
  (bnc#1012628).
- scsi: qla2xxx: Set remote port devloss timeout to 0
  (bnc#1012628).
- scsi: qla2xxx: Fix incorrect region-size setting in optrom
  SYSFS routines (bnc#1012628).
- scsi: lpfc: change snprintf to scnprintf for possible overflow
  (bnc#1012628).
- soc: sunxi: Fix missing dependency on REGMAP_MMIO (bnc#1012628).
- ACPI / LPSS: Use acpi_lpss_* instead of acpi_subsys_* functions
  for hibernate (bnc#1012628).
- cpufreq: armada-37xx: fix frequency calculation for opp
  (bnc#1012628).
- iio: adc: qcom-spmi-adc5: Fix of-based module autoloading
  (bnc#1012628).
- intel_th: pci: Add Comet Lake support (bnc#1012628).
- genirq: Prevent use-after-free and work list corruption
  (bnc#1012628).
- usb-storage: Set virt_boundary_mask to avoid SG overflows
  (bnc#1012628).
- USB: cdc-acm: fix unthrottle races (bnc#1012628).
- USB: serial: f81232: fix interrupt worker not stop
  (bnc#1012628).
- usb: dwc3: Fix default lpm_nyet_threshold value (bnc#1012628).
- usb: dwc3: Allow building USB_DWC3_QCOM without EXTCON
  (bnc#1012628).
- staging: most: sound: pass correct device when creating a
  sound card (bnc#1012628).
- staging: most: cdev: fix chrdev_region leak in mod_exit
  (bnc#1012628).
- staging: wilc1000: Avoid GFP_KERNEL allocation from atomic
  context (bnc#1012628).
- staging: greybus: power_supply: fix prop-descriptor request size
  (bnc#1012628).
- ubsan: Fix nasty -Wbuiltin-declaration-mismatch GCC-9 warnings
  (bnc#1012628).
- Drivers: hv: vmbus: Remove the undesired put_cpu_ptr() in
  hv_synic_cleanup() (bnc#1012628).
- commit 8e0a089
* Thu May  9 2019 guillaume.gardet@free.fr
- Sign non-x86 kernels when possible (boo#1134303)
- commit bac621c
* Mon May  6 2019 mkubecek@suse.cz
- Update to 5.1 final
- Eliminated 1 patch
- New config options:
  - PCI:
  - PCIE_BW=n (recommended default)
- commit a974d8b
* Tue Apr 30 2019 mkubecek@suse.cz
- rdma: fix build errors on s390 and MIPS due to bad ZERO_PAGE use
  (http://lkml.kernel.org/r/20190429052136.GA21672@unicorn.suse.cz).
- Delete
  patches.suse/rdma-fix-argument-of-ZERO_PAGE-in-rdma_umap_fault.patch.
- commit a764394
* Mon Apr 29 2019 mkubecek@suse.cz
- Update to 5.1-rc7
- add patches.suse/rdma-fix-argument-of-ZERO_PAGE-in-rdma_umap_fault.patch
  (tentative s390x build fix)
- New config options:
  - ARM:
  - KEYBOARD_SNVS_PWRKEY=m
  - armv7hl:
  - FRAME_POINTER=y
  - UNWINDER_FRAME_POINTER=y
- commit 04c1966
* Sun Apr 21 2019 mkubecek@suse.cz
- Update to v5.1-rc6
- New config options:
  - IIO:
  - SENSIRION_SGP30=n
- commit ab97af0
* Tue Apr 16 2019 mkubecek@suse.cz
- series.conf: cleanup
  patches.suse/ext2-fsync-err was deleted in 2011 but its (commented out)
  line in series.conf was left behind.
- commit d2aebe3
* Mon Apr 15 2019 jkosina@suse.cz
- Delete
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Delete
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Delete
  patches.suse/0003-x86-idle-Control-Indirect-Branch-Speculation-in-idle.patch.
- Delete
  patches.suse/0004-x86-enter-Create-macros-to-restrict-unrestrict-Indir.patch.
- Delete
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
  Drop SUSE-specific IBRS-on-SKL implementation. Please refer to
  page 16 of [1]
  [1] https://software.intel.com/security-software-guidance/api-app/sites/default/files/Retpoline-A-Branch-Target-Injection-Mitigation.pdf
- commit 5e8da3a
* Mon Apr 15 2019 mkubecek@suse.cz
- Update to 5.1-rc5
- commit 2fd333d
* Thu Apr 11 2019 msuchanek@suse.de
- Do not provide kernel-default from kernel-default-base (boo#1132154, bsc#1106751).
- commit 0e54e61
* Thu Apr 11 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: only provide firmware actually present in
  subpackage.
- commit 839debd
* Wed Apr 10 2019 msuchanek@suse.de
- kernel-subpackage-spec: Add dummy package to ensure subpackages are
  rebuilt with kernel update (bsc#1106751).
  In factory packages are not rebuilt automatically so a dependency is
  needed on the old kernel to get a rebuild with the new kernel. THe
  subpackage itself cannot depend on the kernel so add another empty
  pacakge that does depend on it.
- commit 6d14837
* Tue Apr  9 2019 jdelvare@suse.de
- Disable CONFIG_SERIO_OLPC_APSP on all but armv7
  This driver is only used by ARMv7-based OLPC laptops.
- commit 7b1b640
* Tue Apr  9 2019 jdelvare@suse.de
- Disable CONFIG_SENSORS_OCC_*
  These drivers are running on the BMC of PowerPC servers. The BMC runs
  OpenBMC and is not a target for SUSE distributions.
- commit a82eb87
* Mon Apr  8 2019 mkubecek@suse.cz
- config: disable DEVKMEM (bsc#1128045)
- commit 1478096
* Mon Apr  8 2019 mkubecek@suse.cz
- Update to 5.1-rc4
- Refresh configs
- commit e334e4f
* Mon Apr  1 2019 tiwai@suse.de
- efifb: Omit memory map check on legacy boot (bsc#1127339).
- commit 8a60576
* Mon Apr  1 2019 mkubecek@suse.cz
- Update to 5.1-rc3
- Eliminated 1 patch
- Config changes:
  - SECURITY_DEFAULT_* are back
  - enable CONFIG_OF in i386/pae and copy dependent options from default
- commit 7474ec2
* Thu Mar 28 2019 yousaf.kaukab@suse.com
- config: arm64: enable CPPC support
- commit c97748e
* Tue Mar 26 2019 msuchanek@suse.de
- Revert "Bluetooth: btusb: driver to enable the usb-wakeup
  feature" (boo#1130448).
  System still wakes up when connected BT device is powered off.
- Revert "Bluetooth: btusb: driver to enable the usb-wakeup
  feature" (boo#1130448).
- commit 1172cb0
* Tue Mar 26 2019 mkubecek@suse.cz
- Revert "parport: daisy: use new parport device model"
  (http://lkml.kernel.org/r/20190313064557.GA14531@unicorn.suse.cz).
- Delete
  patches.suse/parport-daisy-do-not-try-to-load-lowlevel-driver.patch.
- commit 7da01f5
* Tue Mar 26 2019 jbeulich@suse.com
- patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch:
  Fix re-basing mistake - IBRS enabling should not be skipped for PV Xen.
- commit 177c0f8
* Tue Mar 26 2019 mkubecek@suse.cz
- parport: daisy: do not try to load lowlevel driver
  (http://lkml.kernel.org/r/20190313064557.GA14531@unicorn.suse.cz).
- commit 4f8876e
* Mon Mar 25 2019 mkubecek@suse.cz
- Update to 5.1-rc2
- New config options:
  - CHARLCD_BL_FLASH=y
  - PARPORT_PANEL=m (renamed from PANEL)
  - PANEL=m
- commit ede8a59
* Fri Mar 22 2019 msuchanek@suse.de
- Do not provide kernel-default-srchash from kernel-default-base.
- commit d6c71ce
* Thu Mar 21 2019 mkubecek@suse.cz
- config: apply recent changes to ARM configs
- CONFIG_PREEMPT_VOLUNTARY=y
- disable CONFIG_IMA_ARCH_POLICY
- enable CONFIG_IMA_APPRAISE_BOOTPARAM
- CONFIG_LSM=""
- commit fd95045
* Wed Mar 20 2019 yousaf.kaukab@suse.com
- config: arm64: Update to v5.1-rc1
- commit 590226b
* Wed Mar 20 2019 msuchanek@suse.de
- rpm/kernel-subpackage-build: handle arm kernel zImage.
- commit 81a63c3
* Wed Mar 20 2019 jslaby@suse.cz
- config: disable IMA_ARCH_POLICY for now
  When IMA_ARCH_POLICY was enabled during the 5.0-rc* stage, IMA causes
  kdump load to fail:
  kexec_file_load failed: Permission denied
  ima: impossible to appraise a kernel image without a file descriptor; try using kexec_file_load syscall.
  We have to fix kexec tooling before enabling IMA for everyone.
  BTW IMA_APPRAISE_BOOTPARAM was disabled by IMA_ARCH_POLICY=y. So
  restore the original state (and functionality).
- commit f738bd5
* Wed Mar 20 2019 yousaf.kaukab@suse.com
- config: armv6hl: Update to v5.1-rc1
  CONFIG_BPFILTER_UMH is disabled due to bsc#1127188
- commit 608f8e5
* Wed Mar 20 2019 tiwai@suse.de
- rpm/kernel-source.changes.old: Really drop old changelogs (bsc#1098995)
- commit 93056b5
* Tue Mar 19 2019 yousaf.kaukab@suse.com
- config: armv7hl: Update to v5.1-rc1
  CONFIG_BPFILTER_UMH is disabled due to bsc#1127188
- commit 0042582
* Mon Mar 18 2019 mkubecek@suse.cz
- Update to 5.1-rc1
- Eliminated 74 patches (73 stable, 1 other)
- ARM configs need update
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  patches.suse/genksyms-add-override-flag.diff
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
  patches.suse/readahead-request-tunables.patch
  patches.suse/supported-flag
  patches.suse/vfs-add-super_operations-get_inode_dev
- New config options:
  - General:
  - IO_URING=y
  - PRINTK_CALLER=n
  - File systems:
  - CONFIG_SUNRPC_DISABLE_INSECURE_ENCTYPES=n
  - VALIDATE_FS_PARSER=n
  - Networking:
  - NET_DEVLINK=y
  - XDP_SOCKETS_DIAG=m
  - MT7603E=m
  - TI_CPSW_PHY_SEL=n
  - Power management:
  - CPU_IDLE_GOV_TEO=y
  - DAX:
  - DEV_DAX_KMEM=m
  - DEV_DAX_PMEM_COMPAT=m
  - USB:
  - USB_AUTOSUSPEND_DELAY=2
  - USB_EHCI_FSL=m
  - Graphics:
  - DRM_ETNAVIV=n
  - DRM_NOUVEAU_SVM=n
  - VIDEO_FB_IVTV_FORCE_PAT=n
  - Sound:
  - SND_SOC_CROS_EC_CODEC=m
  - SND_SOC_CS35L36=m
  - SND_SOC_CS4341=m
  - SND_SOC_FSL_MICFIL=n
  - SND_SOC_MAX98373=m
  - SND_SOC_MT6358=n
  - SND_SOC_MTK_BTCVSD=m
  - SND_SOC_RK3328=n
  - SND_SOC_WM8904=n
  - SND_SOC_XILINX_AUDIO_FORMATTER=n
  - SND_SOC_XILINX_SPDIF=n
  - Input:
  - HID_MALTRON=m
  - HID_VIEWSONIC=m
  - TTY:
  - LDISC_AUTOLOAD=y
  - RTC:
  - RTC_DRV_ABEOZ9=m
  - RTC_DRV_RV3028=m
  - RTC_DRV_SD3078=m
  - RTC_DRV_WILCO_EC=m
  - Industrial IO:
  - AD7606_IFACE_PARALLEL=n
  - AD7606_IFACE_SPI=n
  - AD7768_1=n
  - MAX44009=m
  - PMS7003=n
  - SPS30=n
  - TI_DAC7612=n
  - Misc drivers:
  - ALTERA_FREEZE_BRIDGE=m
  - EDAC_I10NM=m
  - EXTCON_PTN5150=m
  - GNSS_MTK_SERIAL=m
  - GPIO_AMD_FCH=m
  - GPIO_TQMX86=m
  - HABANA_AI=m
  - INPUT_MSM_VIBRATOR=n
  - INTEL_MEI_HDCP=m
  - INTERCONNECT=m
  - IR_RCMM_DECODER=m
  - MFD_TQMX86=m
  - MLX_WDT=m
  - SPI_MTK_QUADSPI=m
  - SPI_NXP_FLEXSPI=n
  - SPI_SIFIVE=n
  - WILCO_EC=m
  - WILCO_EC_DEBUGFS=n
  - Virtualization:
  - HYPERV_IOMMU=y
  - Security:
  - LSM=""
  - SECURITY_SAFESETID=n
  - Testing:
  - TEST_LIVEPATCH=n
  - TEST_STACKINIT=n
  - TEST_VMALLOC=n
  - x86:
  - PCENGINES_APU2=m
  - ppc64/ppc64le:
  - NVRAM=m
  - KCOV=n
  - s390x:
  UID16=y
  DMA_FENCE_TRACE=n
  SCSI_GDTH=n
  UDMABUF=y
  - */debug:
  - PRINTK_CALLER=n
- commit b493de0
* Mon Mar 18 2019 msuchanek@suse.de
- Trim build dependencies of sample subpackage spec file (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit 2eae420
* Sun Mar 17 2019 mkubecek@suse.cz
- Drop stale disabled patches
  As discussed in
  http://mailman.suse.de/mlarch/SuSE/kernel/2019/kernel.2019.02/msg00118.html
  http://mailman.suse.de/mlarch/SuSE/kernel/2019/kernel.2019.03/msg00016.html
  some of our patches have been disabled for quite long and attempts to get
  them reviewed failed. Let's drop them now:
  patches.suse/0036-arm-Add-BTB-invalidation-on-switch_mm-for-Cortex-A9-.patch
  patches.suse/0037-arm-Invalidate-BTB-on-prefetch-abort-outside-of-user.patch
  patches.suse/0038-arm-KVM-Invalidate-BTB-on-guest-exit.patch
  patches.suse/0039-arm-Add-icache-invalidation-on-switch_mm-for-Cortex-.patch
  patches.suse/0040-arm-Invalidate-icache-on-prefetch-abort-outside-of-u.patch
  patches.suse/0041-arm-KVM-Invalidate-icache-on-guest-exit-for-Cortex-A.patch
  patches.suse/binutils2_26.patch
  patches.suse/dm-mpath-accept-failed-paths
  patches.suse/pstore-backend-autoaction
- commit 55d6d1e
* Sun Mar 17 2019 mkubecek@suse.cz
- config: enable RANDOM_TRUST_CPU
  The outcome from mailing list discussion when this config option
  appeared was that it makes more sense to enable it by default and let
  those who do not trust their CPU override it on command line; but then
  I forgot to actually change the value.
- commit 138b5df
* Fri Mar 15 2019 tiwai@suse.de
- Update config files: disable CONFIG_FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER (bsc#1127552)
  The deferred fbcon takeover makes little sense with the current openSUSE
  boot setup, and it's harmful (more glitches, etc).  Disable it for now.
- commit 14fa903
* Fri Mar 15 2019 msuchanek@suse.de
- Remove the previous subpackage infrastructure.
  This partially reverts commit 9b3ca32c11854156b2f950ff5e26131377d8445e
  ("Add kernel-subpackage-build.spec (FATE#326579).")
- commit a5ee24e
* Fri Mar 15 2019 msuchanek@suse.de
- Add sample kernel-default-base spec file (FATE#326579, jsc#SLE-4117,
  jsc#SLE-3853, bsc#1128910).
- commit 35c4a52
* Thu Mar 14 2019 msuchanek@suse.de
- Install extra rpm scripts for kernel subpackaging (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit ad7c227
* Thu Mar 14 2019 jslaby@suse.cz
- Linux 5.0.2 (bnc#1012628).
- perf/x86/intel: Implement support for TSX Force Abort
  (bnc#1012628).
- x86: Add TSX Force Abort CPUID/MSR (bnc#1012628).
- perf/x86/intel: Generalize dynamic constraint creation
  (bnc#1012628).
- perf/x86/intel: Make cpuc allocations consistent (bnc#1012628).
- ath9k: Avoid OF no-EEPROM quirks without qca,no-eeprom
  (bnc#1012628).
- scripts/gdb: replace flags (MS_xyz -> SB_xyz) (bnc#1012628).
- staging: erofs: compressed_pages should not be accessed again
  after freed (bnc#1012628).
- staging: erofs: keep corrupted fs from crashing kernel in
  erofs_namei() (bnc#1012628).
- gfs2: Fix missed wakeups in find_insert_glock (bnc#1012628).
- bpf: Stop the psock parser before canceling its work
  (bnc#1012628).
- Revert "PCI/PME: Implement runtime PM callbacks" (bnc#1012628).
- media: Revert "media: rc: some events are dropped by userspace"
  (bnc#1012628).
- drm: disable uncached DMA optimization for ARM and arm64
  (bnc#1012628).
- ARM: dts: exynos: Fix max voltage for buck8 regulator on Odroid
  XU3/XU4 (bnc#1012628).
- ARM: dts: exynos: Add minimal clkout parameters to Exynos3250
  PMU (bnc#1012628).
- ARM: dts: exynos: Fix pinctrl definition for eMMC RTSN line
  on Odroid X2/U3 (bnc#1012628).
- arm64: dts: hikey: Revert "Enable HS200 mode on eMMC"
  (bnc#1012628).
- arm64: dts: hikey: Give wifi some time after power-on
  (bnc#1012628).
- arm64: dts: zcu100-revC: Give wifi some time after power-on
  (bnc#1012628).
- x86/PCI: Fixup RTIT_BAR of Intel Denverton Trace Hub
  (bnc#1012628).
- scsi: aacraid: Fix missing break in switch statement
  (bnc#1012628).
- iscsi_ibft: Fix missing break in switch statement (bnc#1012628).
- Input: elan_i2c - add id for touchpad found in Lenovo s21e-20
  (bnc#1012628).
- Input: wacom_serial4 - add support for Wacom ArtPad II tablet
  (bnc#1012628).
- media: uvcvideo: Fix 'type' check leading to overflow
  (bnc#1012628).
- commit 815c1bc
* Mon Mar 11 2019 mkubecek@suse.cz
- Update patches.suse/0001-media-usb-pwc-Don-t-use-coherent-DMA-buffers-for-ISO.patch
  upstream reference.
- commit ff7c8cd
* Sun Mar 10 2019 jslaby@suse.cz
- Linux 5.0.1 (bnc#1012628).
- exec: Fix mem leak in kernel_read_file (bnc#1012628).
- Bluetooth: Fix locking in bt_accept_enqueue() for BH context
  (bnc#1012628).
- Bluetooth: btrtl: Restore old logic to assume firmware is
  already loaded (bnc#1012628).
- selftests: firmware: fix verify_reqs() return value
  (bnc#1012628).
- Revert "selftests: firmware: remove use of non-standard diff
  - Z option" (bnc#1012628).
- Revert "selftests: firmware: add
  CONFIG_FW_LOADER_USER_HELPER_FALLBACK to config" (bnc#1012628).
- USB: serial: cp210x: fix GPIO in autosuspend (bnc#1012628).
- gnss: sirf: fix premature wakeup interrupt enable (bnc#1012628).
- xtensa: fix get_wchan (bnc#1012628).
- aio: Fix locking in aio_poll() (bnc#1012628).
- MIPS: irq: Allocate accurate order pages for irq stack
  (bnc#1012628).
- alpha: wire up io_pgetevents system call (bnc#1012628).
- applicom: Fix potential Spectre v1 vulnerabilities
  (bnc#1012628).
- usb: xhci: Fix for Enabling USB ROLE SWITCH QUIRK on
  INTEL_SUNRISEPOINT_LP_XHCI (bnc#1012628).
- xhci: tegra: Prevent error pointer dereference (bnc#1012628).
- tracing: Fix event filters and triggers to handle negative
  numbers (bnc#1012628).
- x86/boot/compressed/64: Do not read legacy ROM on EFI system
  (bnc#1012628).
- x86/CPU/AMD: Set the CPB bit unconditionally on F17h
  (bnc#1012628).
- tipc: fix RDM/DGRAM connect() regression (bnc#1012628).
- team: Free BPF filter when unregistering netdev (bnc#1012628).
- sky2: Disable MSI on Dell Inspiron 1545 and Gateway P-79
  (bnc#1012628).
- sctp: call iov_iter_revert() after sending ABORT (bnc#1012628).
- qmi_wwan: Add support for Quectel EG12/EM12 (bnc#1012628).
- net-sysfs: Fix mem leak in netdev_register_kobject
  (bnc#1012628).
- net: sched: put back q.qlen into a single location
  (bnc#1012628).
- net: mscc: Enable all ports in QSGMII (bnc#1012628).
- net: dsa: mv8e6xxx: fix number of internal PHYs for 88E6x90
  family (bnc#1012628).
- net: dsa: mv88e6xxx: handle unknown duplex modes gracefully
  in mv88e6xxx_port_set_duplex (bnc#1012628).
- net: dsa: mv88e6xxx: add call to mv88e6xxx_ports_cmode_init
  to probe for new DSA framework (bnc#1012628).
- ip6mr: Do not call __IP6_INC_STATS() from preemptible context
  (bnc#1012628).
- staging: android: ashmem: Avoid range_alloc() allocation with
  ashmem_mutex held (bnc#1012628).
- staging: android: ashmem: Don't call fallocate() with
  ashmem_mutex held (bnc#1012628).
- staging: android: ion: fix sys heap pool's gfp_flags
  (bnc#1012628).
- staging: wilc1000: fix to set correct value for 'vif_num'
  (bnc#1012628).
- staging: comedi: ni_660x: fix missing break in switch statement
  (bnc#1012628).
- staging: erofs: fix illegal address access under memory pressure
  (bnc#1012628).
- staging: erofs: fix race of initializing xattrs of a inode at
  the same time (bnc#1012628).
- staging: erofs: fix memleak of inode's shared xattr array
  (bnc#1012628).
- staging: erofs: fix fast symlink w/o xattr when fs xattr is on
  (bnc#1012628).
- driver core: Postpone DMA tear-down until after devres release
  (bnc#1012628).
- USB: serial: ftdi_sio: add ID for Hjelmslund Electronics USB485
  (bnc#1012628).
- USB: serial: cp210x: add ID for Ingenico 3070 (bnc#1012628).
- USB: serial: option: add Telit ME910 ECM composition
  (bnc#1012628).
- binder: create node flag to request sender's security context
  (bnc#1012628).
- staging: erofs: fix mis-acted TAIL merging behavior
  (bnc#1012628).
- cpufreq: Use struct kobj_attribute instead of struct global_attr
  (bnc#1012628).
- commit 47a2a02
* Thu Mar  7 2019 msuchanek@suse.de
- KMPs: provide and conflict a kernel version specific KMP name
  (bsc#1127155, bsc#1109137).
- commit 5568093
* Wed Mar  6 2019 msuchanek@suse.de
- Revert "Drop multiversion(kernel) from the KMP template (fate#323189)"
  (bsc#1109137).
  This reverts commit 71504d805c1340f68715ad41958e5ef35da2c351.
- commit adade9f
* Tue Mar  5 2019 mkubecek@suse.cz
- config: disable BPFILTER_UMH on non-x86 architectures (bsc#1127188)
  CONFIG_BPFILTER_UMH depends on ability to compile and link a userspace
  binary so that it currently doesn't work in our kbuild check setups using
  a cross compiler. Disable the option on architectures where cross compiler
  is used (i.e. all except x86_64 and i386).
- commit cfb8371
* Mon Mar  4 2019 msuchanek@suse.de
- KMPs: obsolete older KMPs of the same flavour (bsc#1127155, bsc#1109137).
- commit 821419f
* Mon Mar  4 2019 mkubecek@suse.cz
- Update to 5.0 final
- Refresh configs
- commit 8f71df2
* Wed Feb 27 2019 msuchanek@suse.de
- BPF: UMH: do not detect if compiler can link userspace program
  (boo#1127188).
- commit 784e336
* Mon Feb 25 2019 mkubecek@suse.cz
- Update to 5.0-rc8
- Eliminated 1 patch
- commit 4ddf057
* Fri Feb 22 2019 mkubecek@suse.cz
- net: crypto set sk to NULL when af_alg_release (CVE-2019-8912
  bsc#1125907).
- commit 3aed52e
* Fri Feb 22 2019 mkubecek@suse.cz
- config: enable PREEMPT_VOLUNTARY (bsc#1125004)
  Switch to PREEMPT_VOLUNTARY everywhere except s390x/zfcpdump.
- commit f62cec7
* Tue Feb 19 2019 mbenes@suse.cz
- rpm/klp-symbols: Remove the second column in Symbols.list
  Symbols.list file contains also a symbol type next to its name.
  klp-convert cannot handle it well and it is superfluous anyway.
- commit 62a0a00
* Mon Feb 18 2019 mkubecek@suse.cz
- Update to 5.0-rc7
- commit b094e66
* Mon Feb 11 2019 mkubecek@suse.cz
- Update to 5.0-rc6
- commit eb4b248
* Fri Feb  8 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Build livepatch support in SUSE release
  projects (bsc#1124167).
- commit 7519080
* Mon Feb  4 2019 mkubecek@suse.cz
- Update to 5.0-rc5
- Config changes:
  - x86:
  - X86_RESCTRL renamed to X86_CPU_RESCTRL
- commit a42dcc6
* Wed Jan 30 2019 mwilck@suse.com
- rpm/kernel-binary.spec.in: fix initrd permissions (bsc#1123697)
  dracut has been using permissions 0600 for the initrd for a long
  time. On SLE15 or higher, that leads to a permission mismatch
  reported by "rpm -V". Set the permissions correctly for our
  ghost file.
- commit 9e5e2a5
* Mon Jan 28 2019 tiwai@suse.de
- doc/README.SUSE: Correct description for building a kernel (bsc#1123348)
  The obsoleted make cloneconfig is corrected.  Also the order of make
  scripts and make prepare are corrected as well.
- commit 17a2073
* Mon Jan 28 2019 tiwai@suse.de
- rpm/release-projects: Add SUSE:Maintenance:* for MU kernels (bsc#1123317)
- commit c784b79
* Mon Jan 28 2019 mkubecek@suse.cz
- Update to 5.0-rc4
- commit 8e6abff
* Thu Jan 24 2019 ptesarik@suse.cz
- Add product identifying information to VMCOREINFO (bsc#1123015).
- commit 68ca35e
* Thu Jan 24 2019 msuchanek@suse.de
- rpm/kernel-*.spec.in: replace update srchash dependencies (FATE#325312).
  Due to some limitations version cannot be matched so move the hash into
  the provide name.
- commit 219bcec
* Tue Jan 22 2019 oneukum@suse.com
- media: usb: pwc: Don't use coherent DMA buffers for ISO transfer
  (bsc#1054610).
- commit 59d243a
* Mon Jan 21 2019 mkubecek@suse.cz
- Update to 5.0-rc3
- Config changes:
  - ARM64:
  - HSA_AMD=y
- commit 05bf5c0
* Mon Jan 14 2019 mkubecek@suse.cz
- Update to 5.0-rc2
- Config changes:
  - x86:
  - RESCTRL renamed to X86_RESCTRL
- commit 879eb5c
* Fri Jan 11 2019 afaerber@suse.de
- config: arm64: Update to 5.0-rc1
- commit 88c2434
* Mon Jan  7 2019 mkubecek@suse.cz
- config: restore accidentally lost BPFILTER_UMH (ppc64, ppc64le, s390x)
- commit a56baa9
* Mon Jan  7 2019 mkubecek@suse.cz
- vfio_pci: Add local source directory as include.
- commit ea6d6e3
* Mon Jan  7 2019 mkubecek@suse.cz
- Update to 5.0-rc1
- Eliminated 1 patch
- ARM configs need update
- Config changes:
  - PM:
  - ENERGY_MODEL=y
  - Networking:
  - CAN_FLEXCAN=m
  - USB_NET_AQC111=m
  - QTNFMAC_PCIE=m
  - VIRT_WIFI=m
  - PCI:
  - PCI_MESON=n
  - SCSI:
  - SCSI_UFS_CDNS_PLATFORM=m
  - NVME:
  - NVME_TCP=m
  - NVME_TARGET_TCP=m
  - Graphics:
  - DRM_PANEL_OLIMEX_LCD_OLINUXINO=n
  - DRM_PANEL_SAMSUNG_S6D16D0=n
  - DRM_PANEL_TRULY_NT35597_WQXGA=n
  - TINYDRM_HX8357D=n
  - Sound:
  - SND_SOC_AMD_ACP3x=n
  - SND_SOC_INTEL_KBL_RT5660_MACH=m
  - SND_SOC_XILINX_I2S=n
  - SND_SOC_AK4118=n
  - Multimedia:
  - VIDEO_ASPEED=m
  - VIDEO_SECO_CEC=m
  - VIDEO_SECO_RC=y
  - I3C:
  - I3C=m
  - CDNS_I3C_MASTER=m
  - DW_I3C_MASTER=m
  - IIO:
  - AD7124=n
  - AD7949=n
  - TI_DAC7311=n
  - VCNL4035=n
  - SENSORS_RM3100_I2C=n
  - SENSORS_RM3100_SPI=n
  - MCP41010=m
  - PHY:
  - PHY_CADENCE_SIERRA=m
  - PHY_FSL_IMX8MQ_USB=m
  - misc drivers:
  - MTD_PHYSMAP_GPIO_ADDR=y
  - SPI_MXIC=n
  - MISC_ALCOR_PCI=m
  - RC_XBOX_DVD=m
  - PINCTRL_OCELOT=n
  - GPIO_CADENCE=m
  - SENSORS_OCC_P8_I2C=m
  - TQMX86_WDT=m
  - MMC_ALCOR=m
  - MMC_SDHCI_AM654=m
  - LEDS_TRIGGER_AUDIO=m
  - SERIO_OLPC_APSP=m
  - Security:
  - INTEGRITY_PLATFORM_KEYRING=y
  - IMA_ARCH_POLICY=y
  - Crypto:
  - CRYPTO_ADIANTUM=m
  - CRYPTO_STREEBOG=m
  - CRYPTO_STATS=n
  - Library:
  - RAID6_PQ_BENCHMARK=y (preserve current behaviour)
  - Testing:
  - TEST_OBJAGG=n
  - x86:
  - RESCTRL=y
  - HUAWEI_WMI=m
  - i386:
  - PVH=y
  - MTD_PHYSMAP_OF=m
  - ppc*:
  - PVPANIC=m
  - FB_LOGO_CENTER=n
  - FSI_OCC=m
  - DEBUG_VIRTUAL=n
  - SENSORS_OCC_P9_SBE=m
  - s390x:
  - PCCARD=n
  - RAPIDIO
  - other RapidIO options copy other architectures
  - DMADEVICES related options copy other architectures
  - */debug:
  - CRYPTO_STATS=y
  - TTY_PRINTK_LEVEL=6
- commit 6a4ceaa
* Mon Dec 24 2018 mkubecek@suse.cz
- Update to 4.20 final
- Eliminated 1 patch
- Refresh configs
- commit ba5c149
* Fri Dec 21 2018 mkubecek@suse.cz
- rtlwifi: Fix leak of skb when processing C2H_BT_INFO
  (bsc#1116448).
- commit 9d82d20
* Mon Dec 17 2018 mkubecek@suse.cz
- Update to 4.20-rc7
- Config changes:
  - ARM:
  - MEDIA_CONTROLLER_REQUEST_API=y
- commit 4731528
* Mon Dec 10 2018 afaerber@suse.de
- config: arm: Enable EFI support (boo#1104833)
- commit 7050650
* Mon Dec 10 2018 afaerber@suse.de
- config: armv7hl: Update to 4.20-rc5
- commit f01387b
* Mon Dec 10 2018 jslaby@suse.cz
- Delete
  patches.suse/blk-mq-fix-corruption-with-direct-issue.patch.
  It is in 4.20-rc6 as ffe81d45322c but was partially reverted by
  c616cbee97ae, so this patch still applies cleanly, but is unwanted.
  Drop it.
- commit 7670339
* Mon Dec 10 2018 mkubecek@suse.cz
- Update to 4.20-rc6
- Eliminated 1 patch
- Refresh configs
- commit 93f10c3
* Sat Dec  8 2018 msuchanek@suse.de
- Include modules.fips in kernel-binary as well as kernel-binary-base
  (FATE#323247).
- commit e42315d
* Fri Dec  7 2018 jslaby@suse.cz
- x86/build: Fix compiler support check for CONFIG_RETPOLINE
  (KMP build).
- commit fb5fd39
* Wed Dec  5 2018 mkubecek@suse.cz
- blk-mq: fix corruption with direct issue (bko#201685).
- commit 8970eff
* Tue Dec  4 2018 jroedel@suse.de
- blacklist.conf: Blacklist MAINTAINERS file
- commit c4b3c90
* Mon Dec  3 2018 afaerber@suse.de
- config: armv6hl: Update to 4.20-rc5
- commit c85b385
* Mon Dec  3 2018 guillaume.gardet@free.fr
- config: armv7hl: Build some options as modules (boo#1104833)
  Enable HISI_THERMAL=m while at it.
- commit c9b9dd6
* Mon Dec  3 2018 mkubecek@suse.cz
- Update to 4.20-rc5
- Config changes:
  - General:
  - PSI_DEFAULT_DISABLED=y
  - Sound:
  - SND_SOC_INTEL_SKYLAKE_HDAUDIO_CODEC=y
  - ARM:
  - ARM64_ERRATUM_1286807=y
- commit 2ccaf30
* Mon Nov 26 2018 mkubecek@suse.cz
- Update to 4.20-rc4
- Config changes:
  - Networking:
  - MT76_LEDS=y (split from MT76_CORE)
- commit 1ac69b7
* Fri Nov 23 2018 msuchanek@suse.de
- Build ppc64le for POWER8+ (FATE#325617).
- commit f6da51b
* Fri Nov 23 2018 msuchanek@suse.de
- Revert "Remove Cell/PS3 support from ppc64 kernel (boo#1114846)"
  This reverts commit fd6aaf7f98693355e7dcc5e4e1926fb1664d803b.
  Fixed upstream in 43c6494fa149 ("powerpc/io: Fix the IO workarounds code
  to work with Radix")
- commit 4f86993
* Tue Nov 20 2018 rgoldwyn@suse.com
- apparmor: fix unnecessary creation of net-compat (bsc#1116724).
- commit f5cf767
* Mon Nov 19 2018 mkubecek@suse.cz
- Update to 4.20-rc3
- Refresh configs
- commit 81d20d2
* Tue Nov 13 2018 msuchanek@suse.de
- Add kernel-subpackage-build.spec (FATE#326579).
  - add kernel-subpackage-build.spec.in and support scripts
  - hook it in mkspec
  - extend the mechanism that copies dependencies inside
  kernel-binary.spec.in from kernel-%%build_flavor to
  kernel-%%build_flavor-base to also handle
  kernel-subpackage-build.spec.in using BINARY DEPS marker.
  - expand %%name in kernel-%%build_flavor so the dependencies are expanded
  correctly in kernel-subpackage-build.spec.in
- commit 9b3ca32
* Mon Nov 12 2018 mkubecek@suse.cz
- Update to 4.20-rc2
- Eliminated 1 patch
- Config changes:
  - I2C:
    I2C_NVIDIA_GPU=m
  - USB:
    UCSI_CCG=m
- commit 1c08d7f
* Sun Nov 11 2018 afaerber@suse.de
- config: arm64: Update to 4.20-rc1
- commit 2d02cd8
* Thu Nov  8 2018 jslaby@suse.cz
- doc/README.SUSE: correct GIT url
  No more gitorious, github we use.
- commit 31864f3
* Tue Nov  6 2018 mkubecek@suse.cz
- config: reenable BPFILTER_UMH on ppc64
- commit 46cb36e
* Tue Nov  6 2018 agraf@suse.de
- Remove Cell/PS3 support from ppc64 kernel (boo#1114846)
- commit fd6aaf7
* Mon Nov  5 2018 mkubecek@suse.cz
- scripts/mkmakefile: honor second argument.
- commit 78325a6
* Mon Nov  5 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add macros.s into kernel-*-devel
  Starting with 4.20-rc1, file arch/*/kernel/macros.s is needed to build out
  of tree modules. Add it to kernel-${flavor}-devel packages if it exists.
- commit 09d14c8
* Mon Nov  5 2018 mkubecek@suse.cz
- series.conf: delete an obsolete comment
- commit c3bd57d
* Mon Nov  5 2018 jslaby@suse.cz
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
  Adapt to 4.20.
- commit dcaec93
* Mon Nov  5 2018 mkubecek@suse.cz
- Update to 4.20-rc1
- ARM configs need updating
- disabled (needs refresh):
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch
- Config changes:
  - General:
  - PSI=y
  - Networking:
  - NFT_XFRM=m
  - NET_SCH_TAPRIO=m
  - BATMAN_ADV_TRACING=n
  - NCSI_OEM_CMD_GET_MAC=y
  - EEPROM_EE1004=m
  - SCSI_UFS_BSG=y
  - SCSI_MYRB=m
  - SCSI_MYRS=m
  - IXGBE_IPSEC=y
  - IXGBEVF_IPSEC=y
  - IGC=m
  - NI_XGE_MANAGEMENT_ENET=m
  - MT76x0E=m
  - File systems:
  - EROFS_FS_IO_MAX_RETRIES=5 (default)
  - AFS_DEBUG_CURSOR=n
  - CONFIG_UBIFS_FS_AUTHENTICATION=y
  - Crypto:
  - CRYPTO_OFB=m
  - CRYPTO_STATS=n
  - ASYMMETRIC_TPM_KEY_SUBTYPE=m
  - PKCS8_PRIVATE_KEY_PARSER=m
  - TPM_KEY_PARSER=m
  - Graphics:
  - VIDEO_VICODEC=m
  - DRM_FBDEV_LEAK_PHYS_SMEM=n
  - DRM_I915_DEBUG_RUNTIME_PM=n
  - DRM_TOSHIBA_TC358764=n
  - DRM_TI_SN65DSI86=n
  - Sound:
  - SND_SOC_INTEL_KBL_DA7219_MAX98927_MACH=m
  - SND_SOC_INTEL_SKL_HDA_DSP_GENERIC_MACH=m
  - SND_SOC_MAX98088=n
  - SND_SOC_PCM3060_I2C=n
  - SND_SOC_PCM3060_SPI=n
  - SND_SOC_NAU8822=n
  - Input devices:
  - HID_BIGBEN_FF=m
  - Platform:
  - LG_LAPTOP=m
  - INTEL_ATOMISP2_PM=m
  - IIO:
  - ADXL372_SPI=n
  - ADXL372_I2C=n
  - MCP3911=n
  - QCOM_SPMI_ADC5=n
  - LTC1660=n
  - VL53L0X_I2C=m
  - Misc drivers:
  - UDMABUF=y
  - MFD_AT91_USART=n
  - LEDS_AN30259A=n
  - LEDS_TRIGGER_PATTERN=m
  - PHY_CADENCE_DP=m
  - STM_PROTO_BASIC=m
  - STM_PROTO_SYS_T=m
  - Testing:
  - TEST_XARRAY=n
  - TEST_MEMCAT_P=n
  - x86:
  - X86_CPA_STATISTICS=n (y for -debug)
  - i386:
  - MSCC_OCELOT_SWITCH_OCELOT=m
  - ppc64, ppc64le:
  - PAPR_SCM=m
  - PCI_P2PDMA=y
  - STACKPROTECTOR=y
  - STACKPROTECTOR_STRONG=n
  - BLK_DEV_PMEM=m
  - ND_BLK=m
  - BTT=y
  - NVDIMM_PFN=y
  - NVDIMM_DAX=y
  - OF_PMEM=m
  - DEV_DAX_PMEM=m
  - FAIL_FUNCTION=n
  - ENA_ETHERNET=m
  - s390:
  - VMAP_STACK=y
  - S390_AP_IOMMU=n
  - ZCRYPT_MULTIDEVNODES=y
  - KASAN=n
  - */debug:
  - INTEL_IOMMU_DEBUGFS=y
  - BPF_KPROBE_OVERRIDE=y
  - CONFIG_X86_CPA_STATISTICS=y
  - CONFIG_CRYPTO_STATS=y
- commit f29310b
* Sun Nov  4 2018 mkubecek@suse.cz
- rpm: use syncconfig instead of silentoldconfig where available
  Since mainline commit 0085b4191f3e ("kconfig: remove silentoldconfig
  target"), "make silentoldconfig" can be no longer used. Use "make
  syncconfig" instead if available.
- commit a239c6e
* Fri Nov  2 2018 mkubecek@suse.cz
- series.conf: more descriptive name for network driver section
  We have two networking sections in series.conf: one for networking core and
  one for network drivers. The latter is among other driver related sections
  but it may not be obvious that it is not intended for core networking
  patches. Change the label to "Network drivers" to make its purpose more
  apparent.
- commit 7968e32
* Fri Nov  2 2018 mkubecek@suse.cz
- config: enable SCSI_AACRAID on ppc64le and ppc64 (bsc#1114523)
- commit 5f3762b
* Tue Oct 30 2018 jslaby@suse.cz
- Refresh
  patches.suse/netfilter-bridge-define-INT_MIN-INT_MAX-in-userspace.patch.
  Update upstream status.
- commit 37417fa
* Tue Oct 30 2018 jmoreira@suse.de
- Add version information to KLP_SYMBOLS file
- commit f77f8d2
* Thu Oct 25 2018 mwilck@suse.com
- rpm/kernel-binary.spec.in: allow unsupported modules for -extra
  (bsc#1111183). SLE-15 and later only.
- commit 0d585a8
* Wed Oct 24 2018 mkubecek@suse.cz
- series.conf: move patches.suse/netfilter-bridge-define-INT_MIN-INT_MAX-in-userspace.patch to netfilter section
- commit 7656685
* Wed Oct 24 2018 jslaby@suse.cz
- netfilter: bridge: define INT_MIN & INT_MAX in userspace
  (4.19 fixes).
- commit e7213f6
* Mon Oct 22 2018 mkubecek@suse.cz
- Update to 4.19 final
- Refresh configs
- commit b4c35bb
* Mon Oct 15 2018 mkubecek@suse.cz
- Update to 4.19-rc8
- commit 2e61ca8
* Fri Oct 12 2018 tzimmermann@suse.de
- README: Clean-up trailing whitespace
- commit 06542f9
* Thu Oct 11 2018 tzimmermann@suse.de
- README: Update documentation wrt. Patch-mainline
  Common practice is to set Patch-mainline to a Linux release tag. More
  than 95%% of all patches follow this convention. The remaining 5%% have
  been fixed accordingly in SLE15.
  The README file is inconsistent wrt. to the content of Patch-mainline.
  In some places it refers to a release tag, in others it refers to a version
  number. With this cleanup, it refers to release tags everywhere.
  This change is a follow-up for commit 1d81d2699cd3.
- commit 57326f5
* Tue Oct  9 2018 msuchanek@suse.de
- Revert "Limit kernel-source build to architectures for which we build binaries"
  This reverts commit d6435125446d740016904abe30a60611549ae812.
- commit 48b03c4
* Mon Oct  8 2018 mkubecek@suse.cz
- Update to 4.19-rc7
- commit 63b130b
* Thu Oct  4 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1110716)
  Enable ST LPS25H pressure sensor.
- commit 9882f33
* Tue Oct  2 2018 nborisov@suse.com
- Update config files. (boo##1109665)
- commit 76516eb
* Mon Oct  1 2018 msuchanek@suse.de
- rpm/mkspec: fix ppc64 kernel-source build.
- commit 85c9272
* Sun Sep 30 2018 mkubecek@suse.cz
- Update to 4.19-rc6
- Eliminated 2 patches
- commit 80aa112
* Sat Sep 29 2018 lduncan@suse.com
- Added CVE numbers for two patches (bsc#1107829)
- commit e3ac2a8
* Fri Sep 28 2018 lduncan@suse.com
- scsi: target: iscsi: Use bin2hex instead of a re-implementation
  (bsc#1107829).
- scsi: target: iscsi: Use hex2bin instead of a re-implementation
  (bsc#1107829).
- commit 8791706
* Thu Sep 27 2018 msuchanek@suse.de
- rpm/mkspec: build dtbs for architectures marked -!needs_updating
- commit 2d47640
* Thu Sep 27 2018 msuchanek@suse.de
- Limit kernel-source build to architectures for which we build binaries
  (bsc#1108281).
- commit d643512
* Tue Sep 25 2018 mbrugger@suse.com
- arm64: Update config files.
  Increase NR_CPUS to 480 (fate#325592)
- commit d5464c0
* Mon Sep 24 2018 mkubecek@suse.cz
- Update to 4.19-rc5
- commit b44d7bc
* Mon Sep 17 2018 mkubecek@suse.cz
- Update to 4.19-rc4
- Eliminated 1 patch
- Config changes:
  - Filesystems:
  - EROFS_FS=m
  - EROFS_FS_DEBUG=n
  - EROFS_FS_XATTR=y
  - EROFS_FS_POSIX_ACL=y
  - EROFS_FS_SECURITY=y
  - EROFS_FS_USE_VM_MAP_RAM=n
  - EROFS_FAULT_INJECTION=n
  - EROFS_FS_ZIP=n
- commit 625b101
* Fri Sep 14 2018 mkubecek@suse.cz
- ip: frags: fix crash in ip_do_fragment() (bsc#1108533).
- commit ba41502
* Fri Sep 14 2018 msuchanek@suse.de
- doc/README.SUSE: Remove mentions of cloneconfig (bsc#1103636).
- commit 3371adc
* Thu Sep 13 2018 jbohac@suse.cz
- Delete patches.suse/x86_64-hpet-64bit-timer.patch.
  We removed the patch from SLE15 in commit
  20efbd0c034fea7c97243120a025587d0dbac1c2
  and we don't need it in future versions of SLE.
- commit aa4eb67
* Mon Sep 10 2018 msuchanek@suse.de
- macros.kernel-source: pass -b properly in kernel module package
  (bsc#1107870).
- commit 66709cd
* Mon Sep 10 2018 mkubecek@suse.cz
- Update to 4.19-rc3
- refresh configs
- commit d3995d7
* Fri Sep  7 2018 jeffm@suse.com
- config: disable HFS_FS
  It has no maintainer and has been a source of fuzzer bugs.  hfsplus handles
  the HFS+ file system that became the default on MacOS in 1998.
- commit 0d9481c
* Fri Sep  7 2018 tiwai@suse.de
- supported.conf: Add bpfilter to kernel-default-base (bsc#1106751)
- commit 8f1f1b6
* Mon Sep  3 2018 jslaby@suse.cz
- rpm/kernel-binary.spec.in: fix call of split-modules
  split-modules is called with some parameters depending on config
  options. But since we do not use backslash consistelny, the call to
  split-modules might be evaluated so that also the following cat
  command is appended. Avoid this behaviour by using backslashes
  everywhere and add %%nil to the end.
  This perhaps never happens, but stay on the safe side.
- commit 32df888
* Mon Sep  3 2018 mkubecek@suse.cz
- Update to 4.19-rc2
- refresh configs
- commit a9462db
* Sat Sep  1 2018 afaerber@suse.de
- config: arm64: Increase SERIAL_8250_RUNTIME_UARTS to 32 (boo#1073193)
  (cherry picked from commit 0dbc49ba128ef0931ca04cf22ec5c638534f5b23)
- commit 6aae50e
* Sat Sep  1 2018 afaerber@suse.de
- config: Enable SERIAL_SC16IS7XX_SPI on arm and x86 (bsc#1105672, fate#326668)
  (cherry picked from commit cdc9eced6d892ff77abbeef5f0d5eb38c114602c)
- commit 22a4d36
* Sat Sep  1 2018 afaerber@suse.de
- config: Consistently increase SERIAL_8250_NR_UARTS to 32 (boo#1073193)
  (cherry picked from commit acb36abf212a3a7428d958798d678d82351f4658)
- commit 090b553
* Sat Sep  1 2018 afaerber@suse.de
- config: armv7hl: Update to 4.19-rc1
- commit d1f42dc
* Sat Sep  1 2018 afaerber@suse.de
- config: armv7hl: Update to 4.18.5 (bsc#1012628)
  (cherry picked from commit fa0ebc5508eedec2c9108cafdf854a8c53a28a83)
  [AF: Don't re-enable the configs yet]
- commit f2722e4
* Sat Sep  1 2018 afaerber@suse.de
- config: armv6hl: Update to 4.19-rc1
- commit 2f56919
* Fri Aug 31 2018 afaerber@suse.de
- config: armv6hl: Update to 4.18.5 (bsc#1012628)
  (cherry picked from commit e9071067714392290f6b0d525c77c8abfa8cf075)
  [AF: Don't re-enable configs yet]
- commit d01db43
* Fri Aug 31 2018 afaerber@suse.de
- config: arm64: Update to 4.19-rc1
- commit a6a88d1
* Wed Aug 29 2018 mkubecek@suse.cz
- powerpc/boot: Fix missing crc32poly.h when building with
  KERNEL_XZ.
- Delete
  patches.rpmify/Revert-lib-Use-existing-define-with-polynomial.patch.
- commit cba84f7
* Wed Aug 29 2018 mkubecek@suse.cz
- kernel-binary: check also bzImage on s390/s390x
  Starting with 4.19-rc1, uncompressed image is no longer built on s390x.
  If file "image" is not found in arch/s390/boot after the build, try bzImage
  instead.
  For now, install bzImage under the name image-* until we know grub2 and our
  grub2 scripts can handle correct name.
- commit 92b52c6
* Tue Aug 28 2018 jbeulich@suse.com
- Refresh patches.suse/supported-flag after upstream commit b2c5cdcfd4.
- Refresh
  patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch.
- commit 8b0e2e5
* Mon Aug 27 2018 mkubecek@suse.cz
- Revert "lib: Use existing define with polynomial".
- commit 1dc6366
* Mon Aug 27 2018 mkubecek@suse.cz
- Update to 4.19-rc1
- Eliminated 179 patches (167 stable, 12 other)
- ARM configs need updating
- Config changes:
  - Block:
  - BLK_CGROUP_IOLATENCY=y
  - Networking:
  - XFRM_INTERFACE=m
  - NETFILTER_NETLINK_OSF=m
  - NFT_TUNNEL=m
  - NFT_OSF=m
  - NFT_TPROXY=m
  - NET_SCH_ETF=m
  - NET_SCH_SKBPRIO=m
  - NET_SCH_CAKE=m
  - CAN_UCAN=m
  - BT_HCIUART_RTL=y
  - BT_MTKUART=m
  - BCMGENET=m
  - SYSTEMPORT=m
  - BNXT_HWMON=y
  - NET_VENDOR_CADENCE=y	(rename)
  - BE2NET_BE2=y
  - BE2NET_BE3=y
  - BE2NET_LANCER=y
  - BE2NET_SKYHAWK=y
  - MLX5_EN_ARFS=y
  - MLX5_EN_RXNFC=y
  - NET_VENDOR_NETERION=y
  - NET_VENDOR_PACKET_ENGINES=y
  - MT76x0U=m
  - MT76x2U=m
  - IEEE802154_HWSIM=m
  - File systems:
  - OVERLAY_FS_METACOPY=n
  - UBIFS_FS_XATTR=y
  - PSTORE_ZSTD_COMPRESS=y
  - CIFS_ALLOW_INSECURE_LEGACY=y
  - Security:
  - RANDOM_TRUST_CPU=n
  - IMA_APPRAISE_BUILD_POLICY=n
  - Hacking:
  - CONSOLE_LOGLEVEL_QUIET=4
  - KPROBE_EVENTS_ON_NOTRACE=n
  - TEST_BITFIELD=n
  - TEST_IDA=n
  - Library:
  - CRC64=m
  - Graphics:
  - VIDEO_CROS_EC_CEC=m
  - DRM_DP_CEC=y
  - DRM_VKMS=m
  - TINYDRM_ILI9341=n
  - FRAMEBUFFER_CONSOLE_DEFERRED_TAKEOVER=y
  - Sound:
  - SND_SOC_INTEL_GLK_RT5682_MAX98357A_MACH=m
  - SND_SOC_ES7241=n
  - SND_SOC_SIMPLE_AMPLIFIER=n
  - Input:
  - TOUCHSCREEN_ADC=m
  - TOUCHSCREEN_BU21029=m
  - HID_COUGAR=m
  - USB:
  - TYPEC_DP_ALTMODE=m
  - Multifunction:
  - MFD_MADERA=m
  - MFD_MADERA_I2C=m
  - MFD_MADERA_SPI=m
  - GPIO_MADERA=m
  - MFD_CS47L35=y
  - MFD_CS47L85=y
  - MFD_CS47L90=y
  - IIO:
  - BME680=m
  - AD5758=n
  - SI1133=n
  - ISL29501=m
  - FPGA:
  - FPGA_DFL=m
  - FPGA_DFL_FME=m
  - FPGA_DFL_FME_MGR=m
  - FPGA_DFL_FME_BRIDGE=m
  - FPGA_DFL_FME_REGION=m
  - FPGA_DFL_AFU=m
  - FPGA_DFL_PCI=m
  - XILINX_PR_DECOUPLER=m
  - Power management:
  - IDLE_INJECT=y
  - CHARGER_ADP5061=m
  - CHARGER_CROS_USBPD=m
  - SENSORS_MLXREG_FAN=m
  - SENSORS_NPCM7XX=m
  - Misc drivers:
  - GNSS=m
  - GNSS_SERIAL=m
  - GNSS_SIRF_SERIAL=m
  - GNSS_UBX_SERIAL=m
  - MTD_SPI_NAND=m
  - NVM_PBLK_DEBUG=n
  - PINCTRL_ICELAKE=m
  - COMMON_CLK_MAX9485=n
  - IOMMU_DEFAULT_PASSTHROUGH=n
  - XEN:
  - XEN_GRANT_DMA_ALLOC=y
  - XEN_GNTDEV_DMABUF=y
  - x86:
  - STAGING_GASKET_FRAMEWORK=m
  - STAGING_APEX_DRIVER=m
  - XIL_AXIS_FIFO=m
  - TOUCHSCREEN_DMI=y
  - I2C_MULTI_INSTANTIATE=m
  - CROS_EC_I2C=m
  - CROS_EC_SPI=m
  - MLXREG_IO=m
  - i386:
  - PCIE_XILINX=y
  - MFD_ROHM_BD718XX=n
  - DRM_PANEL_ILITEK_ILI9881C=n
  - MMC_SDHCI_OF_DWCMSHC=n
  - PAGE_TABLE_ISOLATION=y
  - PowerPC:
  - I2C_MUX_PINCTRL=m
  - I2C_DEMUX_PINCTRL=m
  - I2C_FSI=m
  - DEBUG_PINCTRL=n
  - PINCTRL_AMD=m
  - PINCTRL_MCP23S08=n
  - PINCTRL_SINGLE=n
  - PINCTRL_SX150X=n
  - LEDS_AAT1290=n
  - FSI_NEW_DEV_NODE=n
  - FSI_SBEFIFO=m
  - S/390:
  - KERNEL_GZIP=y
  - S2IO=m
  - VXGE=m
  - VXGE_DEBUG_TRACE_ALL=n
  - HAMACHI=m
  - YELLOWFIN=m
  - MDIO_BCM_UNIMAC=m
  - ISM=m
  - */debug:
  - NVM_PBLK_DEBUG=y
  - IOMMU_DEBUGFS=y
  - PREEMPTIRQ_DELAY_TEST=m
- commit a3b9cac
* Fri Aug 24 2018 jslaby@suse.cz
- Linux 4.18.5 (bnc#1012628).
- reiserfs: fix broken xattr handling (heap corruption, bad
  retval) (bnc#1012628).
- i2c: imx: Fix race condition in dma read (bnc#1012628).
- i2c: core: ACPI: Properly set status byte to 0 for multi-byte
  writes (bnc#1012628).
- PCI: pciehp: Fix unprotected list iteration in IRQ handler
  (bnc#1012628).
- PCI: pciehp: Fix use-after-free on unplug (bnc#1012628).
- PCI: Skip MPS logic for Virtual Functions (VFs) (bnc#1012628).
- PCI: aardvark: Size bridges before resources allocation
  (bnc#1012628).
- PCI: hotplug: Don't leak pci_slot on registration failure
  (bnc#1012628).
- PCI / ACPI / PM: Resume all bridges on suspend-to-RAM
  (bnc#1012628).
- PCI: Restore resized BAR state on resume (bnc#1012628).
- parisc: Remove ordered stores from syscall.S (bnc#1012628).
- parisc: Remove unnecessary barriers from spinlock.h
  (bnc#1012628).
- drm/amdgpu/pm: Fix potential Spectre v1 (bnc#1012628).
- drm/i915/kvmgt: Fix potential Spectre v1 (bnc#1012628).
- ext4: fix spectre gadget in ext4_mb_regular_allocator()
  (bnc#1012628).
- powerpc64s: Show ori31 availability in spectre_v1 sysfs file
  not v2 (bnc#1012628).
- x86/mm/init: Remove freed kernel image areas from alias mapping
  (bnc#1012628).
- x86/mm/init: Add helper for freeing kernel image pages
  (bnc#1012628).
- x86/mm/init: Pass unconverted symbol addresses to
  free_init_pages() (bnc#1012628).
- mm: Allow non-direct-map arguments to free_reserved_area()
  (bnc#1012628).
- pty: fix O_CLOEXEC for TIOCGPTPEER (bnc#1012628).
- EDAC: Add missing MEM_LRDDR4 entry in edac_mem_types[]
  (bnc#1012628).
- commit d918293
* Fri Aug 24 2018 vbabka@suse.cz
- x86/speculation/l1tf: Suggest what to do on systems with too
  much RAM (bsc#1105536).
- x86/speculation/l1tf: Fix off-by-one error when warning that
  system has too much RAM (bsc#1105536).
- x86/speculation/l1tf: Fix overflow in l1tf_pfn_limit() on 32bit
  (OBS failures reported on IRC).
- commit f3b24ad
* Fri Aug 24 2018 jslaby@suse.cz
- Update config files.
- Delete
  patches.suse/revert-mm-relax-deferred-struct-page-requirements.patch.
  We actually do not this non-upstream revert. We only need the config
  change. That is: leave DEFERRED_STRUCT_PAGE_INIT=n for i386 as it was
  before 4.16.
- commit 161b8ee
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.4 (bnc#1012628).
- l2tp: use sk_dst_check() to avoid race on sk->sk_dst_cache
  (bnc#1012628).
- net_sched: fix NULL pointer dereference when delete tcindex
  filter (bnc#1012628).
- net_sched: Fix missing res info when create new tc_index filter
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8168g (bnc#1012628).
- ALSA: hda - Sleep for 10ms after entering D3 on Conexant codecs
  (bnc#1012628).
- ALSA: hda - Turn CX8200 into D3 as well upon reboot
  (bnc#1012628).
- ALSA: vx222: Fix invalid endian conversions (bnc#1012628).
- ALSA: virmidi: Fix too long output trigger loop (bnc#1012628).
- ALSA: cs5535audio: Fix invalid endian conversion (bnc#1012628).
- ALSA: dice: fix wrong copy to rx parameters for Alesis iO26
  (bnc#1012628).
- ALSA: hda: Correct Asrock B85M-ITX power_save blacklist entry
  (bnc#1012628).
- ALSA: memalloc: Don't exceed over the requested size
  (bnc#1012628).
- ALSA: vxpocket: Fix invalid endian conversions (bnc#1012628).
- ALSA: seq: Fix poll() error return (bnc#1012628).
- media: gl861: fix probe of dvb_usb_gl861 (bnc#1012628).
- USB: serial: sierra: fix potential deadlock at close
  (bnc#1012628).
- USB: serial: pl2303: add a new device id for ATEN (bnc#1012628).
- USB: option: add support for DW5821e (bnc#1012628).
- ACPI / PM: save NVS memory for ASUS 1025C laptop (bnc#1012628).
- tty: serial: 8250: Revert NXP SC16C2552 workaround
  (bnc#1012628).
- serial: 8250_exar: Read INT0 from slave device, too
  (bnc#1012628).
- serial: 8250_dw: always set baud rate in dw8250_set_termios
  (bnc#1012628).
- serial: 8250_dw: Add ACPI support for uart on Broadcom SoC
  (bnc#1012628).
- uio: fix wrong return value from uio_mmap() (bnc#1012628).
- misc: sram: fix resource leaks in probe error path
  (bnc#1012628).
- Revert "uio: use request_threaded_irq instead" (bnc#1012628).
- Bluetooth: avoid killing an already killed socket (bnc#1012628).
- isdn: Disable IIOCDBGVAR (bnc#1012628).
- net: sock_diag: Fix spectre v1 gadget in __sock_diag_cmd()
  (bnc#1012628).
- r8169: don't use MSI-X on RTL8106e (bnc#1012628).
- ip_vti: fix a null pointer deferrence when create vti fallback
  tunnel (bnc#1012628).
- net: ethernet: mvneta: Fix napi structure mixup on armada 3700
  (bnc#1012628).
- net: mvneta: fix mvneta_config_rss on armada 3700 (bnc#1012628).
- cls_matchall: fix tcf_unbind_filter missing (bnc#1012628).
- commit a7b92e4
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.3 (bnc#1012628).
- x86/speculation/l1tf: Exempt zeroed PTEs from inversion
  (bnc#1012628).
- commit a14f6a3
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.2 (bnc#1012628).
- x86/mm: Add TLB purge to free pmd/pte page interfaces
  (bnc#1012628).
- ioremap: Update pgtable free interfaces with addr (bnc#1012628).
- Bluetooth: hidp: buffer overflow in hidp_process_report
  (bnc#1012628).
- crypto: skcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: skcipher - fix aligning block size in skcipher_copy_iv()
  (bnc#1012628).
- crypto: ablkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: blkcipher - fix crash flushing dcache in error path
  (bnc#1012628).
- crypto: vmac - separate tfm and request context (bnc#1012628).
- crypto: vmac - require a block cipher with 128-bit block size
  (bnc#1012628).
- crypto: x86/sha256-mb - fix digest copy in
  sha256_mb_mgr_get_comp_job_avx2() (bnc#1012628).
- crypto: ccp - Fix command completion detection race
  (bnc#1012628).
- crypto: ccp - Check for NULL PSP pointer at module unload
  (bnc#1012628).
- crypto: ccree - fix iv handling (bnc#1012628).
- crypto: ccree - fix finup (bnc#1012628).
- kbuild: verify that $DEPMOD is installed (bnc#1012628).
- x86/mm: Disable ioremap free page handling on x86-PAE
  (bnc#1012628).
- xen/pv: Call get_cpu_address_sizes to set x86_virt/phys_bits
  (bnc#1012628).
- x86/mm/pti: Clear Global bit more aggressively (bnc#1012628).
- x86/platform/UV: Mark memblock related init code and data
  correctly (bnc#1012628).
- x86/hyper-v: Check for VP_INVAL in hyperv_flush_tlb_others()
  (bnc#1012628).
- x86: i8259: Add missing include file (bnc#1012628).
- x86/l1tf: Fix build error seen if CONFIG_KVM_INTEL is disabled
  (bnc#1012628).
- commit 51ef786
* Wed Aug 22 2018 jslaby@suse.cz
- Linux 4.18.1 (bnc#1012628).
- x86/init: fix build with CONFIG_SWAP=n (bnc#1012628).
- cpu/hotplug: Non-SMP machines do not make use of booted_once
  (bnc#1012628).
- x86/smp: fix non-SMP broken build due to redefinition of
  apic_id_is_primary_thread (bnc#1012628).
- commit 7e40689
* Tue Aug 21 2018 msuchanek@suse.de
- ACPICA: Clear status of all events when entering sleep states
  (boo#1104529).
- commit 5d7a9a7
* Tue Aug 21 2018 msuchanek@suse.de
- Delete patches.suse/Revert-ACPICA-Events-Stop-unconditionally-clearing-A.patch.
- commit fb1dc2b
* Fri Aug 17 2018 mkubecek@suse.cz
- rpm/constraints.in: raise memory constraints
  Build statistics show that most architectures already need more than 2 GB.
  Require 4 GB except s390x where the memory usage is much lower and we might
  have trouble finding any compliant worker.
- commit 494fb32
* Thu Aug 16 2018 msuchanek@suse.de
- Revert "ACPICA: Events: Stop unconditionally clearing ACPI
  IRQs during suspend/resume" (boo#1104529, bko#196249).
- commit 5dac824
* Wed Aug 15 2018 mkubecek@suse.cz
- Update config files.
- commit 07db4aa
* Wed Aug 15 2018 jslaby@suse.cz
- Linux 4.18.1-rc1
  It contains the L1TF fixes, so push the rc1 for now.
- x86/paravirt: Fix spectre-v2 mitigations for paravirt guests
  (bnc#1012628).
- x86/speculation: Protect against userspace-userspace spectreRSB
  (bnc#1012628).
- kprobes/x86: Fix %%p uses in error messages (bnc#1012628).
- x86/irqflags: Provide a declaration for native_save_fl
  (bnc#1012628).
- x86/speculation/l1tf: Increase 32bit PAE __PHYSICAL_PAGE_SHIFT
  (bnc#1012628).
- x86/speculation/l1tf: Change order of offset/type in swap entry
  (bnc#1012628).
- x86/speculation/l1tf: Protect swap entries against L1TF
  (bnc#1012628).
- x86/speculation/l1tf: Protect PROT_NONE PTEs against speculation
  (bnc#1012628).
- x86/speculation/l1tf: Make sure the first page is always
  reserved (bnc#1012628).
- x86/speculation/l1tf: Add sysfs reporting for l1tf
  (bnc#1012628).
- x86/speculation/l1tf: Disallow non privileged high MMIO
  PROT_NONE mappings (bnc#1012628).
- x86/speculation/l1tf: Limit swap file size to MAX_PA/2
  (bnc#1012628).
- x86/bugs: Move the l1tf function and define pr_fmt properly
  (bnc#1012628).
- sched/smt: Update sched_smt_present at runtime (bnc#1012628).
- x86/smp: Provide topology_is_primary_thread() (bnc#1012628).
- x86/topology: Provide topology_smt_supported() (bnc#1012628).
- cpu/hotplug: Make bringup/teardown of smp threads symmetric
  (bnc#1012628).
- cpu/hotplug: Split do_cpu_down() (bnc#1012628).
- cpu/hotplug: Provide knobs to control SMT (bnc#1012628).
- x86/cpu: Remove the pointless CPU printout (bnc#1012628).
- x86/cpu/AMD: Remove the pointless detect_ht() call
  (bnc#1012628).
- x86/cpu/common: Provide detect_ht_early() (bnc#1012628).
- x86/cpu/topology: Provide detect_extended_topology_early()
  (bnc#1012628).
- x86/cpu/intel: Evaluate smp_num_siblings early (bnc#1012628).
- x86/CPU/AMD: Do not check CPUID max ext level before parsing
  SMP info (bnc#1012628).
- x86/cpu/AMD: Evaluate smp_num_siblings early (bnc#1012628).
- x86/apic: Ignore secondary threads if nosmt=force (bnc#1012628).
- x86/speculation/l1tf: Extend 64bit swap file size limit
  (bnc#1012628).
- x86/cpufeatures: Add detection of L1D cache flush support
  (bnc#1012628).
- x86/CPU/AMD: Move TOPOEXT reenablement before reading
  smp_num_siblings (bnc#1012628).
- x86/speculation/l1tf: Protect PAE swap entries against L1TF
  (bnc#1012628).
- x86/speculation/l1tf: Fix up pte->pfn conversion for PAE
  (bnc#1012628).
- Revert "x86/apic: Ignore secondary threads if nosmt=force"
  (bnc#1012628).
- cpu/hotplug: Boot HT siblings at least once (bnc#1012628).
- x86/KVM: Warn user if KVM is loaded SMT and L1TF CPU bug being
  present (bnc#1012628).
- x86/KVM/VMX: Add module argument for L1TF mitigation
  (bnc#1012628).
- x86/KVM/VMX: Add L1D flush algorithm (bnc#1012628).
- x86/KVM/VMX: Add L1D MSR based flush (bnc#1012628).
- x86/KVM/VMX: Add L1D flush logic (bnc#1012628).
- x86/KVM/VMX: Split the VMX MSR LOAD structures to have an
  host/guest numbers (bnc#1012628).
- x86/KVM/VMX: Add find_msr() helper function (bnc#1012628).
- x86/KVM/VMX: Separate the VMX AUTOLOAD guest/host number
  accounting (bnc#1012628).
- x86/KVM/VMX: Extend add_atomic_switch_msr() to allow VMENTER
  only MSRs (bnc#1012628).
- x86/KVM/VMX: Use MSR save list for IA32_FLUSH_CMD if required
  (bnc#1012628).
- cpu/hotplug: Online siblings when SMT control is turned on
  (bnc#1012628).
- x86/litf: Introduce vmx status variable (bnc#1012628).
- x86/kvm: Drop L1TF MSR list approach (bnc#1012628).
- x86/l1tf: Handle EPT disabled state proper (bnc#1012628).
- x86/kvm: Move l1tf setup function (bnc#1012628).
- x86/kvm: Add static key for flush always (bnc#1012628).
- x86/kvm: Serialize L1D flush parameter setter (bnc#1012628).
- x86/kvm: Allow runtime control of L1D flush (bnc#1012628).
- cpu/hotplug: Expose SMT control init function (bnc#1012628).
- cpu/hotplug: Set CPU_SMT_NOT_SUPPORTED early (bnc#1012628).
- x86/bugs, kvm: Introduce boot-time control of L1TF mitigations
  (bnc#1012628).
- Documentation: Add section about CPU vulnerabilities
  (bnc#1012628).
- x86/speculation/l1tf: Unbreak !__HAVE_ARCH_PFN_MODIFY_ALLOWED
  architectures (bnc#1012628).
- x86/KVM/VMX: Initialize the vmx_l1d_flush_pages' content
  (bnc#1012628).
- Documentation/l1tf: Fix typos (bnc#1012628).
- cpu/hotplug: detect SMT disabled by BIOS (bnc#1012628).
- x86/KVM/VMX: Don't set l1tf_flush_l1d to true from
  vmx_l1d_flush() (bnc#1012628).
- x86/KVM/VMX: Replace 'vmx_l1d_flush_always' with
  'vmx_l1d_flush_cond' (bnc#1012628).
- x86/KVM/VMX: Move the l1tf_flush_l1d test to vmx_l1d_flush()
  (bnc#1012628).
- x86/irq: Demote irq_cpustat_t::__softirq_pending to u16
  (bnc#1012628).
- x86/KVM/VMX: Introduce per-host-cpu analogue of l1tf_flush_l1d
  (bnc#1012628).
- x86: Don't include linux/irq.h from asm/hardirq.h (bnc#1012628).
- x86/irq: Let interrupt handlers set kvm_cpu_l1tf_flush_l1d
  (bnc#1012628).
- x86/KVM/VMX: Don't set l1tf_flush_l1d from
  vmx_handle_external_intr() (bnc#1012628).
- Documentation/l1tf: Remove Yonah processors from not vulnerable
  list (bnc#1012628).
- x86/speculation: Simplify sysfs report of VMX L1TF vulnerability
  (bnc#1012628).
- x86/speculation: Use ARCH_CAPABILITIES to skip L1D flush on
  vmentry (bnc#1012628).
- KVM: VMX: Tell the nested hypervisor to skip L1D flush on
  vmentry (bnc#1012628).
- cpu/hotplug: Fix SMT supported evaluation (bnc#1012628).
- x86/speculation/l1tf: Invert all not present mappings
  (bnc#1012628).
- x86/speculation/l1tf: Make pmd/pud_mknotpresent() invert
  (bnc#1012628).
- x86/mm/pat: Make set_memory_np() L1TF safe (bnc#1012628).
- x86/mm/kmmio: Make the tracer robust against L1TF (bnc#1012628).
- tools headers: Synchronise x86 cpufeatures.h for L1TF additions
  (bnc#1012628).
- x86/microcode: Allow late microcode loading with SMT disabled
  (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Update config files.
- commit a23e15c
* Tue Aug 14 2018 mkubecek@suse.cz
- Update upstream reference:
  patches.suse/hv-netvsc-Fix-NULL-dereference-at-single-queue-mode-.patch.
- commit 0425184
* Tue Aug 14 2018 tiwai@suse.de
- hv/netvsc: Fix NULL dereference at single queue mode fallback
  (bsc#1104708).
- commit a0cb9f6
* Mon Aug 13 2018 jslaby@suse.cz
- Refresh
  patches.suse/platform-x86-ideapad-laptop-Apply-no_hw_rfkill-to-Y2.
  Update upstream info.
- commit 799dc2a
* Mon Aug 13 2018 mkubecek@suse.cz
- Update to 4.18-final.
- Refresh configs
- commit 06ab9b3
* Tue Aug  7 2018 mkubecek@suse.cz
- config: refresh s390x/vanilla
  Add new option CONFIG_SYSTEM_DATA_VERIFICATION=n
- commit 3ee2023
* Mon Aug  6 2018 mkubecek@suse.cz
- Update to 4.18-rc8
- commit 9928e10
* Mon Jul 30 2018 mkubecek@suse.cz
- Update to 4.18-rc7
- commit 68c9705
* Tue Jul 24 2018 dmueller@suse.com
- Reenable v8.1/v8.2 aarch64 extensions
  These were enabled already in SLE15 and we want to default to the
  upstream defaults, which enable these features.
  Config changes:
  - aarch64:
    HW_AFDBM=y
    PAN=y
    LSE_ATOMICS=y
    VHE=y
    UAO=y
    SVE=y
- commit 7fdc027
* Mon Jul 23 2018 msuchanek@suse.de
- Update config files.
- commit 8efadc7
* Mon Jul 23 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: Add more stuff to Recommends
  ... and move bc to Recommends as well.  All these packages are needed for
  building a kernel manually from scratch with kernel-source files.
- commit 6fcec9a
* Mon Jul 23 2018 mkubecek@suse.cz
- Update to 4.18-rc6
- Config changes:
  - NF_TABLES_SET=m (replaces NFT_SET_{RBTREE,HASH,BITMAP})
- commit 31ad2a8
* Sun Jul 22 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: require bc for kernel-source
  This is needed for building include/generated/timeconst.h from
  kernel/time/timeconst.bc.
- commit d725e3b
* Tue Jul 17 2018 tiwai@suse.de
- Update config files: enable CONFIG_I2C_PXA for arm64 (bsc#1101465)
- commit d02f285
* Mon Jul 16 2018 rgoldwyn@suse.com
- apparmor: patch to provide compatibility with v2.x net rules (bsc#1100944).
- Delete patches.suse/0001-AppArmor-basic-networking-rules.patch.
- Delete
  patches.suse/0002-apparmor-update-apparmor-basic-networking-rules-for-.patch.
- Delete
  patches.suse/0003-apparmor-Fix-quieting-of-audit-messages-for-network-.patch.
- Delete patches.suse/apparmor-check-all-net-profiles.patch.
- commit 1947b35
* Mon Jul 16 2018 msuchanek@suse.de
- Pass x86 as architecture on x86_64 and i386 (bsc#1093118).
- commit 5f24fb0
* Mon Jul 16 2018 msuchanek@suse.de
- Revert "kconfig: only write '# CONFIG_FOO is not set' for
  visible symbols" (bsc#1093118).
- commit 2b9e26a
* Mon Jul 16 2018 mkubecek@suse.cz
- Update to 4.18-rc5
- commit b3f752f
* Mon Jul  9 2018 tiwai@suse.de
- alarmtimer: Prevent overflow for relative nanosleep
  (CVE-2018-13053 bsc#1099924).
- commit e98ba10
* Mon Jul  9 2018 mkubecek@suse.cz
- Update to 4.18-rc4
- Eliminated 1 patch
- Config changes:
  - s390x:
  - RSEQ=y
  - DEBUG_REQ=n
- commit 36e98dd
* Wed Jul  4 2018 dsterba@suse.com
- Update patches.suse/btrfs-8447-serialize-subvolume-mounts-with-potentially-mi.patch (bsc#951844 bsc#1024015 bsc#1099745).
  Refresh and update for Tumbleweed. No better patch version yet.
- commit dd5896f
* Mon Jul  2 2018 mkubecek@suse.cz
- Update to 4.18-rc3
- Eliminated 6 patches
- Config changes:
  - Input:
  - INPUT_SC27XX_VIBRA=m (aarch64 only)
- commit d44a642
* Fri Jun 29 2018 jslaby@suse.cz
- Refresh
  patches.suse/input-psmouse-fix-button-reporting-for-basic-protoco.patch.
  Update upstream status.
- commit 1e6a85a
* Wed Jun 27 2018 mkubecek@suse.cz
- bpf: enforce correct alignment for instructions (bsc#1099078).
- commit 55e3263
* Tue Jun 26 2018 tiwai@suse.de
- platform/x86: ideapad-laptop: Apply no_hw_rfkill to Y20-15IKBM,
  too (bsc#1098626).
- commit 0d1073f
* Mon Jun 25 2018 jslaby@suse.cz
- Input: psmouse - fix button reporting for basic protocols
  (bnc#1098392).
- commit faf690b
* Mon Jun 25 2018 msuchanek@suse.de
- rpm/kernel-source.changes.old: Add pre-SLE15 history (bsc#1098995).
- commit 631659e
* Mon Jun 25 2018 msuchanek@suse.de
- Refresh patches.suse/s390-fix-random-crashes-illegal-operation-0001-ilc-1.patch.
- commit ff0a7a4
* Sun Jun 24 2018 mkubecek@suse.cz
- Update to 4.18-rc2
- Eliminated 1 patch
- Config changes:
  - aarch64: reenable DWMAC_SOCFPGA (=m)
- commit cc9e91e
* Sun Jun 24 2018 afaerber@suse.de
- config: arm64: Update to 4.18-rc1
- commit b301d60
* Sat Jun 23 2018 mkubecek@suse.cz
- proc: fix missing final NUL in get_mm_cmdline() rewrite
  (https://www.mail-archive.com/linux-kernel@vger.kernel.org/msg1715032.html).
- commit f348790
* Sat Jun 23 2018 mkubecek@suse.cz
- Documentation: e1000: Fix docs build error.
- Documentation: e100: Fix docs build error.
- Documentation: e1000: Use correct heading adornment.
- Documentation: e100: Use correct heading adornment.
- commit 95284f7
* Sat Jun 23 2018 jslaby@suse.cz
- x86/stacktrace: Do not unwind after user regs (bnc#1058115).
- x86/stacktrace: Remove STACKTRACE_DUMP_ONCE (bnc#1058115).
- x86/stacktrace: Clarify the reliable success paths
  (bnc#1058115).
- x86/stacktrace: Do not fail for ORC with regs on stack
  (bnc#1058115).
- x86/unwind/orc: Detect the end of the stack (bnc#1058115).
- x86/stacktrace: Enable HAVE_RELIABLE_STACKTRACE for the ORC
  unwinder (bnc#1058115).
- Delete
  patches.suse/0001-x86-stacktrace-do-now-unwind-after-user-regs.patch.
- Delete
  patches.suse/0002-x86-stacktrace-make-clear-the-success-paths.patch.
- Delete
  patches.suse/0003-x86-stacktrace-remove-STACKTRACE_DUMP_ONCE-from-__sa.patch.
- Delete
  patches.suse/0004-x86-stacktrace-do-not-fail-for-ORC-with-regs-on-stac.patch.
- Delete
  patches.suse/0005-x86-stacktrace-orc-mark-it-as-reliable.patch.
  Replace the ORC patches by the upstream patches. Finally...
- commit c19d75b
* Thu Jun 21 2018 msuchanek@suse.de
- s390: Correct register corruption in critical section cleanup
  (boo#1095717).
- commit 62d3537
* Mon Jun 18 2018 msuchanek@suse.de
- macros.kernel-source: define linux_arch for KMPs (boo#1098050).
  CONFIG_64BIT is no longer defined so KMP spec files need to include
  %%{?linux_make_arch} in any make call to build modules or descent into
  the kernel directory for any reason.
- commit 5dc40af
* Mon Jun 18 2018 mkubecek@suse.cz
- config: update ppc64le configs
- commit fa9e020
* Mon Jun 18 2018 mkubecek@suse.cz
- config: enable NETDEVSIM (as module)
- commit e218eff
* Mon Jun 18 2018 mkubecek@suse.cz
- Update to 4.18-rc1.
- Eliminated 66 patches (62 stable, 4 other).
- ARM configs need updating.
- Config changes:
  - General:
  - RSEQ=y
  - i386:
  - BPF_JIT=y
  - BPF_JIT_ALWAYS_ON=y
  - powerpc:
  - LD_DEAD_CODE_DATA_ELIMINATION=n (experimental)
  - s390:
  - FW_LOADER_USER_HELPER=y
  - PCI:
  - PCI_HOST_GENERIC=y
  - Network:
  - TLS_DEVICE=y
  - XDP_SOCKETS=y
  - NFT_CONNLIMIT=m
  - NFT_SOCKET=m
  - IP_VS_MH=m
  - IP_VS_MH_TAB_INDEX=12 (default)
  - NF_TPROXY_IPV4=m
  - NF_TPROXY_IPV6=m
  - BPFILTER=y
  - BPFILTER_UMH=m
  - FAILOVER=m
  - MLX5_EN_TLS=y
  - NET_VENDOR_MICROSEMI=y
  - MSCC_OCELOT_SWITCH=m
  - MSCC_OCELOT_SWITCH_OCELOT=m
  - NFP_APP_ABM_NIC=y
  - MDIO_MSCC_MIIM=m
  - ASIX_PHY=m
  - DP83TC811_PHY=m
  - MICROCHIP_T1_PHY=m
  - NET_FAILOVER=m
  - Block:
  - DM_WRITECACHE=m
  - Input:
  - MOUSE_PS2_ELANTECH_SMBUS=y
  - TOUCHSCREEN_CHIPONE_ICN8505=m
  - HID_STEAM=m
  - Misc:
  - SPI_MEM=y
  - GPIOLIB_FASTPATH_LIMIT=512 (default)
  - VIDEO_CADENCE=y
  - LCD_OTM3225A=n
  - CHROMEOS_TBMC=m
  - FPGA_MGR_MACHXO2_SPI=m
  - Graphics:
  - DRM_I2C_NXP_TDA9950=m
  - DRM_I915_DEBUG_GUC=n
  - DRM_CDNS_DSI=n
  - DRM_THINE_THC63LVD1024=n
  - DRM_XEN=y
  - DRM_XEN_FRONTEND=m
  - Sound:
  - SND_SOC_SSM2305=n
  - SND_SOC_TSCS454=n
  - SND_SOC_WM8782=n
  - SND_SOC_MT6351=n
  - SND_XEN_FRONTEND=m
  - LED:
  - LEDS_CR0014114=m
  - LEDS_LM3601X=m
  - USB:
  - TYPEC_RT1711H=m
  - IIO:
  - AD5686_SPI=n
  - AD5696_I2C=n
  - TI_DAC5571=n
  - TSL2772=n
  - IIO_RESCALE=n
  - Filesystems:
  - PROC_VMCORE_DEVICE_DUMP=y
  - EVM_ADD_XATTRS=y
  - Testing:
  - TEST_OVERFLOW=n
  - Crypto:
  - CRYPTO_AEGIS128=m
  - CRYPTO_AEGIS128L=m
  - CRYPTO_AEGIS256=m
  - CRYPTO_AEGIS128_AESNI_SSE2=m
  - CRYPTO_AEGIS128L_AESNI_SSE2=m
  - CRYPTO_AEGIS256_AESNI_SSE2=m
  - CRYPTO_MORUS640=m
  - CRYPTO_MORUS640_SSE2=m
  - CRYPTO_MORUS1280=m
  - CRYPTO_MORUS1280_SSE2=m
  - CRYPTO_MORUS1280_AVX2=m
  - CRYPTO_ZSTD=m
- commit 549a5bb
* Mon Jun 18 2018 mkubecek@suse.cz
- rpm: ignore CONFIG_GCC_VERSION when checking for oldconfig changes
  Since 4.18-rc1, "make oldconfig" writes gcc version and capabilities into
  generated .config. Thus whenever we build the package or run checks with
  different gcc version than used to update config/*/*, check for "outdated
  configs" fails.
  As a quick band-aid, omit the lines with CONFIG_GCC_VERSION from both
  configs before comparing them. This way, the check won't fail unless run
  with newer gcc which would add new capabilities. More robust solution will
  require a wider discussion.
- commit 546ef32
* Sat Jun 16 2018 jslaby@suse.cz
- Revert "mm: relax deferred struct page requirements"
  (bnc#1092466).
- Update config files.
- commit 802b05f
* Sat Jun 16 2018 jslaby@suse.cz
- Linux 4.17.2 (bnc#1012628).
- crypto: omap-sham - fix memleak (bnc#1012628).
- crypto: vmx - Remove overly verbose printk from AES XTS init
  (bnc#1012628).
- crypto: vmx - Remove overly verbose printk from AES init
  routines (bnc#1012628).
- crypto: cavium - Limit result reading attempts (bnc#1012628).
- crypto: cavium - Fix fallout from CONFIG_VMAP_STACK
  (bnc#1012628).
- crypto: caam - fix size of RSA prime factor q (bnc#1012628).
- crypto: caam/qi - fix IV DMA mapping and updating (bnc#1012628).
- crypto: caam - fix IV DMA mapping and updating (bnc#1012628).
- crypto: caam - fix DMA mapping dir for generated IV
  (bnc#1012628).
- crypto: caam - strip input zeros from RSA input buffer
  (bnc#1012628).
- Input: elan_i2c - add ELAN0612 (Lenovo v330 14IKB) ACPI ID
  (bnc#1012628).
- Input: goodix - add new ACPI id for GPD Win 2 touch screen
  (bnc#1012628).
- crypto: ccree - correct host regs offset (bnc#1012628).
- tty: pl011: Avoid spuriously stuck-off interrupts (bnc#1012628).
- arm64: defconfig: Enable CONFIG_PINCTRL_MT7622 by default
  (bnc#1012628).
- doc: fix sysfs ABI documentation (bnc#1012628).
- vmw_balloon: fixing double free when batching mode is off
  (bnc#1012628).
- serial: 8250: omap: Fix idling of clocks for unused uarts
  (bnc#1012628).
- serial: samsung: fix maxburst parameter for DMA transactions
  (bnc#1012628).
- tty/serial: atmel: use port->name as name in request_irq()
  (bnc#1012628).
- serial: sh-sci: Stop using printk format %%pCr (bnc#1012628).
- usb: gadget: udc: renesas_usb3: disable the controller's irqs
  for reconnecting (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should fail if devm_phy_get()
  returns error (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should call devm_phy_get()
  before add udc (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should call pm_runtime_enable()
  before add udc (bnc#1012628).
- usb: gadget: udc: renesas_usb3: should remove debugfs
  (bnc#1012628).
- usb: gadget: udc: renesas_usb3: fix double phy_put()
  (bnc#1012628).
- usb: gadget: function: printer: avoid wrong list handling in
  printer_write() (bnc#1012628).
- usb: typec: wcove: Remove dependency on HW FSM (bnc#1012628).
- usb: core: message: remove extra endianness conversion in
  usb_set_isoch_delay (bnc#1012628).
- phy: qcom-qusb2: Fix crash if nvmem cell not specified
  (bnc#1012628).
- Input: xpad - add GPD Win 2 Controller USB IDs (bnc#1012628).
- usb-storage: Add compatibility quirk flags for G-Technologies
  G-Drive (bnc#1012628).
- usb-storage: Add support for FL_ALWAYS_SYNC flag in the UAS
  driver (bnc#1012628).
- usbip: vhci_sysfs: fix potential Spectre v1 (bnc#1012628).
- NFC: pn533: don't send USB data off of the stack (bnc#1012628).
- staging: android: ion: Switch to pr_warn_once in
  ion_buffer_destroy (bnc#1012628).
- kvm: x86: use correct privilege level for
  sgdt/sidt/fxsave/fxrstor access (bnc#1012628).
- KVM: x86: pass kvm_vcpu to kvm_read_guest_virt and
  kvm_write_guest_virt_system (bnc#1012628).
- kvm: nVMX: Enforce cpl=0 for VMX instructions (bnc#1012628).
- kvm: fix typo in flag name (bnc#1012628).
- KVM: x86: introduce linear_{read,write}_system (bnc#1012628).
- KVM: X86: Fix reserved bits check for MOV to CR3 (bnc#1012628).
- blkdev_report_zones_ioctl(): Use vmalloc() to allocate large
  buffers (bnc#1012628).
- crypto: chelsio - request to HW should wrap (bnc#1012628).
- commit 202985c
* Thu Jun 14 2018 mkubecek@suse.cz
- socket: close race condition between sock_close() and
  sockfs_setattr() (CVE-2018-12232 bsc#1097593).
- commit 94bf968
* Thu Jun 14 2018 jslaby@suse.cz
- config.conf: disable syzkaller
  I doubt anybody else (other than me) uses the flavor, so save a lot of
  build resources by this. Leaving syzkaller configs and stuff in place
  so people still can build it if they want.
  The build is currently broken, so this "fixes" it too:
  ERROR: "__sanitizer_cov_trace_cmpd" [drivers/gpu/drm/amd/amdgpu/amdgpu.ko] undefined!
  ERROR: "__sanitizer_cov_trace_cmpf" [drivers/gpu/drm/amd/amdgpu/amdgpu.ko] undefined!
- commit bdee95f
* Tue Jun 12 2018 jslaby@suse.cz
- Linux 4.17.1 (bnc#1012628).
- netfilter: nf_flow_table: attach dst to skbs (bnc#1012628).
- bnx2x: use the right constant (bnc#1012628).
- ip6mr: only set ip6mr_table from setsockopt when ip6mr_new_table
  succeeds (bnc#1012628).
- ipv6: omit traffic class when calculating flow hash (bnc#1012628
  bsc#1095042).
- l2tp: fix refcount leakage on PPPoL2TP sockets (bnc#1012628).
- netdev-FAQ: clarify DaveM's position for stable backports
  (bnc#1012628).
- net: metrics: add proper netlink validation (bnc#1012628).
- net/packet: refine check for priv area size (bnc#1012628).
- rtnetlink: validate attributes in do_setlink() (bnc#1012628).
- sctp: not allow transport timeout value less than HZ/5 for
  hb_timer (bnc#1012628).
- team: use netdev_features_t instead of u32 (bnc#1012628).
- vrf: check the original netdevice for generating redirect
  (bnc#1012628).
- net: dsa: b53: Fix for brcm tag issue in Cygnus SoC
  (bnc#1012628).
- ipmr: fix error path when ipmr_new_table fails (bnc#1012628).
- PCI: hv: Do not wait forever on a device that has disappeared
  (bnc#1012628).
- Delete
  patches.suse/ipv6-omit-traffic-class-when-calculating-flow-hash.patch.
- commit 17c8abe
* Fri Jun  8 2018 tiwai@suse.de
- mtd: spi-nor: intel-spi: Fix atomic sequence handling
  (bsc#1073836).
- commit c31c53d
* Fri Jun  8 2018 mkubecek@suse.cz
- ipv6: omit traffic class when calculating flow hash
  (bsc#1095042).
- commit 1307c29
* Fri Jun  8 2018 tiwai@suse.de
- Delete patches.suse/iwlwifi-expose-default-fallback-ucode-api.
  The workaround is no longer needed as the upstream driver code catches
  up the actual firmware version
- commit d6e069d
* Fri Jun  8 2018 tiwai@suse.de
- Update patch tag of the upstreamed btusb fix
- commit f531f64
* Mon Jun  4 2018 mkubecek@suse.cz
- config: enable preemption in i386/debug
- commit b181e22
* Mon Jun  4 2018 mkubecek@suse.cz
- Update to 4.17-final
- commit fb45ad0
* Mon May 28 2018 mkubecek@suse.cz
- Update to 4.17-rc7
- Eliminated 1 patch
- Config changes:
  - reenable SSB_DRIVER_PCICORE and dependencies after revert of
    commit 882164a4a928
- commit c78299c
* Thu May 24 2018 tiwai@suse.de
- Bluetooth: Apply QCA Rome patches for some ATH3012 models
  (bsc#1082504).
- commit e2f793c
* Wed May 23 2018 msuchanek@suse.de
- mkspec: only build docs for default variant kernel.
- commit 045f5ac
* Mon May 21 2018 mkubecek@suse.cz
- Makefile: disable PIE before testing asm goto (bsc#1092456).
- commit 67bdb0d
* Mon May 21 2018 mkubecek@suse.cz
- Update to 4.17-rc6
- commit 6912f6b
* Thu May 17 2018 msuchanek@suse.de
- kernel-{binary,docs}.spec sort dependencies.
- commit d2ab971
* Thu May 17 2018 mgalbraith@suse.de
- Fix config/x86_64/debug, turn PREEMPT_NONE off, and PREEMPT_DEBUG on.
- commit 3ec7274
* Wed May 16 2018 msuchanek@suse.de
- macros.kernel-source: Fix building non-x86 KMPs
- commit 8631d05
* Tue May 15 2018 jeffm@suse.com
- reiserfs: package in separate KMP (FATE#323394).
- commit d14f152
* Mon May 14 2018 msuchanek@suse.de
- macros.kernel-source: ignore errors when using make to print kernel release
  There is no way to handle the errors anyway and including the error into
  package version does not give good results.
- commit 282e9a6
* Mon May 14 2018 mkubecek@suse.cz
- Update to 4.17-rc5
- commit 80e3a99
* Fri May 11 2018 msuchanek@suse.de
- Revert "kernel-binary: do not package extract-cert when not signing modules"
  This reverts commit 10a8bc496a553b8069d490a8ae7508bdb19f58d9.
- commit 1f7acca
* Mon May  7 2018 mkubecek@suse.cz
- Update to 4.17-rc4
- Eliminated 2 patches
- Update to 4.17-rc3
- Eliminated 2 patches
- commit a993a00
* Wed May  2 2018 msuchanek@suse.de
- kernel-binary: also default klp_symbols to 0 here.
- commit e35f14a
* Wed May  2 2018 msuchanek@suse.de
- klp_symbols: make --klp-symbols argument semantic sane
  It selects build of klp symbols and defaults to off
- commit 0e53042
* Wed May  2 2018 jslaby@suse.cz
- tools: power/acpi, revert to LD = gcc (build fix).
- Delete
  patches.suse/revert-tools-fix-cross-compile-var-clobbering.patch.
  Replace by the upstream commit.
- commit c7b3cf9
* Mon Apr 30 2018 mkubecek@suse.cz
- Update to 4.17-rc3
- Eliminated 1 patch
- Config changes:
  - x86_64 and i386
  - SND_SST_ATOM_HIFI2_PLATFORM_ACPI=m
  - armv7hl
  - CONFIG_NFT_REDIR_IPV4=m (sync with other configs)
  - CONFIG_NFT_REDIR_IPV6=m (sync with other configs)
- commit 088acbb
* Sun Apr 29 2018 afaerber@suse.de
- config: armv7hl: Update to 4.17-rc2
- commit e76ffdc
* Sun Apr 29 2018 afaerber@suse.de
- config: armv6hl: Update to 4.17-rc2
- commit 7ac1254
* Sun Apr 29 2018 afaerber@suse.de
- config: arm64: Update to 4.17-rc2
- commit 8535e20
* Fri Apr 27 2018 msuchanek@suse.de
- kernel-binary: only install modules.fips on modular kernels.
- commit 2cb2bec
* Tue Apr 24 2018 msuchanek@suse.de
- split-modules: use MAKE_ARGS
- commit d8fe174
* Tue Apr 24 2018 mcgrof@suse.com
- xfs: set format back to extents if xfs_bmap_extents_to_btree
  (bsc#1090717, CVE-2018-10323).
- commit 41ecb40
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass MAKE_ARGS to install script as well.
- commit ce62ae7
* Tue Apr 24 2018 mkubecek@suse.cz
- Update config files.
- commit becf16d
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass ARCH= to kernel build
  Recent kernel does not save CONFIG_64BIT so it has to be specified by
  arch.
- commit fb21b73
* Tue Apr 24 2018 mkubecek@suse.cz
- config: fix i386 configs
  Since mainline commit f467c5640c29 ("kconfig: only write '# CONFIG_FOO is
  not set' for visible symbols"), make silentoldconfig (or make syncconfig as
  it is called now) doesn't add CONFIG_64BIT line into i386 configs if called
  with ARCH=i386.
  During the build, it's called without ARCH=i386 so that it requests this
  option to be entered manually and the build fails. Long term solution would
  probably be passing ARCH=%%{cpu_arch} to all make commands; for now, just
  add CONFIG_64BIT line to i386/pae to fix the build as is.
- commit d9a33ad
* Tue Apr 24 2018 mkubecek@suse.cz
- Documentation: typec.rst: Use literal-block element with
  ascii art.
- commit 1aebada
* Mon Apr 23 2018 jeffm@suse.com
- README.BRANCH: Added Michal Kubecek as co-maintainer.
- commit 53ecad7
* Mon Apr 23 2018 mkubecek@suse.cz
- Update to 4.17-rc2
- Eliminated 2 patches
- Config changes:
  - s390x:
  - KEXEC_FILE=y
- commit 8aad964
* Fri Apr 20 2018 mkubecek@suse.cz
- Update to 4.17-rc1.
- Eliminated 55 patches (51 stable 4.16.x)
- ARM configs need updating.
- Config changes:
  - x86:
  - ACPI_TAD=m
  - s390:
  - EXPOLINE_FULL=y
  - VT=y
  - CONSOLE_TRANSLATIONS=y
  - VT_CONSOLE=y
  - VT_HW_CONSOLE_BINDING=n
  - DUMMY_CONSOLE_COLUMNS=80
  - DUMMY_CONSOLE_ROWS=25
  - SPEAKUP=n
  - Network:
  - NF_TABLES_INET=y
  - NF_TABLES_NETDEV=y
  - NF_TABLES_ARP=y
  - NF_TABLES_BRIDGE=y
  - NET_EMATCH_IPT=m
  - ICE=m
  - RSI_COEX=y
  - IEEE802154_MCR20A=m
  - INFINIBAND_EXP_LEGACY_VERBS_NEW_UAPI=n
  - Filesystems:
  - OVERLAY_FS_XINO_AUTO=n
  - PSTORE_DEFLATE_COMPRESS=m
  - PSTORE_LZ4HC_COMPRESS=m
  - PSTORE_842_COMPRESS=n
  - PSTORE_DEFLATE_COMPRESS_DEFAULT=deflate
  - Crypto:
  - CRYPTO_CFB=m
  - CRYPTO_SM4=m
  - CRYPTO_SPECK=m
  - CRYPTO_DEV_CHELSIO_TLS=m
  - Input:
  - JOYSTICK_PXRC=m
  - HID_ELAN=m
  - HID_GOOGLE_HAMMER=m
  - Sound:
  - SND_SOC_INTEL_CHT_BSW_NAU8824_MACH=m
  - SND_SOC_INTEL_KBL_DA7219_MAX98357A_MACH=m
  - SND_SOC_AK4458=n
  - SND_SOC_AK5558=n
  - SND_SOC_BD28623=n
  - SND_SOC_MAX9867=n
  - SND_SOC_PCM1789_I2C=n
  - SND_SOC_TDA7419=m
  - SND_SOC_MAX9759=n
  - USB:
  - TYPEC_MUX_PI3USB30532=m
  - USB_ROLES_INTEL_XHCI=m
  - GPIO:
  - GPIO_104_DIO_48E=m
  - GPIO_104_IDIO_16=m
  - GPIO_104_IDI_48=m
  - GPIO_GPIO_MM=m
  - GPIO_WINBOND=m
  - GPIO_WS16C48=m
  - Media:
  - CEC_PIN_ERROR_INJ=n
  - CXD2880_SPI_DRV=m
  - MTK_MMC=n
  - IIO:
  - 104_QUAD_8=m
  - CIO_DAC=n
  - AD5272=m
  - MCP4018=m
  - MLX90632=m
  - Other:
  - THERMAL_STATISTICS=y
  - EBC_C384_WDT=m
  - LEDS_MLXREG=m
  - COMMON_CLK_SI544=n
  - STX104=n
  - LV0104CS=n
  - Remote controlers:
  - IR_IMON_DECODER=m
  - IR_IMON_RAW=m
  - INTEL_TH_ACPI=m
  - Debugging:
  - DEBUG_RWSEMS=n
- commit 4e61ecf
* Fri Apr 20 2018 mkubecek@suse.cz
- config: enable TCP_MD5SIG (bsc#1090162)
- commit 1cfc938
* Fri Apr 20 2018 mkubecek@suse.cz
- x86/power/64: Fix page-table setup for temporary text mapping
  (https://patchwork.kernel.org/patch/10342491/).
- x86/ldt: Fix support_pte_mask filtering in map_ldt_struct()
  (https://patchwork.kernel.org/patch/10342491/).
- commit 3c56473
* Fri Apr 20 2018 msuchanek@suse.de
- HID: redragon: Fix modifier keys for Redragon Asura Keyboard
  (https://build.opensuse.org/request/show/597583).
  Update config files.
- commit e9bd8ea
* Thu Apr 19 2018 jslaby@suse.cz
- Linux 4.16.3 (bnc#1012628).
- cdc_ether: flag the Cinterion AHS8 modem by gemalto as WWAN
  (bnc#1012628).
- rds: MP-RDS may use an invalid c_path (bnc#1012628).
- slip: Check if rstate is initialized before uncompressing
  (bnc#1012628).
- vhost: fix vhost_vq_access_ok() log check (bnc#1012628).
- l2tp: fix races in tunnel creation (bnc#1012628).
- l2tp: fix race in duplicate tunnel detection (bnc#1012628).
- ip_gre: clear feature flags when incompatible o_flags are set
  (bnc#1012628).
- vhost: Fix vhost_copy_to_user() (bnc#1012628).
- lan78xx: Correctly indicate invalid OTP (bnc#1012628).
- sparc64: Properly range check DAX completion index
  (bnc#1012628).
- media: v4l2-compat-ioctl32: don't oops on overlay (bnc#1012628).
- media: v4l: vsp1: Fix header display list status check in
  continuous mode (bnc#1012628).
- ipmi: Fix some error cleanup issues (bnc#1012628).
- parisc: Fix out of array access in match_pci_device()
  (bnc#1012628).
- parisc: Fix HPMC handler by increasing size to multiple of 16
  bytes (bnc#1012628).
- iwlwifi: add a bunch of new 9000 PCI IDs (bnc#1012628).
- Drivers: hv: vmbus: do not mark HV_PCIE as perf_device
  (bnc#1012628).
- PCI: hv: Serialize the present and eject work items
  (bnc#1012628).
- PCI: hv: Fix 2 hang issues in hv_compose_msi_msg()
  (bnc#1012628).
- KVM: PPC: Book3S HV: trace_tlbie must not be called in realmode
  (bnc#1012628).
- perf intel-pt: Fix overlap detection to identify consecutive
  buffers correctly (bnc#1012628).
- perf intel-pt: Fix sync_switch (bnc#1012628).
- perf intel-pt: Fix error recovery from missing TIP packet
  (bnc#1012628).
- perf intel-pt: Fix timestamp following overflow (bnc#1012628).
- perf/core: Fix use-after-free in uprobe_perf_close()
  (bnc#1012628).
- radeon: hide pointless #warning when compile testing
  (bnc#1012628).
- x86/mce/AMD: Pass the bank number to smca_get_bank_type()
  (bnc#1012628).
- x86/mce/AMD, EDAC/mce_amd: Enumerate Reserved SMCA bank type
  (bnc#1012628).
- x86/mce/AMD: Get address from already initialized block
  (bnc#1012628).
- ath9k: Protect queue draining by rcu_read_lock() (bnc#1012628).
- x86/uapi: Fix asm/bootparam.h userspace compilation errors
  (bnc#1012628).
- x86/apic: Fix signedness bug in APIC ID validity checks
  (bnc#1012628).
- sunrpc: remove incorrect HMAC request initialization
  (bnc#1012628).
- f2fs: fix heap mode to reset it back (bnc#1012628).
- block: Change a rcu_read_{lock,unlock}_sched() pair into
  rcu_read_{lock,unlock}() (bnc#1012628).
- nvme: Skip checking heads without namespaces (bnc#1012628).
- lib: fix stall in __bitmap_parselist() (bnc#1012628).
- zboot: fix stack protector in compressed boot phase
  (bnc#1012628).
- blk-mq: Directly schedule q->timeout_work when aborting a
  request (bnc#1012628).
- blk-mq: order getting budget and driver tag (bnc#1012628).
- blk-mq: make sure that correct hctx->next_cpu is set
  (bnc#1012628).
- blk-mq: don't keep offline CPUs mapped to hctx 0 (bnc#1012628).
- ovl: Set d->last properly during lookup (bnc#1012628).
- ovl: fix lookup with middle layer opaque dir and absolute path
  redirects (bnc#1012628).
- ovl: set i_ino to the value of st_ino for NFS export
  (bnc#1012628).
- ovl: set lower layer st_dev only if setting lower st_ino
  (bnc#1012628).
- xen: xenbus_dev_frontend: Fix XS_TRANSACTION_END handling
  (bnc#1012628).
- hugetlbfs: fix bug in pgoff overflow checking (bnc#1012628).
- nfsd: fix incorrect umasks (bnc#1012628).
- scsi: scsi_dh: Don't look for NULL devices handlers by name
  (bnc#1012628).
- scsi: qla2xxx: Fix small memory leak in qla2x00_probe_one on
  probe failure (bnc#1012628).
- Revert "scsi: core: return BLK_STS_OK for DID_OK in
  __scsi_error_from_host_byte()" (bnc#1012628).
- apparmor: fix logging of the existence test for signals
  (bnc#1012628).
- apparmor: fix display of .ns_name for containers (bnc#1012628).
- apparmor: fix resource audit messages when auditing peer
  (bnc#1012628).
- block/loop: fix deadlock after loop_set_status (bnc#1012628).
- nfit: fix region registration vs block-data-window ranges
  (bnc#1012628).
- s390/qdio: don't retry EQBS after CCQ 96 (bnc#1012628).
- s390/qdio: don't merge ERROR output buffers (bnc#1012628).
- s390/ipl: ensure loadparm valid flag is set (bnc#1012628).
- s390/compat: fix setup_frame32 (bnc#1012628).
- get_user_pages_fast(): return -EFAULT on access_ok failure
  (bnc#1012628).
- mm/gup_benchmark: handle gup failures (bnc#1012628).
- getname_kernel() needs to make sure that ->name != ->iname in
  long case (bnc#1012628).
- Bluetooth: Fix connection if directed advertising and privacy
  is used (bnc#1012628).
- Bluetooth: hci_bcm: Treat Interrupt ACPI resources as always
  being active-low (bnc#1012628).
- rtl8187: Fix NULL pointer dereference in priv->conf_mutex
  (bnc#1012628).
- Refresh patches.suse/0001-AppArmor-basic-networking-rules.patch.
- commit 771261a
* Thu Apr 19 2018 msuchanek@suse.de
- objtool, perf: Fix GCC 8 -Wrestrict error (bsc#1084620).
- commit 0c6114f
* Wed Apr 18 2018 msuchanek@suse.de
- supported.conf: update from openSUSE-15.0
- commit 4ef3f17
* Mon Apr 16 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1089764)
  Increase NR_CPUS to 384
- commit 6f06d9e
* Thu Apr 12 2018 jslaby@suse.cz
- Linux 4.16.2 (bnc#1012628).
- nfp: use full 40 bits of the NSP buffer address (bnc#1012628).
- net_sched: fix a missing idr_remove() in u32_delete_key()
  (bnc#1012628).
- vti6: better validate user provided tunnel names (bnc#1012628).
- ip6_tunnel: better validate user provided tunnel names
  (bnc#1012628).
- ip6_gre: better validate user provided tunnel names
  (bnc#1012628).
- ipv6: sit: better validate user provided tunnel names
  (bnc#1012628).
- ip_tunnel: better validate user provided tunnel names
  (bnc#1012628).
- net: fool proof dev_valid_name() (bnc#1012628).
- vlan: also check phy_driver ts_info for vlan's real device
  (bnc#1012628).
- sky2: Increase D3 delay to sky2 stops working after suspend
  (bnc#1012628).
- sctp: sctp_sockaddr_af must check minimal addr length for
  AF_INET6 (bnc#1012628).
- sctp: do not leak kernel memory to user space (bnc#1012628).
- pptp: remove a buggy dst release in pptp_connect()
  (bnc#1012628).
- net/sched: fix NULL dereference in the error path of
  tcf_bpf_init() (bnc#1012628).
- net/ipv6: Increment OUTxxx counters after netfilter hook
  (bnc#1012628).
- net: dsa: Discard frames from unused ports (bnc#1012628).
- arp: fix arp_filter on l3slave devices (bnc#1012628).
- sparc64: Oracle DAX driver depends on SPARC64 (bnc#1012628).
- commit 8ea896b
* Wed Apr 11 2018 jslaby@suse.cz
- Update config files.
  s390x/vanilla fails to build without this.
- commit e8d83e8
* Tue Apr 10 2018 msuchanek@suse.de
- rpm/package-descriptions: fix typo in kernel-azure
- Add azure kernel description.
- commit af0f13e
* Mon Apr  9 2018 tiwai@suse.de
- media: v4l2-core: fix size of devnode_nums[] bitarray
  (bsc#1088640).
- commit 6fcb3b5
* Mon Apr  9 2018 jslaby@suse.cz
- Linux 4.16.1 (bnc#1012628).
- signal: Correct the offset of si_pkey and si_lower in struct
  siginfo on m68k (bnc#1012628).
- Fix slab name "biovec-(1<<(21-12))" (bnc#1012628).
- vt: change SGR 21 to follow the standards (bnc#1012628).
- Input: i8042 - enable MUX on Sony VAIO VGN-CS series to fix
  touchpad (bnc#1012628).
- Input: i8042 - add Lenovo ThinkPad L460 to i8042 reset list
  (bnc#1012628).
- Input: ALPS - fix TrackStick detection on Thinkpad L570 and
  Latitude 7370 (bnc#1012628).
- Revert "base: arch_topology: fix section mismatch build
  warnings" (bnc#1012628).
- staging: comedi: ni_mio_common: ack ai fifo error interrupts
  (bnc#1012628).
- siox: fix possible buffer overflow in device_add_store
  (bnc#1012628).
- Btrfs: fix unexpected cow in run_delalloc_nocow (bnc#1012628).
- Bluetooth: hci_bcm: Add 6 new ACPI HIDs (bnc#1012628).
- crypto: x86/cast5-avx - fix ECB encryption when long sg follows
  short one (bnc#1012628).
- crypto: arm,arm64 - Fix random regeneration of S_shipped
  (bnc#1012628).
- crypto: ccp - return an actual key size from RSA max_size
  callback (bnc#1012628).
- crypto: caam - Fix null dereference at error path (bnc#1012628).
- crypto: ahash - Fix early termination in hash walk
  (bnc#1012628).
- crypto: talitos - fix IPsec cipher in length (bnc#1012628).
- crypto: testmgr - Fix incorrect values in PKCS#1 test vector
  (bnc#1012628).
- crypto: inside-secure - fix clock management (bnc#1012628).
- crypto: talitos - don't persistently map req_ctx->hw_context
  and req_ctx->buf (bnc#1012628).
- crypto: ccp - Fill the result buffer only on digest, finup,
  and final ops (bnc#1012628).
- crypto: lrw - Free rctx->ext with kzfree (bnc#1012628).
- parport_pc: Add support for WCH CH382L PCI-E single parallel
  port card (bnc#1012628).
- media: usbtv: prevent double free in error case (bnc#1012628).
- /dev/mem: Avoid overwriting "err" in read_mem() (bnc#1012628).
- mei: remove dev_err message on an unsupported ioctl
  (bnc#1012628).
- serial: 8250: Add Nuvoton NPCM UART (bnc#1012628).
- USB: serial: cp210x: add ELDAT Easywave RX09 id (bnc#1012628).
- USB: serial: ftdi_sio: add support for Harman
  FirmwareHubEmulator (bnc#1012628).
- USB: serial: ftdi_sio: add RT Systems VX-8 cable (bnc#1012628).
- bitmap: fix memset optimization on big-endian systems
  (bnc#1012628).
- commit 4bf9d1e
* Fri Apr  6 2018 agraf@suse.de
- armv6hl: Disable uacces with memcpy (boo#1080435)
- commit 5eeeb1b
* Thu Apr  5 2018 rgoldwyn@suse.com
- apparmor: Check all profiles attached to the label (bsc#1085996).
- commit b249c9e
* Wed Apr  4 2018 jslaby@suse.cz
- Revert "tools: fix cross-compile var clobbering" (build fix).
- commit 590ff92
* Mon Apr  2 2018 jeffm@suse.com
- Update to 4.16-final.
- commit 1b10c5b
* Mon Mar 26 2018 tiwai@suse.de
- brcmsmac: allocate ucode with GFP_KERNEL (bsc#1085174).
- commit 2971d91
* Mon Mar 26 2018 jeffm@suse.com
- Update to 4.16-rc7.
- Eliminated 1 patch.
- commit 7a36f2f
* Fri Mar 23 2018 agraf@suse.de
- armv7hl: Disable uacces with memcpy (boo#1080435)
- commit b8a701a
* Mon Mar 19 2018 msuchanek@suse.de
- kernel-*.spec: remove remaining occurences of %%release from dependencies
  There is a mix of %%release and %%source_rel in manually added
  dependencies and the %%release dependencies tend to fail due to rebuild
  sync issues. So get rid of them.
- commit b4ec514
* Mon Mar 19 2018 jeffm@suse.com
- Update to 4.16-rc6.
- commit a98eb00
* Mon Mar 19 2018 jeffm@suse.com
- Refresh patches.suse/kernel-add-release-status-to-kernel-build.patch.
- commit cf5ff13
* Thu Mar 15 2018 tiwai@suse.de
- Bluebooth: btusb: Fix quirk for Atheros 1525/QCA6174
  (bsc#1082504).
- commit 8413b00
* Wed Mar 14 2018 jeffm@suse.com
- config: sync i386/default
  Some options had been removed completely.
- commit 95f48d7
* Wed Mar 14 2018 jeffm@suse.com
- rpm/kernel-source.spec.in: Add check-module-license to Sources
  The package builds in the build service but the script won't make it
  into the SRPM if it's not in the Sources list.
- commit 031ed9e
* Tue Mar 13 2018 msuchanek@suse.de
- mkspec: fix perl warning
- commit f15670f
* Mon Mar 12 2018 jeffm@suse.com
- Update to 4.16-rc5.
- Eliminated 1 patch.
- commit 0dfffad
* Sun Mar 11 2018 afaerber@suse.de
- config: armv7hl: Update to 4.16-rc4
- commit ad451a4
* Sun Mar 11 2018 afaerber@suse.de
- config: armv6hl: Update to 4.16-rc4
- commit 6c846e1
* Sat Mar 10 2018 tiwai@suse.de
- Refresh to upstream patch (bsc#1083694)
  patches.suse/Documentation-sphinx-Fix-Directive-import-error.patch
- commit 2d62679
* Sat Mar 10 2018 jeffm@suse.com
- kernel: add release status to kernel build (bsc#FATE#325281).
- commit c51605f
* Sat Mar 10 2018 jeffm@suse.com
- rpm: use %%_sourcedir prefix for release-projects
- rpm: set SUSE_KERNEL_RELEASED based on project name
  Set SUSE_KERNEL_RELEASED in the config only if the project name matches
  a list of projects that are part of official release channels.  This
  list of projects is maintained per-branch.
- commit a391a5b
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is an unreleased internal configuration intended for kernel
  developers to use in simple virtual machines.  It contains only the
  device drivers necessary to use a KVM virtual machine *without* device
  passthrough enabled.  Common local and network file systems are enabled.
  All device mapper targets are enabled.  Only the network and graphics
  drivers for devices that qemu emulates are enabled.  Many subsystems
  enabled in the default kernel are entirely disabled.  This kernel is
  meant to be small and to build very quickly.  There will be no kABI
  stability and its configuration may be changed arbitrarily.
- commit 088f1da
* Fri Mar  9 2018 jeffm@suse.com
- config: convert kvmsmall to fragment config
- commit 7a5941a
* Fri Mar  9 2018 jeffm@suse.com
- config: disabled some more options for kvmsmall
  Disable CAN, BT, rare partition types, unused mouse protocols, UIO,
  STM, and others.
- commit 4707d44
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is intended for kernel developers to use in simple virtual
  machines.  It contains only the device drivers necessary to use a
  KVM virtual machine *without* device passthrough enabled.  Common
  local and network file systems are enabled.  All device mapper targets
  are enabled.  Only the network and graphics drivers for devices that qemu
  emulates are enabled.  Many subsystems enabled in the default kernel
  are entirely disabled.  This kernel is meant to be small and to build
  very quickly.
- commit 3c99d1f
* Thu Mar  8 2018 msuchanek@suse.de
- mkspec: do not build dtbs for architectures with no kernel.
- commit 8394abf
* Thu Mar  8 2018 jeffm@suse.com
- kconfig: move SUSE options from init/Kconfig to init/Kconfig.suse
- commit b7f69ff
* Wed Mar  7 2018 afaerber@suse.de
- config: arm64: Update to 4.16-rc4
- commit 0bb9ed4
* Wed Mar  7 2018 tiwai@suse.de
- rpm/kernel-binary.spec.in: Check module licenses (bsc#1083215,bsc#1083527)
- commit e41de0c
* Tue Mar  6 2018 jslaby@suse.cz
- Update config files.
  Enable module signing (bnc#1082905):
  * CONFIG_MODULE_SIG=y
  * # CONFIG_MODULE_SIG_FORCE is not set
  * # CONFIG_MODULE_SIG_ALL is not set
  * # CONFIG_MODULE_SIG_SHA1 is not set
  * # CONFIG_MODULE_SIG_SHA224 is not set
  * CONFIG_MODULE_SIG_SHA256=y
  * # CONFIG_MODULE_SIG_SHA384 is not set
  * # CONFIG_MODULE_SIG_SHA512 is not set
  * CONFIG_MODULE_SIG_HASH="sha256"
  * CONFIG_MODULE_SIG_KEY="certs/signing_key.pem"
  * CONFIG_SECONDARY_TRUSTED_KEYRING=y
  * CONFIG_SYSTEM_BLACKLIST_KEYRING=y
  * CONFIG_SYSTEM_BLACKLIST_HASH_LIST=""
  This commit synchronizes these options with SLE15.
  We do not add patches for loading keys from the shim layer (as in
  SLE15) for the time being. They were rejected multiple times in
  upstream and we do not want to forward-port them infinitely. This only
  means that loading KMPs with none/invalid signatures generates this:
  <module_name>: loading out-of-tree module taints kernel.
  <module_name>: module verification failed: signature and/or required key missing - tainting kernel
  But the modules load fine after that as we have MODULE_SIG_FORCE set
  to 'n'.
  Tested in qemu+OVMF and bare metal and everything looks fine.
- commit 2539ea5
* Mon Mar  5 2018 msuchanek@suse.de
- rpm: provide %%name%%-srchash = <kernel-source commit hash> (FATE#325312).
  - Also use for kernel-obs-build dependency.
- commit b6fccdf
* Mon Mar  5 2018 jeffm@suse.com
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 1ba5305
* Mon Mar  5 2018 jeffm@suse.com
- Update to 4.16-rc4.
- IBRS patches need review.
- commit 061459a
* Sun Mar  4 2018 msuchanek@suse.de
- arch-symbols: use bash as interpreter since the script uses bashism.
- commit 4cdfb23
* Fri Mar  2 2018 msuchanek@suse.de
- kernel-binary: do not BuildIgnore m4.
  It is actually needed for regenerating zconf when it is not up-to-date
  due to merge.
- commit 967b28b
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add build requirement for flex
  In addition to bison, we also need flex for "make oldconfig".
- commit 83d831c
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: remove m4 from BuildIgnore list
  As bison depends on m4, we cannot set !BuildIgnore for it any more.
- commit d7695e1
* Fri Mar  2 2018 tiwai@suse.de
- Documentation/sphinx: Fix Directive import error (bsc#1083694).
- commit 7f94eb1
* Wed Feb 28 2018 msuchanek@suse.de
- bs-upload-kernel: do not set %%opensuse_bs
  Since SLE15 it is not set in the distribution project so do not set it
  for kernel projects either.
- commit d696aa0
* Wed Feb 28 2018 jslaby@suse.cz
- Linux 4.15.7 (bnc#1012628).
- microblaze: fix endian handling (bnc#1012628).
- drm/i915/breadcrumbs: Ignore unsubmitted signalers
  (bnc#1012628).
- arm64: __show_regs: Only resolve kernel symbols when running
  at EL1 (bnc#1012628).
- drm/amdgpu: add new device to use atpx quirk (bnc#1012628).
- drm/amdgpu: Avoid leaking PM domain on driver unbind (v2)
  (bnc#1012628).
- drm/amdgpu: add atpx quirk handling (v2) (bnc#1012628).
- drm/amdgpu: only check mmBIF_IOV_FUNC_IDENTIFIER on tonga/fiji
  (bnc#1012628).
- drm/amdgpu: Add dpm quirk for Jet PRO (v2) (bnc#1012628).
- drm/amdgpu: fix VA hole handling on Vega10 v3 (bnc#1012628).
- drm/amdgpu: disable MMHUB power gating on raven (bnc#1012628).
- drm: Handle unexpected holes in color-eviction (bnc#1012628).
- drm/atomic: Fix memleak on ERESTARTSYS during non-blocking
  commits (bnc#1012628).
- drm/cirrus: Load lut in crtc_commit (bnc#1012628).
- usb: renesas_usbhs: missed the "running" flag in usb_dmac with
  rx path (bnc#1012628).
- usb: gadget: f_fs: Use config_ep_by_speed() (bnc#1012628).
- usb: gadget: f_fs: Process all descriptors during bind
  (bnc#1012628).
- Revert "usb: musb: host: don't start next rx urb if current
  one failed" (bnc#1012628).
- usb: ldusb: add PIDs for new CASSY devices supported by this
  driver (bnc#1012628).
- usb: phy: mxs: Fix NULL pointer dereference on i.MX23/28
  (bnc#1012628).
- usb: dwc3: ep0: Reset TRB counter for ep0 IN (bnc#1012628).
- usb: dwc3: gadget: Set maxpacket size for ep0 IN (bnc#1012628).
- usb: host: ehci: use correct device pointer for dma ops
  (bnc#1012628).
- drm/edid: Add 6 bpc quirk for CPT panel in Asus UX303LA
  (bnc#1012628).
- Add delay-init quirk for Corsair K70 RGB keyboards
  (bnc#1012628).
- arm64: cpufeature: Fix CTR_EL0 field definitions (bnc#1012628).
- arm64: Disable unhandled signal log messages by default
  (bnc#1012628).
- arm64: Remove unimplemented syscall log message (bnc#1012628).
- usb: ohci: Proper handling of ed_rm_list to handle race
  condition between usb_kill_urb() and finish_unlinks()
  (bnc#1012628).
- ohci-hcd: Fix race condition caused by ohci_urb_enqueue()
  and io_watchdog_func() (bnc#1012628).
- net: thunderbolt: Run disconnect flow asynchronously when
  logout is received (bnc#1012628).
- net: thunderbolt: Tear down connection properly on suspend
  (bnc#1012628).
- PCI/cxgb4: Extend T3 PCI quirk to T4+ devices (bnc#1012628).
- irqchip/mips-gic: Avoid spuriously handling masked interrupts
  (bnc#1012628).
- irqchip/gic-v3: Use wmb() instead of smb_wmb() in
  gic_raise_softirq() (bnc#1012628).
- uapi/if_ether.h: move __UAPI_DEF_ETHHDR libc define
  (bnc#1012628).
- mm: don't defer struct page initialization for Xen pv guests
  (bnc#1012628).
- mm, swap, frontswap: fix THP swap if frontswap enabled
  (bnc#1012628).
- x86/oprofile: Fix bogus GCC-8 warning in nmi_setup()
  (bnc#1012628).
- x86/apic/vector: Handle vector release on CPU unplug correctly
  (bnc#1012628).
- Kbuild: always define endianess in kconfig.h (bnc#1012628).
- iio: adis_lib: Initialize trigger before requesting interrupt
  (bnc#1012628).
- iio: buffer: check if a buffer has been set up when poll is
  called (bnc#1012628).
- iio: srf08: fix link error "devm_iio_triggered_buffer_setup"
  undefined (bnc#1012628).
- iio: adc: stm32: fix stm32h7_adc_enable error handling
  (bnc#1012628).
- RDMA/uverbs: Sanitize user entered port numbers prior to access
  it (bnc#1012628).
- RDMA/uverbs: Fix circular locking dependency (bnc#1012628).
- RDMA/uverbs: Fix bad unlock balance in ib_uverbs_close_xrcd
  (bnc#1012628).
- RDMA/uverbs: Protect from command mask overflow (bnc#1012628).
- RDMA/uverbs: Protect from races between lookup and destroy of
  uobjects (bnc#1012628).
- genirq/matrix: Handle CPU offlining proper (bnc#1012628).
- extcon: int3496: process id-pin first so that we start with
  the right status (bnc#1012628).
- PKCS#7: fix certificate blacklisting (bnc#1012628).
- PKCS#7: fix certificate chain verification (bnc#1012628).
- X.509: fix NULL dereference when restricting key with
  unsupported_sig (bnc#1012628).
- X.509: fix BUG_ON() when hash algorithm is unsupported
  (bnc#1012628).
- i2c: bcm2835: Set up the rising/falling edge delays
  (bnc#1012628).
- i2c: designware: must wait for enable (bnc#1012628).
- cfg80211: fix cfg80211_beacon_dup (bnc#1012628).
- MIPS: Drop spurious __unused in struct compat_flock
  (bnc#1012628).
- scsi: ibmvfc: fix misdefined reserved field in
  ibmvfc_fcp_rsp_info (bnc#1012628).
- xtensa: fix high memory/reserved memory collision (bnc#1012628).
- MIPS: boot: Define __ASSEMBLY__ for its.S build (bnc#1012628).
- kconfig.h: Include compiler types to avoid missed struct
  attributes (bnc#1012628).
- arm64: mm: don't write garbage into TTBR1_EL1 register
  (bnc#1012628).
- netfilter: drop outermost socket lock in getsockopt()
  (bnc#1012628).
- commit 48cfb35
* Wed Feb 28 2018 jeffm@suse.com
- kernel: add product-identifying information to kernel build (FATE#325281).
- commit 450b8db
* Tue Feb 27 2018 msuchanek@suse.de
- Revert "rpm/kernel-binary.spec.in: Also require m4 for build."
  This reverts commit 0d7b4b3f948c2efb67b7d1b95b5e1dcae225991c.
- commit f5686d2
* Tue Feb 27 2018 tiwai@suse.de
- kernel-binary: do not package extract-cert when not signing modules
  (boo#1080250).
- commit 10a8bc4
* Tue Feb 27 2018 jeffm@suse.com
- Update to 4.16-rc3.
- Eliminated 2 patches.
- commit a1d0a5c
* Tue Feb 27 2018 jeffm@suse.com
- Update to 4.16-rc2.
- Eliminated 1 patch.
- Config changes:
  - i386:
  - X86_MINIMUM_CPU_FAMILY (set automatically by oldconfig).
- commit 70f217f
* Tue Feb 27 2018 jeffm@suse.com
- Update to 4.16-rc1.
- Eliminated 624 patches (mostly 4.15.x).
- ARM configs need updating.
- Config changes:
  - General:
  - CC_STACKPROTECTOR_REGULAR=y
  - x86:
  - ACPI_SPCR_TABLE=y
  - ACER_WIRELESS=m
  - GPD_POCKET_FAN=m
  - INTEL_CHTDC_TI_PWRBTN=m
  - MELLANOX_PLATFORM=y
  - MLXREG_HOTPLUG=m
  - JAILHOUSE_GUEST=y
  - i386:
  - MLX_PLATFORM=m
  - DEFERRED_STRUCT_PAGE_INIT=y
  - powerpc:
  - PPC_MEM_KEYS=y
  - OCXL=m
  - PPC_IRQ_SOFT_MASK_DEBUG=n
  - s390:
  - KERNEL_NOBP=y
  - EXPOLINE=y
  - EXPOLINE_FULL=y
  - PCI:
  - PCIE_CADENCE_HOST=y
  - PCIE_CADENCE_EP=y
  - Network:
  - NF_FLOW_TABLE=m
  - NF_FLOW_TABLE_IPV4=m
  - NF_FLOW_TABLE_IPV6=m
  - IP6_NF_MATCH_SRH=m
  - BT_HCIBTUSB_AUTOSUSPEND=y
  - NET_VENDOR_CORTINA=y
  - GEMINI_ETHERNET=m
  - NET_VENDOR_SOCIONEXT=y
  - NETDEVSIM=n
  - NFT_FLOW_OFFLOAD=m
  - NF_FLOW_TABLE_INET=m
  - Block:
  - BLK_DEV_NULL_BLK_FAULT_INJECTION=n
  - SATA_MOBILE_LPM_POLICY=0
  - DM_UNSTRIPED=m
  - MMC_SDHCI_F_SDH30=n
  - Misc:
  - MISC_RTSX_PCI=m
  - MISC_RTSX_USB=m
  - HW_RANDOM_TPM=y (from m)
  - I2C_GPIO_FAULT_INJECTOR=n
  - PINCTRL_AXP209=m
  - GPIO_WINBOND=m
  - GPIO_PCIE_IDIO_24=m
  - SENSORS_W83773G=m
  - MFD_CROS_EC_CHARDEV=n
  - RAVE_SP_CORE=n
  CAVIUM_PTP=m
  - Graphics:
  - DRM_PANEL_ILITEK_IL9322=n
  - TINYDRM_ILI9225=n
  - TINYDRM_ST7735R=n
  - Sound:
  - SND_SOC_INTEL_SST_TOPLEVEL=y
  - SND_SST_ATOM_HIFI2_PLATFORM_PCI=m
  - SND_SOC_INTEL_BYT_MAX98090_MACH=m
  - SND_SOC_INTEL_BYT_RT5640_MACH=m
  - SND_SOC_MAX98373=n
  - SND_SOC_PCM186X_I2C=n
  - SND_SOC_PCM186X_SPI=n
  - SND_SOC_TAS6424=n
  - SND_SOC_TLV320AIC32X4_I2C=n
  - SND_SOC_TLV320AIC32X4_SPI=n
  - SND_SOC_TSCS42XX=n
  - SOUNDWIRE=y
  - SOUNDWIRE_INTEL=m
  - Input:
  - HID_JABRA=n
  - USB:
  - USB_XHCI_DBGCAP=n
  - LEDS:
  - LEDS_LM3692X=n
  - LEDS_TRIGGER_NETDEV=m
  - LEDS_LP8860=n
  - RTC:
  - RTC_DRV_CROS_EC=n
  - VIRT:
  - VBOXGUEST=m
  - VIRTIO_MENU=y
  - KVM_AMD_SEV=y
  - Filesystems:
  - CIFS_SMB_DIRECT=n (still experimental)
  - Other:
  - UNISYSSPAR=n
  - XILINX_VCU=n
  - IIO_BUFFER_HW_CONSUMER=n
  - SD_ADC_MODULATOR=n
  - OF_FPGA_REGION=n
  - SIOX=n
  - SLIMBUS=n
  - BPF_KPROBE_OVERRIDE=n
  - FPGA_BRIDGE=n
  - Sensors:
  - ST_UVIS25=n
  - ZOPT2201=n
  - Media:
  - MT76x2E=m
  - LIRC=y
  - DVB_MMAP=n (still experimental)
  - DVB_ULE_DEBUG=n
  - Testing:
  - FAIL_FUNCTION=n
  - RUNTIME_TESTING_MENU=y
  - FIND_BIT_BENCHMARK=n
  - Crypto:
  - CHELSIO_IPSEC_INLINE=n
  - CRYPTO_DEV_SP_PSP=y
- commit 955d7ce
* Sun Feb 25 2018 jslaby@suse.cz
- bpf: cpumap: use GFP_KERNEL instead of GFP_ATOMIC in
  __cpu_map_entry_alloc() (git-fixes).
- commit b050949
* Sun Feb 25 2018 jslaby@suse.cz
- ptr_ring: prevent integer overflow when calculating size
  (git-fixes).
- commit f95a8d4
* Sun Feb 25 2018 jslaby@suse.cz
- Linux 4.15.6 (bnc#1012628).
- vmalloc: fix __GFP_HIGHMEM usage for vmalloc_32 on 32b systems
  (bnc#1012628).
- mei: me: add cannon point device ids for 4th device
  (bnc#1012628).
- mei: me: add cannon point device ids (bnc#1012628).
- crypto: s5p-sss - Fix kernel Oops in AES-ECB mode (bnc#1012628).
- usbip: keep usbip_device sockfd state in sync with tcp_socket
  (bnc#1012628).
- xhci: fix xhci debugfs errors in xhci_stop (bnc#1012628).
- xhci: xhci debugfs device nodes weren't removed after device
  plugged out (bnc#1012628).
- xhci: Fix xhci debugfs devices node disappearance after
  hibernation (bnc#1012628).
- xhci: Fix NULL pointer in xhci debugfs (bnc#1012628).
- staging: iio: ad5933: switch buffer mode to software
  (bnc#1012628).
- staging: iio: adc: ad7192: fix external frequency setting
  (bnc#1012628).
- staging: fsl-mc: fix build testing on x86 (bnc#1012628).
- binder: replace "%%p" with "%%pK" (bnc#1012628).
- binder: check for binder_thread allocation failure in
  binder_poll() (bnc#1012628).
- staging: android: ashmem: Fix a race condition in pin ioctls
  (bnc#1012628).
- ANDROID: binder: synchronize_rcu() when using POLLFREE
  (bnc#1012628).
- ANDROID: binder: remove WARN() for redundant txn error
  (bnc#1012628).
- dn_getsockoptdecnet: move nf_{get/set}sockopt outside sock lock
  (bnc#1012628).
- arm64: dts: add #cooling-cells to CPU nodes (bnc#1012628).
- ARM: 8743/1: bL_switcher: add MODULE_LICENSE tag (bnc#1012628).
- video: fbdev/mmp: add MODULE_LICENSE (bnc#1012628).
- ASoC: ux500: add MODULE_LICENSE tag (bnc#1012628).
- soc: qcom: rmtfs_mem: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- net_sched: gen_estimator: fix lockdep splat (bnc#1012628).
- net: avoid skb_warn_bad_offload on IS_ERR (bnc#1012628).
- rds: tcp: atomically purge entries from rds_tcp_conn_list
  during netns delete (bnc#1012628).
- rds: tcp: correctly sequence cleanup on netns deletion
  (bnc#1012628).
- netfilter: xt_RATEEST: acquire xt_rateest_mutex for hash insert
  (bnc#1012628).
- netfilter: xt_cgroup: initialize info->priv in
  cgroup_mt_check_v1() (bnc#1012628).
- netfilter: on sockopt() acquire sock lock only in the required
  scope (bnc#1012628).
- netfilter: ipt_CLUSTERIP: fix out-of-bounds accesses in
  clusterip_tg_check() (bnc#1012628).
- netfilter: x_tables: avoid out-of-bounds reads in
  xt_request_find_{match|target} (bnc#1012628).
- netfilter: x_tables: fix int overflow in xt_alloc_table_info()
  (bnc#1012628).
- kcov: detect double association with a single task
  (bnc#1012628).
- KVM: x86: fix escape of guest dr6 to the host (bnc#1012628).
- blk_rq_map_user_iov: fix error override (bnc#1012628).
- staging: android: ion: Switch from WARN to pr_warn
  (bnc#1012628).
- staging: android: ion: Add __GFP_NOWARN for system contig heap
  (bnc#1012628).
- crypto: x86/twofish-3way - Fix %%rbp usage (bnc#1012628).
- media: pvrusb2: properly check endpoint types (bnc#1012628).
- selinux: skip bounded transition processing if the policy
  isn't loaded (bnc#1012628).
- selinux: ensure the context is NUL terminated in
  security_context_to_sid_core() (bnc#1012628).
- ptr_ring: try vmalloc() when kmalloc() fails (bnc#1012628).
- ptr_ring: fail early if queue occupies more than
  KMALLOC_MAX_SIZE (bnc#1012628).
- tun: fix tun_napi_alloc_frags() frag allocator (bnc#1012628).
- commit 71fd692
* Thu Feb 22 2018 jslaby@suse.cz
- powerpc/pseries: Add empty update_numa_cpu_lookup_table()
  for NUMA=n (git-fixes).
- commit 4a82466
* Thu Feb 22 2018 jslaby@suse.cz
- Linux 4.15.5 (bnc#1012628).
- scsi: smartpqi: allow static build ("built-in") (bnc#1012628).
- IB/umad: Fix use of unprotected device pointer (bnc#1012628).
- IB/qib: Fix comparison error with qperf compare/swap test
  (bnc#1012628).
- IB/mlx4: Fix incorrectly releasing steerable UD QPs when have
  only ETH ports (bnc#1012628).
- IB/core: Fix two kernel warnings triggered by rxe registration
  (bnc#1012628).
- IB/core: Fix ib_wc structure size to remain in 64 bytes boundary
  (bnc#1012628).
- IB/core: Avoid a potential OOPs for an unused optional parameter
  (bnc#1012628).
- selftests: seccomp: fix compile error seccomp_bpf (bnc#1012628).
- kselftest: fix OOM in memory compaction test (bnc#1012628).
- RDMA/rxe: Fix a race condition related to the QP error state
  (bnc#1012628).
- RDMA/rxe: Fix a race condition in rxe_requester() (bnc#1012628).
- RDMA/rxe: Fix rxe_qp_cleanup() (bnc#1012628).
- cpufreq: powernv: Dont assume distinct pstate values for
  nominal and pmin (bnc#1012628).
- swiotlb: suppress warning when __GFP_NOWARN is set
  (bnc#1012628).
- PM / devfreq: Propagate error from devfreq_add_device()
  (bnc#1012628).
- mwifiex: resolve reset vs. remove()/shutdown() deadlocks
  (bnc#1012628).
- ocfs2: try a blocking lock before return AOP_TRUNCATED_PAGE
  (bnc#1012628).
- trace_uprobe: Display correct offset in uprobe_events
  (bnc#1012628).
- powerpc/radix: Remove trace_tlbie call from radix__flush_tlb_all
  (bnc#1012628).
- powerpc/kernel: Block interrupts when updating TIDR
  (bnc#1012628).
- powerpc/vas: Don't set uses_vas for kernel windows
  (bnc#1012628).
- powerpc/numa: Invalidate numa_cpu_lookup_table on cpu remove
  (bnc#1012628).
- powerpc/mm: Flush radix process translations when setting MMU
  type (bnc#1012628).
- powerpc/xive: Use hw CPU ids when configuring the CPU queues
  (bnc#1012628).
- dma-buf: fix reservation_object_wait_timeout_rcu once more v2
  (bnc#1012628).
- s390: fix handling of -1 in set{,fs}[gu]id16 syscalls
  (bnc#1012628).
- arm64: dts: msm8916: Correct ipc references for smsm
  (bnc#1012628).
- ARM: lpc3250: fix uda1380 gpio numbers (bnc#1012628).
- ARM: dts: STi: Add gpio polarity for "hdmi,hpd-gpio" property
  (bnc#1012628).
- ARM: dts: nomadik: add interrupt-parent for clcd (bnc#1012628).
- arm: dts: mt7623: fix card detection issue on bananapi-r2
  (bnc#1012628).
- arm: spear600: Add missing interrupt-parent of rtc
  (bnc#1012628).
- arm: spear13xx: Fix dmas cells (bnc#1012628).
- arm: spear13xx: Fix spics gpio controller's warning
  (bnc#1012628).
- x86/gpu: add CFL to early quirks (bnc#1012628).
- x86/kexec: Make kexec (mostly) work in 5-level paging mode
  (bnc#1012628).
- x86/xen: init %%gs very early to avoid page faults with stack
  protector (bnc#1012628).
- x86: PM: Make APM idle driver initialize polling state
  (bnc#1012628).
- mm, memory_hotplug: fix memmap initialization (bnc#1012628).
- x86/entry/64: Clear extra registers beyond syscall arguments,
  to reduce speculation attack surface (bnc#1012628).
- x86/entry/64/compat: Clear registers for compat syscalls,
  to reduce speculation attack surface (bnc#1012628).
- compiler-gcc.h: Introduce __optimize function attribute
  (bnc#1012628).
- compiler-gcc.h: __nostackprotector needs gcc-4.4 and up
  (bnc#1012628).
- crypto: sun4i_ss_prng - fix return value of
  sun4i_ss_prng_generate (bnc#1012628).
- crypto: sun4i_ss_prng - convert lock to _bh in
  sun4i_ss_prng_generate (bnc#1012628).
- powerpc/mm/radix: Split linear mapping on hot-unplug
  (bnc#1012628).
- x86/mm/pti: Fix PTI comment in entry_SYSCALL_64() (bnc#1012628).
- x86/speculation: Update Speculation Control microcode blacklist
  (bnc#1012628).
- x86/speculation: Correct Speculation Control microcode blacklist
  again (bnc#1012628).
- Revert "x86/speculation: Simplify
  indirect_branch_prediction_barrier()" (bnc#1012628).
- KVM/x86: Reduce retpoline performance impact in
  slot_handle_level_range(), by always inlining iterator helper
  methods (bnc#1012628).
- X86/nVMX: Properly set spec_ctrl and pred_cmd before merging
  MSRs (bnc#1012628).
- KVM/nVMX: Set the CPU_BASED_USE_MSR_BITMAPS if we have a valid
  L02 MSR bitmap (bnc#1012628).
- x86/speculation: Clean up various Spectre related details
  (bnc#1012628).
- PM / runtime: Update links_count also if !CONFIG_SRCU
  (bnc#1012628).
- PM: cpuidle: Fix cpuidle_poll_state_init() prototype
  (bnc#1012628).
- platform/x86: wmi: fix off-by-one write in wmi_dev_probe()
  (bnc#1012628).
- x86/entry/64: Clear registers for exceptions/interrupts,
  to reduce speculation attack surface (bnc#1012628).
- x86/entry/64: Merge SAVE_C_REGS and SAVE_EXTRA_REGS, remove
  unused extensions (bnc#1012628).
- x86/entry/64: Merge the POP_C_REGS and POP_EXTRA_REGS macros
  into a single POP_REGS macro (bnc#1012628).
- x86/entry/64: Interleave XOR register clearing with PUSH
  instructions (bnc#1012628).
- x86/entry/64: Introduce the PUSH_AND_CLEAN_REGS macro
  (bnc#1012628).
- x86/entry/64: Use PUSH_AND_CLEAN_REGS in more cases
  (bnc#1012628).
- x86/entry/64: Get rid of the ALLOC_PT_GPREGS_ON_STACK and
  SAVE_AND_CLEAR_REGS macros (bnc#1012628).
- x86/entry/64: Indent PUSH_AND_CLEAR_REGS and POP_REGS properly
  (bnc#1012628).
- x86/entry/64: Fix paranoid_entry() frame pointer warning
  (bnc#1012628).
- x86/entry/64: Remove the unused 'icebp' macro (bnc#1012628).
- selftests/x86: Fix vDSO selftest segfault for vsyscall=none
  (bnc#1012628).
- selftests/x86: Clean up and document sscanf() usage
  (bnc#1012628).
- selftests/x86/pkeys: Remove unused functions (bnc#1012628).
- selftests/x86: Fix build bug caused by the 5lvl test which
  has been moved to the VM directory (bnc#1012628).
- selftests/x86: Do not rely on "int $0x80" in test_mremap_vdso.c
  (bnc#1012628).
- gfs2: Fixes to "Implement iomap for block_map" (bnc#1012628).
- selftests/x86: Do not rely on "int $0x80" in
  single_step_syscall.c (bnc#1012628).
- selftests/x86: Disable tests requiring 32-bit support on pure
  64-bit systems (bnc#1012628).
- objtool: Fix segfault in ignore_unreachable_insn()
  (bnc#1012628).
- x86/debug, objtool: Annotate WARN()-related UD2 as reachable
  (bnc#1012628).
- x86/debug: Use UD2 for WARN() (bnc#1012628).
- x86/speculation: Fix up array_index_nospec_mask() asm constraint
  (bnc#1012628).
- nospec: Move array_index_nospec() parameter checking into
  separate macro (bnc#1012628).
- x86/speculation: Add <asm/msr-index.h> dependency (bnc#1012628).
- x86/mm: Rename flush_tlb_single() and flush_tlb_one() to
  __flush_tlb_one_[user|kernel]() (bnc#1012628).
- selftests/x86/mpx: Fix incorrect bounds with old _sigfault
  (bnc#1012628).
- x86/cpu: Rename cpu_data.x86_mask to cpu_data.x86_stepping
  (bnc#1012628).
- x86/spectre: Fix an error message (bnc#1012628).
- x86/cpu: Change type of x86_cache_size variable to unsigned int
  (bnc#1012628).
- x86/entry/64: Fix CR3 restore in paranoid_exit() (bnc#1012628).
- drm/ttm: Don't add swapped BOs to swap-LRU list (bnc#1012628).
- drm/ttm: Fix 'buf' pointer update in ttm_bo_vm_access_kmap()
  (v2) (bnc#1012628).
- drm/qxl: unref cursor bo when finished with it (bnc#1012628).
- drm/qxl: reapply cursor after resetting primary (bnc#1012628).
- drm/amd/powerplay: Fix smu_table_entry.handle type
  (bnc#1012628).
- drm/ast: Load lut in crtc_commit (bnc#1012628).
- drm: Check for lessee in DROP_MASTER ioctl (bnc#1012628).
- arm64: Add missing Falkor part number for branch predictor
  hardening (bnc#1012628).
- drm/radeon: Add dpm quirk for Jet PRO (v2) (bnc#1012628).
- drm/radeon: adjust tested variable (bnc#1012628).
- x86/smpboot: Fix uncore_pci_remove() indexing bug when
  hot-removing a physical CPU (bnc#1012628).
- rtc-opal: Fix handling of firmware error codes, prevent busy
  loops (bnc#1012628).
- mbcache: initialize entry->e_referenced in
  mb_cache_entry_create() (bnc#1012628).
- mmc: sdhci: Implement an SDHCI-specific bounce buffer
  (bnc#1012628).
- mmc: bcm2835: Don't overwrite max frequency unconditionally
  (bnc#1012628).
- Revert "mmc: meson-gx: include tx phase in the tuning process"
  (bnc#1012628).
- mlx5: fix mlx5_get_vector_affinity to start from completion
  vector 0 (bnc#1012628).
- Revert "apple-gmux: lock iGP IO to protect from vgaarb changes"
  (bnc#1012628).
- jbd2: fix sphinx kernel-doc build warnings (bnc#1012628).
- ext4: fix a race in the ext4 shutdown path (bnc#1012628).
- ext4: save error to disk in __ext4_grp_locked_error()
  (bnc#1012628).
- ext4: correct documentation for grpid mount option
  (bnc#1012628).
- mm: hide a #warning for COMPILE_TEST (bnc#1012628).
- mm: Fix memory size alignment in devm_memremap_pages_release()
  (bnc#1012628).
- MIPS: Fix typo BIG_ENDIAN to CPU_BIG_ENDIAN (bnc#1012628).
- MIPS: CPS: Fix MIPS_ISA_LEVEL_RAW fallout (bnc#1012628).
- MIPS: Fix incorrect mem=X@Y handling (bnc#1012628).
- PCI: Disable MSI for HiSilicon Hip06/Hip07 only in Root Port
  mode (bnc#1012628).
- PCI: iproc: Fix NULL pointer dereference for BCMA (bnc#1012628).
- PCI: pciehp: Assume NoCompl+ for Thunderbolt ports
  (bnc#1012628).
- PCI: keystone: Fix interrupt-controller-node lookup
  (bnc#1012628).
- video: fbdev: atmel_lcdfb: fix display-timings lookup
  (bnc#1012628).
- console/dummy: leave .con_font_get set to NULL (bnc#1012628).
- rbd: whitelist RBD_FEATURE_OPERATIONS feature bit (bnc#1012628).
- xen: Fix {set,clear}_foreign_p2m_mapping on autotranslating
  guests (bnc#1012628).
- xenbus: track caller request id (bnc#1012628).
- seq_file: fix incomplete reset on read from zero offset
  (bnc#1012628).
- tracing: Fix parsing of globs with a wildcard at the beginning
  (bnc#1012628).
- mpls, nospec: Sanitize array index in mpls_label_ok()
  (bnc#1012628).
- rtlwifi: rtl8821ae: Fix connection lost problem correctly
  (bnc#1012628).
- arm64: proc: Set PTE_NG for table entries to avoid traversing
  them twice (bnc#1012628).
- xprtrdma: Fix calculation of ri_max_send_sges (bnc#1012628).
- xprtrdma: Fix BUG after a device removal (bnc#1012628).
- blk-wbt: account flush requests correctly (bnc#1012628).
- target/iscsi: avoid NULL dereference in CHAP auth error path
  (bnc#1012628).
- iscsi-target: make sure to wake up sleeping login worker
  (bnc#1012628).
- dm: correctly handle chained bios in dec_pending()
  (bnc#1012628).
- Btrfs: fix deadlock in run_delalloc_nocow (bnc#1012628).
- Btrfs: fix crash due to not cleaning up tree log block's dirty
  bits (bnc#1012628).
- Btrfs: fix extent state leak from tree log (bnc#1012628).
- Btrfs: fix use-after-free on root->orphan_block_rsv
  (bnc#1012628).
- Btrfs: fix unexpected -EEXIST when creating new inode
  (bnc#1012628).
- 9p/trans_virtio: discard zero-length reply (bnc#1012628).
- mtd: nand: vf610: set correct ooblayout (bnc#1012628).
- ALSA: hda - Fix headset mic detection problem for two Dell
  machines (bnc#1012628).
- ALSA: usb-audio: Fix UAC2 get_ctl request with a RANGE attribute
  (bnc#1012628).
- ALSA: hda/realtek - Add headset mode support for Dell laptop
  (bnc#1012628).
- ALSA: hda/realtek - Enable Thinkpad Dock device for ALC298
  platform (bnc#1012628).
- ALSA: hda/realtek: PCI quirk for Fujitsu U7x7 (bnc#1012628).
- ALSA: usb-audio: add implicit fb quirk for Behringer UFX1204
  (bnc#1012628).
- ALSA: usb: add more device quirks for USB DSD devices
  (bnc#1012628).
- ALSA: seq: Fix racy pool initializations (bnc#1012628).
- mvpp2: fix multicast address filter (bnc#1012628).
- usb: Move USB_UHCI_BIG_ENDIAN_* out of USB_SUPPORT
  (bnc#1012628).
- x86/mm, mm/hwpoison: Don't unconditionally unmap kernel 1:1
  pages (bnc#1012628).
- ARM: dts: exynos: fix RTC interrupt for exynos5410
  (bnc#1012628).
- ARM: pxa/tosa-bt: add MODULE_LICENSE tag (bnc#1012628).
- arm64: dts: msm8916: Add missing #phy-cells (bnc#1012628).
- ARM: dts: s5pv210: add interrupt-parent for ohci (bnc#1012628).
- arm: dts: mt7623: Update ethsys binding (bnc#1012628).
- arm: dts: mt2701: Add reset-cells (bnc#1012628).
- ARM: dts: Delete bogus reference to the charlcd (bnc#1012628).
- media: r820t: fix r820t_write_reg for KASAN (bnc#1012628).
- mmc: sdhci-of-esdhc: fix eMMC couldn't work after kexec
  (bnc#1012628).
- mmc: sdhci-of-esdhc: fix the mmc error after sleep on ls1046ardb
  (bnc#1012628).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Refresh
  patches.suse/0002-x86-speculation-Add-inlines-to-control-Indirect-Bran.patch.
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- commit 078aac5
* Thu Feb 22 2018 lpechacek@suse.com
- rpm/kernel-spec-macros: Try harder to detect Build Service environment (bsc#1078788)
- commit a5f1a4a
* Wed Feb 21 2018 msuchanek@suse.de
- kernel-binary undefine unique_debug_names
  Some tools do not understand names like
  usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
- commit 2b90c1e
* Tue Feb 20 2018 jeffm@suse.com
- config: enable IMA and EVM
- commit 8c97198
* Sun Feb 18 2018 afaerber@suse.de
- config: arm64: Enable MAX77620 for Nvidia Jetson TX1 (boo#1081473)
- commit 5cbffaf
* Sat Feb 17 2018 jslaby@suse.cz
- Linux 4.15.4 (bnc#1012628).
- watchdog: indydog: Add dependency on SGI_HAS_INDYDOG
  (bnc#1012628).
- cifs: Fix missing put_xid in cifs_file_strict_mmap
  (bnc#1012628).
- cifs: Fix autonegotiate security settings mismatch
  (bnc#1012628).
- CIFS: zero sensitive data when freeing (bnc#1012628).
- cpufreq: mediatek: add mediatek related projects into blacklist
  (bnc#1012628).
- dmaengine: dmatest: fix container_of member in dmatest_callback
  (bnc#1012628).
- ssb: Do not disable PCI host on non-Mips (bnc#1012628).
- watchdog: gpio_wdt: set WDOG_HW_RUNNING in gpio_wdt_stop
  (bnc#1012628).
- Revert "drm/i915: mark all device info struct with __initconst"
  (bnc#1012628).
- sched/rt: Use container_of() to get root domain in
  rto_push_irq_work_func() (bnc#1012628).
- sched/rt: Up the root domain ref count when passing it around
  via IPIs (bnc#1012628).
- media: dvb-usb-v2: lmedm04: Improve logic checking of warm start
  (bnc#1012628).
- media: dvb-usb-v2: lmedm04: move ts2020 attach to
  dm04_lme2510_tuner (bnc#1012628).
- media: hdpvr: Fix an error handling path in hdpvr_probe()
  (bnc#1012628).
- arm64: cpu_errata: Add Kryo to Falkor 1003 errata (bnc#1012628).
- arm64: kpti: Make use of nG dependent on
  arm64_kernel_unmapped_at_el0() (bnc#1012628).
- arm64: mm: Permit transitioning from Global to Non-Global
  without BBM (bnc#1012628).
- arm64: kpti: Add ->enable callback to remap swapper using nG
  mappings (bnc#1012628).
- arm64: Force KPTI to be disabled on Cavium ThunderX
  (bnc#1012628).
- arm64: entry: Reword comment about post_ttbr_update_workaround
  (bnc#1012628).
- arm64: idmap: Use "awx" flags for .idmap.text .pushsection
  directives (bnc#1012628).
- arm64: barrier: Add CSDB macros to control data-value prediction
  (bnc#1012628).
- arm64: Implement array_index_mask_nospec() (bnc#1012628).
- arm64: Make USER_DS an inclusive limit (bnc#1012628).
- arm64: Use pointer masking to limit uaccess speculation
  (bnc#1012628).
- arm64: entry: Ensure branch through syscall table is bounded
  under speculation (bnc#1012628).
- arm64: uaccess: Prevent speculative use of the current
  addr_limit (bnc#1012628).
- arm64: uaccess: Don't bother eliding access_ok checks in __{get,
  put}_user (bnc#1012628).
- arm64: uaccess: Mask __user pointers for __arch_{clear,
  copy_*}_user (bnc#1012628).
- arm64: futex: Mask __user pointers prior to dereference
  (bnc#1012628).
- arm64: cpufeature: __this_cpu_has_cap() shouldn't stop early
  (bnc#1012628).
- arm64: entry: Apply BP hardening for high-priority synchronous
  exceptions (bnc#1012628).
- arm64: entry: Apply BP hardening for suspicious interrupts
  from EL0 (bnc#1012628).
- arm64: KVM: Increment PC after handling an SMC trap
  (bnc#1012628).
- arm/arm64: KVM: Consolidate the PSCI include files
  (bnc#1012628).
- arm/arm64: KVM: Add PSCI_VERSION helper (bnc#1012628).
- arm/arm64: KVM: Add smccc accessors to PSCI code (bnc#1012628).
- arm/arm64: KVM: Implement PSCI 1.0 support (bnc#1012628).
- arm/arm64: KVM: Advertise SMCCC v1.1 (bnc#1012628).
- arm/arm64: KVM: Turn kvm_psci_version into a static inline
  (bnc#1012628).
- arm64: KVM: Report SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: KVM: Add SMCCC_ARCH_WORKAROUND_1 fast handling
  (bnc#1012628).
- firmware/psci: Expose PSCI conduit (bnc#1012628).
- firmware/psci: Expose SMCCC version through psci_ops
  (bnc#1012628).
- arm/arm64: smccc: Make function identifiers an unsigned quantity
  (bnc#1012628).
- arm/arm64: smccc: Implement SMCCC v1.1 inline primitive
  (bnc#1012628).
- arm64: Add ARM_SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bnc#1012628).
- arm64: Kill PSCI_GET_VERSION as a variant-2 workaround
  (bnc#1012628).
- mtd: cfi: convert inline functions to macros (bnc#1012628).
- mtd: nand: brcmnand: Disable prefetch by default (bnc#1012628).
- mtd: nand: Fix nand_do_read_oob() return value (bnc#1012628).
- mtd: nand: sunxi: Fix ECC strength choice (bnc#1012628).
- ubi: Fix race condition between ubi volume creation and udev
  (bnc#1012628).
- ubi: fastmap: Erase outdated anchor PEBs during attach
  (bnc#1012628).
- ubi: block: Fix locking for idr_alloc/idr_remove (bnc#1012628).
- ubifs: free the encrypted symlink target (bnc#1012628).
- nfs/pnfs: fix nfs_direct_req ref leak when i/o falls back to
  the mds (bnc#1012628).
- nfs41: do not return ENOMEM on LAYOUTUNAVAILABLE (bnc#1012628).
- NFS: Add a cond_resched() to nfs_commit_release_pages()
  (bnc#1012628).
- NFS: Fix nfsstat breakage due to LOOKUPP (bnc#1012628).
- NFS: commit direct writes even if they fail partially
  (bnc#1012628).
- NFS: reject request for id_legacy key without auxdata
  (bnc#1012628).
- NFS: Fix a race between mmap() and O_DIRECT (bnc#1012628).
- nfsd: Detect unhashed stids in nfsd4_verify_open_stid()
  (bnc#1012628).
- kernfs: fix regression in kernfs_fop_write caused by wrong type
  (bnc#1012628).
- ahci: Annotate PCI ids for mobile Intel chipsets as such
  (bnc#1012628).
- ahci: Add PCI ids for Intel Bay Trail, Cherry Trail and Apollo
  Lake AHCI (bnc#1012628).
- ahci: Add Intel Cannon Lake PCH-H PCI ID (bnc#1012628).
- crypto: hash - introduce crypto_hash_alg_has_setkey()
  (bnc#1012628).
- crypto: cryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: mcryptd - pass through absence of ->setkey()
  (bnc#1012628).
- crypto: poly1305 - remove ->setkey() method (bnc#1012628).
- crypto: hash - annotate algorithms taking optional key
  (bnc#1012628).
- crypto: hash - prevent using keyed hashes without setting key
  (bnc#1012628).
- media: v4l2-ioctl.c: use check_fmt for enum/g/s/try_fmt
  (bnc#1012628).
- media: v4l2-ioctl.c: don't copy back the result for -ENOTTY
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: add missing VIDIOC_PREPARE_BUF
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix the indentation (bnc#1012628).
- media: v4l2-compat-ioctl32.c: move 'helper' functions to
  __get/put_v4l2_format32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: avoid sizeof(type) (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy m.userptr in put_v4l2_plane32
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: fix ctrl_is_pointer (bnc#1012628).
- media: v4l2-compat-ioctl32.c: copy clip list in
  put_v4l2_window32 (bnc#1012628).
- media: v4l2-compat-ioctl32.c: drop pr_info for unknown buffer
  type (bnc#1012628).
- media: v4l2-compat-ioctl32.c: don't copy back the result for
  certain errors (bnc#1012628).
- media: v4l2-compat-ioctl32.c: refactor compat ioctl32 logic
  (bnc#1012628).
- media: v4l2-compat-ioctl32.c: make ctrl_is_pointer work for
  subdevs (bnc#1012628).
- crypto: caam - fix endless loop when DECO acquire fails
  (bnc#1012628).
- crypto: sha512-mb - initialize pending lengths correctly
  (bnc#1012628).
- crypto: talitos - fix Kernel Oops on hashing an empty file
  (bnc#1012628).
- arm: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bnc#1012628).
- KVM: nVMX: Fix races when sending nested PI while dest
  enters/leaves L2 (bnc#1012628).
- KVM: nVMX: Fix bug of injecting L2 exception into L1
  (bnc#1012628).
- KVM: PPC: Book3S HV: Make sure we don't re-enter guest without
  XIVE loaded (bnc#1012628).
- KVM: PPC: Book3S HV: Drop locks before reading guest memory
  (bnc#1012628).
- KVM: arm/arm64: Handle CPU_PM_ENTER_FAILED (bnc#1012628).
- KVM: PPC: Book3S PR: Fix broken select due to misspelling
  (bnc#1012628).
- ASoC: acpi: fix machine driver selection based on quirk
  (bnc#1012628).
- ASoC: rockchip: i2s: fix playback after runtime resume
  (bnc#1012628).
- ASoC: skl: Fix kernel warning due to zero NHTL entry
  (bnc#1012628).
- ASoC: compress: Correct handling of copy callback (bnc#1012628).
- watchdog: imx2_wdt: restore previous timeout after
  suspend+resume (bnc#1012628).
- afs: Add missing afs_put_cell() (bnc#1012628).
- afs: Need to clear responded flag in addr cursor (bnc#1012628).
- afs: Fix missing cursor clearance (bnc#1012628).
- afs: Fix server list handling (bnc#1012628).
- btrfs: Handle btrfs_set_extent_delalloc failure in fixup worker
  (bnc#1012628).
- Btrfs: raid56: iterate raid56 internal bio with
  bio_for_each_segment_all (bnc#1012628).
- kasan: don't emit builtin calls when sanitization is off
  (bnc#1012628).
- kasan: rework Kconfig settings (bnc#1012628).
- media: dvb_frontend: be sure to init dvb_frontend_handle_ioctl()
  return code (bnc#1012628).
- media: dvb-frontends: fix i2c access helpers for KASAN
  (bnc#1012628).
- media: dt-bindings/media/cec-gpio.txt: mention the CEC/HPD
  max voltages (bnc#1012628).
- media: ts2020: avoid integer overflows on 32 bit machines
  (bnc#1012628).
- media: vivid: fix module load error when enabling fb and
  no_error_inj=1 (bnc#1012628).
- media: cxusb, dib0700: ignore XC2028_I2C_FLUSH (bnc#1012628).
- fs/proc/kcore.c: use probe_kernel_read() instead of memcpy()
  (bnc#1012628).
- kernel/async.c: revert "async: simplify lowest_in_progress()"
  (bnc#1012628).
- kernel/relay.c: revert "kernel/relay.c: fix potential memory
  leak" (bnc#1012628).
- pipe: actually allow root to exceed the pipe buffer limits
  (bnc#1012628).
- pipe: fix off-by-one error when checking buffer limits
  (bnc#1012628).
- HID: quirks: Fix keyboard + touchpad on Toshiba Click Mini
  not working (bnc#1012628).
- Bluetooth: btsdio: Do not bind to non-removable BCM43341
  (bnc#1012628).
- Revert "Bluetooth: btusb: fix QCA Rome suspend/resume"
  (bnc#1012628).
- Bluetooth: btusb: Restore QCA Rome suspend/resume fix with a
  "rewritten" version (bnc#1012628).
- ipmi: use dynamic memory for DMI driver override (bnc#1012628).
- signal/openrisc: Fix do_unaligned_access to send the proper
  signal (bnc#1012628).
- signal/sh: Ensure si_signo is initialized in do_divide_error
  (bnc#1012628).
- alpha: fix crash if pthread_create races with signal delivery
  (bnc#1012628).
- alpha: osf_sys.c: fix put_tv32 regression (bnc#1012628).
- alpha: Fix mixed up args in EXC macro in futex operations
  (bnc#1012628).
- alpha: fix reboot on Avanti platform (bnc#1012628).
- alpha: fix formating of stack content (bnc#1012628).
- xtensa: fix futex_atomic_cmpxchg_inatomic (bnc#1012628).
- EDAC, octeon: Fix an uninitialized variable warning
  (bnc#1012628).
- genirq: Make legacy autoprobing work again (bnc#1012628).
- pinctrl: intel: Initialize GPIO properly when used through
  irqchip (bnc#1012628).
- pinctrl: mcp23s08: fix irq setup order (bnc#1012628).
- pinctrl: sx150x: Unregister the pinctrl on release
  (bnc#1012628).
- pinctrl: sx150x: Register pinctrl before adding the gpiochip
  (bnc#1012628).
- pinctrl: sx150x: Add a static gpio/pinctrl pin range mapping
  (bnc#1012628).
- pktcdvd: Fix pkt_setup_dev() error path (bnc#1012628).
- pktcdvd: Fix a recently introduced NULL pointer dereference
  (bnc#1012628).
- blk-mq: quiesce queue before freeing queue (bnc#1012628).
- clocksource/drivers/stm32: Fix kernel panic with multiple timers
  (bnc#1012628).
- lib/ubsan.c: s/missaligned/misaligned/ (bnc#1012628).
- lib/ubsan: add type mismatch handler for new GCC/Clang
  (bnc#1012628).
- objtool: Fix switch-table detection (bnc#1012628).
- arm64: dts: marvell: add Ethernet aliases (bnc#1012628).
- drm/i915: Avoid PPS HW/SW state mismatch due to rounding
  (bnc#1012628).
- ACPI: sbshc: remove raw pointer from printk() message
  (bnc#1012628).
- acpi, nfit: fix register dimm error handling (bnc#1012628).
- ovl: force r/o mount when index dir creation fails
  (bnc#1012628).
- ovl: fix failure to fsync lower dir (bnc#1012628).
- ovl: take mnt_want_write() for work/index dir setup
  (bnc#1012628).
- ovl: take mnt_want_write() for removing impure xattr
  (bnc#1012628).
- ovl: hash directory inodes for fsnotify (bnc#1012628).
- mn10300/misalignment: Use SIGSEGV SEGV_MAPERR to report a
  failed user copy (bnc#1012628).
- devpts: fix error handling in devpts_mntget() (bnc#1012628).
- ftrace: Remove incorrect setting of glob search field
  (bnc#1012628).
- scsi: core: Ensure that the SCSI error handler gets woken up
  (bnc#1012628).
- scsi: lpfc: Fix crash after bad bar setup on driver attachment
  (bnc#1012628).
- scsi: cxlflash: Reset command ioasc (bnc#1012628).
- rcu: Export init_rcu_head() and destroy_rcu_head() to GPL
  modules (bnc#1012628).
- media: dvb_frontend: fix return error code (git-fixes).
- mtd: ubi: wl: Fix error return code in ubi_wl_init()
  (git-fixes).
- Update config files.
- commit 4d42c34
* Thu Feb 15 2018 jmoreira@suse.de
- Add kernel livepatch-devel package
  Resolving non-exported static symbols in kernel livepatches cannot
  be done implicitly. For such, the relocations of these symbols must
  follow a specially crafted format in the respective elf file. Willing
  to make the task of converting the elf into the right format, a tool
  named klp-convert was proposed. Through a file that maps all kernel
  symbols into their respective kernel object, this tool infers which
  non-exported symbol is relative to a livepatch relocation and
  automatically formats the final elf file.
  Add support to the generation of a map file right after the kernel
  compilation.
  Add the package kernel-<flavour>-livepatch-devel that brings
  the map file.
- commit 0b1b4d3
* Tue Feb 13 2018 jslaby@suse.cz
- Linux 4.15.3 (bnc#1012628).
- crypto: tcrypt - fix S/G table for test_aead_speed()
  (bnc#1012628).
- gpio: uniphier: fix mismatch between license text and
  MODULE_LICENSE (bnc#1012628).
- media: tegra-cec: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- media: soc_camera: soc_scale_crop: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- media: mtk-vcodec: add missing MODULE_LICENSE/DESCRIPTION
  (bnc#1012628).
- net: sched: fix use-after-free in tcf_block_put_ext
  (bnc#1012628).
- net_sched: get rid of rcu_barrier() in tcf_block_put_ext()
  (bnc#1012628).
- soreuseport: fix mem leak in reuseport_add_sock() (bnc#1012628).
- ipv6: Fix SO_REUSEPORT UDP socket with implicit sk_ipv6only
  (bnc#1012628).
- cls_u32: add missing RCU annotation (bnc#1012628).
- tcp_bbr: fix pacing_gain to always be unity when using lt_bw
  (bnc#1012628).
- rocker: fix possible null pointer dereference in
  rocker_router_fib_event_work (bnc#1012628).
- net: ipv6: send unsolicited NA after DAD (bnc#1012628).
- Revert "defer call to mem_cgroup_sk_alloc()" (bnc#1012628).
- ipv6: change route cache aging logic (bnc#1012628).
- ipv6: addrconf: break critical section in addrconf_verify_rtnl()
  (bnc#1012628).
- vhost_net: stop device during reset owner (bnc#1012628).
- tcp: release sk_frag.page in tcp_disconnect (bnc#1012628).
- r8169: fix RTL8168EP take too long to complete driver
  initialization (bnc#1012628).
- qmi_wwan: Add support for Quectel EP06 (bnc#1012628).
- qlcnic: fix deadlock bug (bnc#1012628).
- net: igmp: add a missing rcu locking section (bnc#1012628).
- ip6mr: fix stale iterator (bnc#1012628).
- commit e7bb737
* Tue Feb 13 2018 jslaby@suse.cz
- ext4: llseek, do not crop offset on 32bit (bsc#1079747).
- commit c6ab9c6
* Sun Feb 11 2018 afaerber@suse.de
- config: arm64: Enable Hi6421 PMU (bsc#1080449)
- commit 77a784c
* Fri Feb  9 2018 jslaby@suse.cz
- Update i386 config files.
  Switch from almost unusable UNWINDER_GUESS to UNWINDER_FRAME_POINTER
  (which enables FRAME_POINTERs). It will slow down the kernel a bit,
  but improves the stack traces by the order of magnitude. Sad is that
  we have no ORCs on i386...
- commit 1d39996
* Fri Feb  9 2018 jslaby@suse.cz
- Update config files.
  Sync vanilla configs to 4.15.
- commit 85c7881
* Thu Feb  8 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also require m4 for build.
- commit 0d7b4b3
* Thu Feb  8 2018 jslaby@suse.cz
- Linux 4.15.2 (bnc#1012628).
- KVM: x86: Make indirect calls in emulator speculation safe
  (bnc#1012628).
- KVM: VMX: Make indirect call speculation safe (bnc#1012628).
- x86/alternative: Print unadorned pointers (bnc#1012628).
- auxdisplay: img-ascii-lcd: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- iio: adc/accel: Fix up module licenses (bnc#1012628).
- pinctrl: pxa: pxa2xx: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- ASoC: pcm512x: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- KVM: nVMX: Eliminate vmcs02 pool (bnc#1012628).
- KVM: VMX: introduce alloc_loaded_vmcs (bnc#1012628).
- objtool: Improve retpoline alternative handling (bnc#1012628).
- objtool: Add support for alternatives at the end of a section
  (bnc#1012628).
- objtool: Warn on stripped section symbol (bnc#1012628).
- x86/mm: Fix overlap of i386 CPU_ENTRY_AREA with FIX_BTMAP
  (bnc#1012628).
- x86/entry/64: Remove the SYSCALL64 fast path (bnc#1012628).
- x86/entry/64: Push extra regs right away (bnc#1012628).
- x86/asm: Move 'status' from thread_struct to thread_info
  (bnc#1012628).
- x86/spectre: Fix spelling mistake: "vunerable"-> "vulnerable"
  (bnc#1012628).
- x86/paravirt: Remove 'noreplace-paravirt' cmdline option
  (bnc#1012628).
- KVM: VMX: make MSR bitmaps per-VCPU (bnc#1012628).
- x86/kvm: Update spectre-v1 mitigation (bnc#1012628).
- x86/retpoline: Avoid retpolines for built-in __init functions
  (bnc#1012628).
- x86/speculation: Fix typo IBRS_ATT, which should be IBRS_ALL
  (bnc#1012628).
- KVM/x86: Update the reverse_cpuid list to include CPUID_7_EDX
  (bnc#1012628).
- KVM/x86: Add IBPB support (bnc#1012628).
- KVM/VMX: Emulate MSR_IA32_ARCH_CAPABILITIES (bnc#1012628).
- KVM/VMX: Allow direct access to MSR_IA32_SPEC_CTRL
  (bnc#1012628).
- KVM/SVM: Allow direct access to MSR_IA32_SPEC_CTRL
  (bnc#1012628).
- serial: core: mark port as initialized after successful IRQ
  change (bnc#1012628).
- fpga: region: release of_parse_phandle nodes after use
  (bnc#1012628).
- commit 54903ae
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: install ksym-provides tool (bsc#1077692).
- commit 679f5c5
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: require bison for build.
  linux-next tends to have outdated generated files so it needs bison to
  regenerate them.
- commit 4ad1ede
* Wed Feb  7 2018 msuchanek@suse.de
- Add ksym-provides tool (bsc#1077692).
- commit 9cd1e1e
* Mon Feb  5 2018 jslaby@suse.cz
- x86/pti: Mark constant arrays as __initconst (bsc#1068032
  CVE-2017-5753).
- x86/cpuid: Fix up "virtual" IBRS/IBPB/STIBP feature bits on
  Intel (bsc#1068032 CVE-2017-5753).
- commit 7d4f257
* Mon Feb  5 2018 jslaby@suse.cz
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5753).
- x86/pti: Do not enable PTI on CPUs which are not vulnerable
  to Meltdown (bsc#1068032 CVE-2017-5753).
- x86/cpufeature: Blacklist SPEC_CTRL/PRED_CMD on early Spectre
  v2 microcodes (bsc#1068032 CVE-2017-5753).
- x86/nospec: Fix header guards names (bsc#1068032 CVE-2017-5753).
- x86/bugs: Drop one "mitigation" from dmesg (bsc#1068032
  CVE-2017-5753).
- x86/cpu/bugs: Make retpoline module warning conditional
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Clean up Spectre v2 related CPUID flags
  (bsc#1068032 CVE-2017-5753).
- x86/retpoline: Simplify vmexit_fill_RSB() (bsc#1068032
  CVE-2017-5753).
- x86/speculation: Simplify indirect_branch_prediction_barrier()
  (bsc#1068032 CVE-2017-5753).
- module/retpoline: Warn about missing retpoline in module
  (bsc#1068032 CVE-2017-5753).
- x86/spectre: Check CONFIG_RETPOLINE in command line parser
  (bsc#1068032 CVE-2017-5753).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5753).
- Refresh
  patches.suse/0001-x86-cpufeatures-Add-CPUID_7_EDX-CPUID-leaf.patch.
- Refresh
  patches.suse/0002-x86-cpufeatures-Add-Intel-feature-bits-for-Speculati.patch.
- Refresh
  patches.suse/0003-x86-cpufeatures-Add-AMD-feature-bits-for-Speculation.patch.
- Refresh
  patches.suse/0004-x86-msr-Add-definitions-for-new-speculation-control-.patch.
- Refresh
  patches.suse/0007-x86-speculation-Add-basic-IBPB-Indirect-Branch-Predi.patch.
- Refresh patches.suse/supported-flag.
- Delete
  patches.suse/0005-x86-pti-Do-not-enable-PTI-on-processors-which-are-no.patch.
- Delete
  patches.suse/0006-x86-cpufeature-Blacklist-SPEC_CTRL-on-early-Spectre-.patch.
- Delete patches.suse/0008-x86-kvm-Add-IBPB-support.patch.
- Delete
  patches.suse/0009-x86-speculation-Use-Indirect-Branch-Prediction-Barri.patch.
- Delete
  patches.suse/0010-x86-mm-Only-flush-indirect-branches-when-switching-i.patch.
- Delete
  patches.suse/0011-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- Delete
  patches.suse/0017-x86-ibrs-Add-new-helper-macros-to-save-restore-MSR_I-fix.patch.
- Delete
  patches.suse/0017-x86-ibrs-Add-new-helper-macros-to-save-restore-MSR_I.patch.
- Delete
  patches.suse/0018-x86-vmx-Direct-access-to-MSR_IA32_SPEC_CTRL.patch.
  Update to the patches from 4.16-rc1 and the updated IBRS patches from
  the dwmw's repo.
- commit cd20d46
* Mon Feb  5 2018 jslaby@suse.cz
- Documentation: Document array_index_nospec (bsc#1068032
  CVE-2017-5715).
- array_index_nospec: Sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5715).
- x86: Implement array_index_mask_nospec (bsc#1068032
  CVE-2017-5715).
- x86: Introduce barrier_nospec (bsc#1068032 CVE-2017-5715).
- x86: Introduce __uaccess_begin_nospec() and uaccess_try_nospec
  (bsc#1068032 CVE-2017-5715).
- x86/usercopy: Replace open coded stac/clac with
  __uaccess_{begin, end} (bsc#1068032 CVE-2017-5715).
- x86/syscall: Sanitize syscall table de-references under
  speculation (bsc#1068032 CVE-2017-5715).
- nl80211: Sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5715).
- x86/spectre: Report get_user mitigation for spectre_v1
  (bsc#1068032 CVE-2017-5715).
- Delete patches.suse/0001-Documentation-document-array_ptr.patch.
- Delete
  patches.suse/0002-asm-nospec-array_ptr-sanitize-speculative-array-de-r.patch.
- Delete patches.suse/0003-x86-implement-array_ptr_mask.patch.
- Delete
  patches.suse/0004-x86-introduce-__uaccess_begin_nospec-and-ifence.patch.
- Delete
  patches.suse/0007-x86-narrow-out-of-bounds-syscalls-to-sys_read-under-.patch.
- Delete
  patches.suse/0009-kvm-x86-update-spectre-v1-mitigation.patch.
- Delete
  patches.suse/0010-nl80211-sanitize-array-index-in-parse_txq_params.patch.
  Replace by the patches from 4.16-rc1.
- commit 8343cab
* Mon Feb  5 2018 jslaby@suse.cz
- scsi: aacraid: remove redundant setting of variable c
  (git-fixes).
- commit 143e25c
* Sun Feb  4 2018 jslaby@suse.cz
- Linux 4.15.1 (bnc#1012628).
- x86/efi: Clarify that reset attack mitigation needs appropriate
  userspace (bnc#1012628).
- Input: synaptics-rmi4 - do not delete interrupt memory too early
  (bnc#1012628).
- Input: synaptics-rmi4 - unmask F03 interrupts when port is
  opened (bnc#1012628).
- test_firmware: fix missing unlock on error in
  config_num_requests_store() (bnc#1012628).
- iio: chemical: ccs811: Fix output of IIO_CONCENTRATION channels
  (bnc#1012628).
- iio: adc: stm32: fix scan of multiple channels with DMA
  (bnc#1012628).
- spi: imx: do not access registers while clocks disabled
  (bnc#1012628).
- serial: imx: Only wakeup via RTSDEN bit if the system has
  RTS/CTS (bnc#1012628).
- serial: 8250_dw: Revert "Improve clock rate setting"
  (bnc#1012628).
- serial: 8250_uniphier: fix error return code in
  uniphier_uart_probe() (bnc#1012628).
- serial: 8250_of: fix return code when probe function fails to
  get reset (bnc#1012628).
- mei: me: allow runtime pm for platform with D0i3 (bnc#1012628).
- android: binder: use VM_ALLOC to get vm area (bnc#1012628).
- ANDROID: binder: remove waitqueue when thread exits
  (bnc#1012628).
- usb/gadget: Fix "high bandwidth" check in
  usb_gadget_ep_match_desc() (bnc#1012628).
- usb: uas: unconditionally bring back host after reset
  (bnc#1012628).
- usb: f_fs: Prevent gadget unbind if it is already unbound
  (bnc#1012628).
- USB: serial: simple: add Motorola Tetra driver (bnc#1012628).
- usbip: list: don't list devices attached to vhci_hcd
  (bnc#1012628).
- usbip: prevent bind loops on devices attached to vhci_hcd
  (bnc#1012628).
- USB: serial: io_edgeport: fix possible sleep-in-atomic
  (bnc#1012628).
- CDC-ACM: apply quirk for card reader (bnc#1012628).
- USB: cdc-acm: Do not log urb submission errors on disconnect
  (bnc#1012628).
- USB: serial: pl2303: new device id for Chilitag (bnc#1012628).
- usb: option: Add support for FS040U modem (bnc#1012628).
- tty: fix data race between tty_init_dev and flush of buf
  (bnc#1012628).
- staging: ccree: fix fips event irq handling build (bnc#1012628).
- staging: ccree: NULLify backup_info when unused (bnc#1012628).
- staging: lustre: separate a connection destroy from free struct
  kib_conn (bnc#1012628).
- scsi: storvsc: missing error code in storvsc_probe()
  (bnc#1012628).
- scsi: aacraid: Fix hang in kdump (bnc#1012628).
- scsi: aacraid: Fix udev inquiry race condition (bnc#1012628).
- ima/policy: fix parsing of fsuuid (bnc#1012628).
- igb: Free IRQs when device is hotplugged (bnc#1012628).
- mtd: nand: denali_pci: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- gpio: ath79: add missing MODULE_DESCRIPTION/LICENSE
  (bnc#1012628).
- gpio: iop: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bnc#1012628).
- power: reset: zx-reboot: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bnc#1012628).
- HID: wacom: Fix reporting of touch toggle
  (WACOM_HID_WD_MUTE_DEVICE) events (bnc#1012628).
- HID: wacom: EKR: ensure devres groups at higher indexes are
  released (bnc#1012628).
- crypto: af_alg - whitelist mask and type (bnc#1012628).
- crypto: sha3-generic - fixes for alignment and big endian
  operation (bnc#1012628).
- crypto: inside-secure - avoid unmapping DMA memory that was
  not mapped (bnc#1012628).
- crypto: inside-secure - fix hash when length is a multiple of
  a block (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the AAD buffer in
  generic-gcm-aesni (bnc#1012628).
- crypto: aesni - Fix out-of-bounds access of the data buffer
  in generic-gcm-aesni (bnc#1012628).
- crypto: aesni - add wrapper for generic gcm(aes) (bnc#1012628).
- crypto: aesni - fix typo in generic_gcmaes_decrypt
  (bnc#1012628).
- crypto: aesni - handle zero length dst buffer (bnc#1012628).
- crypto: ecdh - fix typo in KPP dependency of CRYPTO_ECDH
  (bnc#1012628).
- ALSA: hda - Reduce the suspend time consumption for ALC256
  (bnc#1012628).
- gpio: Fix kernel stack leak to userspace (bnc#1012628).
- gpio: stmpe: i2c transfer are forbiden in atomic context
  (bnc#1012628).
- tools/gpio: Fix build error with musl libc (bnc#1012628).
- Bluetooth: hci_serdev: Init hci_uart proto_lock to avoid oops
  (bnc#1012628).
- commit 671bf29
* Thu Feb  1 2018 matwey.kornilov@gmail.com
- config: arm64: Enable RockChip 8xx
  We need RockChip RK-808 support to run openSUSE on Rock64 board (RK3328).
  Currently, even voltage regulator is missed.
- commit a348749
* Mon Jan 29 2018 jeffm@suse.com
- Update to 4.15-final.
- Eliminated 5 patches.
- commit 36830f7
* Mon Jan 29 2018 jeffm@suse.com
- btrfs: fix btrfs_evict_inode to handle abnormal inodes correctly (bsc#1078019).
- commit d3f1d2c
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable UNMAP_KERNEL_AT_EL0 and HARDEN_BRANCH_PREDICTOR
- commit c41900c
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- arm64: Turn on KPTI only on CPUs that need it (bsc#1068032).
- arm64: Branch predictor hardening for Cavium ThunderX2
  (bsc#1068032).
- arm64: Run enable method for errata work arounds on late CPUs
  (bsc#1068032).
- arm64: Move BP hardening to check_and_switch_context
  (bsc#1068032).
- arm: KVM: Invalidate icache on guest exit for Cortex-A15
  (bsc#1068032).
- arm: Invalidate icache on prefetch abort outside of user
  mapping on Cortex-A15 (bsc#1068032).
- arm: Add icache invalidation on switch_mm for Cortex-A15
  (bsc#1068032).
- arm: KVM: Invalidate BTB on guest exit (bsc#1068032).
- arm: Invalidate BTB on prefetch abort outside of user mapping
  on Cortex A8, A9, A12 and A17 (bsc#1068032).
- arm: Add BTB invalidation on switch_mm for Cortex-A9, A12 and
  A17 (bsc#1068032).
- arm64: cputype: Add MIDR values for Cavium ThunderX2 CPUs
  (bsc#1068032).
- arm64: Implement branch predictor hardening for Falkor
  (bsc#1068032).
- arm64: Implement branch predictor hardening for affected
  Cortex-A CPUs (bsc#1068032).
- arm64: cputype: Add missing MIDR values for Cortex-A72 and
  Cortex-A75 (bsc#1068032).
- arm64: KVM: Make PSCI_VERSION a fast path (bsc#1068032).
- arm64: KVM: Use per-CPU vector when BP hardening is enabled
  (bsc#1068032).
- arm64: Add skeleton to harden the branch predictor against
  aliasing attacks (bsc#1068032).
- arm64: Move post_ttbr_update_workaround to C code (bsc#1068032).
- drivers/firmware: Expose psci_get_version through psci_ops
  structure (bsc#1068032).
- arm64: Take into account ID_AA64PFR0_EL1.CSV3 (bsc#1068032).
- arm64: Kconfig: Reword UNMAP_KERNEL_AT_EL0 kconfig entry
  (bsc#1068032).
- arm64: use RET instruction for exiting the trampoline
  (bsc#1068032).
- arm64: capabilities: Handle duplicate entries for a capability
  (bsc#1068032).
- arm64: cpufeature: Pass capability structure to ->enable
  callback (bsc#1068032).
- arm64: kpti: Fix the interaction between ASID switching and
  software PAN (bsc#1068032).
- arm64: kaslr: Put kernel vectors address in separate data page
  (bsc#1068032).
- arm64: mm: Introduce TTBR_ASID_MASK for getting at the ASID
  in the TTBR (bsc#1068032).
- perf: arm_spe: Fail device probe when
  arm64_kernel_unmapped_at_el0() (bsc#1068032).
- arm64: Kconfig: Add CONFIG_UNMAP_KERNEL_AT_EL0 (bsc#1068032).
- arm64: entry: Add fake CPU feature for unmapping the kernel
  at EL0 (bsc#1068032).
- arm64: tls: Avoid unconditional zeroing of tpidrro_el0 for
  native tasks (bsc#1068032).
- arm64: erratum: Work around Falkor erratum #E1003 in trampoline
  code (bsc#1068032).
- arm64: entry: Hook up entry trampoline to exception vectors
  (bsc#1068032).
- arm64: entry: Explicitly pass exception level to kernel_ventry
  macro (bsc#1068032).
- arm64: mm: Map entry trampoline into trampoline and kernel
  page tables (bsc#1068032).
- arm64: entry: Add exception trampoline page for exceptions
  from EL0 (bsc#1068032).
- arm64: mm: Invalidate both kernel and user ASIDs when performing
  TLBI (bsc#1068032).
- arm64: mm: Add arm64_kernel_unmapped_at_el0 helper
  (bsc#1068032).
- arm64: mm: Allocate ASIDs in pairs (bsc#1068032).
- arm64: mm: Fix and re-enable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Rename post_ttbr0_update_workaround (bsc#1068032).
- arm64: mm: Remove pre_ttbr0_update_workaround for Falkor
  erratum #E1003 (bsc#1068032).
- arm64: mm: Move ASID from TTBR0 to TTBR1 (bsc#1068032).
- arm64: mm: Temporarily disable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Use non-global mappings for kernel space
  (bsc#1068032).
- commit cdf2ded
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable rk3399 missing drivers
  These drivers are required for Rockchip RK3399 Sapphire board
- commit 94b8551
* Fri Jan 26 2018 jslaby@suse.cz
- x86/ibrs: Add new helper macros to save/restore
  MSR_IA32_SPEC_CTRL fix (bsc#1068032 CVE-2017-5753).
- commit 13295d4
* Thu Jan 25 2018 jslaby@suse.cz
- x86/cpufeature: Move processor tracing out of scattered features
  (bsc#1068032 CVE-2017-5753).
- Refresh
  patches.suse/0001-x86-cpufeatures-Add-CPUID_7_EDX-CPUID-leaf.patch.
- Refresh
  patches.suse/0007-x86-speculation-Add-basic-IBPB-Indirect-Branch-Predi.patch.
- commit 8d8b718
* Wed Jan 24 2018 jslaby@suse.cz
- x86/retpoline: Add LFENCE to the retpoline/RSB filling RSB
  macros (bsc#1068032 CVE-2017-5753).
- commit 8dc7c71
* Wed Jan 24 2018 jslaby@suse.cz
- x86/vmx: Direct access to MSR_IA32_SPEC_CTRL (bsc#1068032
  CVE-2017-5753).
- x86/ibrs: Add new helper macros to save/restore
  MSR_IA32_SPEC_CTRL (bsc#1068032 CVE-2017-5753).
- x86/enter: Use IBRS on syscall and interrupts (bsc#1068032
  CVE-2017-5753).
- x86/enter: Create macros to restrict/unrestrict Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/idle: Control Indirect Branch Speculation in idle
  (bsc#1068032 CVE-2017-5753).
- x86: Simplify spectre_v2 command line parsing (bsc#1068032
  CVE-2017-5753).
- x86/speculation: Add inlines to control Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5753).
- x86/mm: Only flush indirect branches when switching into non
  dumpable process (bsc#1068032 CVE-2017-5753).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5753).
- x86/kvm: Add IBPB support (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add basic IBPB (Indirect Branch Prediction
  Barrier) support (bsc#1068032 CVE-2017-5753).
- x86/cpufeature: Blacklist SPEC_CTRL on early Spectre v2
  microcodes (bsc#1068032 CVE-2017-5753).
- x86/pti: Do not enable PTI on processors which are not
  vulnerable to Meltdown (bsc#1068032 CVE-2017-5753).
- x86/msr: Add definitions for new speculation control MSRs
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add AMD feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add Intel feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5753).
- x86/cpufeatures: Add CPUID_7_EDX CPUID leaf (bsc#1068032
  CVE-2017-5753).
- x86/retpoline: Optimize inline assembler for vmexit_fill_RSB
  (bsc#1068032 CVE-2017-5753).
- x86/retpoline: Fill RSB on context switch for affected CPUs
  (bsc#1068032 CVE-2017-5753).
- commit e36ab4f
* Wed Jan 24 2018 jslaby@suse.cz
- Documentation: document array_ptr (bsc#1068032 CVE-2017-5715).
- asm/nospec, array_ptr: sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5715).
- x86: implement array_ptr_mask() (bsc#1068032 CVE-2017-5715).
- x86: introduce __uaccess_begin_nospec and ifence (bsc#1068032
  CVE-2017-5715).
- x86, __get_user: use __uaccess_begin_nospec (bsc#1068032
  CVE-2017-5715).
- x86, get_user: use pointer masking to limit speculation
  (bsc#1068032 CVE-2017-5715).
- x86: narrow out of bounds syscalls to sys_read under speculation
  (bsc#1068032 CVE-2017-5715).
- vfs, fdtable: prevent bounds-check bypass via speculative
  execution (bsc#1068032 CVE-2017-5715).
- kvm, x86: update spectre-v1 mitigation (bsc#1068032
  CVE-2017-5715).
- nl80211: sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5715).
- Delete
  patches.suse/0003-locking-barriers-introduce-new-observable-speculatio.patch.
- Delete
  patches.suse/0004-bpf-prevent-speculative-execution-in-eBPF-interprete.patch.
- Delete
  patches.suse/0005-x86-bpf-jit-prevent-speculative-execution-when-JIT-i.patch.
- Delete
  patches.suse/0006-uvcvideo-prevent-speculative-execution.patch.
- Delete
  patches.suse/0007-carl9170-prevent-speculative-execution.patch.
- Delete
  patches.suse/0008-p54-prevent-speculative-execution.patch.
- Delete
  patches.suse/0009-qla2xxx-prevent-speculative-execution.patch.
- Delete
  patches.suse/0010-cw1200-prevent-speculative-execution.patch.
- Delete
  patches.suse/0011-Thermal-int340x-prevent-speculative-execution.patch.
- Delete
  patches.suse/0012-ipv4-prevent-speculative-execution.patch.
- Delete
  patches.suse/0013-ipv6-prevent-speculative-execution.patch.
- Delete patches.suse/0014-fs-prevent-speculative-execution.patch.
- Delete
  patches.suse/0015-net-mpls-prevent-speculative-execution.patch.
- Delete
  patches.suse/0016-udf-prevent-speculative-execution.patch.
- Delete
  patches.suse/0017-userns-prevent-speculative-execution.patch.
  Replace by the potential upstream solution.
- commit 804f8a1
* Mon Jan 22 2018 msuchanek@suse.de
- rpm/mkspec-dtb: Remove COPYING file (bsc#1076905).
  It conflicts between different versions of dtb package.
- commit 0e5fcf9
* Thu Jan 18 2018 jslaby@suse.cz
- Update config files (bsc#1068032 CVE-2017-5715).
  Enable RETPOLINE -- the compiler is capable of them already.
- commit 5d5345e
* Wed Jan 17 2018 rjschwei@suse.com
- kernel-obs-build.spec.in: enable xfs module
  This allows the public cloud team to build images with XFS
  as root filesystem
- commit 95a2d6f
* Wed Jan 17 2018 msuchanek@suse.de
- macros.kernel-source: pass -f properly in module subpackage (boo#1076393).
- commit 66bd9b8
* Mon Jan 15 2018 jeffm@suse.com
- Update to 4.15-rc8.
- Eliminated 3 patches.
- Config changes:
  - Security:
  - BPF_JIT_ALWAYS_ON=y
  - RETPOLINE=n (depends on gcc with -mindirect-branch=thunk-extern)
- commit 05e4405
* Fri Jan 12 2018 jslaby@suse.cz
- bpf, array: fix overflow in max_entries and undefined behavior
  in index_mask (bsc#1068032 CVE-2017-5753).
- commit 5fdfc1a
* Fri Jan 12 2018 jslaby@suse.cz
- bpf: prevent out-of-bounds speculation (bsc#1068032
  CVE-2017-5753).
- commit 0eca303
* Thu Jan 11 2018 matwey.kornilov@gmail.com
- config: arm64: Enable Aardvark PCIe controller
  Aardvark PCIe controller is a part of Marvel Armada 3700 SoC.
  This option is required to support PCIe for JeOS-espressobin.
- commit b0bb655
* Thu Jan 11 2018 lpechacek@suse.com
- rpm/kernel-binary.spec.in: more specific kGraft Provides: (fate#323682)
  Follow openSUSE packaging practices described at
  https://en.opensuse.org/openSUSE:Package_dependencies#Renaming_a_package.
- commit 050081b
* Wed Jan 10 2018 jslaby@suse.cz
- x86/cpu/AMD: Make LFENCE a serializing instruction (bsc#1068032
  CVE-2017-5754).
- x86/cpu/AMD: Use LFENCE_RDTSC in preference to MFENCE_RDTSC
  (bsc#1068032 CVE-2017-5754).
- Delete
  patches.suse/0001-x86-cpu-AMD-Make-the-LFENCE-instruction-serialized.patch.
- Delete
  patches.suse/0002-x86-cpu-AMD-Remove-now-unused-definition-of-MFENCE_R.patch.
  Use the variants from upstream (tip tree).
- commit 33b16eb
* Mon Jan  8 2018 msuchanek@suse.de
- kernel-obs-build.spec.in: add --no-hostonly-cmdline to dracut invocation (boo#1062303).
  call dracut with --no-hostonly-cmdline to avoid the random rootfs UUID
  being added into the initrd's /etc/cmdline.d/95root-dev.conf
- commit da5186f
* Mon Jan  8 2018 jeffm@suse.com
- Update to 4.15-rc7.
- Eliminated 1 patch.
- commit b07c570
* Sat Jan  6 2018 jslaby@suse.cz
- rpm/constraints.in: lower kernel-syzkaller's mem requirements
  OBS now reports that it needs only around 2G, so lower the limit to
  8G, so that more compliant workers can be used.
- commit a73399a
* Wed Jan  3 2018 jeffm@suse.com
- config: x86, PAGE_TABLE_ISOLATION=y (bsc#1068032).
- commit 4343d87
* Tue Jan  2 2018 jslaby@suse.cz
- userns: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- udf: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- net: mpls: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- fs: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv6: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- ipv4: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- Thermal/int340x: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- cw1200: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- qla2xxx: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- p54: prevent speculative execution (bnc#1068032 CVE-2017-5753).
- carl9170: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- uvcvideo: prevent speculative execution (bnc#1068032
  CVE-2017-5753).
- x86, bpf, jit: prevent speculative execution when JIT is enabled
  (bnc#1068032 CVE-2017-5753).
- bpf: prevent speculative execution in eBPF interpreter
  (bnc#1068032 CVE-2017-5753).
- locking/barriers: introduce new observable speculation barrier
  (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC
  feature (bnc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Make the LFENCE instruction serialized (bnc#1068032
  CVE-2017-5753).
- commit ee4aa62
* Tue Jan  2 2018 jeffm@suse.com
- Update to 4.15-rc6.
- Config changes:
  - x86: PAGE_TABLE_ISOLATION=n (default, performance)
- commit cd70bd8
* Mon Dec 25 2017 jeffm@suse.com
- config: disable BUG_ON_DATA_CORRUPTION
  On its face this option makes sense but it brings along with it
  DEBUG_LIST, which is very expensive and obvious on benchmarks.
- commit 9fcc9f1
* Mon Dec 25 2017 jeffm@suse.com
- config: refresh i386/default
  Commit 4735d41aeeb added a disabled CONFIG_SPI_INTEL_SPI_PLATFORM option
  that doesn't exist on i386/default (at least in 4.15-rc5).
- commit 84167ae
* Sun Dec 24 2017 jeffm@suse.com
- Update to 4.15-rc5.
- Config changes:
  - i386: NR_CPUS 128->64
  - 7bbcbd3d1cd (x86/Kconfig: Limit NR_CPUS on 32-bit to a sane amount)
- commit 9e8deb3
* Thu Dec 21 2017 msuchanek@suse.de
- kernel-obs-build: use pae and lpae kernels where available
  (bsc#1073579).
- commit 1ac1946
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PCI as well (bsc#1073836)
- commit ddb33b2
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PLATFORM for BIOS breakge on Lenovo laptops
  (bsc#1073836)
- commit 4735d41
* Tue Dec 19 2017 jeffm@suse.com
- Update to 4.15-rc4.
- Eliminated 1 patch.
- Config changes:
  - ARM:
  - QCOM_FALKOR_ERRATUM_E1041=y
  - Overlayfs:
  - OVERLAY_FS_REDIRECT_ALWAYS_FOLLOW=y (preserves existing behavior)
- commit ff8819c
* Fri Dec 15 2017 jslaby@suse.cz
- x86/stacktrace: make clear the success paths (bnc#1058115).
- Refresh
  patches.suse/0003-x86-stacktrace-remove-STACKTRACE_DUMP_ONCE-from-__sa.patch.
- Refresh
  patches.suse/0004-x86-stacktrace-do-not-fail-for-ORC-with-regs-on-stac.patch.
- Delete
  patches.suse/0002-x86-stacktrace-remove-unwind_state-error.patch.
  Fix livepatch to succeed also for kthreads and idle tasks.
- commit 5292470
* Wed Dec 13 2017 msuchanek@suse.de
- s390/sclp: disable FORTIFY_SOURCE for early sclp code (-).
- commit 62412b6
* Mon Dec 11 2017 jeffm@suse.com
- Update to 4.15-rc3.
- Eliminated 1 patch.
- commit 383d72f
* Sat Dec  9 2017 afaerber@suse.de
- config: armv7hl: Enable SUN4I_A10_CCU for Allwinner A20 (boo#1072032)
- commit 170d177
* Fri Dec  8 2017 msuchanek@suse.de
- Add undefine _unique_build_ids (bsc#964063)
- commit 47e91a1
* Tue Dec  5 2017 jslaby@suse.cz
- x86/stacktrace: do now unwind after user regs (bnc#1058115).
- x86/stacktrace: remove unwind_state->error (bnc#1058115).
- x86/stacktrace: remove STACKTRACE_DUMP_ONCE from
  __save_stack_trace_reliable (bnc#1058115).
- x86/stacktrace: do not fail for ORC with regs on stack
  (bnc#1058115).
  More make-ORC-reliable patches.
- commit ef715eb
* Mon Dec  4 2017 jeffm@suse.com
- Update to 4.15-rc2.
- Eliminated 2 patches.
- commit 68549b6
* Thu Nov 30 2017 jslaby@suse.cz
- Refresh
  patches.suse/apparmor-fix-oops-in-audit_signal_cb-hook.patch.
  Update upstream status.
- commit ee861fd
* Thu Nov 30 2017 jslaby@suse.cz
- mmc: sdhci: Avoid swiotlb buffer being full (bnc#1068877).
- commit 2659efd
* Wed Nov 29 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: fix incorrectly moved comment
  While moving # END COMMON DEPS moved following comment with it.
- commit 858b7e7
* Tue Nov 28 2017 afaerber@suse.de
- config: armv7hl: Update to 4.15-rc1
- commit b4c7f19
* Tue Nov 28 2017 afaerber@suse.de
- config: armv6hl: Update to 4.15-rc1
- commit edcdf48
* Tue Nov 28 2017 afaerber@suse.de
- config: arm64: Update to 4.15-rc1
- commit 3278861
* Mon Nov 27 2017 jeffm@suse.com
- Update to 4.15-rc1.
- Eliminated 74 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - CPU_ISOLATION=y
  - GUP_BENCHMARK=n
  - x86:
  - X86_INTEL_UMIP=y
  - PINCTRL_CEDARFORK=m
  - INTEL_SOC_PMIC_CHTDC_TI=m
  - INTEL_WMI_THUNDERBOLT=m
  - DELL_SMBIOS_WMI=m
  - DELL_SMBIOS_SMM=m
  - CHT_DC_TI_PMIC_OPREGION=y
  - RPMSG_CHAR=m
  - i386:
  - IR_SPI=m
  - IR_GPIO_CIR=m
  - IR_GPIO_TX=m
  - IR_PWM_TX=m
  - powerpc:
  - PPC_RADIX_MMU_DEFAULT=y (default)
  - MEM_SOFT_DIRTY=n (needs arch expert review)
  - PINCTRL=n
  - PPC_FAST_ENDIAN_SWITCH=n (default)
  - s390:
  - GCC_PLUGINS=n
  - MEM_SOFT_DIRTY=(needs arch expert review)
  - PINCTRL=n
  - FORTIFY_SOURCE=y
  - s390/zfcpdump:
  - BPF_STREAM_PARSER=n
  - MTD=n
  - Network:
  - NET_SCH_CBS=m
  - VSOCKETS_DIAG=m
  - DP83822_PHY=m
  - RENESAS_PHY=m
  - THUNDERBOLT_NET=m
  - Input:
  - TOUCHSCREEN_EXC3000=m
  - TOUCHSCREEN_HIDEEP=m
  - TOUCHSCREEN_S6SY761=m
  - DRM_I2C_ADV7511_CEC=y
  - Misc:
  - IPMI_PROC_INTERFACE=y
  - GPIO_MAX3191X=m
  - MANAGER_SBS=m
  - W1_SLAVE_DS28E17=m
  - SENSORS_MAX6621=m
  - SENSORS_MAX31785=m
  - CEC_GPIO=m
  - TYPEC_TPS6598X=m
  - RPMSG_VIRTIO=m
  - IIO_CROS_EC_ACCEL_LEGACY=m
  - RFD77402=m
  - NTB_SWITCHTEC=m
  - MMC_SDHCI_OMAP=m
  - Filesystems:
  - XFS_ONLINE_SCRUB=n (still experimental)
  - BTRFS_FS_REF_VERIFY=n
  - CRAMFS_BLOCKDEV=y
  - CRAMFS_MTD=y
  - INTEGRITY_TRUSTED_KEYRING=y
  - Crypto:
  - CRYPTO_SM3=m
  - SIGNED_PE_FILE_VERIFICATION=y
  - SYSTEM_TRUSTED_KEYS (empty)
  - SYSTEM_EXTRA_CERTIFICATE=n
  - SECONDARY_TRUSTED_KEYRING=n
  - LEDS:
  - LEDS_APU=m
  - LEDS_TRIGGER_ACTIVITY=m
  - RTC:
  - RTC_DRV_PCF85363=m
  - Xen:
  - XEN_PVCALLS_FRONTEND=n
  - Graphics:
  - DRM_AMD_DC=y
  - DRM_AMD_DC_PRE_VEGA=y
  - DRM_AMD_DC_FBC=y ?
  - DRM_AMD_DC_DCN1_0=y
  - DEBUG_KERNEL_DC=n
  - NOUVEAU_DEBUG_MMU=n
  - Storage:
  - NVME_MULTIPATH=y
  - IB:
  - MLX4_CORE_GEN2=y
  - Sound:
  - SND_SOC_INTEL_SST_TOPLEVEL=m
  - SND_SOC_INTEL_BAYTRAIL=m
  - Testing:
  - KCOV_ENABLE_COMPARISONS=y (syzkaller)
  - BOOTPARAM_LOCKDEP_CROSSRELEASE_FULLSTACK=n
  - PREEMPTIRQ_EVENTS=y
  - TEST_FIND_BIT=n
  - PKCS7_TEST_KEY=n
  - CHASH_SELFTEST=n
  - CHASH_STATS=n
- commit bc47c49
* Sun Nov 26 2017 afaerber@suse.de
- config: armv6hl: Enable 8250 irq sharing for RPi Zero W (boo#1069828)
- commit 01942c4
* Sat Nov 25 2017 afaerber@suse.de
- config: armv6hl: Enable brcmfmac for RPi Zero W (boo#1069830)
- commit 56423d9
* Sat Nov 25 2017 afaerber@suse.de
- config: armv6hl: Enable 8250 serial console for RPi Zero W (boo#1069828)
- commit 3a3001a
* Fri Nov 24 2017 bp@suse.de
- dvb_frontend: don't use-after-free the frontend struct
  (bsc#1067087 CVE-2017-16648).
- media: dvb-core: always call invoke_release() in fe_free()
  (bsc#1067087).
- commit 2a04ad0
* Fri Nov 24 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Correct supplements for recent SLE products (bsc#1067494)
- commit 8f05b9f
* Fri Nov 24 2017 jbeulich@suse.com
- supported:conf: Remove stale Xen driver entries.
- commit c46464b
* Fri Nov 24 2017 jslaby@suse.cz
- ipmi_si: fix memory leak on new_smi (git-fixes).
- commit 4ca3b35
* Fri Nov 24 2017 jslaby@suse.cz
- Linux 4.14.2 (bnc#1012628).
- af_netlink: ensure that NLMSG_DONE never fails in dumps
  (bnc#1012628).
- vxlan: fix the issue that neigh proxy blocks all icmpv6 packets
  (bnc#1012628).
- net: cdc_ncm: GetNtbFormat endian fix (bnc#1012628).
- fealnx: Fix building error on MIPS (bnc#1012628).
- net/sctp: Always set scope_id in sctp_inet6_skb_msgname
  (bnc#1012628).
- ima: do not update security.ima if appraisal status is not
  INTEGRITY_PASS (bnc#1012628).
- serial: omap: Fix EFR write on RTS deassertion (bnc#1012628).
- serial: 8250_fintek: Fix finding base_port with activated
  SuperIO (bnc#1012628).
- tpm-dev-common: Reject too short writes (bnc#1012628).
- rcu: Fix up pending cbs check in rcu_prepare_for_idle
  (bnc#1012628).
- mm/pagewalk.c: report holes in hugetlb ranges (bnc#1012628).
- ocfs2: fix cluster hang after a node dies (bnc#1012628).
- ocfs2: should wait dio before inode lock in ocfs2_setattr()
  (bnc#1012628).
- ipmi: fix unsigned long underflow (bnc#1012628).
- mm/page_alloc.c: broken deferred calculation (bnc#1012628).
- mm/page_ext.c: check if page_ext is not prepared (bnc#1012628).
- coda: fix 'kernel memory exposure attempt' in fsync
  (bnc#1012628).
- ipmi: Prefer ACPI system interfaces over SMBIOS ones
  (bnc#1012628).
- commit 295c90a
* Thu Nov 23 2017 jslaby@suse.cz
- apparmor: fix oops in audit_signal_cb hook (bnc#1069562).
- Refresh patches.suse/0001-AppArmor-basic-networking-rules.patch.
- commit d091ad8
* Thu Nov 23 2017 jslaby@suse.cz
- bio: ensure __bio_clone_fast copies bi_partno (bnc#1069605).
- commit 59c6ade
* Tue Nov 21 2017 jslaby@suse.cz
- Update config files.
  After renaming the UNWINDER config options, vanilla has the old names
  and they need to be in configs. For example, x86_64 default config
  has CONFIG_UNWINDER_ORC=y, vanilla has CONFIG_ORC_UNWINDER=y.
- commit d0dab46
* Tue Nov 21 2017 jslaby@suse.cz
- objtool: Print top level commands on incorrect usage
  (bnc#1058115).
- commit 6603336
* Tue Nov 21 2017 jslaby@suse.cz
- x86/unwind: Make CONFIG_UNWINDER_ORC=y the default in kconfig
  for 64-bit (bnc#1058115).
- Update config files.
- x86/unwind: Rename unwinder config options to
  'CONFIG_UNWINDER_*' (bnc#1058115).
- Refresh patches.suse/0001-orc-mark-it-as-reliable.patch.
- Update config files.
- x86/unwinder: Make CONFIG_UNWINDER_ORC=y the default in the
  64-bit defconfig (bnc#1058115).
- commit c81ce89
* Tue Nov 21 2017 jslaby@suse.cz
- x86/stacktrace: Avoid recording save_stack_trace() wrappers
  (bnc#1058115).
- commit fa72e96
* Tue Nov 21 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
  Update upstream status.
- commit f655f80
* Tue Nov 21 2017 jslaby@suse.cz
- move all patches to patches.suse/
- commit 6fafae6
* Tue Nov 21 2017 jslaby@suse.cz
- Linux 4.14.1 (bnc#1012628).
- EDAC, sb_edac: Don't create a second memory controller if HA1
  is not present (bnc#1012628).
- dmaengine: dmatest: warn user when dma test times out
  (bnc#1012628).
- crypto: dh - Fix double free of ctx->p (bnc#1012628).
- crypto: dh - Don't permit 'p' to be 0 (bnc#1012628).
- crypto: dh - Don't permit 'key' or 'g' size longer than 'p'
  (bnc#1012628).
- crypto: brcm - Explicity ACK mailbox message (bnc#1012628).
- USB: early: Use new USB product ID and strings for DbC device
  (bnc#1012628).
- USB: usbfs: compute urb->actual_length for isochronous
  (bnc#1012628).
- USB: Add delay-init quirk for Corsair K70 LUX keyboards
  (bnc#1012628).
- usb: gadget: f_fs: Fix use-after-free in ffs_free_inst
  (bnc#1012628).
- USB: serial: metro-usb: stop I/O after failed open
  (bnc#1012628).
- USB: serial: Change DbC debug device binding ID (bnc#1012628).
- USB: serial: qcserial: add pid/vid for Sierra Wireless EM7355
  fw update (bnc#1012628).
- USB: serial: garmin_gps: fix I/O after failed probe and remove
  (bnc#1012628).
- USB: serial: garmin_gps: fix memory leak on probe errors
  (bnc#1012628).
- selftests/x86/protection_keys: Fix syscall NR redefinition
  warnings (bnc#1012628).
- x86/MCE/AMD: Always give panic severity for UC errors in kernel
  context (bnc#1012628).
- platform/x86: peaq-wmi: Add DMI check before binding to the
  WMI interface (bnc#1012628 bsc#1059807).
- platform/x86: peaq_wmi: Fix missing terminating entry for
  peaq_dmi_table (bnc#1012628).
- HID: cp2112: add HIDRAW dependency (bnc#1012628).
- HID: wacom: generic: Recognize WACOM_HID_WD_PEN as a type of
  pen collection (bnc#1012628).
- rpmsg: glink: Add missing MODULE_LICENSE (bnc#1012628).
- staging: wilc1000: Fix bssid buffer offset in Txq (bnc#1012628).
- staging: sm750fb: Fix parameter mistake in poke32 (bnc#1012628).
- staging: ccree: fix 64 bit scatter/gather DMA ops (bnc#1012628).
- staging: greybus: spilib: fix use-after-free after
  deregistration (bnc#1012628).
- staging: vboxvideo: Fix reporting invalid
  suggested-offset-properties (bnc#1012628).
- staging: rtl8188eu: Revert 4 commits breaking ARP (bnc#1012628).
- spi: fix use-after-free at controller deregistration
  (bnc#1012628).
- sparc32: Add cmpxchg64() (bnc#1012628).
- sparc64: mmu_context: Add missing include files (bnc#1012628).
- sparc64: Fix page table walk for PUD hugepages (bnc#1012628).
- commit b1ba0c0
* Wed Nov 15 2017 rgoldwyn@suse.com
- apparmor: Fix quieting of audit messages for network mediation
  (FATE#300516, boo#1065536).
- apparmor: update apparmor-basic-networking-rules for 4.11-rc1
  (FATE#300516, boo#1065536).
- AppArmor: basic networking rules (FATE#300516, boo#1065536).
- commit fca1de8
* Wed Nov 15 2017 rgoldwyn@suse.com
- VFS: Handle lazytime in do_mount() (boo#1068256).
- commit 0f12060
* Mon Nov 13 2017 jeffm@suse.com
- Update to 4.14-final.
- commit c152297
* Thu Nov  9 2017 lpechacek@suse.com
- rpm/kernel-binary.spec.in: rename kGraft to KLP (fate#323682)
- commit 0ed191d
* Wed Nov  8 2017 tiwai@suse.de
- media: dib0700: fix invalid dvb_detach argument (CVE-2017-16646
  bsc#1067105).
- commit c6cd519
* Mon Nov  6 2017 jeffm@suse.com
- Update to 4.14-rc8.
- commit 0fbdeee
* Mon Nov  6 2017 tiwai@suse.de
- media: imon: Fix null-ptr-deref in imon_probe (CVE-2017-16537
  bsc#1066573).
- [media] cx231xx-cards: fix NULL-deref on missing association
  descriptor (CVE-2017-16536 bsc#1066606).
- commit 0cd38c2
* Mon Nov  6 2017 jkosina@suse.cz
- rpm/kernel-binary.spec.in: add explicit dependency of kernel-*-devel on
  libelf-devel.
  Otherwise warning that got turned into error by upstream 3dd40cb3 ("objtool:
  Upgrade libelf-devel warning to error...") would trigger and cause any
  packages being built against kernel-*-devel (such as KMPs, crash) not to have
  the libelf dependency included, and fail to build.
- rpm/kernel-binary.spec.in: add explicit dependency of kernel-*-devel on
  libelf-devel. Otherwise warning that got turned into error by e683952999
  ("objtool: Upgrade libelf-devel warning to error...") would trigger and
  cause any packages being built against kernel-*-devel (such as KMPs,
  crash) not to have the libelf dependency included, and fail to build.
- commit f6c0f80
* Mon Oct 30 2017 neilb@suse.com
- REVERT:  md/bitmap: copy correct data for bitmap super
  (bsc#1062597).
- commit 9382440
* Mon Oct 30 2017 jeffm@suse.com
- Update to 4.14-rc7.
- commit dbf3e9b
* Fri Oct 27 2017 jslaby@suse.cz
- futex: futex_wake_op, fix sign_extend32 sign bits (bnc#1064590).
- commit a6d946f
* Thu Oct 26 2017 neilb@suse.com
- VFS: expedite unmount (bsc#1024412).
- commit 10c4365
* Mon Oct 23 2017 jeffm@suse.com
- Update to 4.14-rc6.
- Eliminated 2 patches.
- commit 8b364ca
* Wed Oct 18 2017 mcgrof@suse.com
- mac80211: accept key reinstall without changing anything (CVE-2017-13080 bsc#1063667).
- commit 19d19fc
* Mon Oct 16 2017 jeffm@suse.com
- Update to 4.14-rc5.
- commit 39eecab
* Fri Oct 13 2017 msuchanek@suse.de
- Revert "rpm/constraints.in: Lower default disk space requirement from 25G to 24G"
  This reverts commit 406abda1467c038842febffe264faae1fa2e3c1d.
  ok, did not wait long enough to see the failure.
- commit ed99981
* Fri Oct 13 2017 msuchanek@suse.de
- rpm/constraints.in: Lower default disk space requirement from 25G to 24G
  25G is rejected by the build service on ARM.
- commit 406abda
* Mon Oct  9 2017 jeffm@suse.com
- Update to 4.14-rc4.
- commit 879f297
* Fri Oct  6 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: add the kernel-binary dependencies to
  kernel-binary-base (bsc#1060333).
- commit 955681c
* Fri Oct  6 2017 pmladek@suse.com
- Delete
  patches.suse/ftrace-x86-xen-use-kernel-identity-mapping-only-when.patch.
  The change is not longer needed with PVOPS Xen (bsc#873195).
- commit 8366b6a
* Thu Oct  5 2017 jeffm@suse.com
- Delete patches.rpmify/cloneconfig.diff.
- commit 437d08e
* Thu Oct  5 2017 jeffm@suse.com
- Only use patches.suse for patches.
  This eliminates patches.arch, patches.drivers, and patches.fixes, and moves
  the patches contained in them to patches.suse.
  Also update feedback for Patch-mainline tags.
- commit 343996e
* Wed Oct  4 2017 jeffm@suse.com
- Delete patches.suse/suse-hv-storvsc-sg_tablesize.patch.
  Per Olaf Hering, this is no longer needed.
- commit 83b19a6
* Wed Oct  4 2017 jslaby@suse.cz
- orc: mark it as reliable (bnc#1058115).
- Update config files.
- commit 3c7d429
* Wed Oct  4 2017 hare@suse.de
- Delete patches.fixes/sd_liberal_28_sense_invalid.diff.
- Delete patches.suse/dm-emulate-blkrrpart-ioctl.
- Delete patches.suse/scsi-netlink-ml.
- commit b8f0083
* Wed Oct  4 2017 agraf@suse.de
- Delete patches.arch/arm-OMAP-Fix-missing-usb.h-include.patch.
  (no longer needed)
- Delete patches.arch/arm-arndale-usb.patch. (no longer needed)
- Delete
  patches.arch/arm64-0006-arm64-Select-reboot-driver-for-X-Gene-platform.patch.
  (not needed, our config already includes the driver)
- Delete patches.arch/ppc64le-build-vmlinux.patch. (no longer needed)
- commit 2b9d327
* Tue Oct  3 2017 jeffm@suse.com
- Disable patches.suse/binutils2_26.patch for testing.
  The issue addressed by this patch should be handled via upstream
  commit 6d92bc9d483 (x86/build: Build compressed x86 kernels as PIE).
- commit f27997b
* Tue Oct  3 2017 neilb@suse.com
- Delete
  patches.fixes/0001-Revert-SUNRPC-xs_sock_mark_closed-does-not-need-to-t.patch.
  Not needed, bug was fixed some other way since that patch
  was created.
- commit d55ee70
* Tue Oct  3 2017 mgorman@suse.de
- Delete patches.suse/connector-read-mostly.
- commit 8ae100a
* Tue Oct  3 2017 jeffm@suse.com
- series.conf: remove commented out lines for removed patches
- commit 7ea9bcc
* Tue Oct  3 2017 jeffm@suse.com
- Delete patches.arch/arm-refresh-mach-types.diff.
  It was marked for refresh in 12/2016 and hasn't been updated.
- commit 8e357d7
* Mon Oct  2 2017 jeffm@suse.com
- Remove s390 message catalog patches.
- Delete patches.arch/kmsg-fix-parameter-limitations.
- Delete patches.arch/s390-message-catalog.diff.
- commit 865e88d
* Mon Oct  2 2017 jeffm@suse.com
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- commit 04a0a7a
* Mon Oct  2 2017 jeffm@suse.com
- Moved powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch to patches.rpmify.
  It's a compiler blacklist addition and should be applied to vanilla too.
- commit e34eae8
* Mon Oct  2 2017 jeffm@suse.com
- Update to 4.14-rc3.
- Eliminated 2 patches.
- Config changes:
  - Crypto:
  - Crypto changes brought by Kconfig changes:
  - CONFIG_CRYPTO_GHASH=y (Kconfig dependency change)
  - CONFIG_CRYPTO_GCM=y (Kconfig dependency change)
  - armv7hl:
  - DRM_SUN4I_HDMI_CEC=y
  - CONFIG_CEC_PIN=y (dependency)
  - s390x/zfcpdump:
  - Crypto changes brought by Kconfig changes, consistent with other configs:
  - CRYPTO_MANAGER_DISABLE_TESTS=n
  - CRYPTO_DRBG_HASH=y
  - CRYPTO_DRBG_CTR=y
  - Lots of dependencies
- commit 37f329b
* Mon Oct  2 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
- Delete
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
  Update upstream status and drop the dwarf remainder.
- commit 8d5b116
* Thu Sep 28 2017 jeffm@suse.com
- Update to 4.14-rc2.
- Eliminated 21 patches.
- commit b61ed0c
* Mon Sep 25 2017 jslaby@suse.cz
- x86/asm: Fix inline asm call constraints for Clang
  (bnc#1058115).
- objtool: Handle another GCC stack pointer adjustment bug
  (bnc#1058115).
- commit 7544781
* Sun Sep 24 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: only rewrite modules.dep if non-zero in size
  (bsc#1056979).
- commit 75691fd
* Fri Sep 22 2017 jslaby@suse.cz
- crypto: x86/blowfish - Fix RBP usage (bnc#1058115).
- crypto: x86/camellia - Fix RBP usage (bnc#1058115).
- crypto: x86/cast5 - Fix RBP usage (bnc#1058115).
- crypto: x86/cast6 - Fix RBP usage (bnc#1058115).
- crypto: x86/des3_ede - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: sha512-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/twofish - Fix RBP usage (bnc#1058115).
  Update upstream status.
- commit 6627c5a
* Thu Sep 21 2017 jeffm@suse.com
- drm/tegra: trace: Fix path to include (build fix).
- commit aecd9be
* Wed Sep 20 2017 afaerber@suse.de
- config: armv7hl: Update to 4.14-rc1
- commit 9d284f8
* Wed Sep 20 2017 afaerber@suse.de
- config: armv6hl: Update to 4.14-rc1
- commit 0c2764f
* Wed Sep 20 2017 afaerber@suse.de
- config: arm64: Update to 4.14-rc1
- commit d6909a3
* Wed Sep 20 2017 jeffm@suse.com
- Revert "KVM: Don't accept obviously wrong gsi values via
  KVM_IRQFD" (build fix).
- commit f436aa0
* Wed Sep 20 2017 mcgrof@suse.com
- nl80211: check for the required netlink attributes presence
  (bsc#1058410 CVE-2017-12153).
- commit 6d93561
* Wed Sep 20 2017 lduncan@suse.com
- Fix incorrect backport of compatibility patch (bsc#1053501)
  This fixes commit fe56e414dcf9, which incorrectly placed
  the back-ported macros in libc-compat.h in the wrong place.
  It is important for __UAPI_DEF_IOVEC to be defined
  correctly with and without GLIBC being defined.
- commit 102e6e3
* Tue Sep 19 2017 jslaby@suse.cz
- objtool: Fix object file corruption (bnc#1058115).
- objtool: Do not retrieve data from empty sections (bnc#1058115).
- objtool: Fix memory leak in elf_create_rela_section()
  (bnc#1058115).
- commit 7fb990b
* Tue Sep 19 2017 jslaby@suse.cz
- x86/crypto: Fix RBP usage in twofish-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in sha512-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-ssse3-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx2-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha256-avx-asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_ssse3_asm.S (bnc#1058115).
- x86/crypto: Fix RBP usage in sha1_avx2_x86_64_asm.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in des3_ede-asm_64.S (bnc#1058115).
- x86/crypto: Fix RBP usage in cast6-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in cast5-avx-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in camellia-x86_64-asm_64.S
  (bnc#1058115).
- x86/crypto: Fix RBP usage in blowfish-x86_64-asm_64.S
  (bnc#1058115).
- commit cb96cd5
* Tue Sep 19 2017 jeffm@suse.com
- Update to 4.14-rc1.
- Eliminated 17 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - HMM_MIRROR=n
  - DEVICE_PRIVATE=n
  - DEVICE_PUBLIC=n
  - SQUASHFS_ZSTD=y
  - ZRAM_WRITEBACK=y
  - x86:
  - INTEL_RDT=y (renamed option)
  - XEN_PVCALLS_BACKEND=y
  - X86_5LEVEL=n (will only boot on systems that support it)
  - AMD_MEM_ENCRYPT=y
  - AMD_MEM_ENCRYPT_ACTIVE_BY_DEFAULT=n
  - ppc:
  - PPC_MEMTRACE=y
  - PPC_VAS=y
  - s390:
  - CMA_DEBUG=n
  - CMA_DEBUGFS=n
  - CMA_AREAS=7 (default)
  - DMA_CMA=n
  - VMCP_CMA_SIZE=4 (default)
  - Netfilter:
  - NFT_FIB_NETDEV
  - Hyperv:
  - HYPERV_VSOCKETS
  - Network:
  - NET_NSH
  - BPF_STREAM_PARSER=y (build fix)
  - BNXT_FLOWER_OFFLOAD=y
  - HINIC
  - MLX5_MPFS=y
  - MLX5_ESWITCH=y
  - RMNET=n
  - ROCKCHIP_PHY
  - WIL6210_DEBUGFS=n
  - ATH10K_USB
  - Bluetooth:
  - BT_LEGACY_IOCTL=y (default)
  - SPI:
  - SPI_INTEL_SPI_PCI
  - Misc:
  - INPUT_PWM_VIBRA=m
  - SERIO_GPIO_PS2=m
  - PINCTRL_DENVERTON
  - PINCTRL_LEWISBURG
  - W1_SLAVE_DS2805
  - BATTERY_BQ27XXX_HDQ=m
  - BATTERY_MAX1721X
  - SENSORS_IBM_CFFPS
  - SENSORS_TPS53679
  - CLOCK_THERMAL=y
  - DEVFREQ_THERMAL=y
  - MFD_BD9571MWV=n
  - INTEL_SOC_PMIC_CHTWC=y
  - MFD_TPS68470=n
  - IR_GPIO_TX=n
  - IR_PWM_TX=n
  - DVB_DDBRIDGE
  - DVB_DDBRIDGE_MSIENABLE=n
  - TINYDRM_REPAPER=n
  - TINYDRM_ST7586=n
  - SND_SOC_CS43130=n
  - SND_SOC_WM8524=n
  - MMC_SPI
  - LEDS_AS3645A=n
  - LEDS_PCA955X_GPIO=y
  - INFINIBAND_EXP_USER_ACCESS=y [?]
  - CONFIG_ALTERA_MSGDMA
  - R8822BE
  - PI433=n
  - CLK_HSDK=n
  - EXTCON_USBC_CROS_EC
  - DLN2_ADC=m
  - LTC2471=n
  - CCS811=n
  - RESET_HSDK_V1=n
  - FPGA_MGR_ALTERA_CVP=m
  - FPGA_MGR_ALTERA_PS_SPI=m
  - CRYPTO_DEV_SP_CCP=y
  - I2C_CHT_WC=m
  - RESET_ATTACK_MITIGATION=y
- commit 08ca987
* Tue Sep 19 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
- Delete
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations-fix.patch.
  Update to the submitted v2.
- commit 27de3c0
* Sun Sep 17 2017 jdelvare@suse.de
- drm/amdgpu: revert tile table update for oland (boo#1027378,
  boo#1039806, bko#194761).
- Delete
  patches.fixes/drm-amdgpu-revert-update-tile-table-for-oland-hainan.patch.
- commit 51745cf
* Thu Sep 14 2017 jslaby@suse.cz
- Linux 4.13.2 (bnc#1012628 bsc#1055826).
- Delete
  patches.drivers/rt2800-fix-TX_PIN_CFG-setting-for-non-MT7620-chips.
- Delete
  patches.fixes/Bluetooth-validate-output-buffer-length-for-config-r.patch.
- commit 96d9efa
* Wed Sep 13 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix a thinko for xmlto buildreq condition
- commit 0ef59d3
* Wed Sep 13 2017 jslaby@suse.cz
- Bluetooth: validate output buffer length for config requests
  and responses (bnc#1057389 CVE-2017-1000251).
- commit c0b7e1f
* Tue Sep 12 2017 jslaby@suse.cz
- fix annotations of xen-head.S (bnc#1058115).
- commit d4c88a5
* Tue Sep 12 2017 msuchanek@suse.de
- rpm/kernel-docs.spec.in: make unpack scripts executable
- commit 1ba3766
* Tue Sep 12 2017 jslaby@suse.cz
- x86/head: Add unwind hint annotations (bnc#1058115).
- x86/xen: Add unwind hint annotations (bnc#1058115).
- x86/xen: Fix xen head ELF annotations (bnc#1058115).
- x86/boot: Annotate verify_cpu() as a callable function
  (bnc#1058115).
- x86/head: Fix head ELF function annotations (bnc#1058115).
- x86/head: Remove unused 'bad_address' code (bnc#1058115).
- x86/head: Remove confusing comment (bnc#1058115).
- objtool: Don't report end of section error after an empty
  unwind hint (bnc#1058115).
- commit 53af152
* Tue Sep 12 2017 jslaby@suse.cz
- objtool: Assume unannotated UD2 instructions are dead ends
  (bnc#1058115).
- objtool: Fix gcov check for older versions of GCC (bnc#1058115).
- objtool: Fix objtool fallthrough detection with function padding
  (bnc#1058115).
- objtool: Fix validate_branch() return codes (bnc#1058115).
- objtool: Handle GCC stack pointer adjustment bug (bnc#1058115).
- x86/asm: Add ASM_UNREACHABLE (bnc#1058115).
- x86/asm: Fix UNWIND_HINT_REGS macro for older binutils
  (bnc#1058115).
- x86/asm: Make objtool unreachable macros independent from GCC
  version (bnc#1058115).
- objtool: Skip unreachable warnings for 'alt' instructions
  (bnc#1058115).
- objtool: Track DRAP separately from callee-saved registers
  (bnc#1058115).
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
  Take all ORC upstream patches. This will go to stable & SLE15 too.
- commit 831ca01
* Mon Sep 11 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0002-x86-kconfig-Make-it-easier-to-switch-to-the-new-ORC-.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-Fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0003-x86-kconfig-Consolidate-unwinders-into-multiple-choi.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-Fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-Add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-Add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-Add-unwind-hint-annotations-to-sync_core.patch.
- Delete
  patches.suse/0001-linkage-new-macros-for-assembler-symbols.patch.
- Delete
  patches.suse/0003-DWARF-EH-frame-based-stack-unwinding.patch.
- Delete patches.suse/stack-unwind-disable-kasan.patch.
  Update upstream status of ORC and drop already-disabled DWARF unwinder.
- commit 2e9b944
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: build ARM on at least 2 cpus
- commit b7edeaf
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: increase memory for kernel-syzkaller
  And see if it helps. If so, push it to packaging...
- commit 7193e65
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable legacy instruction emulation (boo#1029158)
  Needed for execution of older e.g. ARMv6 code.
- commit a4e05e8
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable ACPI_DOCK for consistency
- commit cec354f
* Sun Sep 10 2017 afaerber@suse.de
- config: arm64: Enable some network options
- Marvell Armada 7K/8K Ethernet driver
- Microchip ENC28J60 and related SPI Ethernet drivers
- Micrel KS8851 SPI Ethernet driver
- MMIO MDIO mux driver
- commit cf926f4
* Sun Sep 10 2017 jslaby@suse.cz
- Linux 4.13.1 (bnc#1012628).
- commit 8740849
* Fri Sep  8 2017 jslaby@suse.cz
- rpm/kernel-binary.spec.in: package ftrace-mod.o on arm64
  It is needed for building modules since 4.13:
  CC [M]  /suse/jslaby/a/aaa.o
  Building modules, stage 2.
  MODPOST 1 modules
  CC      /suse/jslaby/a/aaa.mod.o
  LD [M]  /suse/jslaby/a/aaa.ko
  ld: cannot find ./arch/arm64/kernel/ftrace-mod.o: No such file or directory
  ...
- commit 07da115
* Thu Sep  7 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Expand kernel tree directly from sources (bsc#1057199)
- commit a61b4d9
* Wed Sep  6 2017 mcgrof@suse.com
- supported.conf: add test_syctl to new kselftests-kmp package FATE#323821
  As per FATE#323821 we will require new FATE requests per each
  new selftest driver. We don't want to support these module on
  production runs but we do want to support them for QA / testing
  uses. The compromise is to package them into its own package,
  this will be the kselftests-kmp package.
  Selftests can also be used as proof of concept vehicle for issues
  by customers or ourselves.
  Vanilla kernels do not get test_sysctl given that driver was
  using built-in defaults, this also means we cannot run sefltests
  on config/s390x/zfcpdump which does not enable modules.
  Likeweise, since we had to *change* the kernel for test_syctl, it
  it also means we can't test test_syctl with vanilla kernels. It
  should be possible with other selftests drivers if they are
  present in vanilla kernels though.
- commit ae8069f
* Wed Sep  6 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Re-add xmlto buildreq conditionally for SLE15 & co
- commit 259b49e
* Wed Sep  6 2017 mchandras@suse.de
- rpm/group-source-files.pl: Add arch/*/tools/* files to the devel package
  Commit b71c9ffb1405 ("powerpc: Add arch/powerpc/tools directory")
  introduced in v4.12-rc1 release, moved the scripts into the tools
  directory. However, this location is not considered for the kernel devel
  package and the following error occurs when building a kmp for powerpc
  make[2]: /usr/src/linux-4.12.9-1/arch/powerpc/tools/gcc-check-mprofile-kernel.sh: Command not found
- commit 5f1ff53
* Tue Sep  5 2017 jeffm@suse.com
- Update to 4.13-final.
- commit 3fdcb17
* Thu Aug 31 2017 tiwai@suse.de
- rt2800: fix TX_PIN_CFG setting for non MT7620 chips
  (bsc#1055826).
- commit 8116757
* Thu Aug 31 2017 jeffm@suse.com
- Update to 4.13-rc7.
- Eliminate 2 patches.
- commit dd00417
* Thu Aug 31 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit aacb454
* Tue Aug 29 2017 tiwai@suse.de
- Update config files: enable CONFIG_SPI_PXA2XX for MacBook (bsc#1055817)
- commit 3ce18e9
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Update drm-kmp obsolete for SLE12-SP3/Leap-42.3
- commit 77ccbd0
* Mon Aug 28 2017 tiwai@suse.de
- Refresh patch tags of patches.fixes/Input-ALPS-Fix-Alps-Touchpad-two-finger-scroll-does-
- commit 0b3ef4c
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Disable PDF build again
  ... due to the breakage with the recent TeXLive 2017.
  Also add the missing dependency on texlive-varwidth.
- commit 9f682b5
* Wed Aug 23 2017 tiwai@suse.de
- ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
  (bsc#1020657).
- commit 3f6a0b2
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: ice1712: Add support for STAudio ADCIII (bsc#1048934).
- commit 99a99ef
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: hda - Implement mic-mute LED mode enum (bsc#1055013).
- commit a3c362f
* Mon Aug 21 2017 jeffm@suse.com
- Update to 4.13-rc6.
- commit ee50b89
* Fri Aug 18 2017 msuchanek@suse.de
- Do not ship firmware (bsc#1054239).
  Pull firmware from kernel-firmware instead.
- commit 0b0b5c9
* Thu Aug 17 2017 jeffm@suse.com
- supported.conf: clear mistaken external support flag for cifs.ko (bsc#1053802).
- commit 75e287e
* Thu Aug 17 2017 jeffm@suse.com
- supported.conf: mark reiserfs unsupported (FATE#323394).
  ReiserFS is not supported in SLE15.  ReiserFS file systems must be
  transferred or converted before installing.
- commit 8a547c5
* Thu Aug 17 2017 jeffm@suse.com
- Update to 4.13-rc5.
- commit c3fb699
* Tue Aug 15 2017 hare@suse.de
- Delete patches.fixes/scsi-dh-queuedata-accessors.
- commit ee998ab
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/dm-mpath-detach-existing-hardware-handler.
- commit a8291cd
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/no-partition-scan (FATE#323406)
- commit e1cccca
* Sat Aug 12 2017 lduncan@suse.com
- uapi: add a compatibility layer between linux/uio.h and glibc
  (bsc#1053501).
- commit fe56e41
* Thu Aug 10 2017 msuchanek@suse.de
- Refresh vanilla config.
- commit ae18928
* Thu Aug 10 2017 msuchanek@suse.de
- rpm/modules.fips include module list from dracut
- commit f70bab5
* Wed Aug  9 2017 ohering@suse.de
- Delete stale patches.fixes/scsi-ibmvscsi-module_alias.patch.
- Delete stale patches.suse/suse-ppc64-branding.
- commit 1c8934b
* Tue Aug  8 2017 jeffm@suse.com
- Update to 4.13-rc4.
- commit 94b098f
* Wed Aug  2 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix package list and enable building PDFs
  Finally it works!  Added some missing pieces (ImageMagick, some texlive
  subpkgs) in addition to use explicitly python3-Sphinx stuff.
- commit c117a0c
* Tue Aug  1 2017 agraf@suse.de
- Clean up upstreamed patches list. Annotate the remaining ones
  with their current status.
- Delete patches.arch/arm-exynos-dwmmc-modalias.patch.
- Delete
  patches.arch/arm64-Relocate-screen_info.lfb_base-on-PCI-BAR-alloc.patch.
- commit 3f654d5
* Mon Jul 31 2017 jeffm@suse.com
- Update to 4.13-rc3.
- commit 4ef483a
* Thu Jul 27 2017 jslaby@suse.cz
- x86/kconfig: Make it easier to switch to the new ORC unwinder
  (bnc#1018348).
- x86/kconfig: Consolidate unwinders into multiple choice
  selection (bnc#1018348).
- Update config files.
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
  Update to version from -tip. ORC is in -tip completely. So make sure
  we use the upstream version.
- commit 903e200
* Wed Jul 26 2017 jeffm@suse.com
- Update to 4.13-rc2.
- Eliminated 1 patch.
- Config changes:
  - DRM_VBOXVIDEO=m
- commit b545b87
* Wed Jul 26 2017 tiwai@suse.de
- Input: ALPS - Fix Alps Touchpad two finger scroll does not
  work on right side (bsc#1050582).
- commit 474729b
* Sun Jul 23 2017 stefan.bruens@rwth-aachen.de
- config: arm64: Enable RTC and SPI on Allwinner A64/H5
  A64 and H5 share the RTC and SPI functional blocks with older SoCs,
  enable the corresponding drivers.
- commit b5bf58a
* Wed Jul 19 2017 mmarek@suse.cz
- rpm/kernel-binary.spec.in: find-debuginfo.sh should not touch build-id
  This needs rpm-4.14+ (bsc#964063).
- commit f622d60
* Tue Jul 18 2017 afaerber@suse.de
- config: armv7hl: Update to v4.13-rc1
- commit 1d72b01
* Tue Jul 18 2017 afaerber@suse.de
- config: armv6hl: Update to v4.13-rc1
- commit 5ede81f
* Tue Jul 18 2017 afaerber@suse.de
- config: arm64: Update to v4.13-rc1
- commit 7d005f8
* Tue Jul 18 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-add-unwind-hint-annotations-to-sync_core.patch.
  Update upstream information.
- commit ff15779
* Tue Jul 18 2017 tiwai@suse.de
- Delete patches.fixes/drm-i915-Fix-S4-resume-breakage.
  The workaround wasn't merged to upstream, and it seems becoming
  superfluous with the recent i915 driver, so let's drop this one.
- commit f6f228c
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Drop unnecessary xmlto for 4.13+
- commit e47dc84
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Correct kernel-docs package summary/description
- commit 697b763
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: refresh dependencies for PDF build (bsc#1048129)
  But it still doesn't work with Tex Live 2017, thus disabled yet.
  Also add texlive-anyfontsize for HTML math handling.
- commit ead44a1
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/drm-i915-disable-KASAN-for-handlers.patch.
  It was never accepted, is under discussion. But we disabled
  CONFIG_DRM_I915_WERROR in commit 5fc7b327348b, so we are safe anyway.
- commit e2957b5
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/get_builtin_firmware-gcc-7.patch.
  This was never accepted. Instead this seems to be fixed in gcc.
- commit c048497
* Mon Jul 17 2017 jeffm@suse.com
- Updated to 4.13-rc1.
- Eliminated 13 patches.
- ARM configs need updating.
- Config changes:
  - General:
  - SLAB_MERGE_DEFAULT=y (current behavior)
  - REFCOUNT_FULL=n (current behavior)
  - PERCPU_STATS=n (default)
  - FORTIFY_SOURCE=n (needs performance analysis)
  - WARN_ALL_UNSEEDED_RANDOM=n
  - TRACE_EVAL_MAP_FILE=n
  - TEST_SYSCTL=n
  - TEST_KMOD=n
  - Storage:
  - DM_ZONED=m
  - IB:
  - Options for MLX5:
  - MLX5_FPGA
  - MLX5_EN_IPSEC=y
  - MLXFW=m
  - SECURITY_INFINIBAND=y
  - Network:
  - Options for NFP:
  - NFP_APP_FLOWER=y
  - CORTINA_PHY=n (intended for embedded apps)
  - ATH10K_SDIO=m
  - QTNFMAC_PEARL_PCIE=m
  - DRM:
  - DRM_I915_SW_FENCE_CHECK_DAG=n
  - Sound:
  - SND_SOC_INTEL_BYT_CHT_ES8316_MACH=m
  - SND_SOC_INTEL_KBL_RT5663_MAX98927_MACH=m
  - SND_SOC_INTEL_KBL_RT5663_RT5514_MAX98927_MACH=m
  - SND_SOC_ZX_AUD96P22=n
  - HID:
  - HID_ITE=n
  - HID_RETRODE=m
  - USB:
  - TYPEC_UCSI=m
  - UCSI_ACPI=m
  - Misc:
  - RTC_NVMEM=y
  - RTC_DRV_DS3232_HWMON=y
  - WMI_BMOF=m
  - PEAQ_WMI=m
  - INTEL_INT0002_VGPIO=m
  - CROS_EC_LPC_MEC=y
  - EXTCON_INTEL_CHT_WC=m
  - NTB_IDT=m
  - MULTIPLEXER=m
  - KEYBOARD_DLINK_DIR685=n
  - TOUCHSCREEN_STMFTS=n
  - I2C_DESIGNWARE_SLAVE=n
  - SPI_SLAVE=n
  - PINCTRL_MCP23S08=n
  - PINCTRL_CANNONLAKE=m
  - GPIO_XRA1403=n
  - BATTERY_BQ27XXX_DT_UPDATES_NVM=n
  - CHARGER_LTC3651=n
  - SENSORS_IR35221=n
  - WATCHDOG_HANDLE_BOOT_ENABLED=y (default)
  - File Systems:
  - OVERLAY_FS_INDEX=n (mounting on an older kernel read-write will cause unexpected results)
  - CIFS_DEBUG_DUMP_KEYS=n
  - Crypto:
  - CRC4=m
  - X86:
  - INTEL_SOC_PMIC_CHTWC=m
  - CHT_WC_PMIC_OPREGION=y
  - ppc64/ppc64le:
  - CONFIG_IRQ_TIME_ACCOUNTING=n
  - CONFIG_LD_HEAD_STUB_CATCH=n
  - ZONE_DEVICE=y
  - ppc64le:
  - STRICT_KERNEL_RWX=y
  - s390x:
  - CRYPTO_PAES_S390=m
- commit d418532
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.drivers/ppc64-adb.
  This hardware was discontinued in 2006 and the patch was never accepted
  upstream.
- commit 995698b
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-prom-nodisplay.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit d94ed1e
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-pegasos-console-autodetection.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit b42ddc6
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.suse/ppc-powerbook-usb-fn-key-default.patch.
  We no longer support 32-bit ppc and there were no 64-bit powerbooks.
- commit 9e9a512
* Mon Jul 17 2017 jeffm@suse.com
- Disable patches.suse/pstore-backend-autoaction.
  It needs updating and there now exists a mount option instead of a module
  parameter.
- commit 87a5ab7
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.fixes/block-copy-bi_vcnt-in-_bio_clone_fast.
  This was obsoleted by 764f612c6c3c ("blk-merge: don't compute
  bi_phys_segments from bi_vcnt for cloned bio").
- commit f0c2642
* Mon Jul 17 2017 jslaby@suse.cz
- netfilter: expect: fix crash when putting uninited expectation
  (bnc#1048935).
- commit cc9efac
* Mon Jul 17 2017 mmarek@suse.cz
- Drop multiversion(kernel) from the KMP template (fate#323189)
- commit 71504d8
* Tue Jul 11 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix and cleanup for 4.13 doc build (bsc#1048129)
  The whole DocBook stuff has been deleted.  The PDF build still non-working
  thus the sub-packaging disabled so far.
- commit 8e7de10
* Fri Jun  2 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Fix new include path
  Commit 89de3db69113d58cdab14d2c777de6080eac49dc ("rpm/dtb.spec.in.in:
  Update include path for dt-bindings") introduced an additional include
  path for 4.12. The commit message had it correct, but the spec file
  template lacked a path component, breaking the aarch64 build while
  succeeding on armv7hl. Fix that.
- commit c8d853a
* Wed May 31 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Update include path for dt-bindings
  Kernels before 4.12 had arch/{arm,arm64}/boot/dts/include/ directories
  with a symlink to include/dt-bindings/.
  In 4.12 those include/ directories were dropped.
  Therefore use include/ directly.
  Additionally some cross-architecture .dtsi reuse was introduced, which
  requires scripts/dtc/include-prefixes/ that didn't exist on older kernels.
- commit 466f108
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-zte subpackage
  4.9 added arch/arm64/boot/dts/zte/.
- commit 073d831
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-allwinner subpackage
  4.10 added arch/arm64/boot/dts/allwinner/.
- commit dfeb94a
* Tue Dec 20 2016 xxxxxmichl@googlemail.com
- added De0-Nanos-SoC board support (and others based on Altera SOC).
- commit 9278339
* Tue Apr 26 2016 mmarek@suse.cz
- Drop sysctl files for dropped archs, add ppc64le and arm (bsc#1178838).
  Also correct the page size on ppc64.
- commit 7ec816c
* Wed Feb 17 2016 mmarek@suse.com
- oracleasm: 4.0 compat changes (bsc#962720, bsc#1144700).
- commit bad1828
